from .error_dict import ERROR_DICT
from .full_address_error_dict import FULL_ADDRRESS_ERROR_DICT
from .single_vowels import SINGLE_VOWELS
from .standard_addresses import STANDARD_ADDRESSES
from .standard_single_names import STANDARD_SINGLE_NAMES