ACRONYM_DICT = {
    "HN": "Hà Nội",
    "TPHCM": "Hồ Chí Minh",
    "TP.HCM": "Hồ Chí Minh",
    "HP": "Hải Phòng",
    "ĐN": "Đà Nắng",
    "DN": "Đà Nắng",
    "CT": "Cần Thơ",
    "NĐ": "Nam Định",
    "ND": "Nam Định"
}