ERROR_DICT = {
  "I": [
    "i",
    "i"
  ],
  "V": [
    "v",
    "v"
  ],
  "Ba": [
    "ba",
    "ba"
  ],
  "Bo": [
    "bo",
    "bo"
  ],
  "IV": [
    "iv",
    "iv"
  ],
  "Me": [
    "me",
    "me"
  ],
  "Xy": [
    "xy",
    "xy"
  ],
  "Dun": [
    "dun",
    "dun"
  ],
  "Hra": [
    "hra",
    "hra"
  ],
  "III": [
    "iii",
    "iii"
  ],
  "Lim": [
    "lim",
    "lim"
  ],
  "Uar": [
    "uar",
    "uar"
  ],
  "VII": [
    "vii",
    "vii"
  ],
  "Đu": [
    "đu",
    "ddu"
  ],
  " Tư": [
    " tư",
    " tuw"
  ],
  "AYun": [
    "ayun",
    "ayun"
  ],
  "Ayun": [
    "ayun",
    "ayun"
  ],
  "Chũ": [
    "chũ",
    "chux"
  ],
  "Dang": [
    "dang",
    "dang"
  ],
  "Ealy": [
    "ealy",
    "ealy"
  ],
  "Glar": [
    "glar",
    "glar"
  ],
  "Gào": [
    "gào",
    "gafo"
  ],
  "Gôi": [
    "gôi",
    "gooi"
  ],
  "HNol": [
    "hnol",
    "hnol"
  ],
  "Húc": [
    "húc",
    "husc"
  ],
  "Hồ": [
    "hồ",
    "hoof"
  ],
  "Ia O": [
    "ia o",
    "ia o"
  ],
  "Kép": [
    "kép",
    "kesp"
  ],
  "Lát": [
    "lát",
    "last"
  ],
  "Lâm": [
    "lâm",
    "laam"
  ],
  "Lìa": [
    "lìa",
    "lifa"
  ],
  "Nưa": [
    "nưa",
    "nuwa"
  ],
  "Phan": [
    "phan",
    "phan"
  ],
  "Pró": [
    "pró",
    "pros"
  ],
  "SRó": [
    "sró",
    "sros"
  ],
  "Vinh": [
    "vinh",
    "vinh"
  ],
  "Vôi": [
    "vôi",
    "vooi"
  ],
  "A Lù": [
    "a lù",
    "a luf"
  ],
  "A Ngo": [
    "a ngo",
    "a ngo"
  ],
  "A Vao": [
    "a vao",
    "a vao"
  ],
  "A Xan": [
    "a xan",
    "a xan"
  ],
  "B'lao": [
    "b'lao",
    "b'lao"
  ],
  "Ba Xa": [
    "ba xa",
    "ba xa"
  ],
  "Chờ": [
    "chờ",
    "chowf"
  ],
  "Cồn": [
    "cồn",
    "coofn"
  ],
  "D'Ran": [
    "d'ran",
    "d'ran"
  ],
  "Ea Hu": [
    "ea hu",
    "ea hu"
  ],
  "Ea Na": [
    "ea na",
    "ea na"
  ],
  "Ea Tu": [
    "ea tu",
    "ea tu"
  ],
  "Ea Uy": [
    "ea uy",
    "ea uy"
  ],
  "Ea Wy": [
    "ea wy",
    "ea wy"
  ],
  "Ea Ô": [
    "ea ô",
    "ea oo"
  ],
  "EaBar": [
    "eabar",
    "eabar"
  ],
  "EaBia": [
    "eabia",
    "eabia"
  ],
  "Ga Ri": [
    "ga ri",
    "ga ri"
  ],
  "Huế": [
    "huế",
    "huees"
  ],
  "Ia Ga": [
    "ia ga",
    "ia ga"
  ],
  "Ia Ka": [
    "ia ka",
    "ia ka"
  ],
  "Ia Ko": [
    "ia ko",
    "ia ko"
  ],
  "Ia Le": [
    "ia le",
    "ia le"
  ],
  "Ia Ly": [
    "ia ly",
    "ia ly"
  ],
  "Ia Me": [
    "ia me",
    "ia me"
  ],
  "Ia Pa": [
    "ia pa",
    "ia pa"
  ],
  "KBang": [
    "kbang",
    "kbang"
  ],
  "KRong": [
    "krong",
    "krong"
  ],
  "La Gi": [
    "la gi",
    "la gi"
  ],
  "Lăng": [
    "lăng",
    "lawng"
  ],
  "Lắk": [
    "lắk",
    "lawsk"
  ],
  "Na Ư": [
    "na ư",
    "na uw"
  ],
  "P Rao": [
    "p rao",
    "p rao"
  ],
  "Quế": [
    "quế",
    "quees"
  ],
  "Sa Pa": [
    "sa pa",
    "sa pa"
  ],
  "Sịa": [
    "sịa",
    "sija"
  ],
  "Ta Ma": [
    "ta ma",
    "ta ma"
  ],
  "Thanh": [
    "thanh",
    "thanh"
  ],
  "Tr'Hy": [
    "tr'hy",
    "tr'hy"
  ],
  "Trang": [
    "trang",
    "trang"
  ],
  "Xốp": [
    "xốp",
    "xoosp"
  ],
  "Y Can": [
    "y can",
    "y can"
  ],
  "Y Tý": [
    "y tý",
    "y tys"
  ],
  "Ya Ma": [
    "ya ma",
    "ya ma"
  ],
  "Ya ly": [
    "ya ly",
    "ya ly"
  ],
  "A Bung": [
    "a bung",
    "a bung"
  ],
  "A Dơk": [
    "a dơk",
    "a dowk"
  ],
  "A Rooi": [
    "a rooi",
    "a rooi"
  ],
  "A Ting": [
    "a ting",
    "a ting"
  ],
  "AL Bá": [
    "al bá",
    "al bas"
  ],
  "An Bá": [
    "an bá",
    "an bas"
  ],
  "An Cơ": [
    "an cơ",
    "an cow"
  ],
  "An Cư": [
    "an cư",
    "an cuw"
  ],
  "An Hà": [
    "an hà",
    "an haf"
  ],
  "An Lư": [
    "an lư",
    "an luw"
  ],
  "An Quy": [
    "an quy",
    "an quy"
  ],
  "An Vĩ": [
    "an vĩ",
    "an vix"
  ],
  "An Vũ": [
    "an vũ",
    "an vux"
  ],
  "B' Lá": [
    "b' lá",
    "b' las"
  ],
  "Ba Nam": [
    "ba nam",
    "ba nam"
  ],
  "Ba Sao": [
    "ba sao",
    "ba sao"
  ],
  "Ba Tri": [
    "ba tri",
    "ba tri"
  ],
  "Ba Tô": [
    "ba tô",
    "ba too"
  ],
  "Ba Tơ": [
    "ba tơ",
    "ba tow"
  ],
  "Ba Vì": [
    "ba vì",
    "ba vif"
  ],
  "Bao La": [
    "bao la",
    "bao la"
  ],
  "Bom Bo": [
    "bom bo",
    "bom bo"
  ],
  "Bờ Y": [
    "bờ y",
    "bowf y"
  ],
  "Cao An": [
    "cao an",
    "cao an"
  ],
  "Ch'ơm": [
    "ch'ơm",
    "ch'owm"
  ],
  "Cà Dy": [
    "cà dy",
    "caf dy"
  ],
  "Cô Ba": [
    "cô ba",
    "coo ba"
  ],
  "Cư An": [
    "cư an",
    "cuw an"
  ],
  "Cư Ni": [
    "cư ni",
    "cuw ni"
  ],
  "Dĩ An": [
    "dĩ an",
    "dix an"
  ],
  "Ea Bar": [
    "ea bar",
    "ea bar"
  ],
  "Ea Bá": [
    "ea bá",
    "ea bas"
  ],
  "Ea Hiu": [
    "ea hiu",
    "ea hiu"
  ],
  "Ea Kao": [
    "ea kao",
    "ea kao"
  ],
  "Ea Kar": [
    "ea kar",
    "ea kar"
  ],
  "Ea Kly": [
    "ea kly",
    "ea kly"
  ],
  "Ea Lai": [
    "ea lai",
    "ea lai"
  ],
  "Ea Lê": [
    "ea lê",
    "ea lee"
  ],
  "Ea Nam": [
    "ea nam",
    "ea nam"
  ],
  "Ea Pil": [
    "ea pil",
    "ea pil"
  ],
  "Ea Puk": [
    "ea puk",
    "ea puk"
  ],
  "Ea Pô": [
    "ea pô",
    "ea poo"
  ],
  "Ea Ral": [
    "ea ral",
    "ea ral"
  ],
  "Ea Sar": [
    "ea sar",
    "ea sar"
  ],
  "Ea Sin": [
    "ea sin",
    "ea sin"
  ],
  "Ea Sol": [
    "ea sol",
    "ea sol"
  ],
  "Ea Sô": [
    "ea sô",
    "ea soo"
  ],
  "Ea Tam": [
    "ea tam",
    "ea tam"
  ],
  "Ea Tar": [
    "ea tar",
    "ea tar"
  ],
  "Ea Tih": [
    "ea tih",
    "ea tih"
  ],
  "Ea Tir": [
    "ea tir",
    "ea tir"
  ],
  "Ea Tul": [
    "ea tul",
    "ea tul"
  ],
  "Ea Wer": [
    "ea wer",
    "ea wer"
  ],
  "EaTrol": [
    "eatrol",
    "eatrol"
  ],
  "Gia An": [
    "gia an",
    "gia an"
  ],
  "Gio An": [
    "gio an",
    "gio an"
  ],
  "Hiếu": [
    "hiếu",
    "hieesu"
  ],
  "Hua La": [
    "hua la",
    "hua la"
  ],
  "Hà An": [
    "hà an",
    "haf an"
  ],
  "Hà Tu": [
    "hà tu",
    "haf tu"
  ],
  "Ia Ake": [
    "ia ake",
    "ia ake"
  ],
  "Ia Bă": [
    "ia bă",
    "ia baw"
  ],
  "Ia Din": [
    "ia din",
    "ia din"
  ],
  "Ia Dom": [
    "ia dom",
    "ia dom"
  ],
  "Ia Hla": [
    "ia hla",
    "ia hla"
  ],
  "Ia Kha": [
    "ia kha",
    "ia kha"
  ],
  "Ia Kla": [
    "ia kla",
    "ia kla"
  ],
  "Ia Kly": [
    "ia kly",
    "ia kly"
  ],
  "Ia Mơ": [
    "ia mơ",
    "ia mow"
  ],
  "Ia Nan": [
    "ia nan",
    "ia nan"
  ],
  "Ia Pal": [
    "ia pal",
    "ia pal"
  ],
  "Ia Pia": [
    "ia pia",
    "ia pia"
  ],
  "Ia Sao": [
    "ia sao",
    "ia sao"
  ],
  "Ia Sol": [
    "ia sol",
    "ia sol"
  ],
  "Ia Tul": [
    "ia tul",
    "ia tul"
  ],
  "Ia Tô": [
    "ia tô",
    "ia too"
  ],
  "Ia Vê": [
    "ia vê",
    "ia vee"
  ],
  "Ia Yok": [
    "ia yok",
    "ia yok"
  ],
  "Khe Mo": [
    "khe mo",
    "khe mo"
  ],
  "Kim An": [
    "kim an",
    "kim an"
  ],
  "Kroong": [
    "kroong",
    "kroong"
  ],
  "La Hai": [
    "la hai",
    "la hai"
  ],
  "La Hà": [
    "la hà",
    "la haf"
  ],
  "Lai Vu": [
    "lai vu",
    "lai vu"
  ],
  "Laêê": [
    "laêê",
    "laeeee"
  ],
  "Lơ Ku": [
    "lơ ku",
    "low ku"
  ],
  "Mã Ba": [
    "mã ba",
    "max ba"
  ],
  "Mê Pu": [
    "mê pu",
    "mee pu"
  ],
  "Mò Ó": [
    "mò ó",
    "mof os"
  ],
  "Na Lay": [
    "na lay",
    "na lay"
  ],
  "Na Loi": [
    "na loi",
    "na loi"
  ],
  "Na Mao": [
    "na mao",
    "na mao"
  ],
  "Na Rì": [
    "na rì",
    "na rif"
  ],
  "Na Son": [
    "na son",
    "na son"
  ],
  "Nam Du": [
    "nam du",
    "nam du"
  ],
  "Nam Ka": [
    "nam ka",
    "nam ka"
  ],
  "Nga An": [
    "nga an",
    "nga an"
  ],
  "Nga My": [
    "nga my",
    "nga my"
  ],
  "Nghèn": [
    "nghèn",
    "nghefn"
  ],
  "Nong U": [
    "nong u",
    "nong u"
  ],
  "Nếnh": [
    "nếnh",
    "neesnh"
  ],
  "Pa Ham": [
    "pa ham",
    "pa ham"
  ],
  "Pa ủ": [
    "pa ủ",
    "pa ur"
  ],
  "Pha Mu": [
    "pha mu",
    "pha mu"
  ],
  "Phùng": [
    "phùng",
    "phufng"
  ],
  "Pleiku": [
    "pleiku",
    "pleiku"
  ],
  "Pá Hu": [
    "pá hu",
    "pas hu"
  ],
  "Pú Xi": [
    "pú xi",
    "pus xi"
  ],
  "Sơn A": [
    "sơn a",
    "sown a"
  ],
  "Tam An": [
    "tam an",
    "tam an"
  ],
  "Thứa": [
    "thứa",
    "thuwsa"
  ],
  "Tu Tra": [
    "tu tra",
    "tu tra"
  ],
  "Tu Vũ": [
    "tu vũ",
    "tu vux"
  ],
  "Tuy An": [
    "tuy an",
    "tuy an"
  ],
  "Tà Lu": [
    "tà lu",
    "taf lu"
  ],
  "Tú An": [
    "tú an",
    "tus an"
  ],
  "U Minh": [
    "u minh",
    "u minh"
  ],
  "Võ Xu": [
    "võ xu",
    "vox xu"
  ],
  "Vũ An": [
    "vũ an",
    "vux an"
  ],
  "Vũ Di": [
    "vũ di",
    "vux di"
  ],
  "Xa Lý": [
    "xa lý",
    "xa lys"
  ],
  "Óc Eo": [
    "óc eo",
    "osc eo"
  ],
  "Đa Mi": [
    "đa mi",
    "dda mi"
  ],
  "Đông": [
    "đông",
    "ddoong"
  ],
  "Ỷ La": [
    "ỷ la",
    "yr la"
  ],
  " A Dơi": [
    " a dơi",
    " a dowi"
  ],
  "A Nông": [
    "a nông",
    "a noong"
  ],
  "An Bài": [
    "an bài",
    "an bafi"
  ],
  "An Dân": [
    "an dân",
    "an daan"
  ],
  "An Hoà": [
    "an hoà",
    "an hoaf"
  ],
  "An Hòa": [
    "an hòa",
    "an hofa"
  ],
  "An Hóa": [
    "an hóa",
    "an hosa"
  ],
  "An Khê": [
    "an khê",
    "an khee"
  ],
  "An Linh": [
    "an linh",
    "an linh"
  ],
  "An Long": [
    "an long",
    "an long"
  ],
  "An Lâm": [
    "an lâm",
    "an laam"
  ],
  "An Lão": [
    "an lão",
    "an laxo"
  ],
  "An Lưu": [
    "an lưu",
    "an luwu"
  ],
  "An Lễ": [
    "an lễ",
    "an leex"
  ],
  "An Minh": [
    "an minh",
    "an minh"
  ],
  "An Mỹ": [
    "an mỹ",
    "an myx"
  ],
  "An Ninh": [
    "an ninh",
    "an ninh"
  ],
  "An Phú": [
    "an phú",
    "an phus"
  ],
  "An Quí": [
    "an quí",
    "an quis"
  ],
  "An Sinh": [
    "an sinh",
    "an sinh"
  ],
  "An Sơn": [
    "an sơn",
    "an sown"
  ],
  "An Tân": [
    "an tân",
    "an taan"
  ],
  "An Tây": [
    "an tây",
    "an taay"
  ],
  "An Vinh": [
    "an vinh",
    "an vinh"
  ],
  "An Ấp": [
    "an ấp",
    "an aasp"
  ],
  "Ayun Pa": [
    "ayun pa",
    "ayun pa"
  ],
  "Ba Bể": [
    "ba bể",
    "ba beer"
  ],
  "Ba Cung": [
    "ba cung",
    "ba cung"
  ],
  "Ba Dinh": [
    "ba dinh",
    "ba dinh"
  ],
  "Ba Lế": [
    "ba lế",
    "ba lees"
  ],
  "Ba Nang": [
    "ba nang",
    "ba nang"
  ],
  "Ba Vinh": [
    "ba vinh",
    "ba vinh"
  ],
  "Bha Lê": [
    "bha lê",
    "bha lee"
  ],
  "Bù Nho": [
    "bù nho",
    "buf nho"
  ],
  "Bưởi": [
    "bưởi",
    "buwowri"
  ],
  "Cao Xá": [
    "cao xá",
    "cao xas"
  ],
  "Chi Nê": [
    "chi nê",
    "chi nee"
  ],
  "Chư Gu": [
    "chư gu",
    "chuw gu"
  ],
  "Chư Ty": [
    "chư ty",
    "chuw ty"
  ],
  "Chư Á": [
    "chư á",
    "chuw as"
  ],
  "Co Mạ": [
    "co mạ",
    "co maj"
  ],
  "Cà Mau": [
    "cà mau",
    "caf mau"
  ],
  "Cà Ná": [
    "cà ná",
    "caf nas"
  ],
  "Cát Bi": [
    "cát bi",
    "cast bi"
  ],
  "Cô Tô": [
    "cô tô",
    "coo too"
  ],
  "Căn Co": [
    "căn co",
    "cawn co"
  ],
  "Cư Bao": [
    "cư bao",
    "cuw bao"
  ],
  "Cư KTy": [
    "cư kty",
    "cuw kty"
  ],
  "Cư Né": [
    "cư né",
    "cuw nes"
  ],
  "Cư Pui": [
    "cư pui",
    "cuw pui"
  ],
  "Cư San": [
    "cư san",
    "cuw san"
  ],
  "Cổ Am": [
    "cổ am",
    "coor am"
  ],
  "Cổ Bi": [
    "cổ bi",
    "coor bi"
  ],
  "Dak Lua": [
    "dak lua",
    "dak lua"
  ],
  "Di Linh": [
    "di linh",
    "di linh"
  ],
  "Du Già": [
    "du già",
    "du giaf"
  ],
  "Du Lễ": [
    "du lễ",
    "du leex"
  ],
  "Duy Thu": [
    "duy thu",
    "duy thu"
  ],
  "Ea Bung": [
    "ea bung",
    "ea bung"
  ],
  "Ea Dăh": [
    "ea dăh",
    "ea dawh"
  ],
  "Ea Hiao": [
    "ea hiao",
    "ea hiao"
  ],
  "Ea Huar": [
    "ea huar",
    "ea huar"
  ],
  "Ea Hồ": [
    "ea hồ",
    "ea hoof"
  ],
  "Ea KPam": [
    "ea kpam",
    "ea kpam"
  ],
  "Ea Khal": [
    "ea khal",
    "ea khal"
  ],
  "Ea Ktur": [
    "ea ktur",
    "ea ktur"
  ],
  "Ea Lâm": [
    "ea lâm",
    "ea laam"
  ],
  "Ea Ngai": [
    "ea ngai",
    "ea ngai"
  ],
  "Ea Ning": [
    "ea ning",
    "ea ning"
  ],
  "Ea Phê": [
    "ea phê",
    "ea phee"
  ],
  "Ea Păl": [
    "ea păl",
    "ea pawl"
  ],
  "Ea Súp": [
    "ea súp",
    "ea susp"
  ],
  "Ea Trul": [
    "ea trul",
    "ea trul"
  ],
  "Ea Tân": [
    "ea tân",
    "ea taan"
  ],
  "Ea Tóh": [
    "ea tóh",
    "ea tosh"
  ],
  "Ea Đar": [
    "ea đar",
    "ea ddar"
  ],
  "Gia Lai": [
    "gia lai",
    "gia lai"
  ],
  "Gia Mô": [
    "gia mô",
    "gia moo"
  ],
  "Gia Ray": [
    "gia ray",
    "gia ray"
  ],
  "Giao An": [
    "giao an",
    "giao an"
  ],
  "Gio Mai": [
    "gio mai",
    "gio mai"
  ],
  "H Bông": [
    "h bông",
    "h boong"
  ],
  "H' Neng": [
    "h' neng",
    "h' neng"
  ],
  "Him Lam": [
    "him lam",
    "him lam"
  ],
  "Hoa Lư": [
    "hoa lư",
    "hoa luw"
  ],
  "Hoà An": [
    "hoà an",
    "hoaf an"
  ],
  "Hua Bun": [
    "hua bun",
    "hua bun"
  ],
  "Hua Nà": [
    "hua nà",
    "hua naf"
  ],
  "Hà Lai": [
    "hà lai",
    "haf lai"
  ],
  "Hà Lam": [
    "hà lam",
    "haf lam"
  ],
  "Hà Nam": [
    "hà nam",
    "haf nam"
  ],
  "Hà Tam": [
    "hà tam",
    "haf tam"
  ],
  "Hòa An": [
    "hòa an",
    "hofa an"
  ],
  "Hóa An": [
    "hóa an",
    "hosa an"
  ],
  "Ia Bang": [
    "ia bang",
    "ia bang"
  ],
  "Ia Chia": [
    "ia chia",
    "ia chia"
  ],
  "Ia Chim": [
    "ia chim",
    "ia chim"
  ],
  "Ia Dêr": [
    "ia dêr",
    "ia deer"
  ],
  "Ia Dơk": [
    "ia dơk",
    "ia dowk"
  ],
  "Ia Glai": [
    "ia glai",
    "ia glai"
  ],
  "Ia Grai": [
    "ia grai",
    "ia grai"
  ],
  "Ia Hiao": [
    "ia hiao",
    "ia hiao"
  ],
  "Ia Hrú": [
    "ia hrú",
    "ia hrus"
  ],
  "Ia KRai": [
    "ia krai",
    "ia krai"
  ],
  "Ia Khai": [
    "ia khai",
    "ia khai"
  ],
  "Ia Lang": [
    "ia lang",
    "ia lang"
  ],
  "Ia Lâu": [
    "ia lâu",
    "ia laau"
  ],
  "Ia Nhin": [
    "ia nhin",
    "ia nhin"
  ],
  "Ia Peng": [
    "ia peng",
    "ia peng"
  ],
  "Ia Phí": [
    "ia phí",
    "ia phis"
  ],
  "Ia Piar": [
    "ia piar",
    "ia piar"
  ],
  "Ia RBol": [
    "ia rbol",
    "ia rbol"
  ],
  "Ia RMok": [
    "ia rmok",
    "ia rmok"
  ],
  "Ia RSai": [
    "ia rsai",
    "ia rsai"
  ],
  "Ia RTô": [
    "ia rtô",
    "ia rtoo"
  ],
  "Ia RVê": [
    "ia rvê",
    "ia rvee"
  ],
  "Ia Rong": [
    "ia rong",
    "ia rong"
  ],
  "Ia Trok": [
    "ia trok",
    "ia trok"
  ],
  "Ia Tôr": [
    "ia tôr",
    "ia toor"
  ],
  "Ia Tơi": [
    "ia tơi",
    "ia towi"
  ],
  "Ia Yeng": [
    "ia yeng",
    "ia yeng"
  ],
  "Ia Đal": [
    "ia đal",
    "ia ddal"
  ],
  "K' Dang": [
    "k' dang",
    "k' dang"
  ],
  "Ka Long": [
    "ka long",
    "ka long"
  ],
  "Ka Đô": [
    "ka đô",
    "ka ddoo"
  ],
  "Khe Tre": [
    "khe tre",
    "khe tre"
  ],
  "Kim Anh": [
    "kim anh",
    "kim anh"
  ],
  "Kim Bon": [
    "kim bon",
    "kim bon"
  ],
  "Kim Hoa": [
    "kim hoa",
    "kim hoa"
  ],
  "Kim Lan": [
    "kim lan",
    "kim lan"
  ],
  "Kim Lũ": [
    "kim lũ",
    "kim lux"
  ],
  "Kim Lư": [
    "kim lư",
    "kim luw"
  ],
  "Kim Mã": [
    "kim mã",
    "kim max"
  ],
  "Kim Xá": [
    "kim xá",
    "kim xas"
  ],
  "Kon Pne": [
    "kon pne",
    "kon pne"
  ],
  "Kon Tum": [
    "kon tum",
    "kon tum"
  ],
  "Kế An": [
    "kế an",
    "kees an"
  ],
  "La Dạ": [
    "la dạ",
    "la daj"
  ],
  "La Khê": [
    "la khê",
    "la khee"
  ],
  "La Ngà": [
    "la ngà",
    "la ngaf"
  ],
  "La Phù": [
    "la phù",
    "la phuf"
  ],
  "La Sơn": [
    "la sơn",
    "la sown"
  ],
  "Long An": [
    "long an",
    "long an"
  ],
  "Lâm Ca": [
    "lâm ca",
    "laam ca"
  ],
  "Lê Lai": [
    "lê lai",
    "lee lai"
  ],
  "Lê Mao": [
    "lê mao",
    "lee mao"
  ],
  "Lộ 25": [
    "lộ 25",
    "looj 25"
  ],
  "Ma Lâm": [
    "ma lâm",
    "ma laam"
  ],
  "Ma Quai": [
    "ma quai",
    "ma quai"
  ],
  "Mai Pha": [
    "mai pha",
    "mai pha"
  ],
  "Mai Sao": [
    "mai sao",
    "mai sao"
  ],
  "Mi Hòa": [
    "mi hòa",
    "mi hofa"
  ],
  "Minh An": [
    "minh an",
    "minh an"
  ],
  "Má Lé": [
    "má lé",
    "mas les"
  ],
  "Mô Rai": [
    "mô rai",
    "moo rai"
  ],
  "Mậu A": [
    "mậu a",
    "maaju a"
  ],
  "Mỹ An": [
    "mỹ an",
    "myx an"
  ],
  "Na Hang": [
    "na hang",
    "na hang"
  ],
  "Na Khê": [
    "na khê",
    "na khee"
  ],
  "Na Mèo": [
    "na mèo",
    "na mefo"
  ],
  "Na Ngoi": [
    "na ngoi",
    "na ngoi"
  ],
  "Na Sang": [
    "na sang",
    "na sang"
  ],
  "Nam Anh": [
    "nam anh",
    "nam anh"
  ],
  "Nam Ban": [
    "nam ban",
    "nam ban"
  ],
  "Nam Cao": [
    "nam cao",
    "nam cao"
  ],
  "Nam Hoa": [
    "nam hoa",
    "nam hoa"
  ],
  "Nam Hà": [
    "nam hà",
    "nam haf"
  ],
  "Nam Kim": [
    "nam kim",
    "nam kim"
  ],
  "Nam Lý": [
    "nam lý",
    "nam lys"
  ],
  "Ngam La": [
    "ngam la",
    "ngam la"
  ],
  "Ngòi A": [
    "ngòi a",
    "ngofi a"
  ],
  "Ninh An": [
    "ninh an",
    "ninh an"
  ],
  "Nà Pó": [
    "nà pó",
    "naf pos"
  ],
  "Nà Ơt": [
    "nà ơt",
    "naf owt"
  ],
  "Nàn Ma": [
    "nàn ma",
    "nafn ma"
  ],
  "Pa Cheo": [
    "pa cheo",
    "pa cheo"
  ],
  "Phi Tô": [
    "phi tô",
    "phi too"
  ],
  "Phú An": [
    "phú an",
    "phus an"
  ],
  "Phú La": [
    "phú la",
    "phus la"
  ],
  "Pà Cò": [
    "pà cò",
    "paf cof"
  ],
  "Pá Lau": [
    "pá lau",
    "pas lau"
  ],
  "Pô Kô": [
    "pô kô",
    "poo koo"
  ],
  "Pù Nhi": [
    "pù nhi",
    "puf nhi"
  ],
  "Pú Nhi": [
    "pú nhi",
    "pus nhi"
  ],
  "Pả Vi": [
    "pả vi",
    "par vi"
  ],
  "Pờ Ê": [
    "pờ ê",
    "powf ee"
  ],
  "Rô Men": [
    "rô men",
    "roo men"
  ],
  "Sa Pả": [
    "sa pả",
    "sa par"
  ],
  "Sa Rài": [
    "sa rài",
    "sa rafi"
  ],
  "Sa Sơn": [
    "sa sơn",
    "sa sown"
  ],
  "Sam Kha": [
    "sam kha",
    "sam kha"
  ],
  "Song An": [
    "song an",
    "song an"
  ],
  "Song Pe": [
    "song pe",
    "song pe"
  ],
  "Sơ Pai": [
    "sơ pai",
    "sow pai"
  ],
  "Sơn Ba": [
    "sơn ba",
    "sown ba"
  ],
  "Sơn La": [
    "sơn la",
    "sown la"
  ],
  "Sơn Vi": [
    "sơn vi",
    "sown vi"
  ],
  "Tam Gia": [
    "tam gia",
    "tam gia"
  ],
  "Tam Kim": [
    "tam kim",
    "tam kim"
  ],
  "Tam Lư": [
    "tam lư",
    "tam luw"
  ],
  "Tam Đa": [
    "tam đa",
    "tam dda"
  ],
  "Thu Tà": [
    "thu tà",
    "thu taf"
  ],
  "Thuận": [
    "thuận",
    "thuaajn"
  ],
  "Thắng": [
    "thắng",
    "thawsng"
  ],
  "Trà An": [
    "trà an",
    "traf an"
  ],
  "Trà Ka": [
    "trà ka",
    "traf ka"
  ],
  "Trà My": [
    "trà my",
    "traf my"
  ],
  "Tuy Lai": [
    "tuy lai",
    "tuy lai"
  ],
  "Tà Gia": [
    "tà gia",
    "taf gia"
  ],
  "Tà Lai": [
    "tà lai",
    "taf lai"
  ],
  "Tân An": [
    "tân an",
    "taan an"
  ],
  "Tây An": [
    "tây an",
    "taay an"
  ],
  "Tú Lý": [
    "tú lý",
    "tus lys"
  ],
  "Tử Du": [
    "tử du",
    "tuwr du"
  ],
  "Tự An": [
    "tự an",
    "tuwj an"
  ],
  "Tự Do": [
    "tự do",
    "tuwj do"
  ],
  "Uy Nỗ": [
    "uy nỗ",
    "uy noox"
  ],
  "Vinh An": [
    "vinh an",
    "vinh an"
  ],
  "Vân An": [
    "vân an",
    "vaan an"
  ],
  "Vân Du": [
    "vân du",
    "vaan du"
  ],
  "Võ Lao": [
    "võ lao",
    "vox lao"
  ],
  "Văn An": [
    "văn an",
    "vawn an"
  ],
  "Vũ Oai": [
    "vũ oai",
    "vux oai"
  ],
  "Vũ Xá": [
    "vũ xá",
    "vux xas"
  ],
  "Vương": [
    "vương",
    "vuwowng"
  ],
  "Vệ An": [
    "vệ an",
    "veej an"
  ],
  "Xa Dung": [
    "xa dung",
    "xa dung"
  ],
  "Xuy Xá": [
    "xuy xá",
    "xuy xas"
  ],
  "Yên Na": [
    "yên na",
    "yeen na"
  ],
  "Za Hung": [
    "za hung",
    "za hung"
  ],
  "Zuôich": [
    "zuôich",
    "zuooich"
  ],
  "Ân Thi": [
    "ân thi",
    "aan thi"
  ],
  "Âu Cơ": [
    "âu cơ",
    "aau cow"
  ],
  "Ít Ong": [
    "ít ong",
    "ist ong"
  ],
  "Ô Lâm": [
    "ô lâm",
    "oo laam"
  ],
  "Ô Môn": [
    "ô môn",
    "oo moon"
  ],
  "Ý Yên": [
    "ý yên",
    "ys yeen"
  ],
  "Đa Kai": [
    "đa kai",
    "dda kai"
  ],
  "Đa Kao": [
    "đa kao",
    "dda kao"
  ],
  "Đa Kia": [
    "đa kia",
    "dda kia"
  ],
  "Đa Mai": [
    "đa mai",
    "dda mai"
  ],
  "Đak Ơ": [
    "đak ơ",
    "ddak ow"
  ],
  "Đê Ar": [
    "đê ar",
    "ddee ar"
  ],
  "A Tiêng": [
    "a tiêng",
    "a tieeng"
  ],
  "An Biên": [
    "an biên",
    "an bieen"
  ],
  "An Bình": [
    "an bình",
    "an bifnh"
  ],
  "An Châu": [
    "an châu",
    "an chaau"
  ],
  "An Cầu": [
    "an cầu",
    "an caafu"
  ],
  "An Cựu": [
    "an cựu",
    "an cuwju"
  ],
  "An Dũng": [
    "an dũng",
    "an duxng"
  ],
  "An Dục": [
    "an dục",
    "an dujc"
  ],
  "An Giang": [
    "an giang",
    "an giang"
  ],
  "An Hưng": [
    "an hưng",
    "an huwng"
  ],
  "An Hải": [
    "an hải",
    "an hari"
  ],
  "An Hảo": [
    "an hảo",
    "an haro"
  ],
  "An Hội": [
    "an hội",
    "an hooji"
  ],
  "An Hữu": [
    "an hữu",
    "an huwxu"
  ],
  "An Khang": [
    "an khang",
    "an khang"
  ],
  "An Lĩnh": [
    "an lĩnh",
    "an lixnh"
  ],
  "An Lạc": [
    "an lạc",
    "an lajc"
  ],
  "An Lập": [
    "an lập",
    "an laajp"
  ],
  "An Lộc": [
    "an lộc",
    "an loojc"
  ],
  "An Ngãi": [
    "an ngãi",
    "an ngaxi"
  ],
  "An Nhơn": [
    "an nhơn",
    "an nhown"
  ],
  "An Nông": [
    "an nông",
    "an noong"
  ],
  "An Nội": [
    "an nội",
    "an nooji"
  ],
  "An Phong": [
    "an phong",
    "an phong"
  ],
  "An Phúc": [
    "an phúc",
    "an phusc"
  ],
  "An Phụ": [
    "an phụ",
    "an phuj"
  ],
  "An Quang": [
    "an quang",
    "an quang"
  ],
  "An Thanh": [
    "an thanh",
    "an thanh"
  ],
  "An Thái": [
    "an thái",
    "an thasi"
  ],
  "An Thọ": [
    "an thọ",
    "an thoj"
  ],
  "An Toàn": [
    "an toàn",
    "an toafn"
  ],
  "An Trung": [
    "an trung",
    "an trung"
  ],
  "An Tảo": [
    "an tảo",
    "an taro"
  ],
  "An Tức": [
    "an tức",
    "an tuwsc"
  ],
  "An Viên": [
    "an viên",
    "an vieen"
  ],
  "An Xuân": [
    "an xuân",
    "an xuaan"
  ],
  "An Đôn": [
    "an đôn",
    "an ddoon"
  ],
  "An Đổ": [
    "an đổ",
    "an ddoor"
  ],
  "Anh Sơn": [
    "anh sơn",
    "anh sown"
  ],
  "Ba Bích": [
    "ba bích",
    "ba bisch"
  ],
  "Ba Chúc": [
    "ba chúc",
    "ba chusc"
  ],
  "Ba Chẽ": [
    "ba chẽ",
    "ba chex"
  ],
  "Ba Giang": [
    "ba giang",
    "ba giang"
  ],
  "Ba Hàng": [
    "ba hàng",
    "ba hafng"
  ],
  "Ba Khâm": [
    "ba khâm",
    "ba khaam"
  ],
  "Ba Liên": [
    "ba liên",
    "ba lieen"
  ],
  "Ba Láng": [
    "ba láng",
    "ba lasng"
  ],
  "Ba Lòng": [
    "ba lòng",
    "ba lofng"
  ],
  "Ba Ngòi": [
    "ba ngòi",
    "ba ngofi"
  ],
  "Ba Tiêu": [
    "ba tiêu",
    "ba tieeu"
  ],
  "Ba Trang": [
    "ba trang",
    "ba trang"
  ],
  "Ba Trinh": [
    "ba trinh",
    "ba trinh"
  ],
  "Bum Nưa": [
    "bum nưa",
    "bum nuwa"
  ],
  "Bum Tở": [
    "bum tở",
    "bum towr"
  ],
  "Bàng La": [
    "bàng la",
    "bafng la"
  ],
  "Bàu Sen": [
    "bàu sen",
    "bafu sen"
  ],
  "Bác Ái": [
    "bác ái",
    "basc asi"
  ],
  "Bình An": [
    "bình an",
    "bifnh an"
  ],
  "Bình Ba": [
    "bình ba",
    "bifnh ba"
  ],
  "Bình La": [
    "bình la",
    "bifnh la"
  ],
  "Bình Sa": [
    "bình sa",
    "bifnh sa"
  ],
  "Bình Xa": [
    "bình xa",
    "bifnh xa"
  ],
  "Bó Sinh": [
    "bó sinh",
    "bos sinh"
  ],
  "Bản Bo": [
    "bản bo",
    "barn bo"
  ],
  "Bảo An": [
    "bảo an",
    "baro an"
  ],
  "Bắc An": [
    "bắc an",
    "bawsc an"
  ],
  "Bắc La": [
    "bắc la",
    "bawsc la"
  ],
  "Bắc Xa": [
    "bắc xa",
    "bawsc xa"
  ],
  "Bồ Lý": [
    "bồ lý",
    "boof lys"
  ],
  "Bồ Sao": [
    "bồ sao",
    "boof sao"
  ],
  "Cai Bộ": [
    "cai bộ",
    "cai booj"
  ],
  "Cai Kinh": [
    "cai kinh",
    "cai kinh"
  ],
  "Cam Giá": [
    "cam giá",
    "cam gias"
  ],
  "Cam Hòa": [
    "cam hòa",
    "cam hofa"
  ],
  "Cam Linh": [
    "cam linh",
    "cam linh"
  ],
  "Cam Lâm": [
    "cam lâm",
    "cam laam"
  ],
  "Cam Lộ": [
    "cam lộ",
    "cam looj"
  ],
  "Cam Phú": [
    "cam phú",
    "cam phus"
  ],
  "Cam Ranh": [
    "cam ranh",
    "cam ranh"
  ],
  "Cam Tân": [
    "cam tân",
    "cam taan"
  ],
  "Cao Bồ": [
    "cao bồ",
    "cao boof"
  ],
  "Cao Kỳ": [
    "cao kỳ",
    "cao kyf"
  ],
  "Cao Lâu": [
    "cao lâu",
    "cao laau"
  ],
  "Cao Minh": [
    "cao minh",
    "cao minh"
  ],
  "Cao Sơn": [
    "cao sơn",
    "cao sown"
  ],
  "Cao Tân": [
    "cao tân",
    "cao taan"
  ],
  "Cao Xanh": [
    "cao xanh",
    "cao xanh"
  ],
  "Cheo Reo": [
    "cheo reo",
    "cheo reo"
  ],
  "Chi Khê": [
    "chi khê",
    "chi khee"
  ],
  "Chu Hóa": [
    "chu hóa",
    "chu hosa"
  ],
  "Chu Minh": [
    "chu minh",
    "chu minh"
  ],
  "Chu Phan": [
    "chu phan",
    "chu phan"
  ],
  "Chà Là": [
    "chà là",
    "chaf laf"
  ],
  "Chí Cà": [
    "chí cà",
    "chis caf"
  ],
  "Chư Don": [
    "chư don",
    "chuw don"
  ],
  "Chư Sê": [
    "chư sê",
    "chuw see"
  ],
  "Co Tòng": [
    "co tòng",
    "co tofng"
  ],
  "Cun Pheo": [
    "cun pheo",
    "cun pheo"
  ],
  "Cà Lúi": [
    "cà lúi",
    "caf lusi"
  ],
  "Cách Bi": [
    "cách bi",
    "casch bi"
  ],
  "Cái Bè": [
    "cái bè",
    "casi bef"
  ],
  "Cát Bà": [
    "cát bà",
    "cast baf"
  ],
  "Cát Nê": [
    "cát nê",
    "cast nee"
  ],
  "Cù Bị": [
    "cù bị",
    "cuf bij"
  ],
  "Cù Vân": [
    "cù vân",
    "cuf vaan"
  ],
  "Cư Huê": [
    "cư huê",
    "cuw huee"
  ],
  "Cư Jang": [
    "cư jang",
    "cuw jang"
  ],
  "Cư Jút": [
    "cư jút",
    "cuw just"
  ],
  "Cư Knia": [
    "cư knia",
    "cuw knia"
  ],
  "Cư Kuin": [
    "cư kuin",
    "cuw kuin"
  ],
  "Cư Lễ": [
    "cư lễ",
    "cuw leex"
  ],
  "Cư M'ta": [
    "cư m'ta",
    "cuw m'ta"
  ],
  "Cư Prao": [
    "cư prao",
    "cuw prao"
  ],
  "Cư Suê": [
    "cư suê",
    "cuw suee"
  ],
  "Cư Yên": [
    "cư yên",
    "cuw yeen"
  ],
  "Cẩm An": [
    "cẩm an",
    "caarm an"
  ],
  "Cẩm La": [
    "cẩm la",
    "caarm la"
  ],
  "Cốc Ly": [
    "cốc ly",
    "coosc ly"
  ],
  "Cổ Bì": [
    "cổ bì",
    "coor bif"
  ],
  "Cổ Loa": [
    "cổ loa",
    "coor loa"
  ],
  "Củ Chi": [
    "củ chi",
    "cur chi"
  ],
  "Cửu An": [
    "cửu an",
    "cuwru an"
  ],
  "Dak Mang": [
    "dak mang",
    "dak mang"
  ],
  "Di Lăng": [
    "di lăng",
    "di lawng"
  ],
  "Diên An": [
    "diên an",
    "dieen an"
  ],
  "Duy Hòa": [
    "duy hòa",
    "duy hofa"
  ],
  "Duy Minh": [
    "duy minh",
    "duy minh"
  ],
  "Duy Ninh": [
    "duy ninh",
    "duy ninh"
  ],
  "Duy Phú": [
    "duy phú",
    "duy phus"
  ],
  "Duy Sơn": [
    "duy sơn",
    "duy sown"
  ],
  "Duy Tân": [
    "duy tân",
    "duy taan"
  ],
  "Duy Vinh": [
    "duy vinh",
    "duy vinh"
  ],
  "Dào San": [
    "dào san",
    "dafo san"
  ],
  "Dân Lý": [
    "dân lý",
    "daan lys"
  ],
  "Ea Blang": [
    "ea blang",
    "ea blang"
  ],
  "Ea Bông": [
    "ea bông",
    "ea boong"
  ],
  "Ea H'leo": [
    "ea h'leo",
    "ea h'leo"
  ],
  "Ea KNuec": [
    "ea knuec",
    "ea knuec"
  ],
  "Ea Kmút": [
    "ea kmút",
    "ea kmust"
  ],
  "Ea Kuêh": [
    "ea kuêh",
    "ea kueeh"
  ],
  "Ea Kênh": [
    "ea kênh",
    "ea keenh"
  ],
  "Ea Nuôl": [
    "ea nuôl",
    "ea nuool"
  ],
  "Ea Pốk": [
    "ea pốk",
    "ea poosk"
  ],
  "Ea R'Bin": [
    "ea r'bin",
    "ea r'bin"
  ],
  "Ea Rốk": [
    "ea rốk",
    "ea roosk"
  ],
  "Ea Siên": [
    "ea siên",
    "ea sieen"
  ],
  "Ea Tiêu": [
    "ea tiêu",
    "ea tieeu"
  ],
  "Ea Trang": [
    "ea trang",
    "ea trang"
  ],
  "Ea Yông": [
    "ea yông",
    "ea yoong"
  ],
  "Gia Canh": [
    "gia canh",
    "gia canh"
  ],
  "Gia Cát": [
    "gia cát",
    "gia cast"
  ],
  "Gia Hanh": [
    "gia hanh",
    "gia hanh"
  ],
  "Gia Hòa": [
    "gia hòa",
    "gia hofa"
  ],
  "Gia Lâm": [
    "gia lâm",
    "gia laam"
  ],
  "Gia Minh": [
    "gia minh",
    "gia minh"
  ],
  "Gia Ninh": [
    "gia ninh",
    "gia ninh"
  ],
  "Gia Phù": [
    "gia phù",
    "gia phuf"
  ],
  "Gia Phú": [
    "gia phú",
    "gia phus"
  ],
  "Gia Sinh": [
    "gia sinh",
    "gia sinh"
  ],
  "Gia Sơn": [
    "gia sơn",
    "gia sown"
  ],
  "Gia Tân": [
    "gia tân",
    "gia taan"
  ],
  "Gia Vân": [
    "gia vân",
    "gia vaan"
  ],
  "Giang Ly": [
    "giang ly",
    "giang ly"
  ],
  "Giang Ma": [
    "giang ma",
    "giang ma"
  ],
  "Giao Hà": [
    "giao hà",
    "giao haf"
  ],
  "Gio Linh": [
    "gio linh",
    "gio linh"
  ],
  "Gio Mỹ": [
    "gio mỹ",
    "gio myx"
  ],
  "Gio Sơn": [
    "gio sơn",
    "gio sown"
  ],
  "Giá Rai": [
    "giá rai",
    "gias rai"
  ],
  "Gung Ré": [
    "gung ré",
    "gung res"
  ],
  "Gò Quao": [
    "gò quao",
    "gof quao"
  ],
  "Hang Kia": [
    "hang kia",
    "hang kia"
  ],
  "Hanh Cù": [
    "hanh cù",
    "hanh cuf"
  ],
  "Hoa Sơn": [
    "hoa sơn",
    "hoa sown"
  ],
  "Hua Trai": [
    "hua trai",
    "hua trai"
  ],
  "Huy Hạ": [
    "huy hạ",
    "huy haj"
  ],
  "Huy Tân": [
    "huy tân",
    "huy taan"
  ],
  "Hà Kỳ": [
    "hà kỳ",
    "haf kyf"
  ],
  "Hà Lang": [
    "hà lang",
    "haf lang"
  ],
  "Hà Linh": [
    "hà linh",
    "haf linh"
  ],
  "Hà Long": [
    "hà long",
    "haf long"
  ],
  "Hà Lâm": [
    "hà lâm",
    "haf laam"
  ],
  "Hà Lâu": [
    "hà lâu",
    "haf laau"
  ],
  "Hà Mãn": [
    "hà mãn",
    "haf maxn"
  ],
  "Hà Mòn": [
    "hà mòn",
    "haf mofn"
  ],
  "Hà Sơn": [
    "hà sơn",
    "haf sown"
  ],
  "Hà Tân": [
    "hà tân",
    "haf taan"
  ],
  "Hà Tây": [
    "hà tây",
    "haf taay"
  ],
  "Hà Vinh": [
    "hà vinh",
    "haf vinh"
  ],
  "Hòa Cư": [
    "hòa cư",
    "hofa cuw"
  ],
  "Hòa Nam": [
    "hòa nam",
    "hofa nam"
  ],
  "Hòa Xá": [
    "hòa xá",
    "hofa xas"
  ],
  "Hòa Ân": [
    "hòa ân",
    "hofa aan"
  ],
  "Hòn Tre": [
    "hòn tre",
    "hofn tre"
  ],
  "Hùng An": [
    "hùng an",
    "hufng an"
  ],
  "Hạ Lý": [
    "hạ lý",
    "haj lys"
  ],
  "Hải An": [
    "hải an",
    "hari an"
  ],
  "Hải Ba": [
    "hải ba",
    "hari ba"
  ],
  "Hố Nai": [
    "hố nai",
    "hoos nai"
  ],
  "Hồ Nam": [
    "hồ nam",
    "hoof nam"
  ],
  "Hồ Xá": [
    "hồ xá",
    "hoof xas"
  ],
  "Hội An": [
    "hội an",
    "hooji an"
  ],
  "Ia BLứ": [
    "ia blứ",
    "ia bluws"
  ],
  "Ia Blang": [
    "ia blang",
    "ia blang"
  ],
  "Ia Băng": [
    "ia băng",
    "ia bawng"
  ],
  "Ia Dreng": [
    "ia dreng",
    "ia dreng"
  ],
  "Ia HDreh": [
    "ia hdreh",
    "ia hdreh"
  ],
  "Ia Hrung": [
    "ia hrung",
    "ia hrung"
  ],
  "Ia JLơi": [
    "ia jlơi",
    "ia jlowi"
  ],
  "Ia KDăm": [
    "ia kdăm",
    "ia kdawm"
  ],
  "Ia Kreng": [
    "ia kreng",
    "ia kreng"
  ],
  "Ia Kring": [
    "ia kring",
    "ia kring"
  ],
  "Ia Krêl": [
    "ia krêl",
    "ia kreel"
  ],
  "Ia Kênh": [
    "ia kênh",
    "ia keenh"
  ],
  "Ia Lốp": [
    "ia lốp",
    "ia loosp"
  ],
  "Ia Mláh": [
    "ia mláh",
    "ia mlash"
  ],
  "Ia Phang": [
    "ia phang",
    "ia phang"
  ],
  "Ia Phìn": [
    "ia phìn",
    "ia phifn"
  ],
  "Ia Piơr": [
    "ia piơr",
    "ia piowr"
  ],
  "Ia Pnôn": [
    "ia pnôn",
    "ia pnoon"
  ],
  "Ia Púch": [
    "ia púch",
    "ia pusch"
  ],
  "Ia Pết": [
    "ia pết",
    "ia peest"
  ],
  "Ia Tiêm": [
    "ia tiêm",
    "ia tieem"
  ],
  "Ka Dăng": [
    "ka dăng",
    "ka dawng"
  ],
  "Ka Lăng": [
    "ka lăng",
    "ka lawng"
  ],
  "Ka Đơn": [
    "ka đơn",
    "ka ddown"
  ],
  "Kan Hồ": [
    "kan hồ",
    "kan hoof"
  ],
  "Keng Đu": [
    "keng đu",
    "keng ddu"
  ],
  "Keo Lôm": [
    "keo lôm",
    "keo loom"
  ],
  "Kha Sơn": [
    "kha sơn",
    "kha sown"
  ],
  "Khe Sanh": [
    "khe sanh",
    "khe sanh"
  ],
  "Khoen On": [
    "khoen on",
    "khoen on"
  ],
  "Khun Há": [
    "khun há",
    "khun has"
  ],
  "Kim Bài": [
    "kim bài",
    "kim bafi"
  ],
  "Kim Bôi": [
    "kim bôi",
    "kim booi"
  ],
  "Kim Cúc": [
    "kim cúc",
    "kim cusc"
  ],
  "Kim Dinh": [
    "kim dinh",
    "kim dinh"
  ],
  "Kim Hòa": [
    "kim hòa",
    "kim hofa"
  ],
  "Kim Hóa": [
    "kim hóa",
    "kim hosa"
  ],
  "Kim Hỷ": [
    "kim hỷ",
    "kim hyr"
  ],
  "Kim Linh": [
    "kim linh",
    "kim linh"
  ],
  "Kim Loan": [
    "kim loan",
    "kim loan"
  ],
  "Kim Long": [
    "kim long",
    "kim long"
  ],
  "Kim Mỹ": [
    "kim mỹ",
    "kim myx"
  ],
  "Kim Nỗ": [
    "kim nỗ",
    "kim noox"
  ],
  "Kim Phú": [
    "kim phú",
    "kim phus"
  ],
  "Kim Quan": [
    "kim quan",
    "kim quan"
  ],
  "Kim Sơn": [
    "kim sơn",
    "kim sown"
  ],
  "Kim Thư": [
    "kim thư",
    "kim thuw"
  ],
  "Kim Tân": [
    "kim tân",
    "kim taan"
  ],
  "Kon Gang": [
    "kon gang",
    "kon gang"
  ],
  "Ký Phú": [
    "ký phú",
    "kys phus"
  ],
  "Kỳ Anh": [
    "kỳ anh",
    "kyf anh"
  ],
  "Kỳ Bá": [
    "kỳ bá",
    "kyf bas"
  ],
  "Kỳ Hoa": [
    "kỳ hoa",
    "kyf hoa"
  ],
  "Kỳ Hà": [
    "kỳ hà",
    "kyf haf"
  ],
  "Kỳ Nam": [
    "kỳ nam",
    "kyf nam"
  ],
  "La Dêê": [
    "la dêê",
    "la deeee"
  ],
  "La Hiên": [
    "la hiên",
    "la hieen"
  ],
  "La Ngâu": [
    "la ngâu",
    "la ngaau"
  ],
  "Lai Hòa": [
    "lai hòa",
    "lai hofa"
  ],
  "Lai Hạ": [
    "lai hạ",
    "lai haj"
  ],
  "Lai Vung": [
    "lai vung",
    "lai vung"
  ],
  "Lam Hạ": [
    "lam hạ",
    "lam haj"
  ],
  "Lam Sơn": [
    "lam sơn",
    "lam sown"
  ],
  "Lam Vỹ": [
    "lam vỹ",
    "lam vyx"
  ],
  "Lay Nưa": [
    "lay nưa",
    "lay nuwa"
  ],
  "Liên Am": [
    "liên am",
    "lieen am"
  ],
  "Long Anh": [
    "long anh",
    "long anh"
  ],
  "Long Hoa": [
    "long hoa",
    "long hoa"
  ],
  "Long Hà": [
    "long hà",
    "long haf"
  ],
  "Long Mai": [
    "long mai",
    "long mai"
  ],
  "Long Xá": [
    "long xá",
    "long xas"
  ],
  "Lào Cai": [
    "lào cai",
    "lafo cai"
  ],
  "Lâm Hà": [
    "lâm hà",
    "laam haf"
  ],
  "Lâm San": [
    "lâm san",
    "laam san"
  ],
  "Lãm Hà": [
    "lãm hà",
    "laxm haf"
  ],
  "Lê Hóa": [
    "lê hóa",
    "lee hosa"
  ],
  "Lê Hồ": [
    "lê hồ",
    "lee hoof"
  ],
  "Lê Ninh": [
    "lê ninh",
    "lee ninh"
  ],
  "Lê Trì": [
    "lê trì",
    "lee trif"
  ],
  "Lý Bôn": [
    "lý bôn",
    "lys boon"
  ],
  "Lý Sơn": [
    "lý sơn",
    "lys sown"
  ],
  "Lơ Pang": [
    "lơ pang",
    "low pang"
  ],
  "Lạc An": [
    "lạc an",
    "lajc an"
  ],
  "Lệ Chi": [
    "lệ chi",
    "leej chi"
  ],
  "Lệ Xá": [
    "lệ xá",
    "leej xas"
  ],
  "Lộc An": [
    "lộc an",
    "loojc an"
  ],
  "Lợi An": [
    "lợi an",
    "lowji an"
  ],
  "Lục Ba": [
    "lục ba",
    "lujc ba"
  ],
  "Ma Nới": [
    "ma nới",
    "ma nowsi"
  ],
  "Mai Hóa": [
    "mai hóa",
    "mai hosa"
  ],
  "Mai Hạ": [
    "mai hạ",
    "mai haj"
  ],
  "Mai Long": [
    "mai long",
    "mai long"
  ],
  "Mai Lâm": [
    "mai lâm",
    "mai laam"
  ],
  "Mai Sơn": [
    "mai sơn",
    "mai sown"
  ],
  "Mà Cooi": [
    "mà cooi",
    "maf cooi"
  ],
  "Máy Tơ": [
    "máy tơ",
    "masy tow"
  ],
  "Mã Đà": [
    "mã đà",
    "max ddaf"
  ],
  "Mê Linh": [
    "mê linh",
    "mee linh"
  ],
  "Mù Cả": [
    "mù cả",
    "muf car"
  ],
  "Mù Sang": [
    "mù sang",
    "muf sang"
  ],
  "Măng Ri": [
    "măng ri",
    "mawng ri"
  ],
  "Mũi Né": [
    "mũi né",
    "muxi nes"
  ],
  "Mộ Lao": [
    "mộ lao",
    "mooj lao"
  ],
  "Mỹ Gia": [
    "mỹ gia",
    "myx gia"
  ],
  "Mỹ Hà": [
    "mỹ hà",
    "myx haf"
  ],
  "Mỹ Lý": [
    "mỹ lý",
    "myx lys"
  ],
  "Mỹ Tho": [
    "mỹ tho",
    "myx tho"
  ],
  "Mỹ Tú": [
    "mỹ tú",
    "myx tus"
  ],
  "Mỹ Xá": [
    "mỹ xá",
    "myx xas"
  ],
  "Na Hối": [
    "na hối",
    "na hoosi"
  ],
  "Na Sầm": [
    "na sầm",
    "na saafm"
  ],
  "Na Tông": [
    "na tông",
    "na toong"
  ],
  "Nam Cát": [
    "nam cát",
    "nam cast"
  ],
  "Nam Dong": [
    "nam dong",
    "nam dong"
  ],
  "Nam Hoà": [
    "nam hoà",
    "nam hoaf"
  ],
  "Nam Hòa": [
    "nam hòa",
    "nam hofa"
  ],
  "Nam Khê": [
    "nam khê",
    "nam khee"
  ],
  "Nam Mỹ": [
    "nam mỹ",
    "nam myx"
  ],
  "Nam Ninh": [
    "nam ninh",
    "nam ninh"
  ],
  "Nam Phú": [
    "nam phú",
    "nam phus"
  ],
  "Nam Quan": [
    "nam quan",
    "nam quan"
  ],
  "Nam Sơn": [
    "nam sơn",
    "nam sown"
  ],
  "Nam Tân": [
    "nam tân",
    "nam taan"
  ],
  "Nam Vân": [
    "nam vân",
    "nam vaan"
  ],
  "Nam Yang": [
    "nam yang",
    "nam yang"
  ],
  "Nam Yên": [
    "nam yên",
    "nam yeen"
  ],
  "Nam Đà": [
    "nam đà",
    "nam ddaf"
  ],
  "Nga Phú": [
    "nga phú",
    "nga phus"
  ],
  "Nga Sơn": [
    "nga sơn",
    "nga sown"
  ],
  "Nga Tân": [
    "nga tân",
    "nga taan"
  ],
  "Nga Văn": [
    "nga văn",
    "nga vawn"
  ],
  "Nga Yên": [
    "nga yên",
    "nga yeen"
  ],
  "Nghi Hoa": [
    "nghi hoa",
    "nghi hoa"
  ],
  "Nghi Kim": [
    "nghi kim",
    "nghi kim"
  ],
  "Nghi Thu": [
    "nghi thu",
    "nghi thu"
  ],
  "Nghi Xá": [
    "nghi xá",
    "nghi xas"
  ],
  "Nghi Ân": [
    "nghi ân",
    "nghi aan"
  ],
  "Ngok Tem": [
    "ngok tem",
    "ngok tem"
  ],
  "Ngô Xá": [
    "ngô xá",
    "ngoo xas"
  ],
  "Nhi Sơn": [
    "nhi sơn",
    "nhi sown"
  ],
  "Nho Quan": [
    "nho quan",
    "nho quan"
  ],
  "Nhà Bè": [
    "nhà bè",
    "nhaf bef"
  ],
  "Nhân La": [
    "nhân la",
    "nhaan la"
  ],
  "Nhã Nam": [
    "nhã nam",
    "nhax nam"
  ],
  "Nhơn An": [
    "nhơn an",
    "nhown an"
  ],
  "Ninh Gia": [
    "ninh gia",
    "ninh gia"
  ],
  "Ninh Hà": [
    "ninh hà",
    "ninh haf"
  ],
  "Ninh Lai": [
    "ninh lai",
    "ninh lai"
  ],
  "Ninh Sim": [
    "ninh sim",
    "ninh sim"
  ],
  "Ninh Xá": [
    "ninh xá",
    "ninh xas"
  ],
  "Ninh Đa": [
    "ninh đa",
    "ninh dda"
  ],
  "Nà Chì": [
    "nà chì",
    "naf chif"
  ],
  "Nà Hỳ": [
    "nà hỳ",
    "naf hyf"
  ],
  "Nà Khoa": [
    "nà khoa",
    "naf khoa"
  ],
  "Nà Sáy": [
    "nà sáy",
    "naf sasy"
  ],
  "Nà Tăm": [
    "nà tăm",
    "naf tawm"
  ],
  "Núi Sam": [
    "núi sam",
    "nusi sam"
  ],
  "Núi Tô": [
    "núi tô",
    "nusi too"
  ],
  "Núi Voi": [
    "núi voi",
    "nusi voi"
  ],
  "Nậm Ty": [
    "nậm ty",
    "naajm ty"
  ],
  "Nậm Xe": [
    "nậm xe",
    "naajm xe"
  ],
  "Pa Khoá": [
    "pa khoá",
    "pa khoas"
  ],
  "Pa Thơm": [
    "pa thơm",
    "pa thowm"
  ],
  "Pa Tần": [
    "pa tần",
    "pa taafn"
  ],
  "Pha Long": [
    "pha long",
    "pha long"
  ],
  "Phong An": [
    "phong an",
    "phong an"
  ],
  "Phú Gia": [
    "phú gia",
    "phus gia"
  ],
  "Phú Kim": [
    "phú kim",
    "phus kim"
  ],
  "Phú Lai": [
    "phú lai",
    "phus lai"
  ],
  "Phú Lý": [
    "phú lý",
    "phus lys"
  ],
  "Phú Nam": [
    "phú nam",
    "phus nam"
  ],
  "Phú Xá": [
    "phú xá",
    "phus xas"
  ],
  "Phú Đa": [
    "phú đa",
    "phus dda"
  ],
  "Phúc An": [
    "phúc an",
    "phusc an"
  ],
  "Phúc La": [
    "phúc la",
    "phusc la"
  ],
  "Phố Lu": [
    "phố lu",
    "phoos lu"
  ],
  "Phổ An": [
    "phổ an",
    "phoor an"
  ],
  "Pi Toong": [
    "pi toong",
    "pi toong"
  ],
  "Pom Hán": [
    "pom hán",
    "pom hasn"
  ],
  "Pom Lót": [
    "pom lót",
    "pom lost"
  ],
  "Pá Mỳ": [
    "pá mỳ",
    "pas myf"
  ],
  "Pú Đao": [
    "pú đao",
    "pus ddao"
  ],
  "Pắc Ta": [
    "pắc ta",
    "pawsc ta"
  ],
  "Pờ Tó": [
    "pờ tó",
    "powf tos"
  ],
  "Quan Hoa": [
    "quan hoa",
    "quan hoa"
  ],
  "Quy Kỳ": [
    "quy kỳ",
    "quy kyf"
  ],
  "Quận 1": [
    "quận 1",
    "quaajn 1"
  ],
  "Quận 2": [
    "quận 2",
    "quaajn 2"
  ],
  "Quận 3": [
    "quận 3",
    "quaajn 3"
  ],
  "Quận 4": [
    "quận 4",
    "quaajn 4"
  ],
  "Quận 5": [
    "quận 5",
    "quaajn 5"
  ],
  "Quận 6": [
    "quận 6",
    "quaajn 6"
  ],
  "Quận 7": [
    "quận 7",
    "quaajn 7"
  ],
  "Quận 8": [
    "quận 8",
    "quaajn 8"
  ],
  "Quận 9": [
    "quận 9",
    "quaajn 9"
  ],
  "Quế An": [
    "quế an",
    "quees an"
  ],
  "Rơ Kơi": [
    "rơ kơi",
    "row kowi"
  ],
  "Sa Bình": [
    "sa bình",
    "sa bifnh"
  ],
  "Sa Loong": [
    "sa loong",
    "sa loong"
  ],
  "Sa Lông": [
    "sa lông",
    "sa loong"
  ],
  "Sa Nhơn": [
    "sa nhơn",
    "sa nhown"
  ],
  "Sa Đéc": [
    "sa đéc",
    "sa ddesc"
  ],
  "Song Mai": [
    "song mai",
    "song mai"
  ],
  "Sóc Hà": [
    "sóc hà",
    "sosc haf"
  ],
  "Sơn Bao": [
    "sơn bao",
    "sown bao"
  ],
  "Sơn Bua": [
    "sơn bua",
    "sown bua"
  ],
  "Sơn Cao": [
    "sơn cao",
    "sown cao"
  ],
  "Sơn Hà": [
    "sơn hà",
    "sown haf"
  ],
  "Sơn Lai": [
    "sơn lai",
    "sown lai"
  ],
  "Sơn Lư": [
    "sơn lư",
    "sown luw"
  ],
  "Sơn Nam": [
    "sơn nam",
    "sown nam"
  ],
  "Sơn Vĩ": [
    "sơn vĩ",
    "sown vix"
  ],
  "Sập Xa": [
    "sập xa",
    "saajp xa"
  ],
  "Tam Bố": [
    "tam bố",
    "tam boos"
  ],
  "Tam Dân": [
    "tam dân",
    "tam daan"
  ],
  "Tam Dị": [
    "tam dị",
    "tam dij"
  ],
  "Tam Hòa": [
    "tam hòa",
    "tam hofa"
  ],
  "Tam Kỳ": [
    "tam kỳ",
    "tam kyf"
  ],
  "Tam Phú": [
    "tam phú",
    "tam phus"
  ],
  "Tam Quan": [
    "tam quan",
    "tam quan"
  ],
  "Tam Sơn": [
    "tam sơn",
    "tam sown"
  ],
  "Tam Trà": [
    "tam trà",
    "tam traf"
  ],
  "Tam Vinh": [
    "tam vinh",
    "tam vinh"
  ],
  "Tam Văn": [
    "tam văn",
    "tam vawn"
  ],
  "Thanh An": [
    "thanh an",
    "thanh an"
  ],
  "Thanh Ba": [
    "thanh ba",
    "thanh ba"
  ],
  "Thi Sơn": [
    "thi sơn",
    "thi sown"
  ],
  "Thu Cúc": [
    "thu cúc",
    "thu cusc"
  ],
  "Thu Lũm": [
    "thu lũm",
    "thu luxm"
  ],
  "Thái An": [
    "thái an",
    "thasi an"
  ],
  "Thọ An": [
    "thọ an",
    "thoj an"
  ],
  "Thứ Ba": [
    "thứ ba",
    "thuws ba"
  ],
  "Tiên An": [
    "tiên an",
    "tieen an"
  ],
  "Tiên Du": [
    "tiên du",
    "tieen du"
  ],
  "Tri Lễ": [
    "tri lễ",
    "tri leex"
  ],
  "Tri Phú": [
    "tri phú",
    "tri phus"
  ],
  "Tri Tôn": [
    "tri tôn",
    "tri toon"
  ],
  "Trung An": [
    "trung an",
    "trung an"
  ],
  "Trà Bui": [
    "trà bui",
    "traf bui"
  ],
  "Trà Bá": [
    "trà bá",
    "traf bas"
  ],
  "Trà Cú": [
    "trà cú",
    "traf cus"
  ],
  "Trà Don": [
    "trà don",
    "traf don"
  ],
  "Trà Mai": [
    "trà mai",
    "traf mai"
  ],
  "Trà Nam": [
    "trà nam",
    "traf nam"
  ],
  "Trà Nú": [
    "trà nú",
    "traf nus"
  ],
  "Trà Ôn": [
    "trà ôn",
    "traf oon"
  ],
  "Trà Đa": [
    "trà đa",
    "traf dda"
  ],
  "Trị An": [
    "trị an",
    "trij an"
  ],
  "Tuy Hoà": [
    "tuy hoà",
    "tuy hoaf"
  ],
  "Tà Cạ": [
    "tà cạ",
    "taf caj"
  ],
  "Tà Hine": [
    "tà hine",
    "taf hine"
  ],
  "Tà Long": [
    "tà long",
    "taf long"
  ],
  "Tà Lài": [
    "tà lài",
    "taf lafi"
  ],
  "Tà Mung": [
    "tà mung",
    "taf mung"
  ],
  "Tà Mít": [
    "tà mít",
    "taf mist"
  ],
  "Tà Nung": [
    "tà nung",
    "taf nung"
  ],
  "Tà Xùa": [
    "tà xùa",
    "taf xufa"
  ],
  "Tàm Xá": [
    "tàm xá",
    "tafm xas"
  ],
  "Tá Bạ": [
    "tá bạ",
    "tas baj"
  ],
  "Tân Chi": [
    "tân chi",
    "taan chi"
  ],
  "Tân Hoa": [
    "tân hoa",
    "taan hoa"
  ],
  "Tân Hà": [
    "tân hà",
    "taan haf"
  ],
  "Tân Kim": [
    "tân kim",
    "taan kim"
  ],
  "Tân Mai": [
    "tân mai",
    "taan mai"
  ],
  "Tân Nam": [
    "tân nam",
    "taan nam"
  ],
  "Tân Quy": [
    "tân quy",
    "taan quy"
  ],
  "Tân Tri": [
    "tân tri",
    "taan tri"
  ],
  "Tân Tú": [
    "tân tú",
    "taan tus"
  ],
  "Tân Xã": [
    "tân xã",
    "taan xax"
  ],
  "Tân Ân": [
    "tân ân",
    "taan aan"
  ],
  "Tô Múa": [
    "tô múa",
    "too musa"
  ],
  "Tú Lệ": [
    "tú lệ",
    "tus leej"
  ],
  "Tú Nang": [
    "tú nang",
    "tus nang"
  ],
  "Tú Sơn": [
    "tú sơn",
    "tus sown"
  ],
  "Tơ Tung": [
    "tơ tung",
    "tow tung"
  ],
  "Tạ Bú": [
    "tạ bú",
    "taj bus"
  ],
  "Tạ Xá": [
    "tạ xá",
    "taj xas"
  ],
  "Tả Van": [
    "tả van",
    "tar van"
  ],
  "Tầm Vu": [
    "tầm vu",
    "taafm vu"
  ],
  "Tứ Xã": [
    "tứ xã",
    "tuws xax"
  ],
  "Tử Nê": [
    "tử nê",
    "tuwr nee"
  ],
  "Vinh Hà": [
    "vinh hà",
    "vinh haf"
  ],
  "Viên An": [
    "viên an",
    "vieen an"
  ],
  "Vân Cơ": [
    "vân cơ",
    "vaan cow"
  ],
  "Vân Hà": [
    "vân hà",
    "vaan haf"
  ],
  "Vân Nam": [
    "vân nam",
    "vaan nam"
  ],
  "Vân Âm": [
    "vân âm",
    "vaan aam"
  ],
  "Võ Nhai": [
    "võ nhai",
    "vox nhai"
  ],
  "Võ Ninh": [
    "võ ninh",
    "vox ninh"
  ],
  "Võng La": [
    "võng la",
    "voxng la"
  ],
  "Văn Lem": [
    "văn lem",
    "vawn lem"
  ],
  "Văn Lý": [
    "văn lý",
    "vawn lys"
  ],
  "Văn Nho": [
    "văn nho",
    "vawn nho"
  ],
  "Văn Võ": [
    "văn võ",
    "vawn vox"
  ],
  "Văn Vũ": [
    "văn vũ",
    "vawn vux"
  ],
  "Văn Xá": [
    "văn xá",
    "vawn xas"
  ],
  "Vĩ Dạ": [
    "vĩ dạ",
    "vix daj"
  ],
  "Vĩnh An": [
    "vĩnh an",
    "vixnh an"
  ],
  "Vĩnh Ô": [
    "vĩnh ô",
    "vixnh oo"
  ],
  "Vũ Hoà": [
    "vũ hoà",
    "vux hoaf"
  ],
  "Vũ Hòa": [
    "vũ hòa",
    "vux hofa"
  ],
  "Vũ Linh": [
    "vũ linh",
    "vux linh"
  ],
  "Vũ Lễ": [
    "vũ lễ",
    "vux leex"
  ],
  "Vũ Minh": [
    "vũ minh",
    "vux minh"
  ],
  "Vũ Ninh": [
    "vũ ninh",
    "vux ninh"
  ],
  "Vũ Quí": [
    "vũ quí",
    "vux quis"
  ],
  "Vũ Sơn": [
    "vũ sơn",
    "vux sown"
  ],
  "Vũ Thư": [
    "vũ thư",
    "vux thuw"
  ],
  "Vũ Vinh": [
    "vũ vinh",
    "vux vinh"
  ],
  "Vũ Vân": [
    "vũ vân",
    "vux vaan"
  ],
  "Vạn An": [
    "vạn an",
    "vajn an"
  ],
  "Xuân An": [
    "xuân an",
    "xuaan an"
  ],
  "Xuân Du": [
    "xuân du",
    "xuaan du"
  ],
  "Xuân La": [
    "xuân la",
    "xuaan la"
  ],
  "Xà Bang": [
    "xà bang",
    "xaf bang"
  ],
  "Xà Hồ": [
    "xà hồ",
    "xaf hoof"
  ],
  "Y Tịch": [
    "y tịch",
    "y tijch"
  ],
  "Ya Hội": [
    "ya hội",
    "ya hooji"
  ],
  "Ya Tăng": [
    "ya tăng",
    "ya tawng"
  ],
  "Ya Xiêr": [
    "ya xiêr",
    "ya xieer"
  ],
  "Yang Mao": [
    "yang mao",
    "yang mao"
  ],
  "Yang Nam": [
    "yang nam",
    "yang nam"
  ],
  "Yang Reh": [
    "yang reh",
    "yang reh"
  ],
  "Yang Tao": [
    "yang tao",
    "yang tao"
  ],
  "Yên Cư": [
    "yên cư",
    "yeen cuw"
  ],
  "Yên Hoa": [
    "yên hoa",
    "yeen hoa"
  ],
  "Yên Hà": [
    "yên hà",
    "yeen haf"
  ],
  "Yên Lư": [
    "yên lư",
    "yeen luw"
  ],
  "Yên Mô": [
    "yên mô",
    "yeen moo"
  ],
  "Yên Nam": [
    "yên nam",
    "yeen nam"
  ],
  "Ái Tử": [
    "ái tử",
    "asi tuwr"
  ],
  "Ân Hòa": [
    "ân hòa",
    "aan hofa"
  ],
  "Ân Mỹ": [
    "ân mỹ",
    "aan myx"
  ],
  "Ân Phú": [
    "ân phú",
    "aan phus"
  ],
  "Ân Sơn": [
    "ân sơn",
    "aan sown"
  ],
  "Ân Tín": [
    "ân tín",
    "aan tisn"
  ],
  "Âu Lâu": [
    "âu lâu",
    "aau laau"
  ],
  "Úc Kỳ": [
    "úc kỳ",
    "usc kyf"
  ],
  "é Tòng": [
    "é tòng",
    "es tofng"
  ],
  "Đa Quyn": [
    "đa quyn",
    "dda quyn"
  ],
  "Đak Pơ": [
    "đak pơ",
    "ddak pow"
  ],
  " An Lạc": [
    " an lạc",
    " an lajc"
  ],
  " Tam Quan": [
    " tam quan",
    " tam quan"
  ],
  "A Lưới": [
    "a lưới",
    "a luwowsi"
  ],
  "A Roằng": [
    "a roằng",
    "a roawfng"
  ],
  "A Vương": [
    "a vương",
    "a vuwowng"
  ],
  "An Chấn": [
    "an chấn",
    "an chaasn"
  ],
  "An Hiệp": [
    "an hiệp",
    "an hieejp"
  ],
  "An Hồng": [
    "an hồng",
    "an hoofng"
  ],
  "An Khánh": [
    "an khánh",
    "an khasnh"
  ],
  "An Nghĩa": [
    "an nghĩa",
    "an nghixa"
  ],
  "An Nhứt": [
    "an nhứt",
    "an nhuwst"
  ],
  "An Thành": [
    "an thành",
    "an thafnh"
  ],
  "An Thới": [
    "an thới",
    "an thowsi"
  ],
  "An Thủy": [
    "an thủy",
    "an thury"
  ],
  "An Tiến": [
    "an tiến",
    "an tieesn"
  ],
  "An Tràng": [
    "an tràng",
    "an trafng"
  ],
  "An Tịnh": [
    "an tịnh",
    "an tijnh"
  ],
  "An Viễn": [
    "an viễn",
    "an vieexn"
  ],
  "An Xuyên": [
    "an xuyên",
    "an xuyeen"
  ],
  "An Đông": [
    "an đông",
    "an ddoong"
  ],
  "An Đạo": [
    "an đạo",
    "an ddajo"
  ],
  "An Đức": [
    "an đức",
    "an dduwsc"
  ],
  "Anh Dũng": [
    "anh dũng",
    "anh duxng"
  ],
  "Ayun Hạ": [
    "ayun hạ",
    "ayun haj"
  ],
  "Ba Ngạc": [
    "ba ngạc",
    "ba ngajc"
  ],
  "Ba Thành": [
    "ba thành",
    "ba thafnh"
  ],
  "Ba Trại": [
    "ba trại",
    "ba traji"
  ],
  "Ba Tầng": [
    "ba tầng",
    "ba taafng"
  ],
  "Ba Đình": [
    "ba đình",
    "ba ddifnh"
  ],
  "Ba Đồn": [
    "ba đồn",
    "ba ddoofn"
  ],
  "Ban Công": [
    "ban công",
    "ban coong"
  ],
  "Bar Măih": [
    "bar măih",
    "bar mawih"
  ],
  "Bok Tới": [
    "bok tới",
    "bok towsi"
  ],
  "Bà Rịa": [
    "bà rịa",
    "baf rija"
  ],
  "Bài Sơn": [
    "bài sơn",
    "bafi sown"
  ],
  "Bàn Long": [
    "bàn long",
    "bafn long"
  ],
  "Bàu Hàm": [
    "bàu hàm",
    "bafu hafm"
  ],
  "Bàu Lâm": [
    "bàu lâm",
    "bafu laam"
  ],
  "Bát Xát": [
    "bát xát",
    "bast xast"
  ],
  "Bình Gia": [
    "bình gia",
    "bifnh gia"
  ],
  "Bình Lư": [
    "bình lư",
    "bifnh luw"
  ],
  "Bình Nam": [
    "bình nam",
    "bifnh nam"
  ],
  "Bình San": [
    "bình san",
    "bifnh san"
  ],
  "Bình Tú": [
    "bình tú",
    "bifnh tus"
  ],
  "Bình Ân": [
    "bình ân",
    "bifnh aan"
  ],
  "Bình Đa": [
    "bình đa",
    "bifnh dda"
  ],
  "Bính Xá": [
    "bính xá",
    "bisnh xas"
  ],
  "Búng Lao": [
    "búng lao",
    "busng lao"
  ],
  "Bút Sơn": [
    "bút sơn",
    "bust sown"
  ],
  "Bạch Xa": [
    "bạch xa",
    "bajch xa"
  ],
  "Bản Hon": [
    "bản hon",
    "barn hon"
  ],
  "Bản Mù": [
    "bản mù",
    "barn muf"
  ],
  "Bản Qua": [
    "bản qua",
    "barn qua"
  ],
  "Bản Sen": [
    "bản sen",
    "barn sen"
  ],
  "Bản Thi": [
    "bản thi",
    "barn thi"
  ],
  "Bảo Hà": [
    "bảo hà",
    "baro haf"
  ],
  "Bảo Lý": [
    "bảo lý",
    "baro lys"
  ],
  "Bảo Nam": [
    "bảo nam",
    "baro nam"
  ],
  "Bảo Ái": [
    "bảo ái",
    "baro asi"
  ],
  "Bắc Hà": [
    "bắc hà",
    "bawsc haf"
  ],
  "Bắc Lý": [
    "bắc lý",
    "bawsc lys"
  ],
  "Bắc Mê": [
    "bắc mê",
    "bawsc mee"
  ],
  "Bằng An": [
    "bằng an",
    "bawfng an"
  ],
  "Bến Tre": [
    "bến tre",
    "beesn tre"
  ],
  "Bố Hạ": [
    "bố hạ",
    "boos haj"
  ],
  "Ca Thành": [
    "ca thành",
    "ca thafnh"
  ],
  "Ca Đình": [
    "ca đình",
    "ca ddifnh"
  ],
  "Cai Lậy": [
    "cai lậy",
    "cai laajy"
  ],
  "Cam Bình": [
    "cam bình",
    "cam bifnh"
  ],
  "Cam Cọn": [
    "cam cọn",
    "cam cojn"
  ],
  "Cam Lập": [
    "cam lập",
    "cam laajp"
  ],
  "Cam Lộc": [
    "cam lộc",
    "cam loojc"
  ],
  "Cam Lợi": [
    "cam lợi",
    "cam lowji"
  ],
  "Can Lộc": [
    "can lộc",
    "can loojc"
  ],
  "Canh Hòa": [
    "canh hòa",
    "canh hofa"
  ],
  "Canh Tân": [
    "canh tân",
    "canh taan"
  ],
  "Canh Vinh": [
    "canh vinh",
    "canh vinh"
  ],
  "Cao Lãnh": [
    "cao lãnh",
    "cao laxnh"
  ],
  "Cao Lộc": [
    "cao lộc",
    "cao loojc"
  ],
  "Cao Nhân": [
    "cao nhân",
    "cao nhaan"
  ],
  "Cao Phong": [
    "cao phong",
    "cao phong"
  ],
  "Cao Phạ": [
    "cao phạ",
    "cao phaj"
  ],
  "Cao Viên": [
    "cao viên",
    "cao vieen"
  ],
  "Chi Lăng": [
    "chi lăng",
    "chi lawng"
  ],
  "Chim Vàn": [
    "chim vàn",
    "chim vafn"
  ],
  "Chu Trinh": [
    "chu trinh",
    "chu trinh"
  ],
  "Chà Cang": [
    "chà cang",
    "chaf cang"
  ],
  "Chà Nưa": [
    "chà nưa",
    "chaf nuwa"
  ],
  "Chà Tở": [
    "chà tở",
    "chaf towr"
  ],
  "Chà Vàl": [
    "chà vàl",
    "chaf vafl"
  ],
  "Chánh An": [
    "chánh an",
    "chasnh an"
  ],
  "Chân Lý": [
    "chân lý",
    "chaan lys"
  ],
  "Châu Can": [
    "châu can",
    "chaau can"
  ],
  "Châu Kim": [
    "châu kim",
    "chaau kim"
  ],
  "Châu Lý": [
    "châu lý",
    "chaau lys"
  ],
  "Châu Nga": [
    "châu nga",
    "chaau nga"
  ],
  "Châu Pha": [
    "châu pha",
    "chaau pha"
  ],
  "Châu Ổ": [
    "châu ổ",
    "chaau oor"
  ],
  "Chí Hòa": [
    "chí hòa",
    "chis hofa"
  ],
  "Chí Linh": [
    "chí linh",
    "chis linh"
  ],
  "Chí Minh": [
    "chí minh",
    "chis minh"
  ],
  "Chí Tân": [
    "chí tân",
    "chis taan"
  ],
  "Chơ Chun": [
    "chơ chun",
    "chow chun"
  ],
  "Chơ Long": [
    "chơ long",
    "chow long"
  ],
  "Chư Băh": [
    "chư băh",
    "chuw bawh"
  ],
  "Chư KBô": [
    "chư kbô",
    "chuw kboo"
  ],
  "Chư Mố": [
    "chư mố",
    "chuw moos"
  ],
  "Chư Păh": [
    "chư păh",
    "chuw pawh"
  ],
  "Chư Pưh": [
    "chư pưh",
    "chuw puwh"
  ],
  "Chế Là": [
    "chế là",
    "chees laf"
  ],
  "Chợ Chu": [
    "chợ chu",
    "chowj chu"
  ],
  "Chợ Rã": [
    "chợ rã",
    "chowj rax"
  ],
  "Cà Nàng": [
    "cà nàng",
    "caf nafng"
  ],
  "Các Sơn": [
    "các sơn",
    "casc sown"
  ],
  "Cái Nhum": [
    "cái nhum",
    "casi nhum"
  ],
  "Cán Khê": [
    "cán khê",
    "casn khee"
  ],
  "Cán Tỷ": [
    "cán tỷ",
    "casn tyr"
  ],
  "Cát Dài": [
    "cát dài",
    "cast dafi"
  ],
  "Cát Hanh": [
    "cát hanh",
    "cast hanh"
  ],
  "Cát Linh": [
    "cát linh",
    "cast linh"
  ],
  "Cát Lái": [
    "cát lái",
    "cast lasi"
  ],
  "Cát Lâm": [
    "cát lâm",
    "cast laam"
  ],
  "Cát Minh": [
    "cát minh",
    "cast minh"
  ],
  "Cát Sơn": [
    "cát sơn",
    "cast sown"
  ],
  "Cát Tài": [
    "cát tài",
    "cast tafi"
  ],
  "Cát Tân": [
    "cát tân",
    "cast taan"
  ],
  "Cát Vân": [
    "cát vân",
    "cast vaan"
  ],
  "Cát Văn": [
    "cát văn",
    "cast vawn"
  ],
  "Cây Gáo": [
    "cây gáo",
    "caay gaso"
  ],
  "Cò  Nòi": [
    "cò  nòi",
    "cof  nofi"
  ],
  "Cô Giang": [
    "cô giang",
    "coo giang"
  ],
  "Cô Ngân": [
    "cô ngân",
    "coo ngaan"
  ],
  "Côn Lôn": [
    "côn lôn",
    "coon loon"
  ],
  "Côn Minh": [
    "côn minh",
    "coon minh"
  ],
  "Công Lý": [
    "công lý",
    "coong lys"
  ],
  "Công Đa": [
    "công đa",
    "coong dda"
  ],
  "Cư Bông": [
    "cư bông",
    "cuw boong"
  ],
  "Cư Drăm": [
    "cư drăm",
    "cuw drawm"
  ],
  "Cư ELang": [
    "cư elang",
    "cuw elang"
  ],
  "Cư KBang": [
    "cư kbang",
    "cuw kbang"
  ],
  "Cư M'Lan": [
    "cư m'lan",
    "cuw m'lan"
  ],
  "Cư M'gar": [
    "cư m'gar",
    "cuw m'gar"
  ],
  "Cư Mốt": [
    "cư mốt",
    "cuw moost"
  ],
  "Cư Pơng": [
    "cư pơng",
    "cuw powng"
  ],
  "Cư Ê Wi": [
    "cư ê wi",
    "cuw ee wi"
  ],
  "Cư ÊBur": [
    "cư êbur",
    "cuw eebur"
  ],
  "Cảm Ân": [
    "cảm ân",
    "carm aan"
  ],
  "Cầu Bà": [
    "cầu bà",
    "caafu baf"
  ],
  "Cầu Kho": [
    "cầu kho",
    "caafu kho"
  ],
  "Cầu Kè": [
    "cầu kè",
    "caafu kef"
  ],
  "Cầu Tre": [
    "cầu tre",
    "caafu tre"
  ],
  "Cẩm Hà": [
    "cẩm hà",
    "caarm haf"
  ],
  "Cẩm Kim": [
    "cẩm kim",
    "caarm kim"
  ],
  "Cẩm Lý": [
    "cẩm lý",
    "caarm lys"
  ],
  "Cẩm Nam": [
    "cẩm nam",
    "caarm nam"
  ],
  "Cẩm Tú": [
    "cẩm tú",
    "caarm tus"
  ],
  "Cẩm Vũ": [
    "cẩm vũ",
    "caarm vux"
  ],
  "Cẩm Xá": [
    "cẩm xá",
    "caarm xas"
  ],
  "Cốc San": [
    "cốc san",
    "coosc san"
  ],
  "Cổ Linh": [
    "cổ linh",
    "coor linh"
  ],
  "Cổ Lễ": [
    "cổ lễ",
    "coor leex"
  ],
  "Cổ Đô": [
    "cổ đô",
    "coor ddoo"
  ],
  "Cửa Lò": [
    "cửa lò",
    "cuwra lof"
  ],
  "Cửa Nam": [
    "cửa nam",
    "cuwra nam"
  ],
  "Cửu Cao": [
    "cửu cao",
    "cuwru cao"
  ],
  "Cự Khê": [
    "cự khê",
    "cuwj khee"
  ],
  "Dang Kang": [
    "dang kang",
    "dang kang"
  ],
  "Diễn An": [
    "diễn an",
    "dieexn an"
  ],
  "Dray Sáp": [
    "dray sáp",
    "dray sasp"
  ],
  "Du Tiến": [
    "du tiến",
    "du tieesn"
  ],
  "Dur KMăl": [
    "dur kmăl",
    "dur kmawl"
  ],
  "Duy Châu": [
    "duy châu",
    "duy chaau"
  ],
  "Duy Hải": [
    "duy hải",
    "duy hari"
  ],
  "Duy Tiên": [
    "duy tiên",
    "duy tieen"
  ],
  "Duy Trinh": [
    "duy trinh",
    "duy trinh"
  ],
  "Duy Trung": [
    "duy trung",
    "duy trung"
  ],
  "Dân Hòa": [
    "dân hòa",
    "daan hofa"
  ],
  "Dân Hóa": [
    "dân hóa",
    "daan hosa"
  ],
  "Dìn Chin": [
    "dìn chin",
    "difn chin"
  ],
  "Dư Hàng": [
    "dư hàng",
    "duw hafng"
  ],
  "Dị Sử": [
    "dị sử",
    "dij suwr"
  ],
  "Dục Tú": [
    "dục tú",
    "dujc tus"
  ],
  "Ea BHốk": [
    "ea bhốk",
    "ea bhoosk"
  ],
  "Ea Drông": [
    "ea drông",
    "ea droong"
  ],
  "Ea Drăng": [
    "ea drăng",
    "ea drawng"
  ],
  "Ea H'MLay": [
    "ea h'mlay",
    "ea h'mlay"
  ],
  "Ea Kiết": [
    "ea kiết",
    "ea kieest"
  ],
  "Ea Knốp": [
    "ea knốp",
    "ea knoosp"
  ],
  "Ea Kuăng": [
    "ea kuăng",
    "ea kuawng"
  ],
  "Ea M'nang": [
    "ea m'nang",
    "ea m'nang"
  ],
  "Ea Riêng": [
    "ea riêng",
    "ea rieeng"
  ],
  "Ea T'Ling": [
    "ea t'ling",
    "ea t'ling"
  ],
  "Ea Yiêng": [
    "ea yiêng",
    "ea yieeng"
  ],
  "Gia Bình": [
    "gia bình",
    "gia bifnh"
  ],
  "Gia Bắc": [
    "gia bắc",
    "gia bawsc"
  ],
  "Gia Cẩm": [
    "gia cẩm",
    "gia caarm"
  ],
  "Gia Huynh": [
    "gia huynh",
    "gia huynh"
  ],
  "Gia Hưng": [
    "gia hưng",
    "gia huwng"
  ],
  "Gia Hội": [
    "gia hội",
    "gia hooji"
  ],
  "Gia Lạc": [
    "gia lạc",
    "gia lajc"
  ],
  "Gia Lập": [
    "gia lập",
    "gia laajp"
  ],
  "Gia Lộc": [
    "gia lộc",
    "gia loojc"
  ],
  "Gia Phong": [
    "gia phong",
    "gia phong"
  ],
  "Gia Phố": [
    "gia phố",
    "gia phoos"
  ],
  "Gia Sàng": [
    "gia sàng",
    "gia safng"
  ],
  "Gia Thanh": [
    "gia thanh",
    "gia thanh"
  ],
  "Gia Trung": [
    "gia trung",
    "gia trung"
  ],
  "Gia Viên": [
    "gia viên",
    "gia vieen"
  ],
  "Gia Xuân": [
    "gia xuân",
    "gia xuaan"
  ],
  "Giao Long": [
    "giao long",
    "giao long"
  ],
  "Giao Tân": [
    "giao tân",
    "giao taan"
  ],
  "Gio Châu": [
    "gio châu",
    "gio chaau"
  ],
  "Gio Hải": [
    "gio hải",
    "gio hari"
  ],
  "Gio Quang": [
    "gio quang",
    "gio quang"
  ],
  "Giáp Lai": [
    "giáp lai",
    "giasp lai"
  ],
  "Gò Công": [
    "gò công",
    "gof coong"
  ],
  "Gò Dầu": [
    "gò dầu",
    "gof daafu"
  ],
  "Gò Vấp": [
    "gò vấp",
    "gof vaasp"
  ],
  "Hang Chú": [
    "hang chú",
    "hang chus"
  ],
  "Hiệp An": [
    "hiệp an",
    "hieejp an"
  ],
  "Hoa Lộc": [
    "hoa lộc",
    "hoa loojc"
  ],
  "Hoa Thám": [
    "hoa thám",
    "hoa thasm"
  ],
  "Hoà Long": [
    "hoà long",
    "hoaf long"
  ],
  "Hoà Mỹ": [
    "hoà mỹ",
    "hoaf myx"
  ],
  "Hoà Phú": [
    "hoà phú",
    "hoaf phus"
  ],
  "Hoà Quý": [
    "hoà quý",
    "hoaf quys"
  ],
  "Hoà Tân": [
    "hoà tân",
    "hoaf taan"
  ],
  "Hoà Vinh": [
    "hoà vinh",
    "hoaf vinh"
  ],
  "Hoài Ân": [
    "hoài ân",
    "hoafi aan"
  ],
  "Hoàng An": [
    "hoàng an",
    "hoafng an"
  ],
  "Hoàng Sa": [
    "hoàng sa",
    "hoafng sa"
  ],
  "Hua Nhàn": [
    "hua nhàn",
    "hua nhafn"
  ],
  "Hua Păng": [
    "hua păng",
    "hua pawng"
  ],
  "Hua Thanh": [
    "hua thanh",
    "hua thanh"
  ],
  "Huy Bắc": [
    "huy bắc",
    "huy bawsc"
  ],
  "Huy Giáp": [
    "huy giáp",
    "huy giasp"
  ],
  "Hà Bình": [
    "hà bình",
    "haf bifnh"
  ],
  "Hà Bầu": [
    "hà bầu",
    "haf baafu"
  ],
  "Hà Bắc": [
    "hà bắc",
    "haf bawsc"
  ],
  "Hà Châu": [
    "hà châu",
    "haf chaau"
  ],
  "Hà Cầu": [
    "hà cầu",
    "haf caafu"
  ],
  "Hà Giang": [
    "hà giang",
    "haf giang"
  ],
  "Hà Hải": [
    "hà hải",
    "haf hari"
  ],
  "Hà Hồi": [
    "hà hồi",
    "haf hoofi"
  ],
  "Hà Lĩnh": [
    "hà lĩnh",
    "haf lixnh"
  ],
  "Hà Lầm": [
    "hà lầm",
    "haf laafm"
  ],
  "Hà Lộc": [
    "hà lộc",
    "haf loojc"
  ],
  "Hà Nội": [
    "hà nội",
    "haf nooji"
  ],
  "Hà Phong": [
    "hà phong",
    "haf phong"
  ],
  "Hà Thanh": [
    "hà thanh",
    "haf thanh"
  ],
  "Hà Thái": [
    "hà thái",
    "haf thasi"
  ],
  "Hà Tiên": [
    "hà tiên",
    "haf tieen"
  ],
  "Hà Trung": [
    "hà trung",
    "haf trung"
  ],
  "Hà Tĩnh": [
    "hà tĩnh",
    "haf tixnh"
  ],
  "Hàm Minh": [
    "hàm minh",
    "hafm minh"
  ],
  "Hàm Mỹ": [
    "hàm mỹ",
    "hafm myx"
  ],
  "Hàm Ninh": [
    "hàm ninh",
    "hafm ninh"
  ],
  "Hàm Phú": [
    "hàm phú",
    "hafm phus"
  ],
  "Hàm Trí": [
    "hàm trí",
    "hafm tris"
  ],
  "Hàm Tân": [
    "hàm tân",
    "hafm taan"
  ],
  "Hàm Tử": [
    "hàm tử",
    "hafm tuwr"
  ],
  "Hàm Yên": [
    "hàm yên",
    "hafm yeen"
  ],
  "Hàng Gai": [
    "hàng gai",
    "hafng gai"
  ],
  "Hàng Mã": [
    "hàng mã",
    "hafng max"
  ],
  "Hào Phú": [
    "hào phú",
    "hafo phus"
  ],
  "Hán Đà": [
    "hán đà",
    "hasn ddaf"
  ],
  "Hát Lìu": [
    "hát lìu",
    "hast lifu"
  ],
  "Hát Lót": [
    "hát lót",
    "hast lost"
  ],
  "Hát Môn": [
    "hát môn",
    "hast moon"
  ],
  "Hòa Khê": [
    "hòa khê",
    "hofa khee"
  ],
  "Hòa Long": [
    "hòa long",
    "hofa long"
  ],
  "Hòa Lâm": [
    "hòa lâm",
    "hofa laam"
  ],
  "Hòa Lễ": [
    "hòa lễ",
    "hofa leex"
  ],
  "Hòa Minh": [
    "hòa minh",
    "hofa minh"
  ],
  "Hòa Mỹ": [
    "hòa mỹ",
    "hofa myx"
  ],
  "Hòa Ninh": [
    "hòa ninh",
    "hofa ninh"
  ],
  "Hòa Phú": [
    "hòa phú",
    "hofa phus"
  ],
  "Hòa Sơn": [
    "hòa sơn",
    "hofa sown"
  ],
  "Hòa Tâm": [
    "hòa tâm",
    "hofa taam"
  ],
  "Hòa Tân": [
    "hòa tân",
    "hofa taan"
  ],
  "Hòa Vang": [
    "hòa vang",
    "hofa vang"
  ],
  "Hóa Sơn": [
    "hóa sơn",
    "hosa sown"
  ],
  "Hóc Môn": [
    "hóc môn",
    "hosc moon"
  ],
  "Hùng Lô": [
    "hùng lô",
    "hufng loo"
  ],
  "Hơ Moong": [
    "hơ moong",
    "how moong"
  ],
  "Hưng Hà": [
    "hưng hà",
    "huwng haf"
  ],
  "Hưng Thi": [
    "hưng thi",
    "huwng thi"
  ],
  "Hưng Vũ": [
    "hưng vũ",
    "huwng vux"
  ],
  "Hạ Hoà": [
    "hạ hoà",
    "haj hoaf"
  ],
  "Hạ Lang": [
    "hạ lang",
    "haj lang"
  ],
  "Hạ Long": [
    "hạ long",
    "haj long"
  ],
  "Hạ Lễ": [
    "hạ lễ",
    "haj leex"
  ],
  "Hạ Mỗ": [
    "hạ mỗ",
    "haj moox"
  ],
  "Hạ Sơn": [
    "hạ sơn",
    "haj sown"
  ],
  "Hải Anh": [
    "hải anh",
    "hari anh"
  ],
  "Hải Hà": [
    "hải hà",
    "hari haf"
  ],
  "Hải Lý": [
    "hải lý",
    "hari lys"
  ],
  "Hải Nam": [
    "hải nam",
    "hari nam"
  ],
  "Hải Quy": [
    "hải quy",
    "hari quy"
  ],
  "Hố Mít": [
    "hố mít",
    "hoos mist"
  ],
  "Hồ Sơn": [
    "hồ sơn",
    "hoof sown"
  ],
  "Hồng An": [
    "hồng an",
    "hoofng an"
  ],
  "Hồng Ca": [
    "hồng ca",
    "hoofng ca"
  ],
  "Hợp Lý": [
    "hợp lý",
    "howjp lys"
  ],
  "Ia Boòng": [
    "ia boòng",
    "ia boofng"
  ],
  "Ia Broăi": [
    "ia broăi",
    "ia broawi"
  ],
  "Ia Drăng": [
    "ia drăng",
    "ia drawng"
  ],
  "Ia Grăng": [
    "ia grăng",
    "ia grawng"
  ],
  "Ia HLốp": [
    "ia hlốp",
    "ia hloosp"
  ],
  "Ia Pếch": [
    "ia pếch",
    "ia peesch"
  ],
  "Jơ Ngây": [
    "jơ ngây",
    "jow ngaay"
  ],
  "Khai Sơn": [
    "khai sơn",
    "khai sown"
  ],
  "Khao Mang": [
    "khao mang",
    "khao mang"
  ],
  "Khau Tinh": [
    "khau tinh",
    "khau tinh"
  ],
  "Khánh An": [
    "khánh an",
    "khasnh an"
  ],
  "Khâu Vai": [
    "khâu vai",
    "khaau vai"
  ],
  "Kim Bình": [
    "kim bình",
    "kim bifnh"
  ],
  "Kim Chung": [
    "kim chung",
    "kim chung"
  ],
  "Kim Chân": [
    "kim chân",
    "kim chaan"
  ],
  "Kim Giang": [
    "kim giang",
    "kim giang"
  ],
  "Kim Hải": [
    "kim hải",
    "kim hari"
  ],
  "Kim Liên": [
    "kim liên",
    "kim lieen"
  ],
  "Kim Lập": [
    "kim lập",
    "kim laajp"
  ],
  "Kim Nọi": [
    "kim nọi",
    "kim noji"
  ],
  "Kim Thái": [
    "kim thái",
    "kim thasi"
  ],
  "Kim Trung": [
    "kim trung",
    "kim trung"
  ],
  "Kinh Dinh": [
    "kinh dinh",
    "kinh dinh"
  ],
  "Kinh Môn": [
    "kinh môn",
    "kinh moon"
  ],
  "Kiên Lao": [
    "kiên lao",
    "kieen lao"
  ],
  "Kiến An": [
    "kiến an",
    "kieesn an"
  ],
  "Kon Dơng": [
    "kon dơng",
    "kon downg"
  ],
  "Kon Rẫy": [
    "kon rẫy",
    "kon raaxy"
  ],
  "Kon Đào": [
    "kon đào",
    "kon ddafo"
  ],
  "Krông Na": [
    "krông na",
    "kroong na"
  ],
  "Krông Pa": [
    "krông pa",
    "kroong pa"
  ],
  "Krông Á": [
    "krông á",
    "kroong as"
  ],
  "Kông Pla": [
    "kông pla",
    "koong pla"
  ],
  "Kỳ Long": [
    "kỳ long",
    "kyf long"
  ],
  "Kỳ Ninh": [
    "kỳ ninh",
    "kyf ninh"
  ],
  "Kỳ Phú": [
    "kỳ phú",
    "kyf phus"
  ],
  "Kỳ Sơn": [
    "kỳ sơn",
    "kyf sown"
  ],
  "Kỳ Thư": [
    "kỳ thư",
    "kyf thuw"
  ],
  "Kỳ Tân": [
    "kỳ tân",
    "kyf taan"
  ],
  "Kỳ Tây": [
    "kỳ tây",
    "kyf taay"
  ],
  "Kỳ Văn": [
    "kỳ văn",
    "kyf vawn"
  ],
  "La Bằng": [
    "la bằng",
    "la bawfng"
  ],
  "Lai Châu": [
    "lai châu",
    "lai chaau"
  ],
  "Lai Cách": [
    "lai cách",
    "lai casch"
  ],
  "Lai Hưng": [
    "lai hưng",
    "lai huwng"
  ],
  "Lai Uyên": [
    "lai uyên",
    "lai uyeen"
  ],
  "Lam Cốt": [
    "lam cốt",
    "lam coost"
  ],
  "Lan Mẫu": [
    "lan mẫu",
    "lan maaxu"
  ],
  "Lang Minh": [
    "lang minh",
    "lang minh"
  ],
  "Lang Sơn": [
    "lang sơn",
    "lang sown"
  ],
  "Lao Bảo": [
    "lao bảo",
    "lao baro"
  ],
  "Linh Hồ": [
    "linh hồ",
    "linh hoof"
  ],
  "Linh Phú": [
    "linh phú",
    "linh phus"
  ],
  "Linh Sơn": [
    "linh sơn",
    "linh sown"
  ],
  "Linh Tây": [
    "linh tây",
    "linh taay"
  ],
  "Liên Hoa": [
    "liên hoa",
    "lieen hoa"
  ],
  "Liên Hà": [
    "liên hà",
    "lieen haf"
  ],
  "Liêu Tú": [
    "liêu tú",
    "lieeu tus"
  ],
  "Liêu Xá": [
    "liêu xá",
    "lieeu xas"
  ],
  "Loan Mỹ": [
    "loan mỹ",
    "loan myx"
  ],
  "Long Cang": [
    "long cang",
    "long cang"
  ],
  "Long Giao": [
    "long giao",
    "long giao"
  ],
  "Long Hoà": [
    "long hoà",
    "long hoaf"
  ],
  "Long Hòa": [
    "long hòa",
    "long hofa"
  ],
  "Long Hẹ": [
    "long hẹ",
    "long hej"
  ],
  "Long Hồ": [
    "long hồ",
    "long hoof"
  ],
  "Long Khê": [
    "long khê",
    "long khee"
  ],
  "Long Môn": [
    "long môn",
    "long moon"
  ],
  "Long Mỹ": [
    "long mỹ",
    "long myx"
  ],
  "Long Phú": [
    "long phú",
    "long phus"
  ],
  "Long Sơn": [
    "long sơn",
    "long sown"
  ],
  "Long Trì": [
    "long trì",
    "long trif"
  ],
  "Long Tâm": [
    "long tâm",
    "long taam"
  ],
  "Long Tân": [
    "long tân",
    "long taan"
  ],
  "Làng Mô": [
    "làng mô",
    "lafng moo"
  ],
  "Lâm Hóa": [
    "lâm hóa",
    "laam hosa"
  ],
  "Lâm Phú": [
    "lâm phú",
    "laam phus"
  ],
  "Lâm Sơn": [
    "lâm sơn",
    "laam sown"
  ],
  "Lâm Thao": [
    "lâm thao",
    "laam thao"
  ],
  "Lâm Tân": [
    "lâm tân",
    "laam taan"
  ],
  "Lão Hộ": [
    "lão hộ",
    "laxo hooj"
  ],
  "Lê Bình": [
    "lê bình",
    "lee bifnh"
  ],
  "Lê Chung": [
    "lê chung",
    "lee chung"
  ],
  "Lê Chân": [
    "lê chân",
    "lee chaan"
  ],
  "Lê Lợi": [
    "lê lợi",
    "lee lowji"
  ],
  "Lê Thanh": [
    "lê thanh",
    "lee thanh"
  ],
  "Lô Giang": [
    "lô giang",
    "loo giang"
  ],
  "Lùng Vai": [
    "lùng vai",
    "lufng vai"
  ],
  "Lý Học": [
    "lý học",
    "lys hojc"
  ],
  "Lý Nhân": [
    "lý nhân",
    "lys nhaan"
  ],
  "Lý Nhơn": [
    "lý nhơn",
    "lys nhown"
  ],
  "Lăng Can": [
    "lăng can",
    "lawng can"
  ],
  "Lăng Cô": [
    "lăng cô",
    "lawng coo"
  ],
  "Lĩnh Nam": [
    "lĩnh nam",
    "lixnh nam"
  ],
  "Lũng Cao": [
    "lũng cao",
    "luxng cao"
  ],
  "Lũng Cú": [
    "lũng cú",
    "luxng cus"
  ],
  "Lũng Pù": [
    "lũng pù",
    "luxng puf"
  ],
  "Lưu Kỳ": [
    "lưu kỳ",
    "luwu kyf"
  ],
  "Lưu Sơn": [
    "lưu sơn",
    "luwu sown"
  ],
  "Lấp Vò": [
    "lấp vò",
    "laasp vof"
  ],
  "Lệ Mỹ": [
    "lệ mỹ",
    "leej myx"
  ],
  "Lỗ Sơn": [
    "lỗ sơn",
    "loox sown"
  ],
  "Lộc Hà": [
    "lộc hà",
    "loojc haf"
  ],
  "Lộc Nam": [
    "lộc nam",
    "loojc nam"
  ],
  "Lộc Nga": [
    "lộc nga",
    "loojc nga"
  ],
  "Lục Nam": [
    "lục nam",
    "lujc nam"
  ],
  "M'Đrắk": [
    "m'đrắk",
    "m'ddrawsk"
  ],
  "Ma Ly Pho": [
    "ma ly pho",
    "ma ly pho"
  ],
  "Mai Châu": [
    "mai châu",
    "mai chaau"
  ],
  "Mai Hùng": [
    "mai hùng",
    "mai hufng"
  ],
  "Mai Lạp": [
    "mai lạp",
    "mai lajp"
  ],
  "Mai Phụ": [
    "mai phụ",
    "mai phuj"
  ],
  "Mai Trung": [
    "mai trung",
    "mai trung"
  ],
  "Mang Yang": [
    "mang yang",
    "mang yang"
  ],
  "Minh Côi": [
    "minh côi",
    "minh cooi"
  ],
  "Minh Dân": [
    "minh dân",
    "minh daan"
  ],
  "Minh Hoà": [
    "minh hoà",
    "minh hoaf"
  ],
  "Minh Hòa": [
    "minh hòa",
    "minh hofa"
  ],
  "Minh Hóa": [
    "minh hóa",
    "minh hosa"
  ],
  "Minh Khai": [
    "minh khai",
    "minh khai"
  ],
  "Minh Long": [
    "minh long",
    "minh long"
  ],
  "Minh Phú": [
    "minh phú",
    "minh phus"
  ],
  "Minh Sơn": [
    "minh sơn",
    "minh sown"
  ],
  "Minh Trí": [
    "minh trí",
    "minh tris"
  ],
  "Minh Tâm": [
    "minh tâm",
    "minh taam"
  ],
  "Minh Tân": [
    "minh tân",
    "minh taan"
  ],
  "Máy Chai": [
    "máy chai",
    "masy chai"
  ],
  "Môn Sơn": [
    "môn sơn",
    "moon sown"
  ],
  "Mông Ân": [
    "mông ân",
    "moong aan"
  ],
  "Măng Buk": [
    "măng buk",
    "mawng buk"
  ],
  "Mễ Sở": [
    "mễ sở",
    "meex sowr"
  ],
  "Mễ Trì": [
    "mễ trì",
    "meex trif"
  ],
  "Mỏ Chè": [
    "mỏ chè",
    "mor chef"
  ],
  "Mỏ Cày": [
    "mỏ cày",
    "mor cafy"
  ],
  "Mồ Dề": [
    "mồ dề",
    "moof deef"
  ],
  "Mộc Nam": [
    "mộc nam",
    "moojc nam"
  ],
  "Mỹ Cát": [
    "mỹ cát",
    "myx cast"
  ],
  "Mỹ Hào": [
    "mỹ hào",
    "myx hafo"
  ],
  "Mỹ Hòa": [
    "mỹ hòa",
    "myx hofa"
  ],
  "Mỹ Long": [
    "mỹ long",
    "myx long"
  ],
  "Mỹ Lung": [
    "mỹ lung",
    "myx lung"
  ],
  "Mỹ Lâm": [
    "mỹ lâm",
    "myx laam"
  ],
  "Mỹ Lệ": [
    "mỹ lệ",
    "myx leej"
  ],
  "Mỹ Phú": [
    "mỹ phú",
    "myx phus"
  ],
  "Mỹ Quý": [
    "mỹ quý",
    "myx quys"
  ],
  "Mỹ Sơn": [
    "mỹ sơn",
    "myx sown"
  ],
  "Mỹ Trà": [
    "mỹ trà",
    "myx traf"
  ],
  "Mỹ Tài": [
    "mỹ tài",
    "myx tafi"
  ],
  "Mỹ Tân": [
    "mỹ tân",
    "myx taan"
  ],
  "Mỹ Yên": [
    "mỹ yên",
    "myx yeen"
  ],
  "Na Cô Sa": [
    "na cô sa",
    "na coo sa"
  ],
  "Nam Bình": [
    "nam bình",
    "nam bifnh"
  ],
  "Nam Giang": [
    "nam giang",
    "nam giang"
  ],
  "Nam Hùng": [
    "nam hùng",
    "nam hufng"
  ],
  "Nam Hưng": [
    "nam hưng",
    "nam huwng"
  ],
  "Nam Hải": [
    "nam hải",
    "nam hari"
  ],
  "Nam Lĩnh": [
    "nam lĩnh",
    "nam lixnh"
  ],
  "Nam Lợi": [
    "nam lợi",
    "nam lowji"
  ],
  "Nam Mẫu": [
    "nam mẫu",
    "nam maaxu"
  ],
  "Nam Phong": [
    "nam phong",
    "nam phong"
  ],
  "Nam Quang": [
    "nam quang",
    "nam quang"
  ],
  "Nam Sách": [
    "nam sách",
    "nam sasch"
  ],
  "Nam Thanh": [
    "nam thanh",
    "nam thanh"
  ],
  "Nam Thái": [
    "nam thái",
    "nam thasi"
  ],
  "Nam Toàn": [
    "nam toàn",
    "nam toafn"
  ],
  "Nam Trung": [
    "nam trung",
    "nam trung"
  ],
  "Nam Viêm": [
    "nam viêm",
    "nam vieem"
  ],
  "Nam Xuân": [
    "nam xuân",
    "nam xuaan"
  ],
  "Nam Đàn": [
    "nam đàn",
    "nam ddafn"
  ],
  "Nga Giáp": [
    "nga giáp",
    "nga giasp"
  ],
  "Nga Hải": [
    "nga hải",
    "nga hari"
  ],
  "Nga Liên": [
    "nga liên",
    "nga lieen"
  ],
  "Nga Quán": [
    "nga quán",
    "nga quasn"
  ],
  "Nga Thanh": [
    "nga thanh",
    "nga thanh"
  ],
  "Nga Thái": [
    "nga thái",
    "nga thasi"
  ],
  "Nga Trung": [
    "nga trung",
    "nga trung"
  ],
  "Nghi Hòa": [
    "nghi hòa",
    "nghi hofa"
  ],
  "Nghi Long": [
    "nghi long",
    "nghi long"
  ],
  "Nghi Lâm": [
    "nghi lâm",
    "nghi laam"
  ],
  "Nghi Mỹ": [
    "nghi mỹ",
    "nghi myx"
  ],
  "Nghi Phú": [
    "nghi phú",
    "nghi phus"
  ],
  "Nghi Sơn": [
    "nghi sơn",
    "nghi sown"
  ],
  "Nghi Tân": [
    "nghi tân",
    "nghi taan"
  ],
  "Nghi Văn": [
    "nghi văn",
    "nghi vawn"
  ],
  "Nghi Yên": [
    "nghi yên",
    "nghi yeen"
  ],
  "Nghĩa An": [
    "nghĩa an",
    "nghixa an"
  ],
  "Nghệ An": [
    "nghệ an",
    "ngheej an"
  ],
  "Ngok Réo": [
    "ngok réo",
    "ngok reso"
  ],
  "Ngok Wang": [
    "ngok wang",
    "ngok wang"
  ],
  "Ngã Năm": [
    "ngã năm",
    "ngax nawm"
  ],
  "Ngã Sáu": [
    "ngã sáu",
    "ngax sasu"
  ],
  "Ngô Mây": [
    "ngô mây",
    "ngoo maay"
  ],
  "Ngũ Lão": [
    "ngũ lão",
    "ngux laxo"
  ],
  "Ngư Hóa": [
    "ngư hóa",
    "nguw hosa"
  ],
  "Nha Bích": [
    "nha bích",
    "nha bisch"
  ],
  "Nha Trang": [
    "nha trang",
    "nha trang"
  ],
  "Nhà Mát": [
    "nhà mát",
    "nhaf mast"
  ],
  "Nhân Cơ": [
    "nhân cơ",
    "nhaan cow"
  ],
  "Nhân Lý": [
    "nhân lý",
    "nhaan lys"
  ],
  "Nhôn Mai": [
    "nhôn mai",
    "nhoon mai"
  ],
  "Nhơn Lý": [
    "nhơn lý",
    "nhown lys"
  ],
  "Nhơn Ái": [
    "nhơn ái",
    "nhown asi"
  ],
  "Như Cố": [
    "như cố",
    "nhuw coos"
  ],
  "Như Hòa": [
    "như hòa",
    "nhuw hofa"
  ],
  "Nhị Hà": [
    "nhị hà",
    "nhij haf"
  ],
  "Ninh Dân": [
    "ninh dân",
    "ninh daan"
  ],
  "Ninh Hòa": [
    "ninh hòa",
    "ninh hofa"
  ],
  "Ninh Loan": [
    "ninh loan",
    "ninh loan"
  ],
  "Ninh Mỹ": [
    "ninh mỹ",
    "ninh myx"
  ],
  "Ninh Phú": [
    "ninh phú",
    "ninh phus"
  ],
  "Ninh Sơn": [
    "ninh sơn",
    "ninh sown"
  ],
  "Ninh Sở": [
    "ninh sở",
    "ninh sowr"
  ],
  "Ninh Tân": [
    "ninh tân",
    "ninh taan"
  ],
  "Ninh Tây": [
    "ninh tây",
    "ninh taay"
  ],
  "Ninh Vân": [
    "ninh vân",
    "ninh vaan"
  ],
  "Ninh Ích": [
    "ninh ích",
    "ninh isch"
  ],
  "Noong Bua": [
    "noong bua",
    "noong bua"
  ],
  "Noong Lay": [
    "noong lay",
    "noong lay"
  ],
  "Nà Hẩu": [
    "nà hẩu",
    "naf haaru"
  ],
  "Nà Phòn": [
    "nà phòn",
    "naf phofn"
  ],
  "Nà Tòng": [
    "nà tòng",
    "naf tofng"
  ],
  "Nà Tấu": [
    "nà tấu",
    "naf taasu"
  ],
  "Nàn Sán": [
    "nàn sán",
    "nafn sasn"
  ],
  "Nàn Xín": [
    "nàn xín",
    "nafn xisn"
  ],
  "Nàng Mau": [
    "nàng mau",
    "nafng mau"
  ],
  "Nâm Nung": [
    "nâm nung",
    "naam nung"
  ],
  "Núa Ngam": [
    "núa ngam",
    "nusa ngam"
  ],
  "Năm Căn": [
    "năm căn",
    "nawm cawn"
  ],
  "Nấm Lư": [
    "nấm lư",
    "naasm luw"
  ],
  "Nậm Ban": [
    "nậm ban",
    "naajm ban"
  ],
  "Nậm Cha": [
    "nậm cha",
    "naajm cha"
  ],
  "Nậm Có": [
    "nậm có",
    "naajm cos"
  ],
  "Nậm Kè": [
    "nậm kè",
    "naajm kef"
  ],
  "Nậm Pì": [
    "nậm pì",
    "naajm pif"
  ],
  "Nậm Tha": [
    "nậm tha",
    "naajm tha"
  ],
  "Nậm Tin": [
    "nậm tin",
    "naajm tin"
  ],
  "Nậm Vì": [
    "nậm vì",
    "naajm vif"
  ],
  "Nậm Xé": [
    "nậm xé",
    "naajm xes"
  ],
  "Nậm ét": [
    "nậm ét",
    "naajm est"
  ],
  "Phan Hòa": [
    "phan hòa",
    "phan hofa"
  ],
  "Phan Lâm": [
    "phan lâm",
    "phan laam"
  ],
  "Phan Sơn": [
    "phan sơn",
    "phan sown"
  ],
  "Phi Hải": [
    "phi hải",
    "phi hari"
  ],
  "Phong Nha": [
    "phong nha",
    "phong nha"
  ],
  "Phong Thu": [
    "phong thu",
    "phong thu"
  ],
  "Phù Cát": [
    "phù cát",
    "phuf cast"
  ],
  "Phù Cừ": [
    "phù cừ",
    "phuf cuwf"
  ],
  "Phù Hóa": [
    "phù hóa",
    "phuf hosa"
  ],
  "Phù Khê": [
    "phù khê",
    "phuf khee"
  ],
  "Phù Linh": [
    "phù linh",
    "phuf linh"
  ],
  "Phù Long": [
    "phù long",
    "phuf long"
  ],
  "Phù Lưu": [
    "phù lưu",
    "phuf luwu"
  ],
  "Phù Lỗ": [
    "phù lỗ",
    "phuf loox"
  ],
  "Phù Mỹ": [
    "phù mỹ",
    "phuf myx"
  ],
  "Phù Nham": [
    "phù nham",
    "phuf nham"
  ],
  "Phù Ninh": [
    "phù ninh",
    "phuf ninh"
  ],
  "Phù Vân": [
    "phù vân",
    "phuf vaan"
  ],
  "Phù Yên": [
    "phù yên",
    "phuf yeen"
  ],
  "Phú Bài": [
    "phú bài",
    "phus bafi"
  ],
  "Phú Cát": [
    "phú cát",
    "phus cast"
  ],
  "Phú Hoà": [
    "phú hoà",
    "phus hoaf"
  ],
  "Phú Hài": [
    "phú hài",
    "phus hafi"
  ],
  "Phú Hòa": [
    "phú hòa",
    "phus hofa"
  ],
  "Phú Hồ": [
    "phú hồ",
    "phus hoof"
  ],
  "Phú Hộ": [
    "phú hộ",
    "phus hooj"
  ],
  "Phú Khê": [
    "phú khê",
    "phus khee"
  ],
  "Phú Linh": [
    "phú linh",
    "phus linh"
  ],
  "Phú Long": [
    "phú long",
    "phus long"
  ],
  "Phú Lâm": [
    "phú lâm",
    "phus laam"
  ],
  "Phú Lãm": [
    "phú lãm",
    "phus laxm"
  ],
  "Phú Lễ": [
    "phú lễ",
    "phus leex"
  ],
  "Phú Lệ": [
    "phú lệ",
    "phus leej"
  ],
  "Phú Minh": [
    "phú minh",
    "phus minh"
  ],
  "Phú Mãn": [
    "phú mãn",
    "phus maxn"
  ],
  "Phú Mỡ": [
    "phú mỡ",
    "phus mowx"
  ],
  "Phú Mỹ": [
    "phú mỹ",
    "phus myx"
  ],
  "Phú Nham": [
    "phú nham",
    "phus nham"
  ],
  "Phú Ninh": [
    "phú ninh",
    "phus ninh"
  ],
  "Phú Quí": [
    "phú quí",
    "phus quis"
  ],
  "Phú Quý": [
    "phú quý",
    "phus quys"
  ],
  "Phú Sơn": [
    "phú sơn",
    "phus sown"
  ],
  "Phú Tài": [
    "phú tài",
    "phus tafi"
  ],
  "Phú Tâm": [
    "phú tâm",
    "phus taam"
  ],
  "Phú Tân": [
    "phú tân",
    "phus taan"
  ],
  "Phú Túc": [
    "phú túc",
    "phus tusc"
  ],
  "Phú Vang": [
    "phú vang",
    "phus vang"
  ],
  "Phú Vinh": [
    "phú vinh",
    "phus vinh"
  ],
  "Phú Văn": [
    "phú văn",
    "phus vawn"
  ],
  "Phú Yên": [
    "phú yên",
    "phus yeen"
  ],
  "Phú Đô": [
    "phú đô",
    "phus ddoo"
  ],
  "Phúc Chu": [
    "phúc chu",
    "phusc chu"
  ],
  "Phúc Hà": [
    "phúc hà",
    "phusc haf"
  ],
  "Phúc Lai": [
    "phúc lai",
    "phusc lai"
  ],
  "Phúc Sen": [
    "phúc sen",
    "phusc sen"
  ],
  "Phúc Xá": [
    "phúc xá",
    "phusc xas"
  ],
  "Phố Cò": [
    "phố cò",
    "phoos cof"
  ],
  "Phố Là": [
    "phố là",
    "phoos laf"
  ],
  "Phủ Hà": [
    "phủ hà",
    "phur haf"
  ],
  "Phủ Lý": [
    "phủ lý",
    "phur lys"
  ],
  "Pá Lông": [
    "pá lông",
    "pas loong"
  ],
  "Pú Nhung": [
    "pú nhung",
    "pus nhung"
  ],
  "Pú Pẩu": [
    "pú pẩu",
    "pus paaru"
  ],
  "Púng Tra": [
    "púng tra",
    "pusng tra"
  ],
  "Pố Lồ": [
    "pố lồ",
    "poos loof"
  ],
  "Quan Hóa": [
    "quan hóa",
    "quan hosa"
  ],
  "Quan Sơn": [
    "quan sơn",
    "quan sown"
  ],
  "Quang Huy": [
    "quang huy",
    "quang huy"
  ],
  "Quang Kim": [
    "quang kim",
    "quang kim"
  ],
  "Qui Nhơn": [
    "qui nhơn",
    "qui nhown"
  ],
  "Quy Mông": [
    "quy mông",
    "quy moong"
  ],
  "Quân Chu": [
    "quân chu",
    "quaan chu"
  ],
  "Quân Hà": [
    "quân hà",
    "quaan haf"
  ],
  "Quý Hòa": [
    "quý hòa",
    "quys hofa"
  ],
  "Quý Sơn": [
    "quý sơn",
    "quys sown"
  ],
  "Quận 10": [
    "quận 10",
    "quaajn 10"
  ],
  "Quận 11": [
    "quận 11",
    "quaajn 11"
  ],
  "Quận 12": [
    "quận 12",
    "quaajn 12"
  ],
  "Quế Võ": [
    "quế võ",
    "quees vox"
  ],
  "Quới An": [
    "quới an",
    "quowsi an"
  ],
  "Sa Nghĩa": [
    "sa nghĩa",
    "sa nghixa"
  ],
  "Sa Thầy": [
    "sa thầy",
    "sa thaafy"
  ],
  "Sam Mứn": [
    "sam mứn",
    "sam muwsn"
  ],
  "Sao Vàng": [
    "sao vàng",
    "sao vafng"
  ],
  "Sao Đỏ": [
    "sao đỏ",
    "sao ddor"
  ],
  "Si Ma Cai": [
    "si ma cai",
    "si ma cai"
  ],
  "Sinh Long": [
    "sinh long",
    "sinh long"
  ],
  "Song Hồ": [
    "song hồ",
    "song hoof"
  ],
  "Song Khê": [
    "song khê",
    "song khee"
  ],
  "Song Phú": [
    "song phú",
    "song phus"
  ],
  "Song Vân": [
    "song vân",
    "song vaan"
  ],
  "Suối Bu": [
    "suối bu",
    "suoosi bu"
  ],
  "Sài Sơn": [
    "sài sơn",
    "safi sown"
  ],
  "Sào Báy": [
    "sào báy",
    "safo basy"
  ],
  "Sìn Hồ": [
    "sìn hồ",
    "sifn hoof"
  ],
  "Sóc Sơn": [
    "sóc sơn",
    "sosc sown"
  ],
  "Sông Lô": [
    "sông lô",
    "soong loo"
  ],
  "Sông Mã": [
    "sông mã",
    "soong max"
  ],
  "Sông Ray": [
    "sông ray",
    "soong ray"
  ],
  "Sĩ Bình": [
    "sĩ bình",
    "six bifnh"
  ],
  "Sơn Dung": [
    "sơn dung",
    "sown dung"
  ],
  "Sơn Hàm": [
    "sơn hàm",
    "sown hafm"
  ],
  "Sơn Hòa": [
    "sơn hòa",
    "sown hofa"
  ],
  "Sơn Hóa": [
    "sơn hóa",
    "sown hosa"
  ],
  "Sơn Hạ": [
    "sơn hạ",
    "sown haj"
  ],
  "Sơn Kỳ": [
    "sơn kỳ",
    "sown kyf"
  ],
  "Sơn Lang": [
    "sơn lang",
    "sown lang"
  ],
  "Sơn Linh": [
    "sơn linh",
    "sown linh"
  ],
  "Sơn Long": [
    "sơn long",
    "sown long"
  ],
  "Sơn Lâm": [
    "sơn lâm",
    "sown laam"
  ],
  "Sơn Lôi": [
    "sơn lôi",
    "sown looi"
  ],
  "Sơn Lễ": [
    "sơn lễ",
    "sown leex"
  ],
  "Sơn Lộ": [
    "sơn lộ",
    "sown looj"
  ],
  "Sơn Màu": [
    "sơn màu",
    "sown mafu"
  ],
  "Sơn Mùa": [
    "sơn mùa",
    "sown mufa"
  ],
  "Sơn Mỹ": [
    "sơn mỹ",
    "sown myx"
  ],
  "Sơn Nham": [
    "sơn nham",
    "sown nham"
  ],
  "Sơn Ninh": [
    "sơn ninh",
    "sown ninh"
  ],
  "Sơn Phú": [
    "sơn phú",
    "sown phus"
  ],
  "Sơn Tinh": [
    "sơn tinh",
    "sown tinh"
  ],
  "Sơn Trà": [
    "sơn trà",
    "sown traf"
  ],
  "Sơn Tân": [
    "sơn tân",
    "sown taan"
  ],
  "Sơn Tây": [
    "sơn tây",
    "sown taay"
  ],
  "Sơn Đà": [
    "sơn đà",
    "sown ddaf"
  ],
  "Tam Bình": [
    "tam bình",
    "tam bifnh"
  ],
  "Tam Chung": [
    "tam chung",
    "tam chung"
  ],
  "Tam Giang": [
    "tam giang",
    "tam giang"
  ],
  "Tam Hưng": [
    "tam hưng",
    "tam huwng"
  ],
  "Tam Hải": [
    "tam hải",
    "tam hari"
  ],
  "Tam Hợp": [
    "tam hợp",
    "tam howjp"
  ],
  "Tam Lãnh": [
    "tam lãnh",
    "tam laxnh"
  ],
  "Tam Lập": [
    "tam lập",
    "tam laajp"
  ],
  "Tam Lộc": [
    "tam lộc",
    "tam loojc"
  ],
  "Tam Ngãi": [
    "tam ngãi",
    "tam ngaxi"
  ],
  "Tam Nông": [
    "tam nông",
    "tam noong"
  ],
  "Tam Phúc": [
    "tam phúc",
    "tam phusc"
  ],
  "Tam Quang": [
    "tam quang",
    "tam quang"
  ],
  "Tam Thanh": [
    "tam thanh",
    "tam thanh"
  ],
  "Tam Thái": [
    "tam thái",
    "tam thasi"
  ],
  "Tam Đàn": [
    "tam đàn",
    "tam ddafn"
  ],
  "Thanh Cao": [
    "thanh cao",
    "thanh cao"
  ],
  "Thanh Chi": [
    "thanh chi",
    "thanh chi"
  ],
  "Thanh Hà": [
    "thanh hà",
    "thanh haf"
  ],
  "Thanh Mai": [
    "thanh mai",
    "thanh mai"
  ],
  "Thanh Nho": [
    "thanh nho",
    "thanh nho"
  ],
  "Thanh Oai": [
    "thanh oai",
    "thanh oai"
  ],
  "Thanh Xá": [
    "thanh xá",
    "thanh xas"
  ],
  "Thanh Đa": [
    "thanh đa",
    "thanh dda"
  ],
  "Thu Phong": [
    "thu phong",
    "thu phong"
  ],
  "Thung Nai": [
    "thung nai",
    "thung nai"
  ],
  "Thành An": [
    "thành an",
    "thafnh an"
  ],
  "Thác Bà": [
    "thác bà",
    "thasc baf"
  ],
  "Thác Mơ": [
    "thác mơ",
    "thasc mow"
  ],
  "Thèn Sin": [
    "thèn sin",
    "thefn sin"
  ],
  "Thư Phú": [
    "thư phú",
    "thuw phus"
  ],
  "Thần Xa": [
    "thần xa",
    "thaafn xa"
  ],
  "Thị Hoa": [
    "thị hoa",
    "thij hoa"
  ],
  "Thới An": [
    "thới an",
    "thowsi an"
  ],
  "Thụy An": [
    "thụy an",
    "thujy an"
  ],
  "Thủy An": [
    "thủy an",
    "thury an"
  ],
  "Tiên Hà": [
    "tiên hà",
    "tieen haf"
  ],
  "Tiên Nha": [
    "tiên nha",
    "tieen nha"
  ],
  "Tiền An": [
    "tiền an",
    "tieefn an"
  ],
  "Tri Hải": [
    "tri hải",
    "tri hari"
  ],
  "Tri Trung": [
    "tri trung",
    "tri trung"
  ],
  "Trung Hà": [
    "trung hà",
    "trung haf"
  ],
  "Trung Lý": [
    "trung lý",
    "trung lys"
  ],
  "Trung Nam": [
    "trung nam",
    "trung nam"
  ],
  "Trung Thu": [
    "trung thu",
    "trung thu"
  ],
  "Trung Tú": [
    "trung tú",
    "trung tus"
  ],
  "Trà Bùi": [
    "trà bùi",
    "traf bufi"
  ],
  "Trà Cang": [
    "trà cang",
    "traf cang"
  ],
  "Trà Côn": [
    "trà côn",
    "traf coon"
  ],
  "Trà Cổ": [
    "trà cổ",
    "traf coor"
  ],
  "Trà Dơn": [
    "trà dơn",
    "traf down"
  ],
  "Trà Kót": [
    "trà kót",
    "traf kost"
  ],
  "Trà Leng": [
    "trà leng",
    "traf leng"
  ],
  "Trà Linh": [
    "trà linh",
    "traf linh"
  ],
  "Trà Lâm": [
    "trà lâm",
    "traf laam"
  ],
  "Trà Nóc": [
    "trà nóc",
    "traf nosc"
  ],
  "Trà Phú": [
    "trà phú",
    "traf phus"
  ],
  "Trà Sơn": [
    "trà sơn",
    "traf sown"
  ],
  "Trà Tân": [
    "trà tân",
    "traf taan"
  ],
  "Trà Tây": [
    "trà tây",
    "traf taay"
  ],
  "Trà Vinh": [
    "trà vinh",
    "traf vinh"
  ],
  "Trà Vong": [
    "trà vong",
    "traf vong"
  ],
  "Trà Vân": [
    "trà vân",
    "traf vaan"
  ],
  "Trà Xinh": [
    "trà xinh",
    "traf xinh"
  ],
  "Tràng An": [
    "tràng an",
    "trafng an"
  ],
  "Trí Nang": [
    "trí nang",
    "tris nang"
  ],
  "Trí Yên": [
    "trí yên",
    "tris yeen"
  ],
  "Trù Sơn": [
    "trù sơn",
    "truf sown"
  ],
  "Tuy Lộc": [
    "tuy lộc",
    "tuy loojc"
  ],
  "Tuy Phong": [
    "tuy phong",
    "tuy phong"
  ],
  "Tà Bhinh": [
    "tà bhinh",
    "taf bhinh"
  ],
  "Tà Hộc": [
    "tà hộc",
    "taf hoojc"
  ],
  "Tà Hừa": [
    "tà hừa",
    "taf huwfa"
  ],
  "Tà Lùng": [
    "tà lùng",
    "taf lufng"
  ],
  "Tà Năng": [
    "tà năng",
    "taf nawng"
  ],
  "Tà Pơơ": [
    "tà pơơ",
    "taf powow"
  ],
  "Tà Rụt": [
    "tà rụt",
    "taf rujt"
  ],
  "Tài Văn": [
    "tài văn",
    "tafi vawn"
  ],
  "Tào Sơn": [
    "tào sơn",
    "tafo sown"
  ],
  "Tái Sơn": [
    "tái sơn",
    "tasi sown"
  ],
  "Tát Ngà": [
    "tát ngà",
    "tast ngaf"
  ],
  "Tân Dân": [
    "tân dân",
    "taan daan"
  ],
  "Tân Hoà": [
    "tân hoà",
    "taan hoaf"
  ],
  "Tân Hào": [
    "tân hào",
    "taan hafo"
  ],
  "Tân Hòa": [
    "tân hòa",
    "taan hofa"
  ],
  "Tân Hóa": [
    "tân hóa",
    "taan hosa"
  ],
  "Tân Khai": [
    "tân khai",
    "taan khai"
  ],
  "Tân Kỳ": [
    "tân kỳ",
    "taan kyf"
  ],
  "Tân Lang": [
    "tân lang",
    "taan lang"
  ],
  "Tân Linh": [
    "tân linh",
    "taan linh"
  ],
  "Tân Long": [
    "tân long",
    "taan long"
  ],
  "Tân Lâm": [
    "tân lâm",
    "taan laam"
  ],
  "Tân Lân": [
    "tân lân",
    "taan laan"
  ],
  "Tân Lễ": [
    "tân lễ",
    "taan leex"
  ],
  "Tân Minh": [
    "tân minh",
    "taan minh"
  ],
  "Tân Mỹ": [
    "tân mỹ",
    "taan myx"
  ],
  "Tân Ninh": [
    "tân ninh",
    "taan ninh"
  ],
  "Tân Pheo": [
    "tân pheo",
    "taan pheo"
  ],
  "Tân Phú": [
    "tân phú",
    "taan phus"
  ],
  "Tân Quan": [
    "tân quan",
    "taan quan"
  ],
  "Tân Quý": [
    "tân quý",
    "taan quys"
  ],
  "Tân Sơn": [
    "tân sơn",
    "taan sown"
  ],
  "Tân Tác": [
    "tân tác",
    "taan tasc"
  ],
  "Tân Tây": [
    "tân tây",
    "taan taay"
  ],
  "Tân Túc": [
    "tân túc",
    "taan tusc"
  ],
  "Tân Vinh": [
    "tân vinh",
    "taan vinh"
  ],
  "Tân Văn": [
    "tân văn",
    "taan vawn"
  ],
  "Tân Yên": [
    "tân yên",
    "taan yeen"
  ],
  "Tây Hoà": [
    "tây hoà",
    "taay hoaf"
  ],
  "Tây Hồ": [
    "tây hồ",
    "taay hoof"
  ],
  "Tây Mỗ": [
    "tây mỗ",
    "taay moox"
  ],
  "Tây Ninh": [
    "tây ninh",
    "taay ninh"
  ],
  "Tây Phú": [
    "tây phú",
    "taay phus"
  ],
  "Tây Sơn": [
    "tây sơn",
    "taay sown"
  ],
  "Tây Vinh": [
    "tây vinh",
    "taay vinh"
  ],
  "Tây Yên": [
    "tây yên",
    "taay yeen"
  ],
  "Tây Đô": [
    "tây đô",
    "taay ddoo"
  ],
  "Tê Xăng": [
    "tê xăng",
    "tee xawng"
  ],
  "Tô Châu": [
    "tô châu",
    "too chaau"
  ],
  "Tô Hạp": [
    "tô hạp",
    "too hajp"
  ],
  "Tô Mậu": [
    "tô mậu",
    "too maaju"
  ],
  "Tùng Bá": [
    "tùng bá",
    "tufng bas"
  ],
  "Tĩnh Gia": [
    "tĩnh gia",
    "tixnh gia"
  ],
  "Tư Mại": [
    "tư mại",
    "tuw maji"
  ],
  "Tạ Khoa": [
    "tạ khoa",
    "taj khoa"
  ],
  "Tả Ván": [
    "tả ván",
    "tar vasn"
  ],
  "Tề Lễ": [
    "tề lễ",
    "teef leex"
  ],
  "Tề Lỗ": [
    "tề lỗ",
    "teef loox"
  ],
  "Tịnh An": [
    "tịnh an",
    "tijnh an"
  ],
  "Tứ Dân": [
    "tứ dân",
    "tuws daan"
  ],
  "Tứ Hạ": [
    "tứ hạ",
    "tuws haj"
  ],
  "Tứ Kỳ": [
    "tứ kỳ",
    "tuws kyf"
  ],
  "Tứ Minh": [
    "tứ minh",
    "tuws minh"
  ],
  "Tứ Yên": [
    "tứ yên",
    "tuws yeen"
  ],
  "Từ Sơn": [
    "từ sơn",
    "tuwf sown"
  ],
  "Tự Tân": [
    "tự tân",
    "tuwj taan"
  ],
  "Uông Bí": [
    "uông bí",
    "uoong bis"
  ],
  "Vinh Mỹ": [
    "vinh mỹ",
    "vinh myx"
  ],
  "Vinh Quý": [
    "vinh quý",
    "vinh quys"
  ],
  "Vinh Tân": [
    "vinh tân",
    "vinh taan"
  ],
  "Vàng San": [
    "vàng san",
    "vafng san"
  ],
  "Vân Canh": [
    "vân canh",
    "vaan canh"
  ],
  "Vân Côn": [
    "vân côn",
    "vaan coon"
  ],
  "Vân Hòa": [
    "vân hòa",
    "vaan hofa"
  ],
  "Vân Hồ": [
    "vân hồ",
    "vaan hoof"
  ],
  "Vân Nham": [
    "vân nham",
    "vaan nham"
  ],
  "Vân Phú": [
    "vân phú",
    "vaan phus"
  ],
  "Vân Sơn": [
    "vân sơn",
    "vaan sown"
  ],
  "Vân Từ": [
    "vân từ",
    "vaan tuwf"
  ],
  "Vô Tranh": [
    "vô tranh",
    "voo tranh"
  ],
  "Văn Bàn": [
    "văn bàn",
    "vawn bafn"
  ],
  "Văn Bán": [
    "văn bán",
    "vawn basn"
  ],
  "Văn Hán": [
    "văn hán",
    "vawn hasn"
  ],
  "Văn Hóa": [
    "văn hóa",
    "vawn hosa"
  ],
  "Văn Khê": [
    "văn khê",
    "vawn khee"
  ],
  "Văn Lang": [
    "văn lang",
    "vawn lang"
  ],
  "Văn Lung": [
    "văn lung",
    "vawn lung"
  ],
  "Văn Lâm": [
    "văn lâm",
    "vawn laam"
  ],
  "Văn Minh": [
    "văn minh",
    "vawn minh"
  ],
  "Văn Môn": [
    "văn môn",
    "vawn moon"
  ],
  "Văn Phú": [
    "văn phú",
    "vawn phus"
  ],
  "Văn Quan": [
    "văn quan",
    "vawn quan"
  ],
  "Văn Sơn": [
    "văn sơn",
    "vawn sown"
  ],
  "Văn Tố": [
    "văn tố",
    "vawn toos"
  ],
  "Văn Tự": [
    "văn tự",
    "vawn tuwj"
  ],
  "Văn Yên": [
    "văn yên",
    "vawn yeen"
  ],
  "Vĩnh Gia": [
    "vĩnh gia",
    "vixnh gia"
  ],
  "Vĩnh Hà": [
    "vĩnh hà",
    "vixnh haf"
  ],
  "Vĩnh Kim": [
    "vĩnh kim",
    "vixnh kim"
  ],
  "Vĩnh Tuy": [
    "vĩnh tuy",
    "vixnh tuy"
  ],
  "Vĩnh Tú": [
    "vĩnh tú",
    "vixnh tus"
  ],
  "Vĩnh Xá": [
    "vĩnh xá",
    "vixnh xas"
  ],
  "Vũ Bình": [
    "vũ bình",
    "vux bifnh"
  ],
  "Vũ Bản": [
    "vũ bản",
    "vux barn"
  ],
  "Vũ Công": [
    "vũ công",
    "vux coong"
  ],
  "Vũ Hội": [
    "vũ hội",
    "vux hooji"
  ],
  "Vũ Lăng": [
    "vũ lăng",
    "vux lawng"
  ],
  "Vũ Lạc": [
    "vũ lạc",
    "vux lajc"
  ],
  "Vũ Nông": [
    "vũ nông",
    "vux noong"
  ],
  "Vũ Phúc": [
    "vũ phúc",
    "vux phusc"
  ],
  "Vũ Quang": [
    "vũ quang",
    "vux quang"
  ],
  "Vũ Trung": [
    "vũ trung",
    "vux trung"
  ],
  "Vạn Kim": [
    "vạn kim",
    "vajn kim"
  ],
  "Vạn Mai": [
    "vạn mai",
    "vajn mai"
  ],
  "Vị Tân": [
    "vị tân",
    "vij taan"
  ],
  "Xiêng My": [
    "xiêng my",
    "xieeng my"
  ],
  "Xuân Cao": [
    "xuân cao",
    "xuaan cao"
  ],
  "Xuân Huy": [
    "xuân huy",
    "xuaan huy"
  ],
  "Xuân Hà": [
    "xuân hà",
    "xuaan haf"
  ],
  "Xuân Lai": [
    "xuân lai",
    "xuaan lai"
  ],
  "Xuân Lam": [
    "xuân lam",
    "xuaan lam"
  ],
  "Xuân Lao": [
    "xuân lao",
    "xuaan lao"
  ],
  "Xuân Mai": [
    "xuân mai",
    "xuaan mai"
  ],
  "Xuân Nha": [
    "xuân nha",
    "xuaan nha"
  ],
  "Xuân Thu": [
    "xuân thu",
    "xuaan thu"
  ],
  "Xuân Ái": [
    "xuân ái",
    "xuaan asi"
  ],
  "Xà Phìn": [
    "xà phìn",
    "xaf phifn"
  ],
  "Xín Cái": [
    "xín cái",
    "xisn casi"
  ],
  "Yên Bài": [
    "yên bài",
    "yeen bafi"
  ],
  "Yên Bái": [
    "yên bái",
    "yeen basi"
  ],
  "Yên Cát": [
    "yên cát",
    "yeen cast"
  ],
  "Yên Hoà": [
    "yên hoà",
    "yeen hoaf"
  ],
  "Yên Hân": [
    "yên hân",
    "yeen haan"
  ],
  "Yên Hòa": [
    "yên hòa",
    "yeen hofa"
  ],
  "Yên Hóa": [
    "yên hóa",
    "yeen hosa"
  ],
  "Yên Hồ": [
    "yên hồ",
    "yeen hoof"
  ],
  "Yên Khê": [
    "yên khê",
    "yeen khee"
  ],
  "Yên Kỳ": [
    "yên kỳ",
    "yeen kyf"
  ],
  "Yên Lâm": [
    "yên lâm",
    "yeen laam"
  ],
  "Yên Lỗ": [
    "yên lỗ",
    "yeen loox"
  ],
  "Yên Minh": [
    "yên minh",
    "yeen minh"
  ],
  "Yên Mỹ": [
    "yên mỹ",
    "yeen myx"
  ],
  "Yên Ninh": [
    "yên ninh",
    "yeen ninh"
  ],
  "Yên Phú": [
    "yên phú",
    "yeen phus"
  ],
  "Yên Sơn": [
    "yên sơn",
    "yeen sown"
  ],
  "Yên Sở": [
    "yên sở",
    "yeen sowr"
  ],
  "Yên Than": [
    "yên than",
    "yeen than"
  ],
  "Yên Tâm": [
    "yên tâm",
    "yeen taam"
  ],
  "Yên Tân": [
    "yên tân",
    "yeen taan"
  ],
  "Yên Từ": [
    "yên từ",
    "yeen tuwf"
  ],
  "Ân Hữu": [
    "ân hữu",
    "aan huwxu"
  ],
  "Ân Phong": [
    "ân phong",
    "aan phong"
  ],
  "ĐLiê Ya": [
    "đliê ya",
    "ddliee ya"
  ],
  "Đa Lộc": [
    "đa lộc",
    "dda loojc"
  ],
  "Đa Phúc": [
    "đa phúc",
    "dda phusc"
  ],
  "Đa Tốn": [
    "đa tốn",
    "dda toosn"
  ],
  "Đak Nhau": [
    "đak nhau",
    "ddak nhau"
  ],
  "Đak SMar": [
    "đak smar",
    "ddak smar"
  ],
  "Đinh Xá": [
    "đinh xá",
    "ddinh xas"
  ],
  "Đà Loan": [
    "đà loan",
    "ddaf loan"
  ],
  "Đà Sơn": [
    "đà sơn",
    "ddaf sown"
  ],
  "Đà Vị": [
    "đà vị",
    "ddaf vij"
  ],
  "Đào Xá": [
    "đào xá",
    "ddafo xas"
  ],
  "Đèo Gia": [
    "đèo gia",
    "ddefo gia"
  ],
  "Đô Vinh": [
    "đô vinh",
    "ddoo vinh"
  ],
  "Đông An": [
    "đông an",
    "ddoong an"
  ],
  "Đông La": [
    "đông la",
    "ddoong la"
  ],
  "Đông Á": [
    "đông á",
    "ddoong as"
  ],
  "Đăk Pơ": [
    "đăk pơ",
    "ddawk pow"
  ],
  "Đăk Yă": [
    "đăk yă",
    "ddawk yaw"
  ],
  "Đạ Kho": [
    "đạ kho",
    "ddaj kho"
  ],
  "Đạ Oai": [
    "đạ oai",
    "ddaj oai"
  ],
  "Đạ Pal": [
    "đạ pal",
    "ddaj pal"
  ],
  "Đạ Sar": [
    "đạ sar",
    "ddaj sar"
  ],
  "Đại An": [
    "đại an",
    "ddaji an"
  ],
  "Đắk Ha": [
    "đắk ha",
    "ddawsk ha"
  ],
  "Đắk La": [
    "đắk la",
    "ddawsk la"
  ],
  "Đắk Na": [
    "đắk na",
    "ddawsk na"
  ],
  "Đắk Ru": [
    "đắk ru",
    "ddawsk ru"
  ],
  "Đắk Ui": [
    "đắk ui",
    "ddawsk ui"
  ],
  "Đồi 61": [
    "đồi 61",
    "ddoofi 61"
  ],
  "Đức An": [
    "đức an",
    "dduwsc an"
  ],
  "Ấm Hạ": [
    "ấm hạ",
    "aasm haj"
  ],
  " Tây Sơn": [
    " tây sơn",
    " taay sown"
  ],
  "A Mú Sung": [
    "a mú sung",
    "a mus sung"
  ],
  "An Bình A": [
    "an bình a",
    "an bifnh a"
  ],
  "An Bình B": [
    "an bình b",
    "an bifnh b"
  ],
  "An Dương": [
    "an dương",
    "an duwowng"
  ],
  "An Lương": [
    "an lương",
    "an luwowng"
  ],
  "An Lạc A": [
    "an lạc a",
    "an lajc a"
  ],
  "An Thuận": [
    "an thuận",
    "an thuaajn"
  ],
  "An Thạch": [
    "an thạch",
    "an thajch"
  ],
  "An Thạnh": [
    "an thạnh",
    "an thajnh"
  ],
  "An Thắng": [
    "an thắng",
    "an thawsng"
  ],
  "An Thịnh": [
    "an thịnh",
    "an thijnh"
  ],
  "An Trạch": [
    "an trạch",
    "an trajch"
  ],
  "An Điền": [
    "an điền",
    "an ddieefn"
  ],
  "An Định": [
    "an định",
    "an ddijnh"
  ],
  "An Đồng": [
    "an đồng",
    "an ddoofng"
  ],
  "Ba Điền": [
    "ba điền",
    "ba ddieefn"
  ],
  "Ba Động": [
    "ba động",
    "ba ddoojng"
  ],
  "Biên Hòa": [
    "biên hòa",
    "bieen hofa"
  ],
  "Biên Sơn": [
    "biên sơn",
    "bieen sown"
  ],
  "Buôn Hồ": [
    "buôn hồ",
    "buoon hoof"
  ],
  "Bàu Bàng": [
    "bàu bàng",
    "bafu bafng"
  ],
  "Bàu Chinh": [
    "bàu chinh",
    "bafu chinh"
  ],
  "Bàu Cạn": [
    "bàu cạn",
    "bafu cajn"
  ],
  "Bàu Năng": [
    "bàu năng",
    "bafu nawng"
  ],
  "Bàu Trâm": [
    "bàu trâm",
    "bafu traam"
  ],
  "Bá Hiến": [
    "bá hiến",
    "bas hieesn"
  ],
  "Bá Xuyên": [
    "bá xuyên",
    "bas xuyeen"
  ],
  "Bách Khoa": [
    "bách khoa",
    "basch khoa"
  ],
  "Báo Đáp": [
    "báo đáp",
    "baso ddasp"
  ],
  "Bát Mọt": [
    "bát mọt",
    "bast mojt"
  ],
  "Bát Trang": [
    "bát trang",
    "bast trang"
  ],
  "Bãi Bông": [
    "bãi bông",
    "baxi boong"
  ],
  "Bãi Cháy": [
    "bãi cháy",
    "baxi chasy"
  ],
  "Bãi Sậy": [
    "bãi sậy",
    "baxi saajy"
  ],
  "Bãi Thơm": [
    "bãi thơm",
    "baxi thowm"
  ],
  "Bình Dân": [
    "bình dân",
    "bifnh daan"
  ],
  "Bình Giã": [
    "bình giã",
    "bifnh giax"
  ],
  "Bình Hoà": [
    "bình hoà",
    "bifnh hoaf"
  ],
  "Bình Hàn": [
    "bình hàn",
    "bifnh hafn"
  ],
  "Bình Hòa": [
    "bình hòa",
    "bifnh hofa"
  ],
  "Bình Khê": [
    "bình khê",
    "bifnh khee"
  ],
  "Bình Long": [
    "bình long",
    "bifnh long"
  ],
  "Bình Lâm": [
    "bình lâm",
    "bifnh laam"
  ],
  "Bình Minh": [
    "bình minh",
    "bifnh minh"
  ],
  "Bình Mỹ": [
    "bình mỹ",
    "bifnh myx"
  ],
  "Bình Nghi": [
    "bình nghi",
    "bifnh nghi"
  ],
  "Bình Nhì": [
    "bình nhì",
    "bifnh nhif"
  ],
  "Bình Ninh": [
    "bình ninh",
    "bifnh ninh"
  ],
  "Bình Phan": [
    "bình phan",
    "bifnh phan"
  ],
  "Bình Phú": [
    "bình phú",
    "bifnh phus"
  ],
  "Bình Quý": [
    "bình quý",
    "bifnh quys"
  ],
  "Bình Sơn": [
    "bình sơn",
    "bifnh sown"
  ],
  "Bình Tâm": [
    "bình tâm",
    "bifnh taam"
  ],
  "Bình Tân": [
    "bình tân",
    "bifnh taan"
  ],
  "Bình Văn": [
    "bình văn",
    "bifnh vawn"
  ],
  "Bình Yên": [
    "bình yên",
    "bifnh yeen"
  ],
  "Bích Hòa": [
    "bích hòa",
    "bisch hofa"
  ],
  "Bù Đăng": [
    "bù đăng",
    "buf ddawng"
  ],
  "Bù Đốp": [
    "bù đốp",
    "buf ddoosp"
  ],
  "Búng Tàu": [
    "búng tàu",
    "busng tafu"
  ],
  "Bạch Hà": [
    "bạch hà",
    "bajch haf"
  ],
  "Bạch Mai": [
    "bạch mai",
    "bajch mai"
  ],
  "Bạch Sam": [
    "bạch sam",
    "bajch sam"
  ],
  "Bản Cái": [
    "bản cái",
    "barn casi"
  ],
  "Bản Díu": [
    "bản díu",
    "barn disu"
  ],
  "Bản Hồ": [
    "bản hồ",
    "barn hoof"
  ],
  "Bản Lang": [
    "bản lang",
    "barn lang"
  ],
  "Bản Máy": [
    "bản máy",
    "barn masy"
  ],
  "Bản Mế": [
    "bản mế",
    "barn mees"
  ],
  "Bản Ngò": [
    "bản ngò",
    "barn ngof"
  ],
  "Bản Xèo": [
    "bản xèo",
    "barn xefo"
  ],
  "Bảo Hoà": [
    "bảo hoà",
    "baro hoaf"
  ],
  "Bảo Khê": [
    "bảo khê",
    "baro khee"
  ],
  "Bảo Linh": [
    "bảo linh",
    "baro linh"
  ],
  "Bảo Lâm": [
    "bảo lâm",
    "baro laam"
  ],
  "Bảo Nhai": [
    "bảo nhai",
    "baro nhai"
  ],
  "Bảo Ninh": [
    "bảo ninh",
    "baro ninh"
  ],
  "Bảo Sơn": [
    "bảo sơn",
    "baro sown"
  ],
  "Bảo Vinh": [
    "bảo vinh",
    "baro vinh"
  ],
  "Bảo Yên": [
    "bảo yên",
    "baro yeen"
  ],
  "Bắc Hòa": [
    "bắc hòa",
    "bawsc hofa"
  ],
  "Bắc Ninh": [
    "bắc ninh",
    "bawsc ninh"
  ],
  "Bắc Phú": [
    "bắc phú",
    "bawsc phus"
  ],
  "Bắc Sơn": [
    "bắc sơn",
    "bawsc sown"
  ],
  "Bắc Yên": [
    "bắc yên",
    "bawsc yeen"
  ],
  "Bến Cát": [
    "bến cát",
    "beesn cast"
  ],
  "Bến Gót": [
    "bến gót",
    "beesn gost"
  ],
  "Bến Quan": [
    "bến quan",
    "beesn quan"
  ],
  "Bến Sung": [
    "bến sung",
    "beesn sung"
  ],
  "Bỉm Sơn": [
    "bỉm sơn",
    "birm sown"
  ],
  "Bồ Đề": [
    "bồ đề",
    "boof ddeef"
  ],
  "Bồi Sơn": [
    "bồi sơn",
    "boofi sown"
  ],
  "Bồng Lai": [
    "bồng lai",
    "boofng lai"
  ],
  "Bộc Bố": [
    "bộc bố",
    "boojc boos"
  ],
  "Bửu Hòa": [
    "bửu hòa",
    "buwru hofa"
  ],
  "Bửu Long": [
    "bửu long",
    "buwru long"
  ],
  "Cam An Nam": [
    "cam an nam",
    "cam an nam"
  ],
  "Cam Chính": [
    "cam chính",
    "cam chisnh"
  ],
  "Cam Hiếu": [
    "cam hiếu",
    "cam hieesu"
  ],
  "Cam Nghĩa": [
    "cam nghĩa",
    "cam nghixa"
  ],
  "Cam Thành": [
    "cam thành",
    "cam thafnh"
  ],
  "Cam Thủy": [
    "cam thủy",
    "cam thury"
  ],
  "Cam Đức": [
    "cam đức",
    "cam dduwsc"
  ],
  "Canh Liên": [
    "canh liên",
    "canh lieen"
  ],
  "Canh Nậu": [
    "canh nậu",
    "canh naaju"
  ],
  "Cao Bằng": [
    "cao bằng",
    "cao bawfng"
  ],
  "Cao Ngạn": [
    "cao ngạn",
    "cao ngajn"
  ],
  "Cao Ngọc": [
    "cao ngọc",
    "cao ngojc"
  ],
  "Cao Thành": [
    "cao thành",
    "cao thafnh"
  ],
  "Cao Thăng": [
    "cao thăng",
    "cao thawng"
  ],
  "Cao Đại": [
    "cao đại",
    "cao ddaji"
  ],
  "Cao Đức": [
    "cao đức",
    "cao dduwsc"
  ],
  "Chi Đông": [
    "chi đông",
    "chi ddoong"
  ],
  "Chiêu Vũ": [
    "chiêu vũ",
    "chieeu vux"
  ],
  "Chân Sơn": [
    "chân sơn",
    "chaan sown"
  ],
  "Châu Hòa": [
    "châu hòa",
    "chaau hofa"
  ],
  "Châu Hóa": [
    "châu hóa",
    "chaau hosa"
  ],
  "Châu Khê": [
    "châu khê",
    "chaau khee"
  ],
  "Châu Minh": [
    "châu minh",
    "chaau minh"
  ],
  "Châu Phú": [
    "châu phú",
    "chaau phus"
  ],
  "Châu Sơn": [
    "châu sơn",
    "chaau sown"
  ],
  "Chí Công": [
    "chí công",
    "chis coong"
  ],
  "Chí Tiên": [
    "chí tiên",
    "chis tieen"
  ],
  "Chí Đám": [
    "chí đám",
    "chis ddasm"
  ],
  "Chính Lý": [
    "chính lý",
    "chisnh lys"
  ],
  "Chùa Hang": [
    "chùa hang",
    "chufa hang"
  ],
  "Chúc Sơn": [
    "chúc sơn",
    "chusc sown"
  ],
  "Chăn Nưa": [
    "chăn nưa",
    "chawn nuwa"
  ],
  "Chư Hreng": [
    "chư hreng",
    "chuw hreng"
  ],
  "Chư Krêy": [
    "chư krêy",
    "chuw kreey"
  ],
  "Chư Pơng": [
    "chư pơng",
    "chuw powng"
  ],
  "Chư Rcăm": [
    "chư rcăm",
    "chuw rcawm"
  ],
  "Chư Răng": [
    "chư răng",
    "chuw rawng"
  ],
  "Chợ Vàm": [
    "chợ vàm",
    "chowj vafm"
  ],
  "Con Cuông": [
    "con cuông",
    "con cuoong"
  ],
  "Cuôr KNia": [
    "cuôr knia",
    "cuoor knia"
  ],
  "Càng Long": [
    "càng long",
    "cafng long"
  ],
  "Cách Linh": [
    "cách linh",
    "casch linh"
  ],
  "Cái Dầu": [
    "cái dầu",
    "casi daafu"
  ],
  "Cái Khế": [
    "cái khế",
    "casi khees"
  ],
  "Cái Răng": [
    "cái răng",
    "casi rawng"
  ],
  "Cái Tắc": [
    "cái tắc",
    "casi tawsc"
  ],
  "Cái Vồn": [
    "cái vồn",
    "casi voofn"
  ],
  "Cán Cấu": [
    "cán cấu",
    "casn caasu"
  ],
  "Cát Hưng": [
    "cát hưng",
    "cast huwng"
  ],
  "Cát Hải": [
    "cát hải",
    "cast hari"
  ],
  "Cát Nhơn": [
    "cát nhơn",
    "cast nhown"
  ],
  "Cát Quế": [
    "cát quế",
    "cast quees"
  ],
  "Cát Tiên": [
    "cát tiên",
    "cast tieen"
  ],
  "Cát Trinh": [
    "cát trinh",
    "cast trinh"
  ],
  "Cây Thị": [
    "cây thị",
    "caay thij"
  ],
  "Công Sơn": [
    "công sơn",
    "coong sown"
  ],
  "Cư A Mung": [
    "cư a mung",
    "cuw a mung"
  ],
  "Cư K Róa": [
    "cư k róa",
    "cuw k rosa"
  ],
  "Cư Klông": [
    "cư klông",
    "cuw kloong"
  ],
  "Cư Prông": [
    "cư prông",
    "cuw proong"
  ],
  "Cải Đan": [
    "cải đan",
    "cari ddan"
  ],
  "Cấm Sơn": [
    "cấm sơn",
    "caasm sown"
  ],
  "Cần Thơ": [
    "cần thơ",
    "caafn thow"
  ],
  "Cần Yên": [
    "cần yên",
    "caafn yeen"
  ],
  "Cầu Mây": [
    "cầu mây",
    "caafu maay"
  ],
  "Cầu Quan": [
    "cầu quan",
    "caafu quan"
  ],
  "Cầu Thia": [
    "cầu thia",
    "caafu thia"
  ],
  "Cẩm Khê": [
    "cẩm khê",
    "caarm khee"
  ],
  "Cẩm Long": [
    "cẩm long",
    "caarm long"
  ],
  "Cẩm Lệ": [
    "cẩm lệ",
    "caarm leej"
  ],
  "Cẩm Minh": [
    "cẩm minh",
    "caarm minh"
  ],
  "Cẩm Mỹ": [
    "cẩm mỹ",
    "caarm myx"
  ],
  "Cẩm Ninh": [
    "cẩm ninh",
    "caarm ninh"
  ],
  "Cẩm Phô": [
    "cẩm phô",
    "caarm phoo"
  ],
  "Cẩm Phú": [
    "cẩm phú",
    "caarm phus"
  ],
  "Cẩm Quan": [
    "cẩm quan",
    "caarm quan"
  ],
  "Cẩm Quý": [
    "cẩm quý",
    "caarm quys"
  ],
  "Cẩm Sơn": [
    "cẩm sơn",
    "caarm sown"
  ],
  "Cẩm Tâm": [
    "cẩm tâm",
    "caarm taam"
  ],
  "Cẩm Tân": [
    "cẩm tân",
    "caarm taan"
  ],
  "Cẩm Tây": [
    "cẩm tây",
    "caarm taay"
  ],
  "Cẩm Vân": [
    "cẩm vân",
    "caarm vaan"
  ],
  "Cẩm Văn": [
    "cẩm văn",
    "caarm vawn"
  ],
  "Cẩm Yên": [
    "cẩm yên",
    "caarm yeen"
  ],
  "Cốc Mỳ": [
    "cốc mỳ",
    "coosc myf"
  ],
  "Cốc Pài": [
    "cốc pài",
    "coosc pafi"
  ],
  "Cốc Rế": [
    "cốc rế",
    "coosc rees"
  ],
  "Cồn Cỏ": [
    "cồn cỏ",
    "coofn cor"
  ],
  "Cồn Thoi": [
    "cồn thoi",
    "coofn thoi"
  ],
  "Cổ Dũng": [
    "cổ dũng",
    "coor duxng"
  ],
  "Cổ Lũng": [
    "cổ lũng",
    "coor luxng"
  ],
  "Cổ Phúc": [
    "cổ phúc",
    "coor phusc"
  ],
  "Cờ Đỏ": [
    "cờ đỏ",
    "cowf ddor"
  ],
  "Cửa Ông": [
    "cửa ông",
    "cuwra oong"
  ],
  "Cự Nẫm": [
    "cự nẫm",
    "cuwj naaxm"
  ],
  "Di Trạch": [
    "di trạch",
    "di trajch"
  ],
  "Diên Hòa": [
    "diên hòa",
    "dieen hofa"
  ],
  "Diên Lâm": [
    "diên lâm",
    "dieen laam"
  ],
  "Diên Lãm": [
    "diên lãm",
    "dieen laxm"
  ],
  "Diên Phú": [
    "diên phú",
    "dieen phus"
  ],
  "Diên Sanh": [
    "diên sanh",
    "dieen sanh"
  ],
  "Diên Sơn": [
    "diên sơn",
    "dieen sown"
  ],
  "Diên Tân": [
    "diên tân",
    "dieen taan"
  ],
  "Diêu Trì": [
    "diêu trì",
    "dieeu trif"
  ],
  "Diễn Hoa": [
    "diễn hoa",
    "dieexn hoa"
  ],
  "Diễn Kim": [
    "diễn kim",
    "dieexn kim"
  ],
  "Dliê Yang": [
    "dliê yang",
    "dliee yang"
  ],
  "Duy Nghĩa": [
    "duy nghĩa",
    "duy nghixa"
  ],
  "Duy Nhất": [
    "duy nhất",
    "duy nhaast"
  ],
  "Duy Phiên": [
    "duy phiên",
    "duy phieen"
  ],
  "Duy Thành": [
    "duy thành",
    "duy thafnh"
  ],
  "Duy Xuyên": [
    "duy xuyên",
    "duy xuyeen"
  ],
  "Duyên Hà": [
    "duyên hà",
    "duyeen haf"
  ],
  "Dân Chủ": [
    "dân chủ",
    "daan chur"
  ],
  "Dân Lực": [
    "dân lực",
    "daan luwjc"
  ],
  "Dĩnh Kế": [
    "dĩnh kế",
    "dixnh kees"
  ],
  "Dĩnh Trì": [
    "dĩnh trì",
    "dixnh trif"
  ],
  "Dị Chế": [
    "dị chế",
    "dij chees"
  ],
  "Dị Nậu": [
    "dị nậu",
    "dij naaju"
  ],
  "Dồm Cang": [
    "dồm cang",
    "doofm cang"
  ],
  "Dữu Lâu": [
    "dữu lâu",
    "duwxu laau"
  ],
  "Dực Yên": [
    "dực yên",
    "duwjc yeen"
  ],
  "Ea D'Rơng": [
    "ea d'rơng",
    "ea d'rowng"
  ],
  "Ea H'đinh": [
    "ea h'đinh",
    "ea h'ddinh"
  ],
  "Ea M' Doal": [
    "ea m' doal",
    "ea m' doal"
  ],
  "Ea M'DRóh": [
    "ea m'dróh",
    "ea m'drosh"
  ],
  "Gia Hiệp": [
    "gia hiệp",
    "gia hieejp"
  ],
  "Gia Hòa 1": [
    "gia hòa 1",
    "gia hofa 1"
  ],
  "Gia Hòa 2": [
    "gia hòa 2",
    "gia hofa 2"
  ],
  "Gia Khánh": [
    "gia khánh",
    "gia khasnh"
  ],
  "Gia Kiệm": [
    "gia kiệm",
    "gia kieejm"
  ],
  "Gia Luận": [
    "gia luận",
    "gia luaajn"
  ],
  "Gia Miễn": [
    "gia miễn",
    "gia mieexn"
  ],
  "Gia Nghĩa": [
    "gia nghĩa",
    "gia nghixa"
  ],
  "Gia Thụy": [
    "gia thụy",
    "gia thujy"
  ],
  "Gia Thủy": [
    "gia thủy",
    "gia thury"
  ],
  "Gia Tiến": [
    "gia tiến",
    "gia tieesn"
  ],
  "Gia Trấn": [
    "gia trấn",
    "gia traasn"
  ],
  "Gia Tân 1": [
    "gia tân 1",
    "gia taan 1"
  ],
  "Gia Tân 2": [
    "gia tân 2",
    "gia taan 2"
  ],
  "Gia Tân 3": [
    "gia tân 3",
    "gia taan 3"
  ],
  "Gia Viễn": [
    "gia viễn",
    "gia vieexn"
  ],
  "Gia Xuyên": [
    "gia xuyên",
    "gia xuyeen"
  ],
  "Gia Đông": [
    "gia đông",
    "gia ddoong"
  ],
  "Gia Đức": [
    "gia đức",
    "gia dduwsc"
  ],
  "Giai Xuân": [
    "giai xuân",
    "giai xuaan"
  ],
  "Giang Sơn": [
    "giang sơn",
    "giang sown"
  ],
  "Giao Châu": [
    "giao châu",
    "giao chaau"
  ],
  "Giao Hải": [
    "giao hải",
    "giao hari"
  ],
  "Giao Lạc": [
    "giao lạc",
    "giao lajc"
  ],
  "Giao Nhân": [
    "giao nhân",
    "giao nhaan"
  ],
  "Giao Phong": [
    "giao phong",
    "giao phong"
  ],
  "Giao Thanh": [
    "giao thanh",
    "giao thanh"
  ],
  "Giao Xuân": [
    "giao xuân",
    "giao xuaan"
  ],
  "Giao Yến": [
    "giao yến",
    "giao yeesn"
  ],
  "Gio Việt": [
    "gio việt",
    "gio vieejt"
  ],
  "Giáp Bát": [
    "giáp bát",
    "giasp bast"
  ],
  "Giáp Sơn": [
    "giáp sơn",
    "giasp sown"
  ],
  "Gành Hào": [
    "gành hào",
    "gafnh hafo"
  ],
  "Hai Riêng": [
    "hai riêng",
    "hai rieeng"
  ],
  "Hiên Vân": [
    "hiên vân",
    "hieen vaan"
  ],
  "Hiến Nam": [
    "hiến nam",
    "hieesn nam"
  ],
  "Hoa Thành": [
    "hoa thành",
    "hoa thafnh"
  ],
  "Hoa Thủy": [
    "hoa thủy",
    "hoa thury"
  ],
  "Hoà Bình": [
    "hoà bình",
    "hoaf bifnh"
  ],
  "Hoà Chung": [
    "hoà chung",
    "hoaf chung"
  ],
  "Hoà Hải": [
    "hoà hải",
    "hoaf hari"
  ],
  "Hoà Lạc": [
    "hoà lạc",
    "hoaf lajc"
  ],
  "Hoà Lộc": [
    "hoà lộc",
    "hoaf loojc"
  ],
  "Hoà Lợi": [
    "hoà lợi",
    "hoaf lowji"
  ],
  "Hoà Mạc": [
    "hoà mạc",
    "hoaf majc"
  ],
  "Hoà Mục": [
    "hoà mục",
    "hoaf mujc"
  ],
  "Hoài Mỹ": [
    "hoài mỹ",
    "hoafi myx"
  ],
  "Hoài Phú": [
    "hoài phú",
    "hoafi phus"
  ],
  "Hoài Sơn": [
    "hoài sơn",
    "hoafi sown"
  ],
  "Hoài Tân": [
    "hoài tân",
    "hoafi taan"
  ],
  "Hoàn Long": [
    "hoàn long",
    "hoafn long"
  ],
  "Hoàn Lão": [
    "hoàn lão",
    "hoafn laxo"
  ],
  "Hoàn Sơn": [
    "hoàn sơn",
    "hoafn sown"
  ],
  "Hoàng Hoa": [
    "hoàng hoa",
    "hoafng hoa"
  ],
  "Hoàng Kim": [
    "hoàng kim",
    "hoafng kim"
  ],
  "Hoàng Mai": [
    "hoàng mai",
    "hoafng mai"
  ],
  "Hoàng Nam": [
    "hoàng nam",
    "hoafng nam"
  ],
  "Hoàng Xá": [
    "hoàng xá",
    "hoafng xas"
  ],
  "Hoành Mô": [
    "hoành mô",
    "hoafnh moo"
  ],
  "Huy Khiêm": [
    "huy khiêm",
    "huy khieem"
  ],
  "Huổi Mí": [
    "huổi mí",
    "huoori mis"
  ],
  "Huổi Só": [
    "huổi só",
    "huoori sos"
  ],
  "Hy Cương": [
    "hy cương",
    "hy cuwowng"
  ],
  "Hà Hiệu": [
    "hà hiệu",
    "haf hieeju"
  ],
  "Hà Khánh": [
    "hà khánh",
    "haf khasnh"
  ],
  "Hà Khẩu": [
    "hà khẩu",
    "haf khaaru"
  ],
  "Hà Ngọc": [
    "hà ngọc",
    "haf ngojc"
  ],
  "Hà Tiến": [
    "hà tiến",
    "haf tieesn"
  ],
  "Hà Đông": [
    "hà đông",
    "haf ddoong"
  ],
  "Hàm Cần": [
    "hàm cần",
    "hafm caafn"
  ],
  "Hàm Giang": [
    "hàm giang",
    "hafm giang"
  ],
  "Hàm Liêm": [
    "hàm liêm",
    "hafm lieem"
  ],
  "Hàng Bài": [
    "hàng bài",
    "hafng bafi"
  ],
  "Hàng Bồ": [
    "hàng bồ",
    "hafng boof"
  ],
  "Hàng Gòn": [
    "hàng gòn",
    "hafng gofn"
  ],
  "Hành Minh": [
    "hành minh",
    "hafnh minh"
  ],
  "Háng Lìa": [
    "háng lìa",
    "hasng lifa"
  ],
  "Hòa Bình": [
    "hòa bình",
    "hofa bifnh"
  ],
  "Hòa Bắc": [
    "hòa bắc",
    "hofa bawsc"
  ],
  "Hòa Châu": [
    "hòa châu",
    "hofa chaau"
  ],
  "Hòa Hưng": [
    "hòa hưng",
    "hofa huwng"
  ],
  "Hòa Hải": [
    "hòa hải",
    "hofa hari"
  ],
  "Hòa Hậu": [
    "hòa hậu",
    "hofa haaju"
  ],
  "Hòa Hội": [
    "hòa hội",
    "hofa hooji"
  ],
  "Hòa Liên": [
    "hòa liên",
    "hofa lieen"
  ],
  "Hòa Lạc": [
    "hòa lạc",
    "hofa lajc"
  ],
  "Hòa Lộc": [
    "hòa lộc",
    "hofa loojc"
  ],
  "Hòa Lợi": [
    "hòa lợi",
    "hofa lowji"
  ],
  "Hòa Mạc": [
    "hòa mạc",
    "hofa majc"
  ],
  "Hòa Nhơn": [
    "hòa nhơn",
    "hofa nhown"
  ],
  "Hòa Phong": [
    "hòa phong",
    "hofa phong"
  ],
  "Hòa Phát": [
    "hòa phát",
    "hofa phast"
  ],
  "Hòa Trung": [
    "hòa trung",
    "hofa trung"
  ],
  "Hòa Trị": [
    "hòa trị",
    "hofa trij"
  ],
  "Hòa Tú 1": [
    "hòa tú 1",
    "hofa tus 1"
  ],
  "Hòa Xuân": [
    "hòa xuân",
    "hofa xuaan"
  ],
  "Hòn Thơm": [
    "hòn thơm",
    "hofn thowm"
  ],
  "Hóa Hợp": [
    "hóa hợp",
    "hosa howjp"
  ],
  "Hóa Phúc": [
    "hóa phúc",
    "hosa phusc"
  ],
  "Hóa Quỳ": [
    "hóa quỳ",
    "hosa quyf"
  ],
  "Hóa Thanh": [
    "hóa thanh",
    "hosa thanh"
  ],
  "Hóa Trung": [
    "hóa trung",
    "hosa trung"
  ],
  "Hùng Hòa": [
    "hùng hòa",
    "hufng hofa"
  ],
  "Hùng Long": [
    "hùng long",
    "hufng long"
  ],
  "Hùng Mỹ": [
    "hùng mỹ",
    "hufng myx"
  ],
  "Hùng Sơn": [
    "hùng sơn",
    "hufng sown"
  ],
  "Húc Nghì": [
    "húc nghì",
    "husc nghif"
  ],
  "Hưng Hoá": [
    "hưng hoá",
    "huwng hoas"
  ],
  "Hưng Hòa": [
    "hưng hòa",
    "huwng hofa"
  ],
  "Hưng Long": [
    "hưng long",
    "huwng long"
  ],
  "Hưng Lễ": [
    "hưng lễ",
    "huwng leex"
  ],
  "Hưng Mỹ": [
    "hưng mỹ",
    "huwng myx"
  ],
  "Hưng Phú": [
    "hưng phú",
    "huwng phus"
  ],
  "Hưng Trí": [
    "hưng trí",
    "huwng tris"
  ],
  "Hưng Tân": [
    "hưng tân",
    "huwng taan"
  ],
  "Hưng Tây": [
    "hưng tây",
    "huwng taay"
  ],
  "Hưng Yên": [
    "hưng yên",
    "huwng yeen"
  ],
  "Hương An": [
    "hương an",
    "huwowng an"
  ],
  "Hạ Giáp": [
    "hạ giáp",
    "haj giasp"
  ],
  "Hạ Trung": [
    "hạ trung",
    "haj trung"
  ],
  "Hải Hoà": [
    "hải hoà",
    "hari hoaf"
  ],
  "Hải Hòa": [
    "hải hòa",
    "hari hofa"
  ],
  "Hải Khê": [
    "hải khê",
    "hari khee"
  ],
  "Hải Long": [
    "hải long",
    "hari long"
  ],
  "Hải Lâm": [
    "hải lâm",
    "hari laam"
  ],
  "Hải Lệ": [
    "hải lệ",
    "hari leej"
  ],
  "Hải Minh": [
    "hải minh",
    "hari minh"
  ],
  "Hải Ninh": [
    "hải ninh",
    "hari ninh"
  ],
  "Hải Phú": [
    "hải phú",
    "hari phus"
  ],
  "Hải Sơn": [
    "hải sơn",
    "hari sown"
  ],
  "Hải Tân": [
    "hải tân",
    "hari taan"
  ],
  "Hải Tây": [
    "hải tây",
    "hari taay"
  ],
  "Hải Vân": [
    "hải vân",
    "hari vaan"
  ],
  "Hải Yang": [
    "hải yang",
    "hari yang"
  ],
  "Hải Yên": [
    "hải yên",
    "hari yeen"
  ],
  "Hố Nai 3": [
    "hố nai 3",
    "hoos nai 3"
  ],
  "Hồ Bốn": [
    "hồ bốn",
    "hoof boosn"
  ],
  "Hồi Ninh": [
    "hồi ninh",
    "hoofi ninh"
  ],
  "Hồng Gai": [
    "hồng gai",
    "hoofng gai"
  ],
  "Hồng Hà": [
    "hồng hà",
    "hoofng haf"
  ],
  "Hồng Kim": [
    "hồng kim",
    "hoofng kim"
  ],
  "Hồng Lý": [
    "hồng lý",
    "hoofng lys"
  ],
  "Hồng Nam": [
    "hồng nam",
    "hoofng nam"
  ],
  "Hồng Thu": [
    "hồng thu",
    "hoofng thu"
  ],
  "Hộ Hải": [
    "hộ hải",
    "hooj hari"
  ],
  "Hộ Đáp": [
    "hộ đáp",
    "hooj ddasp"
  ],
  "Hộ Độ": [
    "hộ độ",
    "hooj ddooj"
  ],
  "Hội Hoan": [
    "hội hoan",
    "hooji hoan"
  ],
  "Hội Phú": [
    "hội phú",
    "hooji phus"
  ],
  "Hội Sơn": [
    "hội sơn",
    "hooji sown"
  ],
  "Hợp Hòa": [
    "hợp hòa",
    "howjp hofa"
  ],
  "Hợp Minh": [
    "hợp minh",
    "howjp minh"
  ],
  "Hữu Hoà": [
    "hữu hoà",
    "huwxu hoaf"
  ],
  "Hữu Lân": [
    "hữu lân",
    "huwxu laan"
  ],
  "Hữu Lễ": [
    "hữu lễ",
    "huwxu leex"
  ],
  "Hữu Vinh": [
    "hữu vinh",
    "huwxu vinh"
  ],
  "Hữu Văn": [
    "hữu văn",
    "huwxu vawn"
  ],
  "Ia H' Drai": [
    "ia h' drai",
    "ia h' drai"
  ],
  "Ia Khươl": [
    "ia khươl",
    "ia khuwowl"
  ],
  "Ia Kriêng": [
    "ia kriêng",
    "ia krieeng"
  ],
  "Ia Ma Rơn": [
    "ia ma rơn",
    "ia ma rown"
  ],
  "Ia RSươm": [
    "ia rsươm",
    "ia rsuwowm"
  ],
  "Khai Quang": [
    "khai quang",
    "khai quang"
  ],
  "Khai Thái": [
    "khai thái",
    "khai thasi"
  ],
  "Khai Trung": [
    "khai trung",
    "khai trung"
  ],
  "Khang Ninh": [
    "khang ninh",
    "khang ninh"
  ],
  "Khoan Dụ": [
    "khoan dụ",
    "khoan duj"
  ],
  "Khuê Mỹ": [
    "khuê mỹ",
    "khuee myx"
  ],
  "Khuôn Hà": [
    "khuôn hà",
    "khuoon haf"
  ],
  "Khánh Cư": [
    "khánh cư",
    "khasnh cuw"
  ],
  "Khánh Hà": [
    "khánh hà",
    "khasnh haf"
  ],
  "Khánh Nam": [
    "khánh nam",
    "khasnh nam"
  ],
  "Khôi Kỳ": [
    "khôi kỳ",
    "khooi kyf"
  ],
  "Kim Bảng": [
    "kim bảng",
    "kim barng"
  ],
  "Kim Chính": [
    "kim chính",
    "kim chisnh"
  ],
  "Kim Ngọc": [
    "kim ngọc",
    "kim ngojc"
  ],
  "Kim Thành": [
    "kim thành",
    "kim thafnh"
  ],
  "Kim Thủy": [
    "kim thủy",
    "kim thury"
  ],
  "Kim Xuyên": [
    "kim xuyên",
    "kim xuyeen"
  ],
  "Kim Đính": [
    "kim đính",
    "kim ddisnh"
  ],
  "Kim Đông": [
    "kim đông",
    "kim ddoong"
  ],
  "Kim Đức": [
    "kim đức",
    "kim dduwsc"
  ],
  "Kinh Bắc": [
    "kinh bắc",
    "kinh bawsc"
  ],
  "Kinh Cùng": [
    "kinh cùng",
    "kinh cufng"
  ],
  "Kiêu Kỵ": [
    "kiêu kỵ",
    "kieeu kyj"
  ],
  "Kon Plông": [
    "kon plông",
    "kon ploong"
  ],
  "Kon Thụp": [
    "kon thụp",
    "kon thujp"
  ],
  "Krông Nô": [
    "krông nô",
    "kroong noo"
  ],
  "Kông Chro": [
    "kông chro",
    "koong chro"
  ],
  "Kông HTok": [
    "kông htok",
    "koong htok"
  ],
  "Kông Yang": [
    "kông yang",
    "koong yang"
  ],
  "Kẻ Sặt": [
    "kẻ sặt",
    "ker sawjt"
  ],
  "Kế Sách": [
    "kế sách",
    "kees sasch"
  ],
  "Kỳ Bắc": [
    "kỳ bắc",
    "kyf bawsc"
  ],
  "Kỳ Châu": [
    "kỳ châu",
    "kyf chaau"
  ],
  "Kỳ Giang": [
    "kỳ giang",
    "kyf giang"
  ],
  "Kỳ Hải": [
    "kỳ hải",
    "kyf hari"
  ],
  "Kỳ Khang": [
    "kỳ khang",
    "kyf khang"
  ],
  "Kỳ Liên": [
    "kỳ liên",
    "kyf lieen"
  ],
  "Kỳ Lạc": [
    "kỳ lạc",
    "kyf lajc"
  ],
  "Kỳ Lợi": [
    "kỳ lợi",
    "kyf lowji"
  ],
  "Kỳ Phong": [
    "kỳ phong",
    "kyf phong"
  ],
  "Kỳ Thọ": [
    "kỳ thọ",
    "kyf thoj"
  ],
  "Kỳ Trinh": [
    "kỳ trinh",
    "kyf trinh"
  ],
  "Kỳ Trung": [
    "kỳ trung",
    "kyf trung"
  ],
  "Kỳ Xuân": [
    "kỳ xuân",
    "kyf xuaan"
  ],
  "Lai Thành": [
    "lai thành",
    "lai thafnh"
  ],
  "Lan Giới": [
    "lan giới",
    "lan giowsi"
  ],
  "Lang Quán": [
    "lang quán",
    "lang quasn"
  ],
  "Lang Thíp": [
    "lang thíp",
    "lang thisp"
  ],
  "Lao Chải": [
    "lao chải",
    "lao chari"
  ],
  "Linh Hải": [
    "linh hải",
    "linh hari"
  ],
  "Linh Trung": [
    "linh trung",
    "linh trung"
  ],
  "Linh Xuân": [
    "linh xuân",
    "linh xuaan"
  ],
  "Liêm Phú": [
    "liêm phú",
    "lieem phus"
  ],
  "Liêm Sơn": [
    "liêm sơn",
    "lieem sown"
  ],
  "Liêm Túc": [
    "liêm túc",
    "lieem tusc"
  ],
  "Liên Bão": [
    "liên bão",
    "lieen baxo"
  ],
  "Liên Hoà": [
    "liên hoà",
    "lieen hoaf"
  ],
  "Liên Hòa": [
    "liên hòa",
    "lieen hofa"
  ],
  "Liên Khê": [
    "liên khê",
    "lieen khee"
  ],
  "Liên Minh": [
    "liên minh",
    "lieen minh"
  ],
  "Liên Ninh": [
    "liên ninh",
    "lieen ninh"
  ],
  "Liên Quan": [
    "liên quan",
    "lieen quan"
  ],
  "Liên Sang": [
    "liên sang",
    "lieen sang"
  ],
  "Liên Sơn": [
    "liên sơn",
    "lieen sown"
  ],
  "Liên Vị": [
    "liên vị",
    "lieen vij"
  ],
  "Liệp Tè": [
    "liệp tè",
    "lieejp tef"
  ],
  "Long Biên": [
    "long biên",
    "long bieen"
  ],
  "Long Bình": [
    "long bình",
    "long bifnh"
  ],
  "Long Châu": [
    "long châu",
    "long chaau"
  ],
  "Long Chữ": [
    "long chữ",
    "long chuwx"
  ],
  "Long Cốc": [
    "long cốc",
    "long coosc"
  ],
  "Long Giang": [
    "long giang",
    "long giang"
  ],
  "Long Hưng": [
    "long hưng",
    "long huwng"
  ],
  "Long Hải": [
    "long hải",
    "long hari"
  ],
  "Long Hậu": [
    "long hậu",
    "long haaju"
  ],
  "Long Hữu": [
    "long hữu",
    "long huwxu"
  ],
  "Long Thọ": [
    "long thọ",
    "long thoj"
  ],
  "Long Tiên": [
    "long tiên",
    "long tieen"
  ],
  "Long Toàn": [
    "long toàn",
    "long toafn"
  ],
  "Long Trung": [
    "long trung",
    "long trung"
  ],
  "Long Trị": [
    "long trị",
    "long trij"
  ],
  "Long Vĩnh": [
    "long vĩnh",
    "long vixnh"
  ],
  "Làng Nhì": [
    "làng nhì",
    "lafng nhif"
  ],
  "Láng Dài": [
    "láng dài",
    "lasng dafi"
  ],
  "Láng Hạ": [
    "láng hạ",
    "lasng haj"
  ],
  "Lâm Bình": [
    "lâm bình",
    "laam bifnh"
  ],
  "Lâm Giang": [
    "lâm giang",
    "laam giang"
  ],
  "Lâm Hải": [
    "lâm hải",
    "laam hari"
  ],
  "Lâm Hợp": [
    "lâm hợp",
    "laam howjp"
  ],
  "Lãng Sơn": [
    "lãng sơn",
    "laxng sown"
  ],
  "Lê Chánh": [
    "lê chánh",
    "lee chasnh"
  ],
  "Lê Hồng": [
    "lê hồng",
    "lee hoofng"
  ],
  "Lùng Tám": [
    "lùng tám",
    "lufng tasm"
  ],
  "Lý Quốc": [
    "lý quốc",
    "lys quoosc"
  ],
  "Lý Thành": [
    "lý thành",
    "lys thafnh"
  ],
  "Lĩnh Sơn": [
    "lĩnh sơn",
    "lixnh sown"
  ],
  "Lũng Hoà": [
    "lũng hoà",
    "luxng hoaf"
  ],
  "Lũng Hồ": [
    "lũng hồ",
    "luxng hoof"
  ],
  "Lũng Táo": [
    "lũng táo",
    "luxng taso"
  ],
  "Lạc Hòa": [
    "lạc hòa",
    "lajc hofa"
  ],
  "Lạc Long": [
    "lạc long",
    "lajc long"
  ],
  "Lạc Lâm": [
    "lạc lâm",
    "lajc laam"
  ],
  "Lạc Sơn": [
    "lạc sơn",
    "lajc sown"
  ],
  "Lạc Sỹ": [
    "lạc sỹ",
    "lajc syx"
  ],
  "Lạc Vân": [
    "lạc vân",
    "lajc vaan"
  ],
  "Lạc Vệ": [
    "lạc vệ",
    "lajc veej"
  ],
  "Lại Sơn": [
    "lại sơn",
    "laji sown"
  ],
  "Lại Yên": [
    "lại yên",
    "laji yeen"
  ],
  "Lập Lễ": [
    "lập lễ",
    "laajp leex"
  ],
  "Lộc Hòa": [
    "lộc hòa",
    "loojc hofa"
  ],
  "Lộc Hạ": [
    "lộc hạ",
    "loojc haj"
  ],
  "Lộc Lâm": [
    "lộc lâm",
    "loojc laam"
  ],
  "Lộc Ninh": [
    "lộc ninh",
    "loojc ninh"
  ],
  "Lộc Phú": [
    "lộc phú",
    "loojc phus"
  ],
  "Lộc Sơn": [
    "lộc sơn",
    "loojc sown"
  ],
  "Lộc Trì": [
    "lộc trì",
    "loojc trif"
  ],
  "Lộc Tân": [
    "lộc tân",
    "loojc taan"
  ],
  "Lộc Yên": [
    "lộc yên",
    "loojc yeen"
  ],
  "Lợi Bác": [
    "lợi bác",
    "lowji basc"
  ],
  "Lục Dạ": [
    "lục dạ",
    "lujc daj"
  ],
  "Lục Sơn": [
    "lục sơn",
    "lujc sown"
  ],
  "Lục Yên": [
    "lục yên",
    "lujc yeen"
  ],
  "Mai Dịch": [
    "mai dịch",
    "mai dijch"
  ],
  "Mai Hịch": [
    "mai hịch",
    "mai hijch"
  ],
  "Mai Thủy": [
    "mai thủy",
    "mai thury"
  ],
  "Mai Đình": [
    "mai đình",
    "mai ddifnh"
  ],
  "Mang Thít": [
    "mang thít",
    "mang thist"
  ],
  "Minh Bảo": [
    "minh bảo",
    "minh baro"
  ],
  "Minh Châu": [
    "minh châu",
    "minh chaau"
  ],
  "Minh Cầm": [
    "minh cầm",
    "minh caafm"
  ],
  "Minh Hưng": [
    "minh hưng",
    "minh huwng"
  ],
  "Minh Hạc": [
    "minh hạc",
    "minh hajc"
  ],
  "Minh Hải": [
    "minh hải",
    "minh hari"
  ],
  "Minh Hợp": [
    "minh hợp",
    "minh howjp"
  ],
  "Minh Khôi": [
    "minh khôi",
    "minh khooi"
  ],
  "Minh Lãng": [
    "minh lãng",
    "minh laxng"
  ],
  "Minh Lập": [
    "minh lập",
    "minh laajp"
  ],
  "Minh Lộc": [
    "minh lộc",
    "minh loojc"
  ],
  "Minh Nông": [
    "minh nông",
    "minh noong"
  ],
  "Minh Quang": [
    "minh quang",
    "minh quang"
  ],
  "Minh Quán": [
    "minh quán",
    "minh quasn"
  ],
  "Minh Quân": [
    "minh quân",
    "minh quaan"
  ],
  "Minh Thanh": [
    "minh thanh",
    "minh thanh"
  ],
  "Minh Xuân": [
    "minh xuân",
    "minh xuaan"
  ],
  "Minh Đài": [
    "minh đài",
    "minh ddafi"
  ],
  "Mong Thọ": [
    "mong thọ",
    "mong thoj"
  ],
  "Mái Dầm": [
    "mái dầm",
    "masi daafm"
  ],
  "Mân Thái": [
    "mân thái",
    "maan thasi"
  ],
  "Mã Thành": [
    "mã thành",
    "max thafnh"
  ],
  "Mèo Vạc": [
    "mèo vạc",
    "mefo vajc"
  ],
  "Móng Cái": [
    "móng cái",
    "mosng casi"
  ],
  "Mông Hóa": [
    "mông hóa",
    "moong hosa"
  ],
  "Mông Sơn": [
    "mông sơn",
    "moong sown"
  ],
  "Mùn Chung": [
    "mùn chung",
    "mufn chung"
  ],
  "Măng Tố": [
    "măng tố",
    "mawng toos"
  ],
  "Măng Đen": [
    "măng đen",
    "mawng dden"
  ],
  "Mạo Khê": [
    "mạo khê",
    "majo khee"
  ],
  "Mẫu Sơn": [
    "mẫu sơn",
    "maaxu sown"
  ],
  "Mậu Long": [
    "mậu long",
    "maaju long"
  ],
  "Mậu Lâm": [
    "mậu lâm",
    "maaju laam"
  ],
  "Mỏ Công": [
    "mỏ công",
    "mor coong"
  ],
  "Mỏ Vàng": [
    "mỏ vàng",
    "mor vafng"
  ],
  "Mộc Hóa": [
    "mộc hóa",
    "moojc hosa"
  ],
  "Mỹ Bình": [
    "mỹ bình",
    "myx bifnh"
  ],
  "Mỹ Châu": [
    "mỹ châu",
    "myx chaau"
  ],
  "Mỹ Cẩm": [
    "mỹ cẩm",
    "myx caarm"
  ],
  "Mỹ Hưng": [
    "mỹ hưng",
    "myx huwng"
  ],
  "Mỹ Hải": [
    "mỹ hải",
    "myx hari"
  ],
  "Mỹ Hội": [
    "mỹ hội",
    "myx hooji"
  ],
  "Mỹ Lạc": [
    "mỹ lạc",
    "myx lajc"
  ],
  "Mỹ Lộc": [
    "mỹ lộc",
    "myx loojc"
  ],
  "Mỹ Lợi": [
    "mỹ lợi",
    "myx lowji"
  ],
  "Mỹ Ngãi": [
    "mỹ ngãi",
    "myx ngaxi"
  ],
  "Mỹ Nhơn": [
    "mỹ nhơn",
    "myx nhown"
  ],
  "Mỹ Phong": [
    "mỹ phong",
    "myx phong"
  ],
  "Mỹ Phúc": [
    "mỹ phúc",
    "myx phusc"
  ],
  "Mỹ Quang": [
    "mỹ quang",
    "myx quang"
  ],
  "Mỹ Thanh": [
    "mỹ thanh",
    "myx thanh"
  ],
  "Mỹ Thái": [
    "mỹ thái",
    "myx thasi"
  ],
  "Mỹ Thọ": [
    "mỹ thọ",
    "myx thoj"
  ],
  "Mỹ Trinh": [
    "mỹ trinh",
    "myx trinh"
  ],
  "Mỹ Trung": [
    "mỹ trung",
    "myx trung"
  ],
  "Mỹ Xuân": [
    "mỹ xuân",
    "myx xuaan"
  ],
  "Mỹ Độ": [
    "mỹ độ",
    "myx ddooj"
  ],
  "Na Dương": [
    "na dương",
    "na duwowng"
  ],
  "Nam Chính": [
    "nam chính",
    "nam chisnh"
  ],
  "Nam Hồng": [
    "nam hồng",
    "nam hoofng"
  ],
  "Nam Nghĩa": [
    "nam nghĩa",
    "nam nghixa"
  ],
  "Nam Ngạn": [
    "nam ngạn",
    "nam ngajn"
  ],
  "Nam Thành": [
    "nam thành",
    "nam thafnh"
  ],
  "Nam Tiến": [
    "nam tiến",
    "nam tieesn"
  ],
  "Nam Trực": [
    "nam trực",
    "nam truwjc"
  ],
  "Nam Tuấn": [
    "nam tuấn",
    "nam tuaasn"
  ],
  "Nam Đông": [
    "nam đông",
    "nam ddoong"
  ],
  "Nga Bạch": [
    "nga bạch",
    "nga bajch"
  ],
  "Nga Hoàng": [
    "nga hoàng",
    "nga hoafng"
  ],
  "Nga Thành": [
    "nga thành",
    "nga thafnh"
  ],
  "Nga Thủy": [
    "nga thủy",
    "nga thury"
  ],
  "Nga Tiến": [
    "nga tiến",
    "nga tieesn"
  ],
  "Nga Vịnh": [
    "nga vịnh",
    "nga vijnh"
  ],
  "Ngan Dừa": [
    "ngan dừa",
    "ngan duwfa"
  ],
  "Nghi Diên": [
    "nghi diên",
    "nghi dieen"
  ],
  "Nghi Hưng": [
    "nghi hưng",
    "nghi huwng"
  ],
  "Nghi Hải": [
    "nghi hải",
    "nghi hari"
  ],
  "Nghi Liên": [
    "nghi liên",
    "nghi lieen"
  ],
  "Nghi Lộc": [
    "nghi lộc",
    "nghi loojc"
  ],
  "Nghi Phong": [
    "nghi phong",
    "nghi phong"
  ],
  "Nghi Quang": [
    "nghi quang",
    "nghi quang"
  ],
  "Nghi Thái": [
    "nghi thái",
    "nghi thasi"
  ],
  "Nghi Trung": [
    "nghi trung",
    "nghi trung"
  ],
  "Nghi Vạn": [
    "nghi vạn",
    "nghi vajn"
  ],
  "Nghi Xuân": [
    "nghi xuân",
    "nghi xuaan"
  ],
  "Nghĩa Hà": [
    "nghĩa hà",
    "nghixa haf"
  ],
  "Nghĩa Mai": [
    "nghĩa mai",
    "nghixa mai"
  ],
  "Nghĩa Tá": [
    "nghĩa tá",
    "nghixa tas"
  ],
  "Nghĩa Xá": [
    "nghĩa xá",
    "nghixa xas"
  ],
  "Ngân Sơn": [
    "ngân sơn",
    "ngaan sown"
  ],
  "Ngã Bảy": [
    "ngã bảy",
    "ngax bary"
  ],
  "Ngãi Giao": [
    "ngãi giao",
    "ngaxi giao"
  ],
  "Ngãi Tứ": [
    "ngãi tứ",
    "ngaxi tuws"
  ],
  "Ngũ Hùng": [
    "ngũ hùng",
    "ngux hufng"
  ],
  "Ngũ Kiên": [
    "ngũ kiên",
    "ngux kieen"
  ],
  "Ngũ Lạc": [
    "ngũ lạc",
    "ngux lajc"
  ],
  "Ngũ Phúc": [
    "ngũ phúc",
    "ngux phusc"
  ],
  "Ngũ Thái": [
    "ngũ thái",
    "ngux thasi"
  ],
  "Ngũ Đoan": [
    "ngũ đoan",
    "ngux ddoan"
  ],
  "Ngư Lộc": [
    "ngư lộc",
    "nguw loojc"
  ],
  "Ngọc Hà": [
    "ngọc hà",
    "ngojc haf"
  ],
  "Ngọc Lý": [
    "ngọc lý",
    "ngojc lys"
  ],
  "Ngọc Lũ": [
    "ngọc lũ",
    "ngojc lux"
  ],
  "Ngọc Xá": [
    "ngọc xá",
    "ngojc xas"
  ],
  "Ngọk Bay": [
    "ngọk bay",
    "ngojk bay"
  ],
  "Nhà Bàng": [
    "nhà bàng",
    "nhaf bafng"
  ],
  "Nhân Hoà": [
    "nhân hoà",
    "nhaan hoaf"
  ],
  "Nhân Hòa": [
    "nhân hòa",
    "nhaan hofa"
  ],
  "Nhân Mỹ": [
    "nhân mỹ",
    "nhaan myx"
  ],
  "Nhân Sơn": [
    "nhân sơn",
    "nhaan sown"
  ],
  "Nhơn Hoà": [
    "nhơn hoà",
    "nhown hoaf"
  ],
  "Nhơn Mỹ": [
    "nhơn mỹ",
    "nhown myx"
  ],
  "Nhơn Ninh": [
    "nhơn ninh",
    "nhown ninh"
  ],
  "Nhơn Phú": [
    "nhơn phú",
    "nhown phus"
  ],
  "Nhơn Sơn": [
    "nhơn sơn",
    "nhown sown"
  ],
  "Nhơn Tân": [
    "nhơn tân",
    "nhown taan"
  ],
  "Như Thanh": [
    "như thanh",
    "nhuw thanh"
  ],
  "Như Xuân": [
    "như xuân",
    "nhuw xuaan"
  ],
  "Nhị Khê": [
    "nhị khê",
    "nhij khee"
  ],
  "Nhị Long": [
    "nhị long",
    "nhij long"
  ],
  "Nhị Mỹ": [
    "nhị mỹ",
    "nhij myx"
  ],
  "Nhị Quý": [
    "nhị quý",
    "nhij quys"
  ],
  "Nhữ Hán": [
    "nhữ hán",
    "nhuwx hasn"
  ],
  "Nhữ Khê": [
    "nhữ khê",
    "nhuwx khee"
  ],
  "Ninh Bình": [
    "ninh bình",
    "ninh bifnh"
  ],
  "Ninh Diêm": [
    "ninh diêm",
    "ninh dieem"
  ],
  "Ninh Giang": [
    "ninh giang",
    "ninh giang"
  ],
  "Ninh Hưng": [
    "ninh hưng",
    "ninh huwng"
  ],
  "Ninh Hải": [
    "ninh hải",
    "ninh hari"
  ],
  "Ninh Khang": [
    "ninh khang",
    "ninh khang"
  ],
  "Ninh Lộc": [
    "ninh lộc",
    "ninh loojc"
  ],
  "Ninh Phong": [
    "ninh phong",
    "ninh phong"
  ],
  "Ninh Phúc": [
    "ninh phúc",
    "ninh phusc"
  ],
  "Ninh Quang": [
    "ninh quang",
    "ninh quang"
  ],
  "Ninh Thân": [
    "ninh thân",
    "ninh thaan"
  ],
  "Ninh Thọ": [
    "ninh thọ",
    "ninh thoj"
  ],
  "Ninh Trung": [
    "ninh trung",
    "ninh trung"
  ],
  "Ninh Xuân": [
    "ninh xuân",
    "ninh xuaan"
  ],
  "Niêm Sơn": [
    "niêm sơn",
    "nieem sown"
  ],
  "Nà Bủng": [
    "nà bủng",
    "naf burng"
  ],
  "Nà Nhạn": [
    "nà nhạn",
    "naf nhajn"
  ],
  "Nà Phặc": [
    "nà phặc",
    "naf phawjc"
  ],
  "Nàn Xỉn": [
    "nàn xỉn",
    "nafn xirn"
  ],
  "Nông Hạ": [
    "nông hạ",
    "noong haj"
  ],
  "Nông Sơn": [
    "nông sơn",
    "noong sown"
  ],
  "Núi Sập": [
    "núi sập",
    "nusi saajp"
  ],
  "Núi Đèo": [
    "núi đèo",
    "nusi ddefo"
  ],
  "Nậm Chua": [
    "nậm chua",
    "naajm chua"
  ],
  "Nậm Chà": [
    "nậm chà",
    "naajm chaf"
  ],
  "Nậm Càn": [
    "nậm càn",
    "naajm cafn"
  ],
  "Nậm Hăn": [
    "nậm hăn",
    "naajm hawn"
  ],
  "Nậm Khao": [
    "nậm khao",
    "naajm khao"
  ],
  "Nậm Lúc": [
    "nậm lúc",
    "naajm lusc"
  ],
  "Nậm Manh": [
    "nậm manh",
    "naajm manh"
  ],
  "Nậm Mòn": [
    "nậm mòn",
    "naajm mofn"
  ],
  "Nậm Mạ": [
    "nậm mạ",
    "naajm maj"
  ],
  "Nậm Mả": [
    "nậm mả",
    "naajm mar"
  ],
  "Nậm Nèn": [
    "nậm nèn",
    "naajm nefn"
  ],
  "Nậm Pung": [
    "nậm pung",
    "naajm pung"
  ],
  "Nậm Păm": [
    "nậm păm",
    "naajm pawm"
  ],
  "Nậm Pồ": [
    "nậm pồ",
    "naajm poof"
  ],
  "Nậm Sỏ": [
    "nậm sỏ",
    "naajm sor"
  ],
  "Nậm Tăm": [
    "nậm tăm",
    "naajm tawm"
  ],
  "Nậm Tỵ": [
    "nậm tỵ",
    "naajm tyj"
  ],
  "Nậm Xây": [
    "nậm xây",
    "naajm xaay"
  ],
  "Phan Dũng": [
    "phan dũng",
    "phan duxng"
  ],
  "Phan Thanh": [
    "phan thanh",
    "phan thanh"
  ],
  "Phi Liêng": [
    "phi liêng",
    "phi lieeng"
  ],
  "Phi Thông": [
    "phi thông",
    "phi thoong"
  ],
  "Phong Dụ": [
    "phong dụ",
    "phong duj"
  ],
  "Phong Hòa": [
    "phong hòa",
    "phong hofa"
  ],
  "Phong Hóa": [
    "phong hóa",
    "phong hosa"
  ],
  "Phong Khê": [
    "phong khê",
    "phong khee"
  ],
  "Phong Minh": [
    "phong minh",
    "phong minh"
  ],
  "Phong Mỹ": [
    "phong mỹ",
    "phong myx"
  ],
  "Phong Phú": [
    "phong phú",
    "phong phus"
  ],
  "Phong Sơn": [
    "phong sơn",
    "phong sown"
  ],
  "Phong Tân": [
    "phong tân",
    "phong taan"
  ],
  "Phong Vân": [
    "phong vân",
    "phong vaan"
  ],
  "Phu Luông": [
    "phu luông",
    "phu luoong"
  ],
  "Phì Nhừ": [
    "phì nhừ",
    "phif nhuwf"
  ],
  "Phìn Hồ": [
    "phìn hồ",
    "phifn hoof"
  ],
  "Phìn Ngan": [
    "phìn ngan",
    "phifn ngan"
  ],
  "Phù Lãng": [
    "phù lãng",
    "phuf laxng"
  ],
  "Phù Ủng": [
    "phù ủng",
    "phuf urng"
  ],
  "Phùng Xá": [
    "phùng xá",
    "phufng xas"
  ],
  "Phú Bình": [
    "phú bình",
    "phus bifnh"
  ],
  "Phú Châu": [
    "phú châu",
    "phus chaau"
  ],
  "Phú Cần": [
    "phú cần",
    "phus caafn"
  ],
  "Phú Diên": [
    "phú diên",
    "phus dieen"
  ],
  "Phú Giáo": [
    "phú giáo",
    "phus giaso"
  ],
  "Phú Hưng": [
    "phú hưng",
    "phus huwng"
  ],
  "Phú Hải": [
    "phú hải",
    "phus hari"
  ],
  "Phú Hậu": [
    "phú hậu",
    "phus haaju"
  ],
  "Phú Hội": [
    "phú hội",
    "phus hooji"
  ],
  "Phú Hữu": [
    "phú hữu",
    "phus huwxu"
  ],
  "Phú Hựu": [
    "phú hựu",
    "phus huwju"
  ],
  "Phú Lũng": [
    "phú lũng",
    "phus luxng"
  ],
  "Phú Lạc": [
    "phú lạc",
    "phus lajc"
  ],
  "Phú Lập": [
    "phú lập",
    "phus laajp"
  ],
  "Phú Lộc": [
    "phú lộc",
    "phus loojc"
  ],
  "Phú Lợi": [
    "phú lợi",
    "phus lowji"
  ],
  "Phú Mậu": [
    "phú mậu",
    "phus maaju"
  ],
  "Phú Phong": [
    "phú phong",
    "phus phong"
  ],
  "Phú Phúc": [
    "phú phúc",
    "phus phusc"
  ],
  "Phú Thanh": [
    "phú thanh",
    "phus thanh"
  ],
  "Phú Thái": [
    "phú thái",
    "phus thasi"
  ],
  "Phú Thị": [
    "phú thị",
    "phus thij"
  ],
  "Phú Thọ": [
    "phú thọ",
    "phus thoj"
  ],
  "Phú Thứ": [
    "phú thứ",
    "phus thuws"
  ],
  "Phú Trinh": [
    "phú trinh",
    "phus trinh"
  ],
  "Phú Trung": [
    "phú trung",
    "phus trung"
  ],
  "Phú Vĩnh": [
    "phú vĩnh",
    "phus vixnh"
  ],
  "Phú Xuân": [
    "phú xuân",
    "phus xuaan"
  ],
  "Phúc Hòa": [
    "phúc hòa",
    "phusc hofa"
  ],
  "Phúc Khoa": [
    "phúc khoa",
    "phusc khoa"
  ],
  "Phúc Lâm": [
    "phúc lâm",
    "phusc laam"
  ],
  "Phúc Ninh": [
    "phúc ninh",
    "phusc ninh"
  ],
  "Phúc Sơn": [
    "phúc sơn",
    "phusc sown"
  ],
  "Phúc Than": [
    "phúc than",
    "phusc than"
  ],
  "Phúc Tân": [
    "phúc tân",
    "phusc taan"
  ],
  "Phúc Yên": [
    "phúc yên",
    "phusc yeen"
  ],
  "Phạm Kha": [
    "phạm kha",
    "phajm kha"
  ],
  "Phả Lễ": [
    "phả lễ",
    "phar leex"
  ],
  "Phố Cáo": [
    "phố cáo",
    "phoos caso"
  ],
  "Phổ Hòa": [
    "phổ hòa",
    "phoor hofa"
  ],
  "Phổ Minh": [
    "phổ minh",
    "phoor minh"
  ],
  "Phổ Ninh": [
    "phổ ninh",
    "phoor ninh"
  ],
  "Phổ Vinh": [
    "phổ vinh",
    "phoor vinh"
  ],
  "Phổ Văn": [
    "phổ văn",
    "phoor vawn"
  ],
  "Phổ Yên": [
    "phổ yên",
    "phoor yeen"
  ],
  "Plei Kần": [
    "plei kần",
    "plei kaafn"
  ],
  "Pá Khoang": [
    "pá khoang",
    "pas khoang"
  ],
  "Pác Nặm": [
    "pác nặm",
    "pasc nawjm"
  ],
  "Pú Hồng": [
    "pú hồng",
    "pus hoofng"
  ],
  "Pắc Ngà": [
    "pắc ngà",
    "pawsc ngaf"
  ],
  "Quan Lạn": [
    "quan lạn",
    "quan lajn"
  ],
  "Quang Hanh": [
    "quang hanh",
    "quang hanh"
  ],
  "Quang Hán": [
    "quang hán",
    "quang hasn"
  ],
  "Quang Húc": [
    "quang húc",
    "quang husc"
  ],
  "Quang Long": [
    "quang long",
    "quang long"
  ],
  "Quang Minh": [
    "quang minh",
    "quang minh"
  ],
  "Quang Phú": [
    "quang phú",
    "quang phus"
  ],
  "Quang Sơn": [
    "quang sơn",
    "quang sown"
  ],
  "Quang Vinh": [
    "quang vinh",
    "quang vinh"
  ],
  "Quang Yên": [
    "quang yên",
    "quang yeen"
  ],
  "Quy Đạt": [
    "quy đạt",
    "quy ddajt"
  ],
  "Quy Đức": [
    "quy đức",
    "quy dduwsc"
  ],
  "Quài Cang": [
    "quài cang",
    "quafi cang"
  ],
  "Quài Nưa": [
    "quài nưa",
    "quafi nuwa"
  ],
  "Quài Tở": [
    "quài tở",
    "quafi towr"
  ],
  "Quán Bàu": [
    "quán bàu",
    "quasn bafu"
  ],
  "Quán Hàu": [
    "quán hàu",
    "quasn hafu"
  ],
  "Quán Lào": [
    "quán lào",
    "quasn lafo"
  ],
  "Quán Toan": [
    "quán toan",
    "quasn toan"
  ],
  "Quí Lộc": [
    "quí lộc",
    "quis loojc"
  ],
  "Quí Quân": [
    "quí quân",
    "quis quaan"
  ],
  "Quý Quân": [
    "quý quân",
    "quys quaan"
  ],
  "Quơn Long": [
    "quơn long",
    "quown long"
  ],
  "Quảng An": [
    "quảng an",
    "quarng an"
  ],
  "Quảng La": [
    "quảng la",
    "quarng la"
  ],
  "Quế Long": [
    "quế long",
    "quees long"
  ],
  "Quế Lâm": [
    "quế lâm",
    "quees laam"
  ],
  "Quế Lưu": [
    "quế lưu",
    "quees luwu"
  ],
  "Quế Minh": [
    "quế minh",
    "quees minh"
  ],
  "Quế Mỹ": [
    "quế mỹ",
    "quees myx"
  ],
  "Quế Nham": [
    "quế nham",
    "quees nham"
  ],
  "Quế Phú": [
    "quế phú",
    "quees phus"
  ],
  "Quế Sơn": [
    "quế sơn",
    "quees sown"
  ],
  "Quế Tân": [
    "quế tân",
    "quees taan"
  ],
  "Quốc Oai": [
    "quốc oai",
    "quoosc oai"
  ],
  "San Thàng": [
    "san thàng",
    "san thafng"
  ],
  "Sen Thủy": [
    "sen thủy",
    "sen thury"
  ],
  "Sinh Tồn": [
    "sinh tồn",
    "sinh toofn"
  ],
  "Song Bình": [
    "song bình",
    "song bifnh"
  ],
  "Song Giang": [
    "song giang",
    "song giang"
  ],
  "Song Lãng": [
    "song lãng",
    "song laxng"
  ],
  "Song Lộc": [
    "song lộc",
    "song loojc"
  ],
  "Suối Bau": [
    "suối bau",
    "suoosi bau"
  ],
  "Suối Cao": [
    "suối cao",
    "suoosi cao"
  ],
  "Suối Hoa": [
    "suối hoa",
    "suoosi hoa"
  ],
  "Suối Nho": [
    "suối nho",
    "suoosi nho"
  ],
  "Suối Rao": [
    "suối rao",
    "suoosi rao"
  ],
  "Suối Tre": [
    "suối tre",
    "suoosi tre"
  ],
  "Sàn Viên": [
    "sàn viên",
    "safn vieen"
  ],
  "Sáng Nhè": [
    "sáng nhè",
    "sasng nhef"
  ],
  "Sông Bờ": [
    "sông bờ",
    "soong bowf"
  ],
  "Sông Hinh": [
    "sông hinh",
    "soong hinh"
  ],
  "Sông Kôn": [
    "sông kôn",
    "soong koon"
  ],
  "Sông Lũy": [
    "sông lũy",
    "soong luxy"
  ],
  "Sông Phan": [
    "sông phan",
    "soong phan"
  ],
  "Sông Thao": [
    "sông thao",
    "soong thao"
  ],
  "Sông Trà": [
    "sông trà",
    "soong traf"
  ],
  "Sông Vệ": [
    "sông vệ",
    "soong veej"
  ],
  "Sông Đà": [
    "sông đà",
    "soong ddaf"
  ],
  "Sùng Đô": [
    "sùng đô",
    "sufng ddoo"
  ],
  "Săm Khóe": [
    "săm khóe",
    "sawm khose"
  ],
  "Sơn Bình": [
    "sơn bình",
    "sown bifnh"
  ],
  "Sơn Châu": [
    "sơn châu",
    "sown chaau"
  ],
  "Sơn Công": [
    "sơn công",
    "sown coong"
  ],
  "Sơn Cẩm": [
    "sơn cẩm",
    "sown caarm"
  ],
  "Sơn Giang": [
    "sơn giang",
    "sown giang"
  ],
  "Sơn Hùng": [
    "sơn hùng",
    "sown hufng"
  ],
  "Sơn Hải": [
    "sơn hải",
    "sown hari"
  ],
  "Sơn Hội": [
    "sơn hội",
    "sown hooji"
  ],
  "Sơn Kim 1": [
    "sơn kim 1",
    "sown kim 1"
  ],
  "Sơn Kim 2": [
    "sơn kim 2",
    "sown kim 2"
  ],
  "Sơn Kiên": [
    "sơn kiên",
    "sown kieen"
  ],
  "Sơn Liên": [
    "sơn liên",
    "sown lieen"
  ],
  "Sơn Lĩnh": [
    "sơn lĩnh",
    "sown lixnh"
  ],
  "Sơn Lập": [
    "sơn lập",
    "sown laajp"
  ],
  "Sơn Lộc": [
    "sơn lộc",
    "sown loojc"
  ],
  "Sơn Phong": [
    "sơn phong",
    "sown phong"
  ],
  "Sơn Thái": [
    "sơn thái",
    "sown thasi"
  ],
  "Sơn Trung": [
    "sơn trung",
    "sown trung"
  ],
  "Sơn Tình": [
    "sơn tình",
    "sown tifnh"
  ],
  "Sơn Viên": [
    "sơn viên",
    "sown vieen"
  ],
  "Sơn Xuân": [
    "sơn xuân",
    "sown xuaan"
  ],
  "Sầm Sơn": [
    "sầm sơn",
    "saafm sown"
  ],
  "Sở Dầu": [
    "sở dầu",
    "sowr daafu"
  ],
  "Sủ Ngòi": [
    "sủ ngòi",
    "sur ngofi"
  ],
  "Sủng Là": [
    "sủng là",
    "surng laf"
  ],
  "Tam Hiệp": [
    "tam hiệp",
    "tam hieejp"
  ],
  "Tam Hồng": [
    "tam hồng",
    "tam hoofng"
  ],
  "Tam Nghĩa": [
    "tam nghĩa",
    "tam nghixa"
  ],
  "Tam Ngọc": [
    "tam ngọc",
    "tam ngojc"
  ],
  "Tam Thành": [
    "tam thành",
    "tam thafnh"
  ],
  "Tam Thăng": [
    "tam thăng",
    "tam thawng"
  ],
  "Tam Tiến": [
    "tam tiến",
    "tam tieesn"
  ],
  "Tam Đình": [
    "tam đình",
    "tam ddifnh"
  ],
  "Tam Đại": [
    "tam đại",
    "tam ddaji"
  ],
  "Tam Đảo": [
    "tam đảo",
    "tam ddaro"
  ],
  "Tham Đôn": [
    "tham đôn",
    "tham ddoon"
  ],
  "Than Uyên": [
    "than uyên",
    "than uyeen"
  ],
  "Thanh Hòa": [
    "thanh hòa",
    "thanh hofa"
  ],
  "Thanh Hóa": [
    "thanh hóa",
    "thanh hosa"
  ],
  "Thanh Khai": [
    "thanh khai",
    "thanh khai"
  ],
  "Thanh Khê": [
    "thanh khê",
    "thanh khee"
  ],
  "Thanh Kỳ": [
    "thanh kỳ",
    "thanh kyf"
  ],
  "Thanh Lang": [
    "thanh lang",
    "thanh lang"
  ],
  "Thanh Long": [
    "thanh long",
    "thanh long"
  ],
  "Thanh Lâm": [
    "thanh lâm",
    "thanh laam"
  ],
  "Thanh Lân": [
    "thanh lân",
    "thanh laan"
  ],
  "Thanh Lòa": [
    "thanh lòa",
    "thanh lofa"
  ],
  "Thanh Minh": [
    "thanh minh",
    "thanh minh"
  ],
  "Thanh Mỹ": [
    "thanh mỹ",
    "thanh myx"
  ],
  "Thanh Ninh": [
    "thanh ninh",
    "thanh ninh"
  ],
  "Thanh Nưa": [
    "thanh nưa",
    "thanh nuwa"
  ],
  "Thanh Phú": [
    "thanh phú",
    "thanh phus"
  ],
  "Thanh Sơn": [
    "thanh sơn",
    "thanh sown"
  ],
  "Thanh Trì": [
    "thanh trì",
    "thanh trif"
  ],
  "Thanh Trù": [
    "thanh trù",
    "thanh truf"
  ],
  "Thanh Tâm": [
    "thanh tâm",
    "thanh taam"
  ],
  "Thanh Tân": [
    "thanh tân",
    "thanh taan"
  ],
  "Thanh Vinh": [
    "thanh vinh",
    "thanh vinh"
  ],
  "Thanh Vân": [
    "thanh vân",
    "thanh vaan"
  ],
  "Thanh Văn": [
    "thanh văn",
    "thanh vawn"
  ],
  "Thanh Yên": [
    "thanh yên",
    "thanh yeen"
  ],
  "Thiện An": [
    "thiện an",
    "thieejn an"
  ],
  "Thu Ngạc": [
    "thu ngạc",
    "thu ngajc"
  ],
  "Thu Thuỷ": [
    "thu thuỷ",
    "thu thuyr"
  ],
  "Thuận An": [
    "thuận an",
    "thuaajn an"
  ],
  "Thành Tô": [
    "thành tô",
    "thafnh too"
  ],
  "Thái Hoà": [
    "thái hoà",
    "thasi hoaf"
  ],
  "Thái Hòa": [
    "thái hòa",
    "thasi hofa"
  ],
  "Thái Long": [
    "thái long",
    "thasi long"
  ],
  "Thái Mỹ": [
    "thái mỹ",
    "thasi myx"
  ],
  "Thái Sơn": [
    "thái sơn",
    "thasi sown"
  ],
  "Thái Tân": [
    "thái tân",
    "thasi taan"
  ],
  "Thái Đô": [
    "thái đô",
    "thasi ddoo"
  ],
  "Thôm Mòn": [
    "thôm mòn",
    "thoom mofn"
  ],
  "Thúy Sơn": [
    "thúy sơn",
    "thusy sown"
  ],
  "Thạch An": [
    "thạch an",
    "thajch an"
  ],
  "Thạnh An": [
    "thạnh an",
    "thajnh an"
  ],
  "Thọ Dân": [
    "thọ dân",
    "thoj daan"
  ],
  "Thọ Lâm": [
    "thọ lâm",
    "thoj laam"
  ],
  "Thọ Phú": [
    "thọ phú",
    "thoj phus"
  ],
  "Thọ Sơn": [
    "thọ sơn",
    "thoj sown"
  ],
  "Thọ Tân": [
    "thọ tân",
    "thoj taan"
  ],
  "Thọ Vinh": [
    "thọ vinh",
    "thoj vinh"
  ],
  "Thọ Văn": [
    "thọ văn",
    "thoj vawn"
  ],
  "Thổ Quan": [
    "thổ quan",
    "thoor quan"
  ],
  "Thổ Sơn": [
    "thổ sơn",
    "thoor sown"
  ],
  "Thổ Tang": [
    "thổ tang",
    "thoor tang"
  ],
  "Thới Lai": [
    "thới lai",
    "thowsi lai"
  ],
  "Thủ Sỹ": [
    "thủ sỹ",
    "thur syx"
  ],
  "Tiên Cát": [
    "tiên cát",
    "tieen cast"
  ],
  "Tiên Kỳ": [
    "tiên kỳ",
    "tieen kyf"
  ],
  "Tiên Long": [
    "tiên long",
    "tieen long"
  ],
  "Tiên Lữ": [
    "tiên lữ",
    "tieen luwx"
  ],
  "Tiên Minh": [
    "tiên minh",
    "tieen minh"
  ],
  "Tiên Mỹ": [
    "tiên mỹ",
    "tieen myx"
  ],
  "Tiên Phú": [
    "tiên phú",
    "tieen phus"
  ],
  "Tiên Sơn": [
    "tiên sơn",
    "tieen sown"
  ],
  "Tiên Tân": [
    "tiên tân",
    "tieen taan"
  ],
  "Tiên Yên": [
    "tiên yên",
    "tieen yeen"
  ],
  "Tiêu Sơn": [
    "tiêu sơn",
    "tieeu sown"
  ],
  "Toàn Sơn": [
    "toàn sơn",
    "toafn sown"
  ],
  "Trang Hạ": [
    "trang hạ",
    "trang haj"
  ],
  "Tri Thủy": [
    "tri thủy",
    "tri thury"
  ],
  "Trinh Phú": [
    "trinh phú",
    "trinh phus"
  ],
  "Triệu An": [
    "triệu an",
    "trieeju an"
  ],
  "Trung Giã": [
    "trung giã",
    "trung giax"
  ],
  "Trung Hoà": [
    "trung hoà",
    "trung hoaf"
  ],
  "Trung Hòa": [
    "trung hòa",
    "trung hofa"
  ],
  "Trung Hóa": [
    "trung hóa",
    "trung hosa"
  ],
  "Trung Hạ": [
    "trung hạ",
    "trung haj"
  ],
  "Trung Minh": [
    "trung minh",
    "trung minh"
  ],
  "Trung Môn": [
    "trung môn",
    "trung moon"
  ],
  "Trung Mỹ": [
    "trung mỹ",
    "trung myx"
  ],
  "Trung Sơn": [
    "trung sơn",
    "trung sown"
  ],
  "Trung Tâm": [
    "trung tâm",
    "trung taam"
  ],
  "Trung Tự": [
    "trung tự",
    "trung tuwj"
  ],
  "Trung Văn": [
    "trung văn",
    "trung vawn"
  ],
  "Trung Yên": [
    "trung yên",
    "trung yeen"
  ],
  "Trung Đô": [
    "trung đô",
    "trung ddoo"
  ],
  "Trà Bình": [
    "trà bình",
    "traf bifnh"
  ],
  "Trà Giang": [
    "trà giang",
    "traf giang"
  ],
  "Trà Giác": [
    "trà giác",
    "traf giasc"
  ],
  "Trà Giáp": [
    "trà giáp",
    "traf giasp"
  ],
  "Trà Lĩnh": [
    "trà lĩnh",
    "traf lixnh"
  ],
  "Trà Phong": [
    "trà phong",
    "traf phong"
  ],
  "Trà Thanh": [
    "trà thanh",
    "traf thanh"
  ],
  "Trà Tập": [
    "trà tập",
    "traf taajp"
  ],
  "Trà Xuân": [
    "trà xuân",
    "traf xuaan"
  ],
  "Tràm Chim": [
    "tràm chim",
    "trafm chim"
  ],
  "Tràng Xá": [
    "tràng xá",
    "trafng xas"
  ],
  "Trác Văn": [
    "trác văn",
    "trasc vawn"
  ],
  "Trì Quang": [
    "trì quang",
    "trif quang"
  ],
  "Trí Bình": [
    "trí bình",
    "tris bifnh"
  ],
  "Trí Lực": [
    "trí lực",
    "tris luwjc"
  ],
  "Trí Quả": [
    "trí quả",
    "tris quar"
  ],
  "Trù Hựu": [
    "trù hựu",
    "truf huwju"
  ],
  "Trúc Lâm": [
    "trúc lâm",
    "trusc laam"
  ],
  "Trúc Lâu": [
    "trúc lâu",
    "trusc laau"
  ],
  "Trúc Sơn": [
    "trúc sơn",
    "trusc sown"
  ],
  "Trại Cau": [
    "trại cau",
    "traji cau"
  ],
  "Trần Cao": [
    "trần cao",
    "traafn cao"
  ],
  "Tuy Đức": [
    "tuy đức",
    "tuy dduwsc"
  ],
  "Tà Chải": [
    "tà chải",
    "taf chari"
  ],
  "Tà Tổng": [
    "tà tổng",
    "taf toorng"
  ],
  "Tánh Linh": [
    "tánh linh",
    "tasnh linh"
  ],
  "Tân Biên": [
    "tân biên",
    "taan bieen"
  ],
  "Tân Bình": [
    "tân bình",
    "taan bifnh"
  ],
  "Tân Bắc": [
    "tân bắc",
    "taan bawsc"
  ],
  "Tân Bửu": [
    "tân bửu",
    "taan buwru"
  ],
  "Tân Châu": [
    "tân châu",
    "taan chaau"
  ],
  "Tân Dĩnh": [
    "tân dĩnh",
    "taan dixnh"
  ],
  "Tân Giang": [
    "tân giang",
    "taan giang"
  ],
  "Tân Huề": [
    "tân huề",
    "taan hueef"
  ],
  "Tân Hùng": [
    "tân hùng",
    "taan hufng"
  ],
  "Tân Hưng": [
    "tân hưng",
    "taan huwng"
  ],
  "Tân Hải": [
    "tân hải",
    "taan hari"
  ],
  "Tân Học": [
    "tân học",
    "taan hojc"
  ],
  "Tân Hội": [
    "tân hội",
    "taan hooji"
  ],
  "Tân Hợp": [
    "tân hợp",
    "taan howjp"
  ],
  "Tân Khang": [
    "tân khang",
    "taan khang"
  ],
  "Tân Kiên": [
    "tân kiên",
    "taan kieen"
  ],
  "Tân Liên": [
    "tân liên",
    "taan lieen"
  ],
  "Tân Lãng": [
    "tân lãng",
    "taan laxng"
  ],
  "Tân Lĩnh": [
    "tân lĩnh",
    "taan lixnh"
  ],
  "Tân Lạc": [
    "tân lạc",
    "taan lajc"
  ],
  "Tân Lập": [
    "tân lập",
    "taan laajp"
  ],
  "Tân Lộc": [
    "tân lộc",
    "taan loojc"
  ],
  "Tân Lợi": [
    "tân lợi",
    "taan lowji"
  ],
  "Tân Mộc": [
    "tân mộc",
    "taan moojc"
  ],
  "Tân Ngãi": [
    "tân ngãi",
    "taan ngaxi"
  ],
  "Tân Phong": [
    "tân phong",
    "taan phong"
  ],
  "Tân Phúc": [
    "tân phúc",
    "taan phusc"
  ],
  "Tân Quang": [
    "tân quang",
    "taan quang"
  ],
  "Tân Sỏi": [
    "tân sỏi",
    "taan sori"
  ],
  "Tân Thanh": [
    "tân thanh",
    "taan thanh"
  ],
  "Tân Thái": [
    "tân thái",
    "taan thasi"
  ],
  "Tân Thọ": [
    "tân thọ",
    "taan thoj"
  ],
  "Tân Trung": [
    "tân trung",
    "taan trung"
  ],
  "Tân Trào": [
    "tân trào",
    "taan trafo"
  ],
  "Tân Trụ": [
    "tân trụ",
    "taan truj"
  ],
  "Tân Tạo": [
    "tân tạo",
    "taan tajo"
  ],
  "Tân Tập": [
    "tân tập",
    "taan taajp"
  ],
  "Tân Uyên": [
    "tân uyên",
    "taan uyeen"
  ],
  "Tân Viên": [
    "tân viên",
    "taan vieen"
  ],
  "Tân Vạn": [
    "tân vạn",
    "taan vajn"
  ],
  "Tân Xuân": [
    "tân xuân",
    "taan xuaan"
  ],
  "Tây Bình": [
    "tây bình",
    "taay bifnh"
  ],
  "Tây Cốc": [
    "tây cốc",
    "taay coosc"
  ],
  "Tây Giang": [
    "tây giang",
    "taay giang"
  ],
  "Tây Hưng": [
    "tây hưng",
    "taay huwng"
  ],
  "Tây Lộc": [
    "tây lộc",
    "taay loojc"
  ],
  "Tây Phong": [
    "tây phong",
    "taay phong"
  ],
  "Tây Tựu": [
    "tây tựu",
    "taay tuwju"
  ],
  "Tây Xuân": [
    "tây xuân",
    "taay xuaan"
  ],
  "Tìa Dình": [
    "tìa dình",
    "tifa difnh"
  ],
  "Tích Sơn": [
    "tích sơn",
    "tisch sown"
  ],
  "Tóc Tiên": [
    "tóc tiên",
    "tosc tieen"
  ],
  "Tô Hiệu": [
    "tô hiệu",
    "too hieeju"
  ],
  "Tông Cọ": [
    "tông cọ",
    "toong coj"
  ],
  "Tùng Khê": [
    "tùng khê",
    "tufng khee"
  ],
  "Tùng Lâm": [
    "tùng lâm",
    "tufng laam"
  ],
  "Tùng Vài": [
    "tùng vài",
    "tufng vafi"
  ],
  "Tú Mịch": [
    "tú mịch",
    "tus mijch"
  ],
  "Tú Xuyên": [
    "tú xuyên",
    "tus xuyeen"
  ],
  "Túc Đán": [
    "túc đán",
    "tusc ddasn"
  ],
  "Túng Sán": [
    "túng sán",
    "tusng sasn"
  ],
  "Tăng Hoà": [
    "tăng hoà",
    "tawng hoaf"
  ],
  "Tĩnh Túc": [
    "tĩnh túc",
    "tixnh tusc"
  ],
  "Tư Nghĩa": [
    "tư nghĩa",
    "tuw nghixa"
  ],
  "Tả Lèng": [
    "tả lèng",
    "tar lefng"
  ],
  "Tả Nhìu": [
    "tả nhìu",
    "tar nhifu"
  ],
  "Tả Phìn": [
    "tả phìn",
    "tar phifn"
  ],
  "Tấn Mỹ": [
    "tấn mỹ",
    "taasn myx"
  ],
  "Tấn Tài": [
    "tấn tài",
    "taasn tafi"
  ],
  "Tập Sơn": [
    "tập sơn",
    "taajp sown"
  ],
  "Tắc Vân": [
    "tắc vân",
    "tawsc vaan"
  ],
  "Tế Lợi": [
    "tế lợi",
    "tees lowji"
  ],
  "Tế Nông": [
    "tế nông",
    "tees noong"
  ],
  "Tịnh Hà": [
    "tịnh hà",
    "tijnh haf"
  ],
  "Tụ Nhân": [
    "tụ nhân",
    "tuj nhaan"
  ],
  "Tứ Liên": [
    "tứ liên",
    "tuws lieen"
  ],
  "Tự Lạn": [
    "tự lạn",
    "tuwj lajn"
  ],
  "Tự Lập": [
    "tự lập",
    "tuwj laajp"
  ],
  "Vi Hương": [
    "vi hương",
    "vi huwowng"
  ],
  "Vinh Hưng": [
    "vinh hưng",
    "vinh huwng"
  ],
  "Vinh Quang": [
    "vinh quang",
    "vinh quang"
  ],
  "Vinh Thanh": [
    "vinh thanh",
    "vinh thanh"
  ],
  "Vinh Xuân": [
    "vinh xuân",
    "vinh xuaan"
  ],
  "Viên Sơn": [
    "viên sơn",
    "vieen sown"
  ],
  "Vàm Láng": [
    "vàm láng",
    "vafm lasng"
  ],
  "Vàng Danh": [
    "vàng danh",
    "vafng danh"
  ],
  "Vân Giang": [
    "vân giang",
    "vaan giang"
  ],
  "Vân Hội": [
    "vân hội",
    "vaan hooji"
  ],
  "Vân Lĩnh": [
    "vân lĩnh",
    "vaan lixnh"
  ],
  "Vân Nội": [
    "vân nội",
    "vaan nooji"
  ],
  "Vân Phúc": [
    "vân phúc",
    "vaan phusc"
  ],
  "Vân Trung": [
    "vân trung",
    "vaan trung"
  ],
  "Vân Tùng": [
    "vân tùng",
    "vaan tufng"
  ],
  "Vân Tảo": [
    "vân tảo",
    "vaan taro"
  ],
  "Vân Xuân": [
    "vân xuân",
    "vaan xuaan"
  ],
  "Vô Ngại": [
    "vô ngại",
    "voo ngaji"
  ],
  "Võ Liệt": [
    "võ liệt",
    "vox lieejt"
  ],
  "Võ Miếu": [
    "võ miếu",
    "vox mieesu"
  ],
  "Văn Bình": [
    "văn bình",
    "vawn bifnh"
  ],
  "Văn Cẩm": [
    "văn cẩm",
    "vawn caarm"
  ],
  "Văn Giang": [
    "văn giang",
    "vawn giang"
  ],
  "Văn Giáo": [
    "văn giáo",
    "vawn giaso"
  ],
  "Văn Hải": [
    "văn hải",
    "vawn hari"
  ],
  "Văn Hội": [
    "văn hội",
    "vawn hooji"
  ],
  "Văn Khúc": [
    "văn khúc",
    "vawn khusc"
  ],
  "Văn Lãng": [
    "văn lãng",
    "vawn laxng"
  ],
  "Văn Lăng": [
    "văn lăng",
    "vawn lawng"
  ],
  "Văn Lợi": [
    "văn lợi",
    "vawn lowji"
  ],
  "Văn Phong": [
    "văn phong",
    "vawn phong"
  ],
  "Văn Quán": [
    "văn quán",
    "vawn quasn"
  ],
  "Văn Xuôi": [
    "văn xuôi",
    "vawn xuooi"
  ],
  "Vĩnh Hanh": [
    "vĩnh hanh",
    "vixnh hanh"
  ],
  "Vĩnh Hoà": [
    "vĩnh hoà",
    "vixnh hoaf"
  ],
  "Vĩnh Hào": [
    "vĩnh hào",
    "vixnh hafo"
  ],
  "Vĩnh Hòa": [
    "vĩnh hòa",
    "vixnh hofa"
  ],
  "Vĩnh Khê": [
    "vĩnh khê",
    "vixnh khee"
  ],
  "Vĩnh Linh": [
    "vĩnh linh",
    "vixnh linh"
  ],
  "Vĩnh Long": [
    "vĩnh long",
    "vixnh long"
  ],
  "Vĩnh Lâm": [
    "vĩnh lâm",
    "vixnh laam"
  ],
  "Vĩnh Mỹ": [
    "vĩnh mỹ",
    "vixnh myx"
  ],
  "Vĩnh Ninh": [
    "vĩnh ninh",
    "vixnh ninh"
  ],
  "Vĩnh Phú": [
    "vĩnh phú",
    "vixnh phus"
  ],
  "Vĩnh Sơn": [
    "vĩnh sơn",
    "vixnh sown"
  ],
  "Vĩnh Tân": [
    "vĩnh tân",
    "vixnh taan"
  ],
  "Vĩnh Tế": [
    "vĩnh tế",
    "vixnh tees"
  ],
  "Vĩnh Yên": [
    "vĩnh yên",
    "vixnh yeen"
  ],
  "Vũ Chính": [
    "vũ chính",
    "vux chisnh"
  ],
  "Vũ Chấn": [
    "vũ chấn",
    "vux chaasn"
  ],
  "Vũ Muộn": [
    "vũ muộn",
    "vux muoojn"
  ],
  "Vũ Tiến": [
    "vũ tiến",
    "vux tieesn"
  ],
  "Vũ Đoài": [
    "vũ đoài",
    "vux ddoafi"
  ],
  "Vũ Đông": [
    "vũ đông",
    "vux ddoong"
  ],
  "Vũng Tàu": [
    "vũng tàu",
    "vuxng tafu"
  ],
  "Vạn Giã": [
    "vạn giã",
    "vajn giax"
  ],
  "Vạn Hoà": [
    "vạn hoà",
    "vajn hoaf"
  ],
  "Vạn Hòa": [
    "vạn hòa",
    "vajn hofa"
  ],
  "Vạn Linh": [
    "vạn linh",
    "vajn linh"
  ],
  "Vạn Long": [
    "vạn long",
    "vajn long"
  ],
  "Vạn Mỹ": [
    "vạn mỹ",
    "vajn myx"
  ],
  "Vạn Ninh": [
    "vạn ninh",
    "vajn ninh"
  ],
  "Vạn Phú": [
    "vạn phú",
    "vajn phus"
  ],
  "Vạn Yên": [
    "vạn yên",
    "vajn yeen"
  ],
  "Vầy Nưa": [
    "vầy nưa",
    "vaafy nuwa"
  ],
  "Vị Bình": [
    "vị bình",
    "vij bifnh"
  ],
  "Vị Thanh": [
    "vị thanh",
    "vij thanh"
  ],
  "Vị Trung": [
    "vị trung",
    "vij trung"
  ],
  "Vụ Bản": [
    "vụ bản",
    "vuj barn"
  ],
  "Vụ Bổn": [
    "vụ bổn",
    "vuj boorn"
  ],
  "Vụ Quang": [
    "vụ quang",
    "vuj quang"
  ],
  "Xuân Bái": [
    "xuân bái",
    "xuaan basi"
  ],
  "Xuân Canh": [
    "xuân canh",
    "xuaan canh"
  ],
  "Xuân Giao": [
    "xuân giao",
    "xuaan giao"
  ],
  "Xuân Hoà": [
    "xuân hoà",
    "xuaan hoaf"
  ],
  "Xuân Hòa": [
    "xuân hòa",
    "xuaan hofa"
  ],
  "Xuân Hóa": [
    "xuân hóa",
    "xuaan hosa"
  ],
  "Xuân Khê": [
    "xuân khê",
    "xuaan khee"
  ],
  "Xuân Long": [
    "xuân long",
    "xuaan long"
  ],
  "Xuân Lâm": [
    "xuân lâm",
    "xuaan laam"
  ],
  "Xuân Lôi": [
    "xuân lôi",
    "xuaan looi"
  ],
  "Xuân Lẹ": [
    "xuân lẹ",
    "xuaan lej"
  ],
  "Xuân Minh": [
    "xuân minh",
    "xuaan minh"
  ],
  "Xuân Mỹ": [
    "xuân mỹ",
    "xuaan myx"
  ],
  "Xuân Ninh": [
    "xuân ninh",
    "xuaan ninh"
  ],
  "Xuân Phú": [
    "xuân phú",
    "xuaan phus"
  ],
  "Xuân Quan": [
    "xuân quan",
    "xuaan quan"
  ],
  "Xuân Sinh": [
    "xuân sinh",
    "xuaan sinh"
  ],
  "Xuân Sơn": [
    "xuân sơn",
    "xuaan sown"
  ],
  "Xuân Tâm": [
    "xuân tâm",
    "xuaan taam"
  ],
  "Xuân Tân": [
    "xuân tân",
    "xuaan taan"
  ],
  "Xuân Tây": [
    "xuân tây",
    "xuaan taay"
  ],
  "Xuân Tín": [
    "xuân tín",
    "xuaan tisn"
  ],
  "Xuân Vinh": [
    "xuân vinh",
    "xuaan vinh"
  ],
  "Xuân Vân": [
    "xuân vân",
    "xuaan vaan"
  ],
  "Xuân Yên": [
    "xuân yên",
    "xuaan yeen"
  ],
  "Xuân Áng": [
    "xuân áng",
    "xuaan asng"
  ],
  "Xà Phiên": [
    "xà phiên",
    "xaf phieen"
  ],
  "Xá Tổng": [
    "xá tổng",
    "xas toorng"
  ],
  "Xím Vàng": [
    "xím vàng",
    "xism vafng"
  ],
  "Xín Mần": [
    "xín mần",
    "xisn maafn"
  ],
  "Yang Bắc": [
    "yang bắc",
    "yang bawsc"
  ],
  "Yang Trung": [
    "yang trung",
    "yang trung"
  ],
  "Yên Bình": [
    "yên bình",
    "yeen bifnh"
  ],
  "Yên Bắc": [
    "yên bắc",
    "yeen bawsc"
  ],
  "Yên Châu": [
    "yên châu",
    "yeen chaau"
  ],
  "Yên Dũng": [
    "yên dũng",
    "yeen duxng"
  ],
  "Yên Giang": [
    "yên giang",
    "yeen giang"
  ],
  "Yên Giả": [
    "yên giả",
    "yeen giar"
  ],
  "Yên Hùng": [
    "yên hùng",
    "yeen hufng"
  ],
  "Yên Hưng": [
    "yên hưng",
    "yeen huwng"
  ],
  "Yên Hải": [
    "yên hải",
    "yeen hari"
  ],
  "Yên Hợp": [
    "yên hợp",
    "yeen howjp"
  ],
  "Yên Khang": [
    "yên khang",
    "yeen khang"
  ],
  "Yên Lãng": [
    "yên lãng",
    "yeen laxng"
  ],
  "Yên Lạc": [
    "yên lạc",
    "yeen lajc"
  ],
  "Yên Lập": [
    "yên lập",
    "yeen laajp"
  ],
  "Yên Lộc": [
    "yên lộc",
    "yeen loojc"
  ],
  "Yên Lợi": [
    "yên lợi",
    "yeen lowji"
  ],
  "Yên Mông": [
    "yên mông",
    "yeen moong"
  ],
  "Yên Mạc": [
    "yên mạc",
    "yeen majc"
  ],
  "Yên Nhân": [
    "yên nhân",
    "yeen nhaan"
  ],
  "Yên Phong": [
    "yên phong",
    "yeen phong"
  ],
  "Yên Phúc": [
    "yên phúc",
    "yeen phusc"
  ],
  "Yên Phụ": [
    "yên phụ",
    "yeen phuj"
  ],
  "Yên Quang": [
    "yên quang",
    "yeen quang"
  ],
  "Yên Thanh": [
    "yên thanh",
    "yeen thanh"
  ],
  "Yên Thái": [
    "yên thái",
    "yeen thasi"
  ],
  "Yên Thế": [
    "yên thế",
    "yeen thees"
  ],
  "Yên Thọ": [
    "yên thọ",
    "yeen thoj"
  ],
  "Yên Thổ": [
    "yên thổ",
    "yeen thoor"
  ],
  "Yên Trung": [
    "yên trung",
    "yeen trung"
  ],
  "Yên Trị": [
    "yên trị",
    "yeen trij"
  ],
  "Yên Tĩnh": [
    "yên tĩnh",
    "yeen tixnh"
  ],
  "Yên Tập": [
    "yên tập",
    "yeen taajp"
  ],
  "Yên Viên": [
    "yên viên",
    "yeen vieen"
  ],
  "Yên Đổ": [
    "yên đổ",
    "yeen ddoor"
  ],
  "Yên Đỗ": [
    "yên đỗ",
    "yeen ddoox"
  ],
  "Yến Sơn": [
    "yến sơn",
    "yeesn sown"
  ],
  "Ái Nghĩa": [
    "ái nghĩa",
    "asi nghixa"
  ],
  "Ái Quốc": [
    "ái quốc",
    "asi quoosc"
  ],
  "Ân Nghĩa": [
    "ân nghĩa",
    "aan nghixa"
  ],
  "Ân Đức": [
    "ân đức",
    "aan dduwsc"
  ],
  "Ích Hậu": [
    "ích hậu",
    "isch haaju"
  ],
  "Đa Krông": [
    "đa krông",
    "dda kroong"
  ],
  "Đa Thông": [
    "đa thông",
    "dda thoong"
  ],
  "Đam Rông": [
    "đam rông",
    "ddam roong"
  ],
  "Đan Hội": [
    "đan hội",
    "ddan hooji"
  ],
  "Đinh Văn": [
    "đinh văn",
    "ddinh vawn"
  ],
  "Điềm He": [
    "điềm he",
    "ddieefm he"
  ],
  "Điềm Hy": [
    "điềm hy",
    "ddieefm hy"
  ],
  "Điện An": [
    "điện an",
    "ddieejn an"
  ],
  "Đoan Bái": [
    "đoan bái",
    "ddoan basi"
  ],
  "Đoan Hạ": [
    "đoan hạ",
    "ddoan haj"
  ],
  "Đoàn Xá": [
    "đoàn xá",
    "ddoafn xas"
  ],
  "Đà Bắc": [
    "đà bắc",
    "ddaf bawsc"
  ],
  "Đà Lạt": [
    "đà lạt",
    "ddaf lajt"
  ],
  "Đài Sơn": [
    "đài sơn",
    "ddafi sown"
  ],
  "Đào Mỹ": [
    "đào mỹ",
    "ddafo myx"
  ],
  "Đá Bạc": [
    "đá bạc",
    "ddas bajc"
  ],
  "Đá Đỏ": [
    "đá đỏ",
    "ddas ddor"
  ],
  "Đình Cao": [
    "đình cao",
    "ddifnh cao"
  ],
  "Đình Chu": [
    "đình chu",
    "ddifnh chu"
  ],
  "Đình Dù": [
    "đình dù",
    "ddifnh duf"
  ],
  "Đông Anh": [
    "đông anh",
    "ddoong anh"
  ],
  "Đông Cao": [
    "đông cao",
    "ddoong cao"
  ],
  "Đông Cơ": [
    "đông cơ",
    "ddoong cow"
  ],
  "Đông Dư": [
    "đông dư",
    "ddoong duw"
  ],
  "Đông Hà": [
    "đông hà",
    "ddoong haf"
  ],
  "Đông Lai": [
    "đông lai",
    "ddoong lai"
  ],
  "Đông Mai": [
    "đông mai",
    "ddoong mai"
  ],
  "Đông Nam": [
    "đông nam",
    "ddoong nam"
  ],
  "Đông Xá": [
    "đông xá",
    "ddoong xas"
  ],
  "Đú Sáng": [
    "đú sáng",
    "ddus sasng"
  ],
  "Đăk HLơ": [
    "đăk hlơ",
    "ddawk hlow"
  ],
  "Đăk Long": [
    "đăk long",
    "ddawk long"
  ],
  "Đăk Song": [
    "đăk song",
    "ddawk song"
  ],
  "Đăk Đoa": [
    "đăk đoa",
    "ddawk ddoa"
  ],
  "Đăng Hà": [
    "đăng hà",
    "ddawng haf"
  ],
  "Đạ Long": [
    "đạ long",
    "ddaj long"
  ],
  "Đạ Lây": [
    "đạ lây",
    "ddaj laay"
  ],
  "Đạ M'ri": [
    "đạ m'ri",
    "ddaj m'ri"
  ],
  "Đạ Nhim": [
    "đạ nhim",
    "ddaj nhim"
  ],
  "Đạ Ploa": [
    "đạ ploa",
    "ddaj ploa"
  ],
  "Đạ Rsal": [
    "đạ rsal",
    "ddaj rsal"
  ],
  "Đạ Ròn": [
    "đạ ròn",
    "ddaj rofn"
  ],
  "Đại Hà": [
    "đại hà",
    "ddaji haf"
  ],
  "Đại Kim": [
    "đại kim",
    "ddaji kim"
  ],
  "Đại Lai": [
    "đại lai",
    "ddaji lai"
  ],
  "Đạm Bri": [
    "đạm bri",
    "ddajm bri"
  ],
  "Đạo Lý": [
    "đạo lý",
    "ddajo lys"
  ],
  "Đạo Tú": [
    "đạo tú",
    "ddajo tus"
  ],
  "Đầm Hà": [
    "đầm hà",
    "ddaafm haf"
  ],
  "Đắc Pre": [
    "đắc pre",
    "ddawsc pre"
  ],
  "Đắk Ang": [
    "đắk ang",
    "ddawsk ang"
  ],
  "Đắk Hà": [
    "đắk hà",
    "ddawsk haf"
  ],
  "Đắk Kan": [
    "đắk kan",
    "ddawsk kan"
  ],
  "Đắk Man": [
    "đắk man",
    "ddawsk man"
  ],
  "Đắk Mar": [
    "đắk mar",
    "ddawsk mar"
  ],
  "Đắk Mil": [
    "đắk mil",
    "ddawsk mil"
  ],
  "Đắk Ngo": [
    "đắk ngo",
    "ddawsk ngo"
  ],
  "Đắk Nia": [
    "đắk nia",
    "ddawsk nia"
  ],
  "Đắk PXi": [
    "đắk pxi",
    "ddawsk pxi"
  ],
  "Đắk Pne": [
    "đắk pne",
    "ddawsk pne"
  ],
  "Đắk Rve": [
    "đắk rve",
    "ddawsk rve"
  ],
  "Đắk Sao": [
    "đắk sao",
    "ddawsk sao"
  ],
  "Đắk Sin": [
    "đắk sin",
    "ddawsk sin"
  ],
  "Đắk Som": [
    "đắk som",
    "ddawsk som"
  ],
  "Đắk Tô": [
    "đắk tô",
    "ddawsk too"
  ],
  "Đắk Wer": [
    "đắk wer",
    "ddawsk wer"
  ],
  "Đắk Wil": [
    "đắk wil",
    "ddawsk wil"
  ],
  "Đắk Xú": [
    "đắk xú",
    "ddawsk xus"
  ],
  "Định An": [
    "định an",
    "ddijnh an"
  ],
  "Đồ Sơn": [
    "đồ sơn",
    "ddoof sown"
  ],
  "Đồn Xá": [
    "đồn xá",
    "ddoofn xas"
  ],
  "Đồng Du": [
    "đồng du",
    "ddoofng du"
  ],
  "Đồng ý": [
    "đồng ý",
    "ddoofng ys"
  ],
  "Đỗ Sơn": [
    "đỗ sơn",
    "ddoox sown"
  ],
  "Đức Cơ": [
    "đức cơ",
    "dduwsc cow"
  ],
  "Đức Lý": [
    "đức lý",
    "dduwsc lys"
  ],
  "Ẳng Cang": [
    "ẳng cang",
    "awrng cang"
  ],
  "Ẳng Nưa": [
    "ẳng nưa",
    "awrng nuwa"
  ],
  "Ẳng Tở": [
    "ẳng tở",
    "awrng towr"
  ],
  "Ứng Hoè": [
    "ứng hoè",
    "uwsng hoef"
  ],
  "Ứng Hòa": [
    "ứng hòa",
    "uwsng hofa"
  ],
  " Mỹ Lộc": [
    " mỹ lộc",
    " myx loojc"
  ],
  " Đắk Lao": [
    " đắk lao",
    " ddawsk lao"
  ],
  "An Khương": [
    "an khương",
    "an khuwowng"
  ],
  "An Nghiệp": [
    "an nghiệp",
    "an nghieejp"
  ],
  "An Phước": [
    "an phước",
    "an phuwowsc"
  ],
  "An Tường": [
    "an tường",
    "an tuwowfng"
  ],
  "Biên Giang": [
    "biên giang",
    "bieen giang"
  ],
  "Biển Hồ": [
    "biển hồ",
    "bieern hoof"
  ],
  "Bon Phặng": [
    "bon phặng",
    "bon phawjng"
  ],
  "Buôn Choah": [
    "buôn choah",
    "buoon choah"
  ],
  "Buôn Tría": [
    "buôn tría",
    "buoon trisa"
  ],
  "Buôn Đôn": [
    "buôn đôn",
    "buoon ddoon"
  ],
  "Bà Triệu": [
    "bà triệu",
    "baf trieeju"
  ],
  "Bà Điểm": [
    "bà điểm",
    "baf ddieerm"
  ],
  "Bàn Giản": [
    "bàn giản",
    "bafn giarn"
  ],
  "Bàn Đạt": [
    "bàn đạt",
    "bafn ddajt"
  ],
  "Bàu Hàm 2": [
    "bàu hàm 2",
    "bafu hafm 2"
  ],
  "Bàu Đồn": [
    "bàu đồn",
    "bafu ddoofn"
  ],
  "Bách Quang": [
    "bách quang",
    "basch quang"
  ],
  "Bát Tràng": [
    "bát tràng",
    "bast trafng"
  ],
  "Bãi Trành": [
    "bãi trành",
    "baxi trafnh"
  ],
  "Bình Châu": [
    "bình châu",
    "bifnh chaau"
  ],
  "Bình Giang": [
    "bình giang",
    "bifnh giang"
  ],
  "Bình Giáo": [
    "bình giáo",
    "bifnh giaso"
  ],
  "Bình Hiên": [
    "bình hiên",
    "bifnh hieen"
  ],
  "Bình Hưng": [
    "bình hưng",
    "bifnh huwng"
  ],
  "Bình Hải": [
    "bình hải",
    "bifnh hari"
  ],
  "Bình Hẻm": [
    "bình hẻm",
    "bifnh herm"
  ],
  "Bình Liêu": [
    "bình liêu",
    "bifnh lieeu"
  ],
  "Bình Lãng": [
    "bình lãng",
    "bifnh laxng"
  ],
  "Bình Lãnh": [
    "bình lãnh",
    "bifnh laxnh"
  ],
  "Bình Lăng": [
    "bình lăng",
    "bifnh lawng"
  ],
  "Bình Lộc": [
    "bình lộc",
    "bifnh loojc"
  ],
  "Bình Lợi": [
    "bình lợi",
    "bifnh lowji"
  ],
  "Bình Lục": [
    "bình lục",
    "bifnh lujc"
  ],
  "Bình Nhâm": [
    "bình nhâm",
    "bifnh nhaam"
  ],
  "Bình Nhân": [
    "bình nhân",
    "bifnh nhaan"
  ],
  "Bình Phúc": [
    "bình phúc",
    "bifnh phusc"
  ],
  "Bình Quế": [
    "bình quế",
    "bifnh quees"
  ],
  "Bình Thanh": [
    "bình thanh",
    "bifnh thanh"
  ],
  "Bình Thọ": [
    "bình thọ",
    "bifnh thoj"
  ],
  "Bình Trung": [
    "bình trung",
    "bifnh trung"
  ],
  "Bình Trị": [
    "bình trị",
    "bifnh trij"
  ],
  "Bình Tấn": [
    "bình tấn",
    "bifnh taasn"
  ],
  "Bình Xuân": [
    "bình xuân",
    "bifnh xuaan"
  ],
  "Bình Đào": [
    "bình đào",
    "bifnh ddafo"
  ],
  "Bích Đào": [
    "bích đào",
    "bisch ddafo"
  ],
  "Bó Mười": [
    "bó mười",
    "bos muwowfi"
  ],
  "Bông Krang": [
    "bông krang",
    "boong krang"
  ],
  "Bông Trang": [
    "bông trang",
    "boong trang"
  ],
  "Bạc Liêu": [
    "bạc liêu",
    "bajc lieeu"
  ],
  "Bạch Hạ": [
    "bạch hạ",
    "bajch haj"
  ],
  "Bạch Long": [
    "bạch long",
    "bajch long"
  ],
  "Bạch Lưu": [
    "bạch lưu",
    "bajch luwu"
  ],
  "Bản Công": [
    "bản công",
    "barn coong"
  ],
  "Bản Cầm": [
    "bản cầm",
    "barn caafm"
  ],
  "Bản Giang": [
    "bản giang",
    "barn giang"
  ],
  "Bản Lầm": [
    "bản lầm",
    "barn laafm"
  ],
  "Bản Lầu": [
    "bản lầu",
    "barn laafu"
  ],
  "Bản Phố": [
    "bản phố",
    "barn phoos"
  ],
  "Bản Rịa": [
    "bản rịa",
    "barn rija"
  ],
  "Bảo Bình": [
    "bảo bình",
    "baro bifnh"
  ],
  "Bảo Hưng": [
    "bảo hưng",
    "baro huwng"
  ],
  "Bảo Lạc": [
    "bảo lạc",
    "baro lajc"
  ],
  "Bảo Lộc": [
    "bảo lộc",
    "baro loojc"
  ],
  "Bảo Quang": [
    "bảo quang",
    "baro quang"
  ],
  "Bảo Thanh": [
    "bảo thanh",
    "baro thanh"
  ],
  "Bảo Toàn": [
    "bảo toàn",
    "baro toafn"
  ],
  "Bảo Đài": [
    "bảo đài",
    "baro ddafi"
  ],
  "Bảy Ngàn": [
    "bảy ngàn",
    "bary ngafn"
  ],
  "Bắc Bình": [
    "bắc bình",
    "bawsc bifnh"
  ],
  "Bắc Giang": [
    "bắc giang",
    "bawsc giang"
  ],
  "Bắc Hùng": [
    "bắc hùng",
    "bawsc hufng"
  ],
  "Bắc Hưng": [
    "bắc hưng",
    "bawsc huwng"
  ],
  "Bắc Hải": [
    "bắc hải",
    "bawsc hari"
  ],
  "Bắc Kạn": [
    "bắc kạn",
    "bawsc kajn"
  ],
  "Bắc Lãng": [
    "bắc lãng",
    "bawsc laxng"
  ],
  "Bắc Lũng": [
    "bắc lũng",
    "bawsc luxng"
  ],
  "Bắc Phong": [
    "bắc phong",
    "bawsc phong"
  ],
  "Bắc Quang": [
    "bắc quang",
    "bawsc quang"
  ],
  "Bằng Cả": [
    "bằng cả",
    "bawfng car"
  ],
  "Bằng Giã": [
    "bằng giã",
    "bawfng giax"
  ],
  "Bằng Lang": [
    "bằng lang",
    "bawfng lang"
  ],
  "Bằng Vân": [
    "bằng vân",
    "bawfng vaan"
  ],
  "Bến Cầu": [
    "bến cầu",
    "beesn caafu"
  ],
  "Bến Củi": [
    "bến củi",
    "beesn curi"
  ],
  "Bến Lức": [
    "bến lức",
    "beesn luwsc"
  ],
  "Bến Nghé": [
    "bến nghé",
    "beesn nghes"
  ],
  "Bến Tắm": [
    "bến tắm",
    "beesn tawsm"
  ],
  "Bối Cầu": [
    "bối cầu",
    "boosi caafu"
  ],
  "Bồ Xuyên": [
    "bồ xuyên",
    "boof xuyeen"
  ],
  "Bồng Khê": [
    "bồng khê",
    "boofng khee"
  ],
  "Bồng Sơn": [
    "bồng sơn",
    "boofng sown"
  ],
  "Bờ Ngoong": [
    "bờ ngoong",
    "bowf ngoong"
  ],
  "Cam Thuận": [
    "cam thuận",
    "cam thuaajn"
  ],
  "Cam Tuyền": [
    "cam tuyền",
    "cam tuyeefn"
  ],
  "Canh Hiển": [
    "canh hiển",
    "canh hieern"
  ],
  "Canh Hiệp": [
    "canh hiệp",
    "canh hieejp"
  ],
  "Cao Dương": [
    "cao dương",
    "cao duwowng"
  ],
  "Cao Quảng": [
    "cao quảng",
    "cao quarng"
  ],
  "Cao Thắng": [
    "cao thắng",
    "cao thawsng"
  ],
  "Cao Thịnh": [
    "cao thịnh",
    "cao thijnh"
  ],
  "Chi Thiết": [
    "chi thiết",
    "chi thieest"
  ],
  "Chiêm Hóa": [
    "chiêm hóa",
    "chieem hosa"
  ],
  "Chiêu Lưu": [
    "chiêu lưu",
    "chieeu luwu"
  ],
  "Chiêu Yên": [
    "chiêu yên",
    "chieeu yeen"
  ],
  "Chiềng An": [
    "chiềng an",
    "chieefng an"
  ],
  "Chiềng En": [
    "chiềng en",
    "chieefng en"
  ],
  "Chiềng La": [
    "chiềng la",
    "chieefng la"
  ],
  "Chiềng Ly": [
    "chiềng ly",
    "chieefng ly"
  ],
  "Chiềng On": [
    "chiềng on",
    "chieefng on"
  ],
  "Chiềng Ve": [
    "chiềng ve",
    "chieefng ve"
  ],
  "Chu Hương": [
    "chu hương",
    "chu huwowng"
  ],
  "Chu Điện": [
    "chu điện",
    "chu ddieejn"
  ],
  "Chàng Sơn": [
    "chàng sơn",
    "chafng sown"
  ],
  "Chánh Lộ": [
    "chánh lộ",
    "chasnh looj"
  ],
  "Chánh Mỹ": [
    "chánh mỹ",
    "chasnh myx"
  ],
  "Châu Bình": [
    "châu bình",
    "chaau bifnh"
  ],
  "Châu Bính": [
    "châu bính",
    "chaau bisnh"
  ],
  "Châu Giang": [
    "châu giang",
    "chaau giang"
  ],
  "Châu Hoàn": [
    "châu hoàn",
    "chaau hoafn"
  ],
  "Châu Hưng": [
    "châu hưng",
    "chaau huwng"
  ],
  "Châu Hội": [
    "châu hội",
    "chaau hooji"
  ],
  "Châu Lăng": [
    "châu lăng",
    "chaau lawng"
  ],
  "Châu Lộc": [
    "châu lộc",
    "chaau loojc"
  ],
  "Châu Nhân": [
    "châu nhân",
    "chaau nhaan"
  ],
  "Châu Phong": [
    "châu phong",
    "chaau phong"
  ],
  "Châu Quang": [
    "châu quang",
    "chaau quang"
  ],
  "Châu Thái": [
    "châu thái",
    "chaau thasi"
  ],
  "Châu Thôn": [
    "châu thôn",
    "chaau thoon"
  ],
  "Chí Thảo": [
    "chí thảo",
    "chis tharo"
  ],
  "Chí Viễn": [
    "chí viễn",
    "chis vieexn"
  ],
  "Chí Đạo": [
    "chí đạo",
    "chis ddajo"
  ],
  "Chính Mỹ": [
    "chính mỹ",
    "chisnh myx"
  ],
  "Chư A Thai": [
    "chư a thai",
    "chuw a thai"
  ],
  "Chư Drăng": [
    "chư drăng",
    "chuw drawng"
  ],
  "Chư Ngọc": [
    "chư ngọc",
    "chuw ngojc"
  ],
  "Chư Prông": [
    "chư prông",
    "chuw proong"
  ],
  "Chế Tạo": [
    "chế tạo",
    "chees tajo"
  ],
  "Chợ Chùa": [
    "chợ chùa",
    "chowj chufa"
  ],
  "Chợ Gạo": [
    "chợ gạo",
    "chowj gajo"
  ],
  "Chợ Lách": [
    "chợ lách",
    "chowj lasch"
  ],
  "Chợ Lầu": [
    "chợ lầu",
    "chowj laafu"
  ],
  "Chợ Mới": [
    "chợ mới",
    "chowj mowsi"
  ],
  "Cuor Đăng": [
    "cuor đăng",
    "cuor ddawng"
  ],
  "Cuối Hạ": [
    "cuối hạ",
    "cuoosi haj"
  ],
  "Cành Nàng": [
    "cành nàng",
    "cafnh nafng"
  ],
  "Cái Chiên": [
    "cái chiên",
    "casi chieen"
  ],
  "Cái Rồng": [
    "cái rồng",
    "casi roofng"
  ],
  "Cát Chánh": [
    "cát chánh",
    "cast chasnh"
  ],
  "Cát Hiệp": [
    "cát hiệp",
    "cast hieejp"
  ],
  "Cát Khánh": [
    "cát khánh",
    "cast khasnh"
  ],
  "Cát Thành": [
    "cát thành",
    "cast thafnh"
  ],
  "Cát Tiến": [
    "cát tiến",
    "cast tieesn"
  ],
  "Côn Đảo": [
    "côn đảo",
    "coon ddaro"
  ],
  "Công Hải": [
    "công hải",
    "coong hari"
  ],
  "Công Liêm": [
    "công liêm",
    "coong lieem"
  ],
  "Căm Muộn": [
    "căm muộn",
    "cawm muoojn"
  ],
  "Cải Viên": [
    "cải viên",
    "cari vieen"
  ],
  "Cảm Nhân": [
    "cảm nhân",
    "carm nhaan"
  ],
  "Cảnh Hóa": [
    "cảnh hóa",
    "carnh hosa"
  ],
  "Cấn Hữu": [
    "cấn hữu",
    "caasn huwxu"
  ],
  "Cấp Dẫn": [
    "cấp dẫn",
    "caasp daaxn"
  ],
  "Cần Giờ": [
    "cần giờ",
    "caafn giowf"
  ],
  "Cần Nông": [
    "cần nông",
    "caafn noong"
  ],
  "Cầu Dền": [
    "cầu dền",
    "caafu deefn"
  ],
  "Cầu Giát": [
    "cầu giát",
    "caafu giast"
  ],
  "Cầu Lộc": [
    "cầu lộc",
    "caafu loojc"
  ],
  "Cầu Ngang": [
    "cầu ngang",
    "caafu ngang"
  ],
  "Cẩm Bình": [
    "cẩm bình",
    "caarm bifnh"
  ],
  "Cẩm Châu": [
    "cẩm châu",
    "caarm chaau"
  ],
  "Cẩm Chế": [
    "cẩm chế",
    "caarm chees"
  ],
  "Cẩm Duệ": [
    "cẩm duệ",
    "caarm dueej"
  ],
  "Cẩm Giang": [
    "cẩm giang",
    "caarm giang"
  ],
  "Cẩm Hưng": [
    "cẩm hưng",
    "caarm huwng"
  ],
  "Cẩm Hải": [
    "cẩm hải",
    "caarm hari"
  ],
  "Cẩm Liên": [
    "cẩm liên",
    "caarm lieen"
  ],
  "Cẩm Lĩnh": [
    "cẩm lĩnh",
    "caarm lixnh"
  ],
  "Cẩm Lạc": [
    "cẩm lạc",
    "caarm lajc"
  ],
  "Cẩm Lộc": [
    "cẩm lộc",
    "caarm loojc"
  ],
  "Cẩm Phúc": [
    "cẩm phúc",
    "caarm phusc"
  ],
  "Cẩm Phả": [
    "cẩm phả",
    "caarm phar"
  ],
  "Cẩm Quang": [
    "cẩm quang",
    "caarm quang"
  ],
  "Cẩm Thanh": [
    "cẩm thanh",
    "caarm thanh"
  ],
  "Cẩm Trung": [
    "cẩm trung",
    "caarm trung"
  ],
  "Cẩm Vĩnh": [
    "cẩm vĩnh",
    "caarm vixnh"
  ],
  "Cẩm Đàn": [
    "cẩm đàn",
    "caarm ddafn"
  ],
  "Cốc Lầu": [
    "cốc lầu",
    "coosc laafu"
  ],
  "Cốc Lếu": [
    "cốc lếu",
    "coosc leesu"
  ],
  "Cốc Pàng": [
    "cốc pàng",
    "coosc pafng"
  ],
  "Cốc Đán": [
    "cốc đán",
    "coosc ddasn"
  ],
  "Cống Vị": [
    "cống vị",
    "coosng vij"
  ],
  "Cổ Thành": [
    "cổ thành",
    "coor thafnh"
  ],
  "Cổ Đông": [
    "cổ đông",
    "coor ddoong"
  ],
  "Cỗ Đạm": [
    "cỗ đạm",
    "coox ddajm"
  ],
  "Cộng Hoà": [
    "cộng hoà",
    "coojng hoaf"
  ],
  "Cộng Hòa": [
    "cộng hòa",
    "coojng hofa"
  ],
  "Củng Sơn": [
    "củng sơn",
    "curng sown"
  ],
  "Cửa Bắc": [
    "cửa bắc",
    "cuwra bawsc"
  ],
  "Cửa Cạn": [
    "cửa cạn",
    "cuwra cajn"
  ],
  "Cửa Tùng": [
    "cửa tùng",
    "cuwra tufng"
  ],
  "Cự Khối": [
    "cự khối",
    "cuwj khoosi"
  ],
  "Diên Bình": [
    "diên bình",
    "dieen bifnh"
  ],
  "Diên Lạc": [
    "diên lạc",
    "dieen lajc"
  ],
  "Diên Thọ": [
    "diên thọ",
    "dieen thoj"
  ],
  "Diên Toàn": [
    "diên toàn",
    "dieen toafn"
  ],
  "Diên Xuân": [
    "diên xuân",
    "dieen xuaan"
  ],
  "Diễn Cát": [
    "diễn cát",
    "dieexn cast"
  ],
  "Diễn Kỷ": [
    "diễn kỷ",
    "dieexn kyr"
  ],
  "Diễn Lâm": [
    "diễn lâm",
    "dieexn laam"
  ],
  "Diễn Mỹ": [
    "diễn mỹ",
    "dieexn myx"
  ],
  "Diễn Phú": [
    "diễn phú",
    "dieexn phus"
  ],
  "Diễn Tân": [
    "diễn tân",
    "dieexn taan"
  ],
  "Diễn Yên": [
    "diễn yên",
    "dieexn yeen"
  ],
  "Dray Bhăng": [
    "dray bhăng",
    "dray bhawng"
  ],
  "Dân Thành": [
    "dân thành",
    "daan thafnh"
  ],
  "Dân Tiến": [
    "dân tiến",
    "daan tieesn"
  ],
  "Dũng Phong": [
    "dũng phong",
    "duxng phong"
  ],
  "Dương Huy": [
    "dương huy",
    "duwowng huy"
  ],
  "Dương Hà": [
    "dương hà",
    "duwowng haf"
  ],
  "Dương Tơ": [
    "dương tơ",
    "duwowng tow"
  ],
  "Dương Xá": [
    "dương xá",
    "duwowng xas"
  ],
  "Dầu Giây": [
    "dầu giây",
    "daafu giaay"
  ],
  "Dền Sáng": [
    "dền sáng",
    "deefn sasng"
  ],
  "Eachà Rang": [
    "eachà rang",
    "eachaf rang"
  ],
  "Gia Lương": [
    "gia lương",
    "gia luwowng"
  ],
  "Gia Thuận": [
    "gia thuận",
    "gia thuaajn"
  ],
  "Gia Thắng": [
    "gia thắng",
    "gia thawsng"
  ],
  "Gia Thịnh": [
    "gia thịnh",
    "gia thijnh"
  ],
  "Gia Điền": [
    "gia điền",
    "gia ddieefn"
  ],
  "Giai Phạm": [
    "giai phạm",
    "giai phajm"
  ],
  "Giang Biên": [
    "giang biên",
    "giang bieen"
  ],
  "Giang Hải": [
    "giang hải",
    "giang hari"
  ],
  "Giang Tiên": [
    "giang tiên",
    "giang tieen"
  ],
  "Giao Thủy": [
    "giao thủy",
    "giao thury"
  ],
  "Giao Tiến": [
    "giao tiến",
    "giao tieesn"
  ],
  "Giáo Liêm": [
    "giáo liêm",
    "giaso lieem"
  ],
  "Giáp Trung": [
    "giáp trung",
    "giasp trung"
  ],
  "Giảng Võ": [
    "giảng võ",
    "giarng vox"
  ],
  "Gành Dầu": [
    "gành dầu",
    "gafnh daafu"
  ],
  "Hiến Sơn": [
    "hiến sơn",
    "hieesn sown"
  ],
  "Hiếu Tử": [
    "hiếu tử",
    "hieesu tuwr"
  ],
  "Hiền Hào": [
    "hiền hào",
    "hieefn hafo"
  ],
  "Hiền Ninh": [
    "hiền ninh",
    "hieefn ninh"
  ],
  "Hiền Quan": [
    "hiền quan",
    "hieefn quan"
  ],
  "Hiệp Cát": [
    "hiệp cát",
    "hieejp cast"
  ],
  "Hiệp Hoà": [
    "hiệp hoà",
    "hieejp hoaf"
  ],
  "Hiệp Hòa": [
    "hiệp hòa",
    "hieejp hofa"
  ],
  "Hiệp Ninh": [
    "hiệp ninh",
    "hieejp ninh"
  ],
  "Hiệp Phú": [
    "hiệp phú",
    "hieejp phus"
  ],
  "Hiệp Sơn": [
    "hiệp sơn",
    "hieejp sown"
  ],
  "Hiệp Tân": [
    "hiệp tân",
    "hieejp taan"
  ],
  "Hoa Động": [
    "hoa động",
    "hoa ddoojng"
  ],
  "Hoang Thèn": [
    "hoang thèn",
    "hoang thefn"
  ],
  "Hoà Chánh": [
    "hoà chánh",
    "hoaf chasnh"
  ],
  "Hoà Hiếu": [
    "hoà hiếu",
    "hoaf hieesu"
  ],
  "Hoà Nghĩa": [
    "hoà nghĩa",
    "hoaf nghixa"
  ],
  "Hoài Châu": [
    "hoài châu",
    "hoafi chaau"
  ],
  "Hoài Hải": [
    "hoài hải",
    "hoafi hari"
  ],
  "Hoài Hảo": [
    "hoài hảo",
    "hoafi haro"
  ],
  "Hoài Nhơn": [
    "hoài nhơn",
    "hoafi nhown"
  ],
  "Hoài Thanh": [
    "hoài thanh",
    "hoafi thanh"
  ],
  "Hoài Xuân": [
    "hoài xuân",
    "hoafi xuaan"
  ],
  "Hoàng Hanh": [
    "hoàng hanh",
    "hoafng hanh"
  ],
  "Hoàng Khai": [
    "hoàng khai",
    "hoafng khai"
  ],
  "Hoàng Long": [
    "hoàng long",
    "hoafng long"
  ],
  "Hoàng Lâu": [
    "hoàng lâu",
    "hoafng laau"
  ],
  "Hoàng Sơn": [
    "hoàng sơn",
    "hoafng sown"
  ],
  "Hoàng Trĩ": [
    "hoàng trĩ",
    "hoafng trix"
  ],
  "Hoàng Tung": [
    "hoàng tung",
    "hoafng tung"
  ],
  "Hoàng Tân": [
    "hoàng tân",
    "hoafng taan"
  ],
  "Hoàng Tây": [
    "hoàng tây",
    "hoafng taay"
  ],
  "Hoàng Vân": [
    "hoàng vân",
    "hoafng vaan"
  ],
  "Hoàng Đan": [
    "hoàng đan",
    "hoafng ddan"
  ],
  "Hoành Bồ": [
    "hoành bồ",
    "hoafnh boof"
  ],
  "Hoành Sơn": [
    "hoành sơn",
    "hoafnh sown"
  ],
  "Hoả Lựu": [
    "hoả lựu",
    "hoar luwju"
  ],
  "Hoằng Hà": [
    "hoằng hà",
    "hoawfng haf"
  ],
  "Hoằng Kim": [
    "hoằng kim",
    "hoawfng kim"
  ],
  "Huồi Tụ": [
    "huồi tụ",
    "huoofi tuj"
  ],
  "Hà Lương": [
    "hà lương",
    "haf luwowng"
  ],
  "Hà Quảng": [
    "hà quảng",
    "haf quarng"
  ],
  "Hà Thạch": [
    "hà thạch",
    "haf thajch"
  ],
  "Hàm Chính": [
    "hàm chính",
    "hafm chisnh"
  ],
  "Hàm Hiệp": [
    "hàm hiệp",
    "hafm hieejp"
  ],
  "Hàm Kiệm": [
    "hàm kiệm",
    "hafm kieejm"
  ],
  "Hàm Rồng": [
    "hàm rồng",
    "hafm roofng"
  ],
  "Hàm Tiến": [
    "hàm tiến",
    "hafm tieesn"
  ],
  "Hàm Đức": [
    "hàm đức",
    "hafm dduwsc"
  ],
  "Hàng Bông": [
    "hàng bông",
    "hafng boong"
  ],
  "Hàng Bạc": [
    "hàng bạc",
    "hafng bajc"
  ],
  "Hàng Bột": [
    "hàng bột",
    "hafng boojt"
  ],
  "Hàng Kênh": [
    "hàng kênh",
    "hafng keenh"
  ],
  "Hàng Đào": [
    "hàng đào",
    "hafng ddafo"
  ],
  "Hành Dũng": [
    "hành dũng",
    "hafnh duxng"
  ],
  "Hành Nhân": [
    "hành nhân",
    "hafnh nhaan"
  ],
  "Hành Trung": [
    "hành trung",
    "hafnh trung"
  ],
  "Hòa Chính": [
    "hòa chính",
    "hofa chisnh"
  ],
  "Hòa Cuông": [
    "hòa cuông",
    "hofa cuoong"
  ],
  "Hòa Hiệp": [
    "hòa hiệp",
    "hofa hieejp"
  ],
  "Hòa Khánh": [
    "hòa khánh",
    "hofa khasnh"
  ],
  "Hòa Kiến": [
    "hòa kiến",
    "hofa kieesn"
  ],
  "Hòa Nghĩa": [
    "hòa nghĩa",
    "hofa nghixa"
  ],
  "Hòa Thành": [
    "hòa thành",
    "hofa thafnh"
  ],
  "Hòa Tiến": [
    "hòa tiến",
    "hofa tieesn"
  ],
  "Hòa Tú II": [
    "hòa tú ii",
    "hofa tus ii"
  ],
  "Hòa Tịnh": [
    "hòa tịnh",
    "hofa tijnh"
  ],
  "Hòa Đông": [
    "hòa đông",
    "hofa ddoong"
  ],
  "Hòn Nghệ": [
    "hòn nghệ",
    "hofn ngheej"
  ],
  "Hòn Đất": [
    "hòn đất",
    "hofn ddaast"
  ],
  "Hóa Tiến": [
    "hóa tiến",
    "hosa tieesn"
  ],
  "Hùng Dũng": [
    "hùng dũng",
    "hufng duxng"
  ],
  "Hùng Lợi": [
    "hùng lợi",
    "hufng lowji"
  ],
  "Hưng Bình": [
    "hưng bình",
    "huwng bifnh"
  ],
  "Hưng Công": [
    "hưng công",
    "huwng coong"
  ],
  "Hưng Dũng": [
    "hưng dũng",
    "huwng duxng"
  ],
  "Hưng Hội": [
    "hưng hội",
    "huwng hooji"
  ],
  "Hưng Lĩnh": [
    "hưng lĩnh",
    "huwng lixnh"
  ],
  "Hưng Lộc": [
    "hưng lộc",
    "huwng loojc"
  ],
  "Hưng Lợi": [
    "hưng lợi",
    "huwng lowji"
  ],
  "Hưng Nhân": [
    "hưng nhân",
    "huwng nhaan"
  ],
  "Hưng Phong": [
    "hưng phong",
    "huwng phong"
  ],
  "Hưng Phúc": [
    "hưng phúc",
    "huwng phusc"
  ],
  "Hưng Trung": [
    "hưng trung",
    "huwng trung"
  ],
  "Hương Mai": [
    "hương mai",
    "huwowng mai"
  ],
  "Hương Sơ": [
    "hương sơ",
    "huwowng sow"
  ],
  "Hương Vĩ": [
    "hương vĩ",
    "huwowng vix"
  ],
  "Hạ Bằng": [
    "hạ bằng",
    "haj bawfng"
  ],
  "Hạ Đình": [
    "hạ đình",
    "haj ddifnh"
  ],
  "Hạnh Lâm": [
    "hạnh lâm",
    "hajnh laam"
  ],
  "Hạnh Sơn": [
    "hạnh sơn",
    "hajnh sown"
  ],
  "Hạp Lĩnh": [
    "hạp lĩnh",
    "hajp lixnh"
  ],
  "Hải Bình": [
    "hải bình",
    "hari bifnh"
  ],
  "Hải Bắc": [
    "hải bắc",
    "hari bawsc"
  ],
  "Hải Bối": [
    "hải bối",
    "hari boosi"
  ],
  "Hải Châu": [
    "hải châu",
    "hari chaau"
  ],
  "Hải Giang": [
    "hải giang",
    "hari giang"
  ],
  "Hải Hưng": [
    "hải hưng",
    "hari huwng"
  ],
  "Hải Hậu": [
    "hải hậu",
    "hari haaju"
  ],
  "Hải Lăng": [
    "hải lăng",
    "hari lawng"
  ],
  "Hải Lĩnh": [
    "hải lĩnh",
    "hari lixnh"
  ],
  "Hải Lộc": [
    "hải lộc",
    "hari loojc"
  ],
  "Hải Lựu": [
    "hải lựu",
    "hari luwju"
  ],
  "Hải Nhân": [
    "hải nhân",
    "hari nhaan"
  ],
  "Hải Phong": [
    "hải phong",
    "hari phong"
  ],
  "Hải Phúc": [
    "hải phúc",
    "hari phusc"
  ],
  "Hải Quang": [
    "hải quang",
    "hari quang"
  ],
  "Hải Quế": [
    "hải quế",
    "hari quees"
  ],
  "Hải Thanh": [
    "hải thanh",
    "hari thanh"
  ],
  "Hải Thái": [
    "hải thái",
    "hari thasi"
  ],
  "Hải Trung": [
    "hải trung",
    "hari trung"
  ],
  "Hải Xuân": [
    "hải xuân",
    "hari xuaan"
  ],
  "Hải Yến": [
    "hải yến",
    "hari yeesn"
  ],
  "Hậu Giang": [
    "hậu giang",
    "haaju giang"
  ],
  "Hậu Lộc": [
    "hậu lộc",
    "haaju loojc"
  ],
  "Hẹ Muông": [
    "hẹ muông",
    "hej muoong"
  ],
  "Hồ Thầu": [
    "hồ thầu",
    "hoof thaafu"
  ],
  "Hồi Xuân": [
    "hồi xuân",
    "hoofi xuaan"
  ],
  "Hồng Dân": [
    "hồng dân",
    "hoofng daan"
  ],
  "Hồng Dụ": [
    "hồng dụ",
    "hoofng duj"
  ],
  "Hồng Hóa": [
    "hồng hóa",
    "hoofng hosa"
  ],
  "Hồng Hạ": [
    "hồng hạ",
    "hoofng haj"
  ],
  "Hồng Khê": [
    "hồng khê",
    "hoofng khee"
  ],
  "Hồng Kỳ": [
    "hồng kỳ",
    "hoofng kyf"
  ],
  "Hồng Long": [
    "hồng long",
    "hoofng long"
  ],
  "Hồng Minh": [
    "hồng minh",
    "hoofng minh"
  ],
  "Hồng Sơn": [
    "hồng sơn",
    "hoofng sown"
  ],
  "Hồng Sỹ": [
    "hồng sỹ",
    "hoofng syx"
  ],
  "Hồng Vân": [
    "hồng vân",
    "hoofng vaan"
  ],
  "Hộ Phòng": [
    "hộ phòng",
    "hooj phofng"
  ],
  "Hội Hợp": [
    "hội hợp",
    "hooji howjp"
  ],
  "Hội Xuân": [
    "hội xuân",
    "hooji xuaan"
  ],
  "Hợp Châu": [
    "hợp châu",
    "howjp chaau"
  ],
  "Hợp Giang": [
    "hợp giang",
    "howjp giang"
  ],
  "Hợp Hưng": [
    "hợp hưng",
    "howjp huwng"
  ],
  "Hợp Phong": [
    "hợp phong",
    "howjp phong"
  ],
  "Hợp Thanh": [
    "hợp thanh",
    "howjp thanh"
  ],
  "Hừa Ngài": [
    "hừa ngài",
    "huwfa ngafi"
  ],
  "Hữu Kiên": [
    "hữu kiên",
    "huwxu kieen"
  ],
  "Hữu Liên": [
    "hữu liên",
    "huwxu lieen"
  ],
  "Hữu Lũng": [
    "hữu lũng",
    "huwxu luxng"
  ],
  "Hữu Lập": [
    "hữu lập",
    "huwxu laajp"
  ],
  "Hữu Lợi": [
    "hữu lợi",
    "huwxu lowji"
  ],
  "Hữu Sản": [
    "hữu sản",
    "huwxu sarn"
  ],
  "KRông Búk": [
    "krông búk",
    "kroong busk"
  ],
  "Khuê Trung": [
    "khuê trung",
    "khuee trung"
  ],
  "Khuất Xá": [
    "khuất xá",
    "khuaast xas"
  ],
  "Khánh Hoà": [
    "khánh hoà",
    "khasnh hoaf"
  ],
  "Khánh Hòa": [
    "khánh hòa",
    "khasnh hofa"
  ],
  "Khánh Khê": [
    "khánh khê",
    "khasnh khee"
  ],
  "Khánh Long": [
    "khánh long",
    "khasnh long"
  ],
  "Khánh Lâm": [
    "khánh lâm",
    "khasnh laam"
  ],
  "Khánh Phú": [
    "khánh phú",
    "khasnh phus"
  ],
  "Khánh Sơn": [
    "khánh sơn",
    "khasnh sown"
  ],
  "Khánh Vân": [
    "khánh vân",
    "khasnh vaan"
  ],
  "Khánh Yên": [
    "khánh yên",
    "khasnh yeen"
  ],
  "Khả Cửu": [
    "khả cửu",
    "khar cuwru"
  ],
  "Khả Phong": [
    "khả phong",
    "khar phong"
  ],
  "Kim Thạch": [
    "kim thạch",
    "kim thajch"
  ],
  "Kim Định": [
    "kim định",
    "kim ddijnh"
  ],
  "Kim Đồng": [
    "kim đồng",
    "kim ddoofng"
  ],
  "Kim Động": [
    "kim động",
    "kim ddoojng"
  ],
  "Kiên Bình": [
    "kiên bình",
    "kieen bifnh"
  ],
  "Kiên Giang": [
    "kiên giang",
    "kieen giang"
  ],
  "Kiên Hải": [
    "kiên hải",
    "kieen hari"
  ],
  "Kiên Mộc": [
    "kiên mộc",
    "kieen moojc"
  ],
  "Kiên Thọ": [
    "kiên thọ",
    "kieen thoj"
  ],
  "Kiên Đài": [
    "kiên đài",
    "kieen ddafi"
  ],
  "Kiền Bái": [
    "kiền bái",
    "kieefn basi"
  ],
  "Kiện Khê": [
    "kiện khê",
    "kieejn khee"
  ],
  "Kiệt Sơn": [
    "kiệt sơn",
    "kieejt sown"
  ],
  "Kon Chiêng": [
    "kon chiêng",
    "kon chieeng"
  ],
  "Krông A Na": [
    "krông a na",
    "kroong a na"
  ],
  "Krông Búk": [
    "krông búk",
    "kroong busk"
  ],
  "Krông Jing": [
    "krông jing",
    "kroong jing"
  ],
  "Krông Kmar": [
    "krông kmar",
    "kroong kmar"
  ],
  "Kênh Giang": [
    "kênh giang",
    "keenh giang"
  ],
  "Kế Thành": [
    "kế thành",
    "kees thafnh"
  ],
  "Kỳ Tiến": [
    "kỳ tiến",
    "kyf tieesn"
  ],
  "Lai Đồng": [
    "lai đồng",
    "lai ddoofng"
  ],
  "Lam Điền": [
    "lam điền",
    "lam ddieefn"
  ],
  "Lang Chánh": [
    "lang chánh",
    "lang chasnh"
  ],
  "Linh Thông": [
    "linh thông",
    "linh thoong"
  ],
  "Linh Đông": [
    "linh đông",
    "linh ddoong"
  ],
  "Liêm Chung": [
    "liêm chung",
    "lieem chung"
  ],
  "Liêm Cần": [
    "liêm cần",
    "lieem caafn"
  ],
  "Liêm Hải": [
    "liêm hải",
    "lieem hari"
  ],
  "Liêm Phong": [
    "liêm phong",
    "lieem phong"
  ],
  "Liên Bạt": [
    "liên bạt",
    "lieen bajt"
  ],
  "Liên Bảo": [
    "liên bảo",
    "lieen baro"
  ],
  "Liên Chung": [
    "liên chung",
    "lieen chung"
  ],
  "Liên Châu": [
    "liên châu",
    "lieen chaau"
  ],
  "Liên Giang": [
    "liên giang",
    "lieen giang"
  ],
  "Liên Hội": [
    "liên hội",
    "lieen hooji"
  ],
  "Liên Hợp": [
    "liên hợp",
    "lieen howjp"
  ],
  "Liên Lộc": [
    "liên lộc",
    "lieen loojc"
  ],
  "Liên Mạc": [
    "liên mạc",
    "lieen majc"
  ],
  "Liên Trung": [
    "liên trung",
    "lieen trung"
  ],
  "Liễn Sơn": [
    "liễn sơn",
    "lieexn sown"
  ],
  "Liễu Giai": [
    "liễu giai",
    "lieexu giai"
  ],
  "Liễu Đô": [
    "liễu đô",
    "lieexu ddoo"
  ],
  "Long Chánh": [
    "long chánh",
    "long chasnh"
  ],
  "Long Hiệp": [
    "long hiệp",
    "long hieejp"
  ],
  "Long Khánh": [
    "long khánh",
    "long khasnh"
  ],
  "Long Kiến": [
    "long kiến",
    "long kieesn"
  ],
  "Long Thành": [
    "long thành",
    "long thafnh"
  ],
  "Long Thới": [
    "long thới",
    "long thowsi"
  ],
  "Long Thủy": [
    "long thủy",
    "long thury"
  ],
  "Long Xuyên": [
    "long xuyên",
    "long xuyeen"
  ],
  "Long Đức": [
    "long đức",
    "long dduwsc"
  ],
  "Luận Khê": [
    "luận khê",
    "luaajn khee"
  ],
  "Lái Hiếu": [
    "lái hiếu",
    "lasi hieesu"
  ],
  "Lái Thiêu": [
    "lái thiêu",
    "lasi thieeu"
  ],
  "Láng Lớn": [
    "láng lớn",
    "lasng lowsn"
  ],
  "Láng Tròn": [
    "láng tròn",
    "lasng trofn"
  ],
  "Lâm Kiết": [
    "lâm kiết",
    "laam kieest"
  ],
  "Lâm Thủy": [
    "lâm thủy",
    "laam thury"
  ],
  "Lâm Đớt": [
    "lâm đớt",
    "laam ddowst"
  ],
  "Lãng Công": [
    "lãng công",
    "laxng coong"
  ],
  "Lãng Ngâm": [
    "lãng ngâm",
    "laxng ngaam"
  ],
  "Lê Thiện": [
    "lê thiện",
    "lee thieejn"
  ],
  "Lóng Sập": [
    "lóng sập",
    "losng saajp"
  ],
  "Lùng Cải": [
    "lùng cải",
    "lufng cari"
  ],
  "Lý Trạch": [
    "lý trạch",
    "lys trajch"
  ],
  "Lũng Chinh": [
    "lũng chinh",
    "luxng chinh"
  ],
  "Lũng Niêm": [
    "lũng niêm",
    "luxng nieem"
  ],
  "Lũng Nặm": [
    "lũng nặm",
    "luxng nawjm"
  ],
  "Lũng Phìn": [
    "lũng phìn",
    "luxng phifn"
  ],
  "Lưu Hoàng": [
    "lưu hoàng",
    "luwu hoafng"
  ],
  "Lưu Kiếm": [
    "lưu kiếm",
    "luwu kieesm"
  ],
  "Lưu Kiền": [
    "lưu kiền",
    "luwu kieefn"
  ],
  "Lương Can": [
    "lương can",
    "luwowng can"
  ],
  "Lương Nha": [
    "lương nha",
    "luwowng nha"
  ],
  "Lương Phi": [
    "lương phi",
    "luwowng phi"
  ],
  "Lạc Nông": [
    "lạc nông",
    "lajc noong"
  ],
  "Lạc Tánh": [
    "lạc tánh",
    "lajc tasnh"
  ],
  "Lạc Tấn": [
    "lạc tấn",
    "lajc taasn"
  ],
  "Lạc Viên": [
    "lạc viên",
    "lajc vieen"
  ],
  "Lạc Xuân": [
    "lạc xuân",
    "lajc xuaan"
  ],
  "Lạch Tray": [
    "lạch tray",
    "lajch tray"
  ],
  "Lại Xuân": [
    "lại xuân",
    "laji xuaan"
  ],
  "Lạng Khê": [
    "lạng khê",
    "lajng khee"
  ],
  "Lạng Sơn": [
    "lạng sơn",
    "lajng sown"
  ],
  "Lệ Thủy": [
    "lệ thủy",
    "leej thury"
  ],
  "Lệ Viễn": [
    "lệ viễn",
    "leej vieexn"
  ],
  "Lộc Bình": [
    "lộc bình",
    "loojc bifnh"
  ],
  "Lộc Bảo": [
    "lộc bảo",
    "loojc baro"
  ],
  "Lộc Bắc": [
    "lộc bắc",
    "loojc bawsc"
  ],
  "Lộc Bổn": [
    "lộc bổn",
    "loojc boorn"
  ],
  "Lộc Châu": [
    "lộc châu",
    "loojc chaau"
  ],
  "Lộc Giang": [
    "lộc giang",
    "loojc giang"
  ],
  "Lộc Hưng": [
    "lộc hưng",
    "loojc huwng"
  ],
  "Lộc Ngãi": [
    "lộc ngãi",
    "loojc ngaxi"
  ],
  "Lộc Phát": [
    "lộc phát",
    "loojc phast"
  ],
  "Lộc Quang": [
    "lộc quang",
    "loojc quang"
  ],
  "Lộc Thanh": [
    "lộc thanh",
    "loojc thanh"
  ],
  "Lộc Thái": [
    "lộc thái",
    "loojc thasi"
  ],
  "Lộc Thọ": [
    "lộc thọ",
    "loojc thoj"
  ],
  "Lộc Tấn": [
    "lộc tấn",
    "loojc taasn"
  ],
  "Lộc Vĩnh": [
    "lộc vĩnh",
    "loojc vixnh"
  ],
  "Lợi Hải": [
    "lợi hải",
    "lowji hari"
  ],
  "Lục Bình": [
    "lục bình",
    "lujc bifnh"
  ],
  "Lục Hồn": [
    "lục hồn",
    "lujc hoofn"
  ],
  "Lực Hành": [
    "lực hành",
    "luwjc hafnh"
  ],
  "Mai Động": [
    "mai động",
    "mai ddoojng"
  ],
  "Minh Diệu": [
    "minh diệu",
    "minh dieeju"
  ],
  "Minh Hiệp": [
    "minh hiệp",
    "minh hieejp"
  ],
  "Minh Hoàng": [
    "minh hoàng",
    "minh hoafng"
  ],
  "Minh Nghĩa": [
    "minh nghĩa",
    "minh nghixa"
  ],
  "Minh Ngọc": [
    "minh ngọc",
    "minh ngojc"
  ],
  "Minh Thành": [
    "minh thành",
    "minh thafnh"
  ],
  "Minh Tiến": [
    "minh tiến",
    "minh tieesn"
  ],
  "Minh Đạo": [
    "minh đạo",
    "minh ddajo"
  ],
  "Minh Đức": [
    "minh đức",
    "minh dduwsc"
  ],
  "Mãn Đức": [
    "mãn đức",
    "maxn dduwsc"
  ],
  "Măng Cành": [
    "măng cành",
    "mawng cafnh"
  ],
  "Mường Bo": [
    "mường bo",
    "muwowfng bo"
  ],
  "Mường Do": [
    "mường do",
    "muwowfng do"
  ],
  "Mường La": [
    "mường la",
    "muwowfng la"
  ],
  "Mường So": [
    "mường so",
    "muwowfng so"
  ],
  "Mường Vi": [
    "mường vi",
    "muwowfng vi"
  ],
  "Mường é": [
    "mường é",
    "muwowfng es"
  ],
  "Mạn Lạn": [
    "mạn lạn",
    "majn lajn"
  ],
  "Mậu Duệ": [
    "mậu duệ",
    "maaju dueej"
  ],
  "Mộ Đạo": [
    "mộ đạo",
    "mooj ddajo"
  ],
  "Mộ Đức": [
    "mộ đức",
    "mooj dduwsc"
  ],
  "Mộc Bắc": [
    "mộc bắc",
    "moojc bawsc"
  ],
  "Mộc Châu": [
    "mộc châu",
    "moojc chaau"
  ],
  "Một Ngàn": [
    "một ngàn",
    "moojt ngafn"
  ],
  "Mỹ Bằng": [
    "mỹ bằng",
    "myx bawfng"
  ],
  "Mỹ Chánh": [
    "mỹ chánh",
    "myx chasnh"
  ],
  "Mỹ Hiệp": [
    "mỹ hiệp",
    "myx hieejp"
  ],
  "Mỹ Khánh": [
    "mỹ khánh",
    "myx khasnh"
  ],
  "Mỹ Luông": [
    "mỹ luông",
    "myx luoong"
  ],
  "Mỹ Quới": [
    "mỹ quới",
    "myx quowsi"
  ],
  "Mỹ Thành": [
    "mỹ thành",
    "myx thafnh"
  ],
  "Mỹ Thới": [
    "mỹ thới",
    "myx thowsi"
  ],
  "Mỹ Thủy": [
    "mỹ thủy",
    "myx thury"
  ],
  "Mỹ Tiến": [
    "mỹ tiến",
    "myx tieesn"
  ],
  "Mỹ Xuyên": [
    "mỹ xuyên",
    "myx xuyeen"
  ],
  "Mỹ Đông": [
    "mỹ đông",
    "myx ddoong"
  ],
  "Mỹ Đức": [
    "mỹ đức",
    "myx dduwsc"
  ],
  "N'Thol Hạ": [
    "n'thol hạ",
    "n'thol haj"
  ],
  "Nam Dương": [
    "nam dương",
    "nam duwowng"
  ],
  "Nam Thái A": [
    "nam thái a",
    "nam thasi a"
  ],
  "Nam Thắng": [
    "nam thắng",
    "nam thawsng"
  ],
  "Nam Thịnh": [
    "nam thịnh",
    "nam thijnh"
  ],
  "Nam Triều": [
    "nam triều",
    "nam trieefu"
  ],
  "Nam Trà My": [
    "nam trà my",
    "nam traf my"
  ],
  "Nam Trạch": [
    "nam trạch",
    "nam trajch"
  ],
  "Nam Điền": [
    "nam điền",
    "nam ddieefn"
  ],
  "Nam Định": [
    "nam định",
    "nam ddijnh"
  ],
  "Nam Đồng": [
    "nam đồng",
    "nam ddoofng"
  ],
  "Nam Động": [
    "nam động",
    "nam ddoojng"
  ],
  "Nga Thiện": [
    "nga thiện",
    "nga thieejn"
  ],
  "Nga Thạch": [
    "nga thạch",
    "nga thajch"
  ],
  "Nga Thắng": [
    "nga thắng",
    "nga thawsng"
  ],
  "Nga Điền": [
    "nga điền",
    "nga ddieefn"
  ],
  "Nghi Kiều": [
    "nghi kiều",
    "nghi kieefu"
  ],
  "Nghi Thuỷ": [
    "nghi thuỷ",
    "nghi thuyr"
  ],
  "Nghi Tiến": [
    "nghi tiến",
    "nghi tieesn"
  ],
  "Nghi Đức": [
    "nghi đức",
    "nghi dduwsc"
  ],
  "Nghĩa Dân": [
    "nghĩa dân",
    "nghixa daan"
  ],
  "Nghĩa Hòa": [
    "nghĩa hòa",
    "nghixa hofa"
  ],
  "Nghĩa Kỳ": [
    "nghĩa kỳ",
    "nghixa kyf"
  ],
  "Nghĩa Long": [
    "nghĩa long",
    "nghixa long"
  ],
  "Nghĩa Lâm": [
    "nghĩa lâm",
    "nghixa laam"
  ],
  "Nghĩa Lộ": [
    "nghĩa lộ",
    "nghixa looj"
  ],
  "Nghĩa Minh": [
    "nghĩa minh",
    "nghixa minh"
  ],
  "Nghĩa Mỹ": [
    "nghĩa mỹ",
    "nghixa myx"
  ],
  "Nghĩa Ninh": [
    "nghĩa ninh",
    "nghixa ninh"
  ],
  "Nghĩa Phú": [
    "nghĩa phú",
    "nghixa phus"
  ],
  "Nghĩa Sơn": [
    "nghĩa sơn",
    "nghixa sown"
  ],
  "Nghĩa Tâm": [
    "nghĩa tâm",
    "nghixa taam"
  ],
  "Nghĩa Tân": [
    "nghĩa tân",
    "nghixa taan"
  ],
  "Nghĩa Yên": [
    "nghĩa yên",
    "nghixa yeen"
  ],
  "Nghĩa Đô": [
    "nghĩa đô",
    "nghixa ddoo"
  ],
  "Nguyên Lý": [
    "nguyên lý",
    "nguyeen lys"
  ],
  "Nguyên Xá": [
    "nguyên xá",
    "nguyeen xas"
  ],
  "Nguyễn Du": [
    "nguyễn du",
    "nguyeexn du"
  ],
  "Ngãi Hùng": [
    "ngãi hùng",
    "ngaxi hufng"
  ],
  "Ngũ Hiệp": [
    "ngũ hiệp",
    "ngux hieejp"
  ],
  "Ngọc Côn": [
    "ngọc côn",
    "ngojc coon"
  ],
  "Ngọc Hoà": [
    "ngọc hoà",
    "ngojc hoaf"
  ],
  "Ngọc Hòa": [
    "ngọc hòa",
    "ngojc hofa"
  ],
  "Ngọc Khê": [
    "ngọc khê",
    "ngojc khee"
  ],
  "Ngọc Kỳ": [
    "ngọc kỳ",
    "ngojc kyf"
  ],
  "Ngọc Linh": [
    "ngọc linh",
    "ngojc linh"
  ],
  "Ngọc Long": [
    "ngọc long",
    "ngojc long"
  ],
  "Ngọc Lâm": [
    "ngọc lâm",
    "ngojc laam"
  ],
  "Ngọc Lâu": [
    "ngọc lâu",
    "ngojc laau"
  ],
  "Ngọc Lây": [
    "ngọc lây",
    "ngojc laay"
  ],
  "Ngọc Minh": [
    "ngọc minh",
    "ngojc minh"
  ],
  "Ngọc Mỹ": [
    "ngọc mỹ",
    "ngojc myx"
  ],
  "Ngọc Quan": [
    "ngọc quan",
    "ngojc quan"
  ],
  "Ngọc Sơn": [
    "ngọc sơn",
    "ngojc sown"
  ],
  "Ngọc Tố": [
    "ngọc tố",
    "ngojc toos"
  ],
  "Ngọc Vân": [
    "ngọc vân",
    "ngojc vaan"
  ],
  "Ngọc Yêu": [
    "ngọc yêu",
    "ngojc yeeu"
  ],
  "Ngọk Tụ": [
    "ngọk tụ",
    "ngojk tuj"
  ],
  "Ngối Cáy": [
    "ngối cáy",
    "ngoosi casy"
  ],
  "Nham Biền": [
    "nham biền",
    "nham bieefn"
  ],
  "Nhân Bình": [
    "nhân bình",
    "nhaan bifnh"
  ],
  "Nhân Huệ": [
    "nhân huệ",
    "nhaan hueej"
  ],
  "Nhân Khang": [
    "nhân khang",
    "nhaan khang"
  ],
  "Nhân Mục": [
    "nhân mục",
    "nhaan mujc"
  ],
  "Nhã Lộng": [
    "nhã lộng",
    "nhax loojng"
  ],
  "Nhơn Bình": [
    "nhơn bình",
    "nhown bifnh"
  ],
  "Nhơn Châu": [
    "nhơn châu",
    "nhown chaau"
  ],
  "Nhơn Hưng": [
    "nhơn hưng",
    "nhown huwng"
  ],
  "Nhơn Hải": [
    "nhơn hải",
    "nhown hari"
  ],
  "Nhơn Hậu": [
    "nhơn hậu",
    "nhown haaju"
  ],
  "Nhơn Hội": [
    "nhơn hội",
    "nhown hooji"
  ],
  "Nhơn Lộc": [
    "nhơn lộc",
    "nhown loojc"
  ],
  "Nhơn Phong": [
    "nhơn phong",
    "nhown phong"
  ],
  "Nhơn Phúc": [
    "nhơn phúc",
    "nhown phusc"
  ],
  "Nhơn Thọ": [
    "nhơn thọ",
    "nhown thoj"
  ],
  "Như Thụy": [
    "như thụy",
    "nhuw thujy"
  ],
  "Nhạc Kỳ": [
    "nhạc kỳ",
    "nhajc kyf"
  ],
  "Nhạn Môn": [
    "nhạn môn",
    "nhajn moon"
  ],
  "Nhạo Sơn": [
    "nhạo sơn",
    "nhajo sown"
  ],
  "Nhất Hòa": [
    "nhất hòa",
    "nhaast hofa"
  ],
  "Nhật Tân": [
    "nhật tân",
    "nhaajt taan"
  ],
  "Nhị Bình": [
    "nhị bình",
    "nhij bifnh"
  ],
  "Nhị Châu": [
    "nhị châu",
    "nhij chaau"
  ],
  "Nhựt Ninh": [
    "nhựt ninh",
    "nhuwjt ninh"
  ],
  "Ninh Hiệp": [
    "ninh hiệp",
    "ninh hieejp"
  ],
  "Ninh Khánh": [
    "ninh khánh",
    "ninh khasnh"
  ],
  "Ninh Kiều": [
    "ninh kiều",
    "ninh kieefu"
  ],
  "Ninh Nhất": [
    "ninh nhất",
    "ninh nhaast"
  ],
  "Ninh Quới": [
    "ninh quới",
    "ninh quowsi"
  ],
  "Ninh Thới": [
    "ninh thới",
    "ninh thowsi"
  ],
  "Ninh Thủy": [
    "ninh thủy",
    "ninh thury"
  ],
  "Ninh Tiến": [
    "ninh tiến",
    "ninh tieesn"
  ],
  "Ninh Đông": [
    "ninh đông",
    "ninh ddoong"
  ],
  "Niêm Tòng": [
    "niêm tòng",
    "nieem tofng"
  ],
  "Noong Hẻo": [
    "noong hẻo",
    "noong hero"
  ],
  "Nuông Dăm": [
    "nuông dăm",
    "nuoong dawm"
  ],
  "Nà Nghịu": [
    "nà nghịu",
    "naf nghiju"
  ],
  "Nàng Đôn": [
    "nàng đôn",
    "nafng ddoon"
  ],
  "Nánh Nghê": [
    "nánh nghê",
    "nasnh nghee"
  ],
  "Nâm N'Jang": [
    "nâm n'jang",
    "naam n'jang"
  ],
  "Nâm N'Đir": [
    "nâm n'đir",
    "naam n'ddir"
  ],
  "Nông Trang": [
    "nông trang",
    "noong trang"
  ],
  "Nùng Nàng": [
    "nùng nàng",
    "nufng nafng"
  ],
  "Núi Thành": [
    "núi thành",
    "nusi thafnh"
  ],
  "Núi Đối": [
    "núi đối",
    "nusi ddoosi"
  ],
  "Năng Khả": [
    "năng khả",
    "nawng khar"
  ],
  "Năng Tĩnh": [
    "năng tĩnh",
    "nawng tixnh"
  ],
  "Nước Hai": [
    "nước hai",
    "nuwowsc hai"
  ],
  "Nấm Dẩn": [
    "nấm dẩn",
    "naasm daarn"
  ],
  "Nậm Búng": [
    "nậm búng",
    "naajm busng"
  ],
  "Nậm Cần": [
    "nậm cần",
    "naajm caafn"
  ],
  "Nậm Cắn": [
    "nậm cắn",
    "naajm cawsn"
  ],
  "Nậm Giôn": [
    "nậm giôn",
    "naajm gioon"
  ],
  "Nậm Hàng": [
    "nậm hàng",
    "naajm hafng"
  ],
  "Nậm Khòa": [
    "nậm khòa",
    "naajm khofa"
  ],
  "Nậm Khăn": [
    "nậm khăn",
    "naajm khawn"
  ],
  "Nậm Lành": [
    "nậm lành",
    "naajm lafnh"
  ],
  "Nậm Lầu": [
    "nậm lầu",
    "naajm laafu"
  ],
  "Nậm Mằn": [
    "nậm mằn",
    "naajm mawfn"
  ],
  "Nậm Nhùn": [
    "nậm nhùn",
    "naajm nhufn"
  ],
  "Nậm Nhừ": [
    "nậm nhừ",
    "naajm nhuwf"
  ],
  "Nậm Đét": [
    "nậm đét",
    "naajm ddest"
  ],
  "Nội Duệ": [
    "nội duệ",
    "nooji dueej"
  ],
  "Nội Thôn": [
    "nội thôn",
    "nooji thoon"
  ],
  "Phan Hiệp": [
    "phan hiệp",
    "phan hieejp"
  ],
  "Phan Tiến": [
    "phan tiến",
    "phan tieesn"
  ],
  "Phiêng Ban": [
    "phiêng ban",
    "phieeng ban"
  ],
  "Phong Bình": [
    "phong bình",
    "phong bifnh"
  ],
  "Phong Châu": [
    "phong châu",
    "phong chaau"
  ],
  "Phong Cốc": [
    "phong cốc",
    "phong coosc"
  ],
  "Phong Hải": [
    "phong hải",
    "phong hari"
  ],
  "Phong Lạc": [
    "phong lạc",
    "phong lajc"
  ],
  "Phong Lộc": [
    "phong lộc",
    "phong loojc"
  ],
  "Phong Niên": [
    "phong niên",
    "phong nieen"
  ],
  "Phong Nẫm": [
    "phong nẫm",
    "phong naaxm"
  ],
  "Phong Nậm": [
    "phong nậm",
    "phong naajm"
  ],
  "Phong Quang": [
    "phong quang",
    "phong quang"
  ],
  "Phong Thổ": [
    "phong thổ",
    "phong thoor"
  ],
  "Phong Xuân": [
    "phong xuân",
    "phong xuaan"
  ],
  "Phà Đánh": [
    "phà đánh",
    "phaf ddasnh"
  ],
  "Pháo Đài": [
    "pháo đài",
    "phaso ddafi"
  ],
  "Phình Hồ": [
    "phình hồ",
    "phifnh hoof"
  ],
  "Phó Bảng": [
    "phó bảng",
    "phos barng"
  ],
  "Phù Chẩn": [
    "phù chẩn",
    "phuf chaarn"
  ],
  "Phù Liễn": [
    "phù liễn",
    "phuf lieexn"
  ],
  "Phùng Minh": [
    "phùng minh",
    "phufng minh"
  ],
  "Phú Chánh": [
    "phú chánh",
    "phus chasnh"
  ],
  "Phú Diễn": [
    "phú diễn",
    "phus dieexn"
  ],
  "Phú Hiệp": [
    "phú hiệp",
    "phus hieejp"
  ],
  "Phú Khánh": [
    "phú khánh",
    "phus khasnh"
  ],
  "Phú Kiết": [
    "phú kiết",
    "phus kieest"
  ],
  "Phú Nam An": [
    "phú nam an",
    "phus nam an"
  ],
  "Phú Nghĩa": [
    "phú nghĩa",
    "phus nghixa"
  ],
  "Phú Ngọc": [
    "phú ngọc",
    "phus ngojc"
  ],
  "Phú Quốc": [
    "phú quốc",
    "phus quoosc"
  ],
  "Phú Quới": [
    "phú quới",
    "phus quowsi"
  ],
  "Phú Thành": [
    "phú thành",
    "phus thafnh"
  ],
  "Phú Thủy": [
    "phú thủy",
    "phus thury"
  ],
  "Phú Tiến": [
    "phú tiến",
    "phus tieesn"
  ],
  "Phú Xuyên": [
    "phú xuyên",
    "phus xuyeen"
  ],
  "Phú Đình": [
    "phú đình",
    "phus ddifnh"
  ],
  "Phú Đông": [
    "phú đông",
    "phus ddoong"
  ],
  "Phú Đức": [
    "phú đức",
    "phus dduwsc"
  ],
  "Phúc Lộc": [
    "phúc lộc",
    "phusc loojc"
  ],
  "Phúc Lợi": [
    "phúc lợi",
    "phusc lowji"
  ],
  "Phúc Thọ": [
    "phúc thọ",
    "phusc thoj"
  ],
  "Phúc Trìu": [
    "phúc trìu",
    "phusc trifu"
  ],
  "Phúc Xuân": [
    "phúc xuân",
    "phusc xuaan"
  ],
  "Phúc Ứng": [
    "phúc ứng",
    "phusc uwsng"
  ],
  "Phước An": [
    "phước an",
    "phuwowsc an"
  ],
  "Phường 1": [
    "phường 1",
    "phuwowfng 1"
  ],
  "Phường 2": [
    "phường 2",
    "phuwowfng 2"
  ],
  "Phường 3": [
    "phường 3",
    "phuwowfng 3"
  ],
  "Phường 4": [
    "phường 4",
    "phuwowfng 4"
  ],
  "Phường 5": [
    "phường 5",
    "phuwowfng 5"
  ],
  "Phường 6": [
    "phường 6",
    "phuwowfng 6"
  ],
  "Phường 7": [
    "phường 7",
    "phuwowfng 7"
  ],
  "Phường 8": [
    "phường 8",
    "phuwowfng 8"
  ],
  "Phường 9": [
    "phường 9",
    "phuwowfng 9"
  ],
  "Phả Lại": [
    "phả lại",
    "phar laji"
  ],
  "Phấn Mễ": [
    "phấn mễ",
    "phaasn meex"
  ],
  "Phố Châu": [
    "phố châu",
    "phoos chaau"
  ],
  "Phố Huế": [
    "phố huế",
    "phoos huees"
  ],
  "Phố Mới": [
    "phố mới",
    "phoos mowsi"
  ],
  "Phố Ràng": [
    "phố ràng",
    "phoos rafng"
  ],
  "Phổ Châu": [
    "phổ châu",
    "phoor chaau"
  ],
  "Phổ Nhơn": [
    "phổ nhơn",
    "phoor nhown"
  ],
  "Phổ Phong": [
    "phổ phong",
    "phoor phong"
  ],
  "Phổ Quang": [
    "phổ quang",
    "phoor quang"
  ],
  "Phục Linh": [
    "phục linh",
    "phujc linh"
  ],
  "Phục Lễ": [
    "phục lễ",
    "phujc leex"
  ],
  "Pu Sam Cáp": [
    "pu sam cáp",
    "pu sam casp"
  ],
  "Pác Miầu": [
    "pác miầu",
    "pasc miaafu"
  ],
  "Pú Trạng": [
    "pú trạng",
    "pus trajng"
  ],
  "Púng Bánh": [
    "púng bánh",
    "pusng basnh"
  ],
  "Pơng Drang": [
    "pơng drang",
    "powng drang"
  ],
  "Quang Bình": [
    "quang bình",
    "quang bifnh"
  ],
  "Quang Châu": [
    "quang châu",
    "quang chaau"
  ],
  "Quang Hưng": [
    "quang hưng",
    "quang huwng"
  ],
  "Quang Lãng": [
    "quang lãng",
    "quang laxng"
  ],
  "Quang Lộc": [
    "quang lộc",
    "quang loojc"
  ],
  "Quang Phong": [
    "quang phong",
    "quang phong"
  ],
  "Quang Thọ": [
    "quang thọ",
    "quang thoj"
  ],
  "Quang Trung": [
    "quang trung",
    "quang trung"
  ],
  "Quang Vĩnh": [
    "quang vĩnh",
    "quang vixnh"
  ],
  "Quán Hành": [
    "quán hành",
    "quasn hafnh"
  ],
  "Quán Trữ": [
    "quán trữ",
    "quasn truwx"
  ],
  "Quản Bạ": [
    "quản bạ",
    "quarn baj"
  ],
  "Quảng Chu": [
    "quảng chu",
    "quarng chu"
  ],
  "Quảng Cư": [
    "quảng cư",
    "quarng cuw"
  ],
  "Quảng Hà": [
    "quảng hà",
    "quarng haf"
  ],
  "Quảng Kim": [
    "quảng kim",
    "quarng kim"
  ],
  "Quảng Nam": [
    "quảng nam",
    "quarng nam"
  ],
  "Quất Lâm": [
    "quất lâm",
    "quaast laam"
  ],
  "Quất Lưu": [
    "quất lưu",
    "quaast luwu"
  ],
  "Quế Châu": [
    "quế châu",
    "quees chaau"
  ],
  "Quế Lộc": [
    "quế lộc",
    "quees loojc"
  ],
  "Quế Phong": [
    "quế phong",
    "quees phong"
  ],
  "Quế Thọ": [
    "quế thọ",
    "quees thoj"
  ],
  "Quế Trung": [
    "quế trung",
    "quees trung"
  ],
  "Quỳ Châu": [
    "quỳ châu",
    "quyf chaau"
  ],
  "Quỳ Hợp": [
    "quỳ hợp",
    "quyf howjp"
  ],
  "Quỳnh Bá": [
    "quỳnh bá",
    "quyfnh bas"
  ],
  "Quỳnh Hoa": [
    "quỳnh hoa",
    "quyfnh hoa"
  ],
  "Quỳnh Mai": [
    "quỳnh mai",
    "quyfnh mai"
  ],
  "Quỳnh Tam": [
    "quỳnh tam",
    "quyfnh tam"
  ],
  "Quỳnh Xá": [
    "quỳnh xá",
    "quyfnh xas"
  ],
  "Rạch Giá": [
    "rạch giá",
    "rajch gias"
  ],
  "Rạch Gòi": [
    "rạch gòi",
    "rajch gofi"
  ],
  "Si Pa Phìn": [
    "si pa phìn",
    "si pa phifn"
  ],
  "Song Khủa": [
    "song khủa",
    "song khura"
  ],
  "Song Liễu": [
    "song liễu",
    "song lieexu"
  ],
  "Suối Cát": [
    "suối cát",
    "suoosi cast"
  ],
  "Suối Dây": [
    "suối dây",
    "suoosi daay"
  ],
  "Suối Ngô": [
    "suối ngô",
    "suoosi ngoo"
  ],
  "Suối Trai": [
    "suối trai",
    "suoosi trai"
  ],
  "Suối Tân": [
    "suối tân",
    "suoosi taan"
  ],
  "Suối Tọ": [
    "suối tọ",
    "suoosi toj"
  ],
  "Suối Đá": [
    "suối đá",
    "suoosi ddas"
  ],
  "Sán Chải": [
    "sán chải",
    "sasn chari"
  ],
  "Sín Chéng": [
    "sín chéng",
    "sisn chesng"
  ],
  "Sín Thầu": [
    "sín thầu",
    "sisn thaafu"
  ],
  "Sóc Trăng": [
    "sóc trăng",
    "sosc trawng"
  ],
  "Sóc Đăng": [
    "sóc đăng",
    "sosc ddawng"
  ],
  "Sông Bình": [
    "sông bình",
    "soong bifnh"
  ],
  "Sông Công": [
    "sông công",
    "soong coong"
  ],
  "Sông Cầu": [
    "sông cầu",
    "soong caafu"
  ],
  "Sông Khoai": [
    "sông khoai",
    "soong khoai"
  ],
  "Sông Xoài": [
    "sông xoài",
    "soong xoafi"
  ],
  "Sùng Nhơn": [
    "sùng nhơn",
    "sufng nhown"
  ],
  "Sùng Phài": [
    "sùng phài",
    "sufng phafi"
  ],
  "Sơn Bằng": [
    "sơn bằng",
    "sown bawfng"
  ],
  "Sơn Hiệp": [
    "sơn hiệp",
    "sown hieejp"
  ],
  "Sơn Hồng": [
    "sơn hồng",
    "sown hoofng"
  ],
  "Sơn Thuỷ": [
    "sơn thuỷ",
    "sown thuyr"
  ],
  "Sơn Thành": [
    "sơn thành",
    "sown thafnh"
  ],
  "Sơn Thủy": [
    "sơn thủy",
    "sown thury"
  ],
  "Sơn Tiến": [
    "sơn tiến",
    "sown tieesn"
  ],
  "Sơn Tịnh": [
    "sơn tịnh",
    "sown tijnh"
  ],
  "Sơn Đông": [
    "sơn đông",
    "sown ddoong"
  ],
  "Sập Vạt": [
    "sập vạt",
    "saajp vajt"
  ],
  "Sốp Cộp": [
    "sốp cộp",
    "soosp coojp"
  ],
  "Sủng Trà": [
    "sủng trà",
    "surng traf"
  ],
  "Tam Anh Nam": [
    "tam anh nam",
    "tam anh nam"
  ],
  "Tam Dương": [
    "tam dương",
    "tam duwowng"
  ],
  "Tam Thuấn": [
    "tam thuấn",
    "tam thuaasn"
  ],
  "Tam Thuận": [
    "tam thuận",
    "tam thuaajn"
  ],
  "Tam Thạnh": [
    "tam thạnh",
    "tam thajnh"
  ],
  "Tam Xuân I": [
    "tam xuân i",
    "tam xuaan i"
  ],
  "Tam Điệp": [
    "tam điệp",
    "tam ddieejp"
  ],
  "Tam Đồng": [
    "tam đồng",
    "tam ddoofng"
  ],
  "Thanh Bình": [
    "thanh bình",
    "thanh bifnh"
  ],
  "Thanh Châu": [
    "thanh châu",
    "thanh chaau"
  ],
  "Thanh Chăn": [
    "thanh chăn",
    "thanh chawn"
  ],
  "Thanh Giang": [
    "thanh giang",
    "thanh giang"
  ],
  "Thanh Hưng": [
    "thanh hưng",
    "thanh huwng"
  ],
  "Thanh Hải": [
    "thanh hải",
    "thanh hari"
  ],
  "Thanh Hối": [
    "thanh hối",
    "thanh hoosi"
  ],
  "Thanh Liêm": [
    "thanh liêm",
    "thanh lieem"
  ],
  "Thanh Liên": [
    "thanh liên",
    "thanh lieen"
  ],
  "Thanh Lãng": [
    "thanh lãng",
    "thanh laxng"
  ],
  "Thanh Lĩnh": [
    "thanh lĩnh",
    "thanh lixnh"
  ],
  "Thanh Lạc": [
    "thanh lạc",
    "thanh lajc"
  ],
  "Thanh Lộc": [
    "thanh lộc",
    "thanh loojc"
  ],
  "Thanh Nhàn": [
    "thanh nhàn",
    "thanh nhafn"
  ],
  "Thanh Phong": [
    "thanh phong",
    "thanh phong"
  ],
  "Thanh Quang": [
    "thanh quang",
    "thanh quang"
  ],
  "Thanh Quân": [
    "thanh quân",
    "thanh quaan"
  ],
  "Thanh Thùy": [
    "thanh thùy",
    "thanh thufy"
  ],
  "Thanh Tiên": [
    "thanh tiên",
    "thanh tieen"
  ],
  "Thanh Tùng": [
    "thanh tùng",
    "thanh tufng"
  ],
  "Thanh Uyên": [
    "thanh uyên",
    "thanh uyeen"
  ],
  "Thanh Vận": [
    "thanh vận",
    "thanh vaajn"
  ],
  "Thanh Xuân": [
    "thanh xuân",
    "thanh xuaan"
  ],
  "Thiên Tôn": [
    "thiên tôn",
    "thieen toon"
  ],
  "Thiệu Duy": [
    "thiệu duy",
    "thieeju duy"
  ],
  "Thiệu Lý": [
    "thiệu lý",
    "thieeju lys"
  ],
  "Thiệu Vũ": [
    "thiệu vũ",
    "thieeju vux"
  ],
  "Thuận Hà": [
    "thuận hà",
    "thuaajn haf"
  ],
  "Thuận Nam": [
    "thuận nam",
    "thuaajn nam"
  ],
  "Thuỵ Lâm": [
    "thuỵ lâm",
    "thuyj laam"
  ],
  "Thuỷ Sơn": [
    "thuỷ sơn",
    "thuyr sown"
  ],
  "Thàng Tín": [
    "thàng tín",
    "thafng tisn"
  ],
  "Thành Hòa": [
    "thành hòa",
    "thafnh hofa"
  ],
  "Thành Long": [
    "thành long",
    "thafnh long"
  ],
  "Thành Lâm": [
    "thành lâm",
    "thafnh laam"
  ],
  "Thành Minh": [
    "thành minh",
    "thafnh minh"
  ],
  "Thành Mỹ": [
    "thành mỹ",
    "thafnh myx"
  ],
  "Thành Sơn": [
    "thành sơn",
    "thafnh sown"
  ],
  "Thành Tâm": [
    "thành tâm",
    "thafnh taam"
  ],
  "Thành Tân": [
    "thành tân",
    "thafnh taan"
  ],
  "Thành Vinh": [
    "thành vinh",
    "thafnh vinh"
  ],
  "Thành Yên": [
    "thành yên",
    "thafnh yeen"
  ],
  "Thái Bình": [
    "thái bình",
    "thasi bifnh"
  ],
  "Thái Bảo": [
    "thái bảo",
    "thasi baro"
  ],
  "Thái Giang": [
    "thái giang",
    "thasi giang"
  ],
  "Thái Hưng": [
    "thái hưng",
    "thasi huwng"
  ],
  "Thái Học": [
    "thái học",
    "thasi hojc"
  ],
  "Thái Niên": [
    "thái niên",
    "thasi nieen"
  ],
  "Thái Phúc": [
    "thái phúc",
    "thasi phusc"
  ],
  "Thái Thọ": [
    "thái thọ",
    "thasi thoj"
  ],
  "Thái Trị": [
    "thái trị",
    "thasi trij"
  ],
  "Thái Đào": [
    "thái đào",
    "thasi ddafo"
  ],
  "Thông Hòa": [
    "thông hòa",
    "thoong hofa"
  ],
  "Thăng Long": [
    "thăng long",
    "thawng long"
  ],
  "Thạch Hà": [
    "thạch hà",
    "thajch haf"
  ],
  "Thạch Kim": [
    "thạch kim",
    "thajch kim"
  ],
  "Thạch Xá": [
    "thạch xá",
    "thajch xas"
  ],
  "Thất Khê": [
    "thất khê",
    "thaast khee"
  ],
  "Thắng Tam": [
    "thắng tam",
    "thawsng tam"
  ],
  "Thể Dục": [
    "thể dục",
    "theer dujc"
  ],
  "Thị Cầu": [
    "thị cầu",
    "thij caafu"
  ],
  "Thị Nại": [
    "thị nại",
    "thij naji"
  ],
  "Thọ Bình": [
    "thọ bình",
    "thoj bifnh"
  ],
  "Thọ Diên": [
    "thọ diên",
    "thoj dieen"
  ],
  "Thọ Hải": [
    "thọ hải",
    "thoj hari"
  ],
  "Thọ Hợp": [
    "thọ hợp",
    "thoj howjp"
  ],
  "Thọ Lập": [
    "thọ lập",
    "thoj laajp"
  ],
  "Thọ Lộc": [
    "thọ lộc",
    "thoj loojc"
  ],
  "Thọ Quang": [
    "thọ quang",
    "thoj quang"
  ],
  "Thọ Thanh": [
    "thọ thanh",
    "thoj thanh"
  ],
  "Thọ Thế": [
    "thọ thế",
    "thoj thees"
  ],
  "Thọ Vực": [
    "thọ vực",
    "thoj vuwjc"
  ],
  "Thọ Xuân": [
    "thọ xuân",
    "thoj xuaan"
  ],
  "Thổ Bình": [
    "thổ bình",
    "thoor bifnh"
  ],
  "Thổ Châu": [
    "thổ châu",
    "thoor chaau"
  ],
  "Thới Hòa": [
    "thới hòa",
    "thowsi hofa"
  ],
  "Thới Long": [
    "thới long",
    "thowsi long"
  ],
  "Thới Sơn": [
    "thới sơn",
    "thowsi sown"
  ],
  "Thới Tân": [
    "thới tân",
    "thowsi taan"
  ],
  "Thụy Dân": [
    "thụy dân",
    "thujy daan"
  ],
  "Thụy Hòa": [
    "thụy hòa",
    "thujy hofa"
  ],
  "Thụy Lôi": [
    "thụy lôi",
    "thujy looi"
  ],
  "Thụy Ninh": [
    "thụy ninh",
    "thujy ninh"
  ],
  "Thụy Sơn": [
    "thụy sơn",
    "thujy sown"
  ],
  "Thụy Vân": [
    "thụy vân",
    "thujy vaan"
  ],
  "Thụy Văn": [
    "thụy văn",
    "thujy vawn"
  ],
  "Thủy Phù": [
    "thủy phù",
    "thury phuf"
  ],
  "Thủy Tân": [
    "thủy tân",
    "thury taan"
  ],
  "Thủy Tây": [
    "thủy tây",
    "thury taay"
  ],
  "Thủy Vân": [
    "thủy vân",
    "thury vaan"
  ],
  "Tinh Nhuệ": [
    "tinh nhuệ",
    "tinh nhueej"
  ],
  "Tiên Châu": [
    "tiên châu",
    "tieen chaau"
  ],
  "Tiên Cẩm": [
    "tiên cẩm",
    "tieen caarm"
  ],
  "Tiên Hải": [
    "tiên hải",
    "tieen hari"
  ],
  "Tiên Hội": [
    "tiên hội",
    "tieen hooji"
  ],
  "Tiên Kiên": [
    "tiên kiên",
    "tieen kieen"
  ],
  "Tiên Lãng": [
    "tiên lãng",
    "tieen laxng"
  ],
  "Tiên Lãnh": [
    "tiên lãnh",
    "tieen laxnh"
  ],
  "Tiên Lập": [
    "tiên lập",
    "tieen laajp"
  ],
  "Tiên Lộc": [
    "tiên lộc",
    "tieen loojc"
  ],
  "Tiên Lục": [
    "tiên lục",
    "tieen lujc"
  ],
  "Tiên Nội": [
    "tiên nội",
    "tieen nooji"
  ],
  "Tiên Phong": [
    "tiên phong",
    "tieen phong"
  ],
  "Tiên Thanh": [
    "tiên thanh",
    "tieen thanh"
  ],
  "Tiên Thọ": [
    "tiên thọ",
    "tieen thoj"
  ],
  "Tiên Trang": [
    "tiên trang",
    "tieen trang"
  ],
  "Tiến Bộ": [
    "tiến bộ",
    "tieesn booj"
  ],
  "Tiến Hóa": [
    "tiến hóa",
    "tieesn hosa"
  ],
  "Tiền Yên": [
    "tiền yên",
    "tieefn yeen"
  ],
  "Triệu Ái": [
    "triệu ái",
    "trieeju asi"
  ],
  "Trung Bình": [
    "trung bình",
    "trung bifnh"
  ],
  "Trung Châu": [
    "trung châu",
    "trung chaau"
  ],
  "Trung Dũng": [
    "trung dũng",
    "trung duxng"
  ],
  "Trung Giang": [
    "trung giang",
    "trung giang"
  ],
  "Trung Giáp": [
    "trung giáp",
    "trung giasp"
  ],
  "Trung Hưng": [
    "trung hưng",
    "trung huwng"
  ],
  "Trung Hải": [
    "trung hải",
    "trung hari"
  ],
  "Trung Hội": [
    "trung hội",
    "trung hooji"
  ],
  "Trung Kiên": [
    "trung kiên",
    "trung kieen"
  ],
  "Trung Kênh": [
    "trung kênh",
    "trung keenh"
  ],
  "Trung Lập": [
    "trung lập",
    "trung laajp"
  ],
  "Trung Lộc": [
    "trung lộc",
    "trung loojc"
  ],
  "Trung Mầu": [
    "trung mầu",
    "trung maafu"
  ],
  "Trung Ngãi": [
    "trung ngãi",
    "trung ngaxi"
  ],
  "Trung Phúc": [
    "trung phúc",
    "trung phusc"
  ],
  "Trung Xuân": [
    "trung xuân",
    "trung xuaan"
  ],
  "Trà Bồng": [
    "trà bồng",
    "traf boofng"
  ],
  "Trà Hiệp": [
    "trà hiệp",
    "traf hieejp"
  ],
  "Trà Lồng": [
    "trà lồng",
    "traf loofng"
  ],
  "Trà Thủy": [
    "trà thủy",
    "traf thury"
  ],
  "Trà Đông": [
    "trà đông",
    "traf ddoong"
  ],
  "Trà Đốc": [
    "trà đốc",
    "traf ddoosc"
  ],
  "Tràng Các": [
    "tràng các",
    "trafng casc"
  ],
  "Tràng Cát": [
    "tràng cát",
    "trafng cast"
  ],
  "Tràng Minh": [
    "tràng minh",
    "trafng minh"
  ],
  "Tràng Sơn": [
    "tràng sơn",
    "trafng sown"
  ],
  "Tràng Đà": [
    "tràng đà",
    "trafng ddaf"
  ],
  "Trân Châu": [
    "trân châu",
    "traan chaau"
  ],
  "Trâu Quỳ": [
    "trâu quỳ",
    "traau quyf"
  ],
  "Trí Phải": [
    "trí phải",
    "tris phari"
  ],
  "Trạm Lộ": [
    "trạm lộ",
    "trajm looj"
  ],
  "Trảng Bom": [
    "trảng bom",
    "trarng bom"
  ],
  "Trấn Ninh": [
    "trấn ninh",
    "traasn ninh"
  ],
  "Trấn Yên": [
    "trấn yên",
    "traasn yeen"
  ],
  "Trần Lãm": [
    "trần lãm",
    "traafn laxm"
  ],
  "Trần Phú": [
    "trần phú",
    "traafn phus"
  ],
  "Trịnh Xá": [
    "trịnh xá",
    "trijnh xas"
  ],
  "Trọng Con": [
    "trọng con",
    "trojng con"
  ],
  "Trừng Xá": [
    "trừng xá",
    "truwfng xas"
  ],
  "Trực Mỹ": [
    "trực mỹ",
    "truwjc myx"
  ],
  "Trực Ninh": [
    "trực ninh",
    "truwjc ninh"
  ],
  "Tuyên Hóa": [
    "tuyên hóa",
    "tuyeen hosa"
  ],
  "Tuân Tức": [
    "tuân tức",
    "tuaan tuwsc"
  ],
  "Tà Đảnh": [
    "tà đảnh",
    "taf ddarnh"
  ],
  "Tào Xuyên": [
    "tào xuyên",
    "tafo xuyeen"
  ],
  "Tân Bằng": [
    "tân bằng",
    "taan bawfng"
  ],
  "Tân Chánh": [
    "tân chánh",
    "taan chasnh"
  ],
  "Tân Chính": [
    "tân chính",
    "taan chisnh"
  ],
  "Tân Cảnh": [
    "tân cảnh",
    "taan carnh"
  ],
  "Tân Hiệp": [
    "tân hiệp",
    "taan hieejp"
  ],
  "Tân Hạnh": [
    "tân hạnh",
    "taan hajnh"
  ],
  "Tân Hồng": [
    "tân hồng",
    "taan hoofng"
  ],
  "Tân Khánh": [
    "tân khánh",
    "taan khasnh"
  ],
  "Tân Kiều": [
    "tân kiều",
    "taan kieefu"
  ],
  "Tân Liễu": [
    "tân liễu",
    "taan lieexu"
  ],
  "Tân Nghĩa": [
    "tân nghĩa",
    "taan nghixa"
  ],
  "Tân Nhựt": [
    "tân nhựt",
    "taan nhuwjt"
  ],
  "Tân Quới": [
    "tân quới",
    "taan quowsi"
  ],
  "Tân Thành": [
    "tân thành",
    "taan thafnh"
  ],
  "Tân Thới": [
    "tân thới",
    "taan thowsi"
  ],
  "Tân Thủy": [
    "tân thủy",
    "taan thury"
  ],
  "Tân Tiến": [
    "tân tiến",
    "taan tieesn"
  ],
  "Tân Việt": [
    "tân việt",
    "taan vieejt"
  ],
  "Tân Xuyên": [
    "tân xuyên",
    "taan xuyeen"
  ],
  "Tân Đoàn": [
    "tân đoàn",
    "taan ddoafn"
  ],
  "Tân Đông": [
    "tân đông",
    "taan ddoong"
  ],
  "Tân Đức": [
    "tân đức",
    "taan dduwsc"
  ],
  "Tân Ước": [
    "tân ước",
    "taan uwowsc"
  ],
  "Tây Hiếu": [
    "tây hiếu",
    "taay hieesu"
  ],
  "Tây Thành": [
    "tây thành",
    "taay thafnh"
  ],
  "Tây Tiến": [
    "tây tiến",
    "taay tieesn"
  ],
  "Tây Yên A": [
    "tây yên a",
    "taay yeen a"
  ],
  "Tích Giang": [
    "tích giang",
    "tisch giang"
  ],
  "Tòng Bạt": [
    "tòng bạt",
    "tofng bajt"
  ],
  "Tòng Sành": [
    "tòng sành",
    "tofng safnh"
  ],
  "Tùng Châu": [
    "tùng châu",
    "tufng chaau"
  ],
  "Tùng Lộc": [
    "tùng lộc",
    "tufng loojc"
  ],
  "Tùng Ảnh": [
    "tùng ảnh",
    "tufng arnh"
  ],
  "Tú Thịnh": [
    "tú thịnh",
    "tus thijnh"
  ],
  "Tú Đoạn": [
    "tú đoạn",
    "tus ddoajn"
  ],
  "Túc Duyên": [
    "túc duyên",
    "tusc duyeen"
  ],
  "Túc Trưng": [
    "túc trưng",
    "tusc truwng"
  ],
  "Tĩnh Bắc": [
    "tĩnh bắc",
    "tixnh bawsc"
  ],
  "Tĩnh Hải": [
    "tĩnh hải",
    "tixnh hari"
  ],
  "Tương Mai": [
    "tương mai",
    "tuwowng mai"
  ],
  "Tả Lủng": [
    "tả lủng",
    "tar lurng"
  ],
  "Tả Ngảo": [
    "tả ngảo",
    "tar ngaro"
  ],
  "Tả Phời": [
    "tả phời",
    "tar phowfi"
  ],
  "Tả Thàng": [
    "tả thàng",
    "tar thafng"
  ],
  "Tản Lĩnh": [
    "tản lĩnh",
    "tarn lixnh"
  ],
  "Tập Ngãi": [
    "tập ngãi",
    "taajp ngaxi"
  ],
  "Tịnh Hòa": [
    "tịnh hòa",
    "tijnh hofa"
  ],
  "Tịnh Khê": [
    "tịnh khê",
    "tijnh khee"
  ],
  "Tịnh Kỳ": [
    "tịnh kỳ",
    "tijnh kyf"
  ],
  "Tịnh Long": [
    "tịnh long",
    "tijnh long"
  ],
  "Tịnh Minh": [
    "tịnh minh",
    "tijnh minh"
  ],
  "Tịnh Sơn": [
    "tịnh sơn",
    "tijnh sown"
  ],
  "Tịnh Trà": [
    "tịnh trà",
    "tijnh traf"
  ],
  "Tỏa Tình": [
    "tỏa tình",
    "tora tifnh"
  ],
  "Tống Phan": [
    "tống phan",
    "toosng phan"
  ],
  "Tủa Chùa": [
    "tủa chùa",
    "tura chufa"
  ],
  "Tứ Hiệp": [
    "tứ hiệp",
    "tuws hieejp"
  ],
  "Tứ Quận": [
    "tứ quận",
    "tuws quaajn"
  ],
  "Tứ Trưng": [
    "tứ trưng",
    "tuws truwng"
  ],
  "Tức Tranh": [
    "tức tranh",
    "tuwsc tranh"
  ],
  "Tự Nhiên": [
    "tự nhiên",
    "tuwj nhieen"
  ],
  "Uyên Hưng": [
    "uyên hưng",
    "uyeen huwng"
  ],
  "Vinh Hiền": [
    "vinh hiền",
    "vinh hieefn"
  ],
  "Vinh Tiền": [
    "vinh tiền",
    "vinh tieefn"
  ],
  "Viên Bình": [
    "viên bình",
    "vieen bifnh"
  ],
  "Viên Nội": [
    "viên nội",
    "vieen nooji"
  ],
  "Viêng Lán": [
    "viêng lán",
    "vieeng lasn"
  ],
  "Viễn Sơn": [
    "viễn sơn",
    "vieexn sown"
  ],
  "Việt Dân": [
    "việt dân",
    "vieejt daan"
  ],
  "Việt Hoà": [
    "việt hoà",
    "vieejt hoaf"
  ],
  "Việt Hòa": [
    "việt hòa",
    "vieejt hofa"
  ],
  "Việt Long": [
    "việt long",
    "vieejt long"
  ],
  "Việt Lâm": [
    "việt lâm",
    "vieejt laam"
  ],
  "Việt Trì": [
    "việt trì",
    "vieejt trif"
  ],
  "Việt Vinh": [
    "việt vinh",
    "vieejt vinh"
  ],
  "Việt Yên": [
    "việt yên",
    "vieejt yeen"
  ],
  "Vàng Đán": [
    "vàng đán",
    "vafng ddasn"
  ],
  "Vân Khánh": [
    "vân khánh",
    "vaan khasnh"
  ],
  "Vân Thủy": [
    "vân thủy",
    "vaan thury"
  ],
  "Vân Trình": [
    "vân trình",
    "vaan trifnh"
  ],
  "Vân Trục": [
    "vân trục",
    "vaan trujc"
  ],
  "Vân Đình": [
    "vân đình",
    "vaan ddifnh"
  ],
  "Vân Đồn": [
    "vân đồn",
    "vaan ddoofn"
  ],
  "Vô Điếm": [
    "vô điếm",
    "voo ddieesm"
  ],
  "Văn Chấn": [
    "văn chấn",
    "vawn chaasn"
  ],
  "Văn Hoàng": [
    "văn hoàng",
    "vawn hoafng"
  ],
  "Văn Luông": [
    "văn luông",
    "vawn luoong"
  ],
  "Văn Miếu": [
    "văn miếu",
    "vawn mieesu"
  ],
  "Văn Nghĩa": [
    "văn nghĩa",
    "vawn nghixa"
  ],
  "Văn Nhuệ": [
    "văn nhuệ",
    "vawn nhueej"
  ],
  "Văn Thành": [
    "văn thành",
    "vawn thafnh"
  ],
  "Văn Tiến": [
    "văn tiến",
    "vawn tieesn"
  ],
  "Văn Đẩu": [
    "văn đẩu",
    "vawn ddaaru"
  ],
  "Văn Đức": [
    "văn đức",
    "vawn dduwsc"
  ],
  "Vĩnh Bình": [
    "vĩnh bình",
    "vixnh bifnh"
  ],
  "Vĩnh Bảo": [
    "vĩnh bảo",
    "vixnh baro"
  ],
  "Vĩnh Bửu": [
    "vĩnh bửu",
    "vixnh buwru"
  ],
  "Vĩnh Chân": [
    "vĩnh chân",
    "vixnh chaan"
  ],
  "Vĩnh Châu": [
    "vĩnh châu",
    "vixnh chaau"
  ],
  "Vĩnh Công": [
    "vĩnh công",
    "vixnh coong"
  ],
  "Vĩnh Cửu": [
    "vĩnh cửu",
    "vixnh cuwru"
  ],
  "Vĩnh Giang": [
    "vĩnh giang",
    "vixnh giang"
  ],
  "Vĩnh Hùng": [
    "vĩnh hùng",
    "vixnh hufng"
  ],
  "Vĩnh Hưng": [
    "vĩnh hưng",
    "vixnh huwng"
  ],
  "Vĩnh Hải": [
    "vĩnh hải",
    "vixnh hari"
  ],
  "Vĩnh Hảo": [
    "vĩnh hảo",
    "vixnh haro"
  ],
  "Vĩnh Hậu": [
    "vĩnh hậu",
    "vixnh haaju"
  ],
  "Vĩnh Hựu": [
    "vĩnh hựu",
    "vixnh huwju"
  ],
  "Vĩnh Khúc": [
    "vĩnh khúc",
    "vixnh khusc"
  ],
  "Vĩnh Kiên": [
    "vĩnh kiên",
    "vixnh kieen"
  ],
  "Vĩnh Lạc": [
    "vĩnh lạc",
    "vixnh lajc"
  ],
  "Vĩnh Lại": [
    "vĩnh lại",
    "vixnh laji"
  ],
  "Vĩnh Lập": [
    "vĩnh lập",
    "vixnh laajp"
  ],
  "Vĩnh Lộc": [
    "vĩnh lộc",
    "vixnh loojc"
  ],
  "Vĩnh Lợi": [
    "vĩnh lợi",
    "vixnh lowji"
  ],
  "Vĩnh Phong": [
    "vĩnh phong",
    "vixnh phong"
  ],
  "Vĩnh Phúc": [
    "vĩnh phúc",
    "vixnh phusc"
  ],
  "Vĩnh Quang": [
    "vĩnh quang",
    "vixnh quang"
  ],
  "Vĩnh Thanh": [
    "vĩnh thanh",
    "vixnh thanh"
  ],
  "Vĩnh Thái": [
    "vĩnh thái",
    "vixnh thasi"
  ],
  "Vĩnh Thọ": [
    "vĩnh thọ",
    "vixnh thoj"
  ],
  "Vĩnh Trinh": [
    "vĩnh trinh",
    "vixnh trinh"
  ],
  "Vĩnh Trung": [
    "vĩnh trung",
    "vixnh trung"
  ],
  "Vĩnh Trị": [
    "vĩnh trị",
    "vixnh trij"
  ],
  "Vĩnh Trụ": [
    "vĩnh trụ",
    "vixnh truj"
  ],
  "Vĩnh Xuân": [
    "vĩnh xuân",
    "vixnh xuaan"
  ],
  "Vũ Thắng": [
    "vũ thắng",
    "vux thawsng"
  ],
  "Vũng Liêm": [
    "vũng liêm",
    "vuxng lieem"
  ],
  "Vạn Bình": [
    "vạn bình",
    "vajn bifnh"
  ],
  "Vạn Hưng": [
    "vạn hưng",
    "vajn huwng"
  ],
  "Vạn Phái": [
    "vạn phái",
    "vajn phasi"
  ],
  "Vạn Phúc": [
    "vạn phúc",
    "vajn phusc"
  ],
  "Vạn Thái": [
    "vạn thái",
    "vajn thasi"
  ],
  "Vạn Thọ": [
    "vạn thọ",
    "vajn thoj"
  ],
  "Vạn Xuân": [
    "vạn xuân",
    "vajn xuaan"
  ],
  "Vật Lại": [
    "vật lại",
    "vaajt laji"
  ],
  "Vị Hoàng": [
    "vị hoàng",
    "vij hoafng"
  ],
  "Vị Thuỷ": [
    "vị thuỷ",
    "vij thuyr"
  ],
  "Vị Xuyên": [
    "vị xuyên",
    "vij xuyeen"
  ],
  "Vị Đông": [
    "vị đông",
    "vij ddoong"
  ],
  "Vọng Thê": [
    "vọng thê",
    "vojng thee"
  ],
  "Xuân Bình": [
    "xuân bình",
    "xuaan bifnh"
  ],
  "Xuân Bảo": [
    "xuân bảo",
    "xuaan baro"
  ],
  "Xuân Bắc": [
    "xuân bắc",
    "xuaan bawsc"
  ],
  "Xuân Chinh": [
    "xuân chinh",
    "xuaan chinh"
  ],
  "Xuân Châu": [
    "xuân châu",
    "xuaan chaau"
  ],
  "Xuân Cẩm": [
    "xuân cẩm",
    "xuaan caarm"
  ],
  "Xuân Dục": [
    "xuân dục",
    "xuaan dujc"
  ],
  "Xuân Giang": [
    "xuân giang",
    "xuaan giang"
  ],
  "Xuân Hưng": [
    "xuân hưng",
    "xuaan huwng"
  ],
  "Xuân Hải": [
    "xuân hải",
    "xuaan hari"
  ],
  "Xuân Hội": [
    "xuân hội",
    "xuaan hooji"
  ],
  "Xuân Khang": [
    "xuân khang",
    "xuaan khang"
  ],
  "Xuân Khanh": [
    "xuân khanh",
    "xuaan khanh"
  ],
  "Xuân Kiên": [
    "xuân kiên",
    "xuaan kieen"
  ],
  "Xuân Liên": [
    "xuân liên",
    "xuaan lieen"
  ],
  "Xuân Lãnh": [
    "xuân lãnh",
    "xuaan laxnh"
  ],
  "Xuân Lĩnh": [
    "xuân lĩnh",
    "xuaan lixnh"
  ],
  "Xuân Lũng": [
    "xuân lũng",
    "xuaan luxng"
  ],
  "Xuân Lạc": [
    "xuân lạc",
    "xuaan lajc"
  ],
  "Xuân Lập": [
    "xuân lập",
    "xuaan laajp"
  ],
  "Xuân Lộc": [
    "xuân lộc",
    "xuaan loojc"
  ],
  "Xuân Nội": [
    "xuân nội",
    "xuaan nooji"
  ],
  "Xuân Nộn": [
    "xuân nộn",
    "xuaan noojn"
  ],
  "Xuân Phong": [
    "xuân phong",
    "xuaan phong"
  ],
  "Xuân Phúc": [
    "xuân phúc",
    "xuaan phusc"
  ],
  "Xuân Phổ": [
    "xuân phổ",
    "xuaan phoor"
  ],
  "Xuân Quang": [
    "xuân quang",
    "xuaan quang"
  ],
  "Xuân Quế": [
    "xuân quế",
    "xuaan quees"
  ],
  "Xuân Thanh": [
    "xuân thanh",
    "xuaan thanh"
  ],
  "Xuân Thái": [
    "xuân thái",
    "xuaan thasi"
  ],
  "Xuân Thọ": [
    "xuân thọ",
    "xuaan thoj"
  ],
  "Xuân Trung": [
    "xuân trung",
    "xuaan trung"
  ],
  "Xuân Trúc": [
    "xuân trúc",
    "xuaan trusc"
  ],
  "Xuân Tăng": [
    "xuân tăng",
    "xuaan tawng"
  ],
  "Xuân Tảo": [
    "xuân tảo",
    "xuaan taro"
  ],
  "Xuân Tầm": [
    "xuân tầm",
    "xuaan taafm"
  ],
  "Xuân Viên": [
    "xuân viên",
    "xuaan vieen"
  ],
  "Xuân Đài": [
    "xuân đài",
    "xuaan ddafi"
  ],
  "Xuân Đám": [
    "xuân đám",
    "xuaan ddasm"
  ],
  "Xuất Hóa": [
    "xuất hóa",
    "xuaast hosa"
  ],
  "Xuất Lễ": [
    "xuất lễ",
    "xuaast leex"
  ],
  "Xích Thổ": [
    "xích thổ",
    "xisch thoor"
  ],
  "Xín Chải": [
    "xín chải",
    "xisn chari"
  ],
  "Yên Bằng": [
    "yên bằng",
    "yeen bawfng"
  ],
  "Yên Bồng": [
    "yên bồng",
    "yeen boofng"
  ],
  "Yên Chính": [
    "yên chính",
    "yeen chisnh"
  ],
  "Yên Hồng": [
    "yên hồng",
    "yeen hoofng"
  ],
  "Yên Khoái": [
    "yên khoái",
    "yeen khoasi"
  ],
  "Yên Khánh": [
    "yên khánh",
    "yeen khasnh"
  ],
  "Yên Kiện": [
    "yên kiện",
    "yeen kieejn"
  ],
  "Yên Luông": [
    "yên luông",
    "yeen luoong"
  ],
  "Yên Luật": [
    "yên luật",
    "yeen luaajt"
  ],
  "Yên Nghĩa": [
    "yên nghĩa",
    "yeen nghixa"
  ],
  "Yên Thành": [
    "yên thành",
    "yeen thafnh"
  ],
  "Yên Thủy": [
    "yên thủy",
    "yeen thury"
  ],
  "Yên Tiến": [
    "yên tiến",
    "yeen tieesn"
  ],
  "Yên Đức": [
    "yên đức",
    "yeen dduwsc"
  ],
  "Yến Lạc": [
    "yến lạc",
    "yeesn lajc"
  ],
  "Yết Kiêu": [
    "yết kiêu",
    "yeest kieeu"
  ],
  "Ân Thạnh": [
    "ân thạnh",
    "aan thajnh"
  ],
  "Ôn Lương": [
    "ôn lương",
    "oon luwowng"
  ],
  "Ông Đình": [
    "ông đình",
    "oong ddifnh"
  ],
  "Đak Jơ Ta": [
    "đak jơ ta",
    "ddak jow ta"
  ],
  "Đak Ta Ley": [
    "đak ta ley",
    "ddak ta ley"
  ],
  "Đinh Lạc": [
    "đinh lạc",
    "ddinh lajc"
  ],
  "Điền Lư": [
    "điền lư",
    "ddieefn luw"
  ],
  "Điền Xá": [
    "điền xá",
    "ddieefn xas"
  ],
  "Đoan Hùng": [
    "đoan hùng",
    "ddoan hufng"
  ],
  "Đà Nẵng": [
    "đà nẵng",
    "ddaf nawxng"
  ],
  "Đào Viên": [
    "đào viên",
    "ddafo vieen"
  ],
  "Đáp Cầu": [
    "đáp cầu",
    "ddasp caafu"
  ],
  "Đình Cả": [
    "đình cả",
    "ddifnh car"
  ],
  "Đình Tổ": [
    "đình tổ",
    "ddifnh toor"
  ],
  "Đô Thành": [
    "đô thành",
    "ddoo thafnh"
  ],
  "Đôn Châu": [
    "đôn châu",
    "ddoon chaau"
  ],
  "Đôn Nhân": [
    "đôn nhân",
    "ddoon nhaan"
  ],
  "Đôn Phong": [
    "đôn phong",
    "ddoon phong"
  ],
  "Đôn Xuân": [
    "đôn xuân",
    "ddoon xuaan"
  ],
  "Đông Các": [
    "đông các",
    "ddoong casc"
  ],
  "Đông Hoà": [
    "đông hoà",
    "ddoong hoaf"
  ],
  "Đông Hòa": [
    "đông hòa",
    "ddoong hofa"
  ],
  "Đông Hồ": [
    "đông hồ",
    "ddoong hoof"
  ],
  "Đông Khê": [
    "đông khê",
    "ddoong khee"
  ],
  "Đông Kinh": [
    "đông kinh",
    "ddoong kinh"
  ],
  "Đông Long": [
    "đông long",
    "ddoong long"
  ],
  "Đông Lâm": [
    "đông lâm",
    "ddoong laam"
  ],
  "Đông Lễ": [
    "đông lễ",
    "ddoong leex"
  ],
  "Đông Lỗ": [
    "đông lỗ",
    "ddoong loox"
  ],
  "Đông Minh": [
    "đông minh",
    "ddoong minh"
  ],
  "Đông Mỹ": [
    "đông mỹ",
    "ddoong myx"
  ],
  "Đông Ngũ": [
    "đông ngũ",
    "ddoong ngux"
  ],
  "Đông Ninh": [
    "đông ninh",
    "ddoong ninh"
  ],
  "Đông Phú": [
    "đông phú",
    "ddoong phus"
  ],
  "Đông Quan": [
    "đông quan",
    "ddoong quan"
  ],
  "Đông Quí": [
    "đông quí",
    "ddoong quis"
  ],
  "Đông Sang": [
    "đông sang",
    "ddoong sang"
  ],
  "Đông Sơn": [
    "đông sơn",
    "ddoong sown"
  ],
  "Đông Trà": [
    "đông trà",
    "ddoong traf"
  ],
  "Đông Tân": [
    "đông tân",
    "ddoong taan"
  ],
  "Đông Vinh": [
    "đông vinh",
    "ddoong vinh"
  ],
  "Đông Văn": [
    "đông văn",
    "ddoong vawn"
  ],
  "Đông Vệ": [
    "đông vệ",
    "ddoong veej"
  ],
  "Đông Yên": [
    "đông yên",
    "ddoong yeen"
  ],
  "Đông Đô": [
    "đông đô",
    "ddoong ddoo"
  ],
  "Đăk Glong": [
    "đăk glong",
    "ddawk glong"
  ],
  "Đăk Krong": [
    "đăk krong",
    "ddawk krong"
  ],
  "Đăk Năng": [
    "đăk năng",
    "ddawk nawng"
  ],
  "Đăk Pling": [
    "đăk pling",
    "ddawk pling"
  ],
  "Đăk Roong": [
    "đăk roong",
    "ddawk roong"
  ],
  "Đăk Trôi": [
    "đăk trôi",
    "ddawk trooi"
  ],
  "Đạ Chais": [
    "đạ chais",
    "ddaj chais"
  ],
  "Đạ Huoai": [
    "đạ huoai",
    "ddaj huoai"
  ],
  "Đạ Tông": [
    "đạ tông",
    "ddaj toong"
  ],
  "Đạ Tẻh": [
    "đạ tẻh",
    "ddaj terh"
  ],
  "Đạ Tồn": [
    "đạ tồn",
    "ddaj toofn"
  ],
  "Đại Bái": [
    "đại bái",
    "ddaji basi"
  ],
  "Đại Hòa": [
    "đại hòa",
    "ddaji hofa"
  ],
  "Đại Hóa": [
    "đại hóa",
    "ddaji hosa"
  ],
  "Đại Lào": [
    "đại lào",
    "ddaji lafo"
  ],
  "Đại Lâm": [
    "đại lâm",
    "ddaji laam"
  ],
  "Đại Minh": [
    "đại minh",
    "ddaji minh"
  ],
  "Đại Mỗ": [
    "đại mỗ",
    "ddaji moox"
  ],
  "Đại Nài": [
    "đại nài",
    "ddaji nafi"
  ],
  "Đại Phú": [
    "đại phú",
    "ddaji phus"
  ],
  "Đại Sơn": [
    "đại sơn",
    "ddaji sown"
  ],
  "Đại Tâm": [
    "đại tâm",
    "ddaji taam"
  ],
  "Đại Tân": [
    "đại tân",
    "ddaji taan"
  ],
  "Đại Từ": [
    "đại từ",
    "ddaji tuwf"
  ],
  "Đại Tự": [
    "đại tự",
    "ddaji tuwj"
  ],
  "Đại Yên": [
    "đại yên",
    "ddaji yeen"
  ],
  "Đại áng": [
    "đại áng",
    "ddaji asng"
  ],
  "Đạo Long": [
    "đạo long",
    "ddajo long"
  ],
  "Đạo Trù": [
    "đạo trù",
    "ddajo truf"
  ],
  "Đản Ván": [
    "đản ván",
    "ddarn vasn"
  ],
  "Đất Mũi": [
    "đất mũi",
    "ddaast muxi"
  ],
  "Đầm Dơi": [
    "đầm dơi",
    "ddaafm dowi"
  ],
  "Đập Đá": [
    "đập đá",
    "ddaajp ddas"
  ],
  "Đắc Sơn": [
    "đắc sơn",
    "ddawsc sown"
  ],
  "Đắc Sở": [
    "đắc sở",
    "ddawsc sowr"
  ],
  "Đắc Tôi": [
    "đắc tôi",
    "ddawsc tooi"
  ],
  "Đắk Blà": [
    "đắk blà",
    "ddawsk blaf"
  ],
  "Đắk Blô": [
    "đắk blô",
    "ddawsk bloo"
  ],
  "Đắk Drô": [
    "đắk drô",
    "ddawsk droo"
  ],
  "Đắk Glei": [
    "đắk glei",
    "ddawsk glei"
  ],
  "Đắk Hòa": [
    "đắk hòa",
    "ddawsk hofa"
  ],
  "Đắk Kôi": [
    "đắk kôi",
    "ddawsk kooi"
  ],
  "Đắk Long": [
    "đắk long",
    "ddawsk long"
  ],
  "Đắk Mâm": [
    "đắk mâm",
    "ddawsk maam"
  ],
  "Đắk Môl": [
    "đắk môl",
    "ddawsk mool"
  ],
  "Đắk Môn": [
    "đắk môn",
    "ddawsk moon"
  ],
  "Đắk Nang": [
    "đắk nang",
    "ddawsk nang"
  ],
  "Đắk Nuê": [
    "đắk nuê",
    "ddawsk nuee"
  ],
  "Đắk Nên": [
    "đắk nên",
    "ddawsk neen"
  ],
  "Đắk Plao": [
    "đắk plao",
    "ddawsk plao"
  ],
  "Đắk Pék": [
    "đắk pék",
    "ddawsk pesk"
  ],
  "Đắk R'La": [
    "đắk r'la",
    "ddawsk r'la"
  ],
  "Đắk Ring": [
    "đắk ring",
    "ddawsk ring"
  ],
  "Đắk Song": [
    "đắk song",
    "ddawsk song"
  ],
  "Đắk Sôr": [
    "đắk sôr",
    "ddawsk soor"
  ],
  "Đặng Xá": [
    "đặng xá",
    "ddawjng xas"
  ],
  "Đề Thám": [
    "đề thám",
    "ddeef thasm"
  ],
  "Địa Linh": [
    "địa linh",
    "ddija linh"
  ],
  "Định Cư": [
    "định cư",
    "ddijnh cuw"
  ],
  "Đốc Tín": [
    "đốc tín",
    "ddoosc tisn"
  ],
  "Đống Đa": [
    "đống đa",
    "ddoosng dda"
  ],
  "Đồi Ngô": [
    "đồi ngô",
    "ddoofi ngoo"
  ],
  "Đồng Kho": [
    "đồng kho",
    "ddoofng kho"
  ],
  "Đồng Lê": [
    "đồng lê",
    "ddoofng lee"
  ],
  "Đồng Mai": [
    "đồng mai",
    "ddoofng mai"
  ],
  "Đồng Nai": [
    "đồng nai",
    "ddoofng nai"
  ],
  "Đồng Nơ": [
    "đồng nơ",
    "ddoofng now"
  ],
  "Đồng Rui": [
    "đồng rui",
    "ddoofng rui"
  ],
  "Đổng Xá": [
    "đổng xá",
    "ddoorng xas"
  ],
  "Đội Cung": [
    "đội cung",
    "ddooji cung"
  ],
  "Đứa Mòn": [
    "đứa mòn",
    "dduwsa mofn"
  ],
  "Đức Bác": [
    "đức bác",
    "dduwsc basc"
  ],
  "Đức Hoà": [
    "đức hoà",
    "dduwsc hoaf"
  ],
  "Đức Hòa": [
    "đức hòa",
    "dduwsc hofa"
  ],
  "Đức Hóa": [
    "đức hóa",
    "dduwsc hosa"
  ],
  "Đức Linh": [
    "đức linh",
    "dduwsc linh"
  ],
  "Đức Long": [
    "đức long",
    "dduwsc long"
  ],
  "Đức Lân": [
    "đức lân",
    "dduwsc laan"
  ],
  "Đức Minh": [
    "đức minh",
    "dduwsc minh"
  ],
  "Đức Mỹ": [
    "đức mỹ",
    "dduwsc myx"
  ],
  "Đức Ninh": [
    "đức ninh",
    "dduwsc ninh"
  ],
  "Đức Phú": [
    "đức phú",
    "dduwsc phus"
  ],
  "Đức Sơn": [
    "đức sơn",
    "dduwsc sown"
  ],
  "Đức Tài": [
    "đức tài",
    "dduwsc tafi"
  ],
  "Đức Tân": [
    "đức tân",
    "dduwsc taan"
  ],
  "Đức Tín": [
    "đức tín",
    "dduwsc tisn"
  ],
  "Đức Vân": [
    "đức vân",
    "dduwsc vaan"
  ],
  " Vũng Liêm": [
    " vũng liêm",
    " vuxng lieem"
  ],
  "An Hòa Tây": [
    "an hòa tây",
    "an hofa taay"
  ],
  "An Ninh Tây": [
    "an ninh tây",
    "an ninh taay"
  ],
  "An Phú Tân": [
    "an phú tân",
    "an phus taan"
  ],
  "An Phú Tây": [
    "an phú tây",
    "an phus taay"
  ],
  "An Phượng": [
    "an phượng",
    "an phuwowjng"
  ],
  "An Thượng": [
    "an thượng",
    "an thuwowjng"
  ],
  "An Thạnh 1": [
    "an thạnh 1",
    "an thajnh 1"
  ],
  "An Thạnh 2": [
    "an thạnh 2",
    "an thajnh 2"
  ],
  "An Thạnh 3": [
    "an thạnh 3",
    "an thajnh 3"
  ],
  "An Trường": [
    "an trường",
    "an truwowfng"
  ],
  "An Trạch A": [
    "an trạch a",
    "an trajch a"
  ],
  "Ba Cụm Nam": [
    "ba cụm nam",
    "ba cujm nam"
  ],
  "Biên Giới": [
    "biên giới",
    "bieen giowsi"
  ],
  "Buôn Trấp": [
    "buôn trấp",
    "buoon traasp"
  ],
  "Bàn Thạch": [
    "bàn thạch",
    "bafn thajch"
  ],
  "Bá Thước": [
    "bá thước",
    "bas thuwowsc"
  ],
  "Bình Chánh": [
    "bình chánh",
    "bifnh chasnh"
  ],
  "Bình Hiệp": [
    "bình hiệp",
    "bifnh hieejp"
  ],
  "Bình Khánh": [
    "bình khánh",
    "bifnh khasnh"
  ],
  "Bình Kiến": [
    "bình kiến",
    "bifnh kieesn"
  ],
  "Bình Kiều": [
    "bình kiều",
    "bifnh kieefu"
  ],
  "Bình Nghĩa": [
    "bình nghĩa",
    "bifnh nghixa"
  ],
  "Bình Nghị": [
    "bình nghị",
    "bifnh nghij"
  ],
  "Bình Ngọc": [
    "bình ngọc",
    "bifnh ngojc"
  ],
  "Bình Phục": [
    "bình phục",
    "bifnh phujc"
  ],
  "Bình Quới": [
    "bình quới",
    "bifnh quowsi"
  ],
  "Bình Thanh ": [
    "bình thanh ",
    "bifnh thanh "
  ],
  "Bình Thuỷ": [
    "bình thuỷ",
    "bifnh thuyr"
  ],
  "Bình Thành": [
    "bình thành",
    "bifnh thafnh"
  ],
  "Bình Thới": [
    "bình thới",
    "bifnh thowsi"
  ],
  "Bình Thủy": [
    "bình thủy",
    "bifnh thury"
  ],
  "Bình Tiến": [
    "bình tiến",
    "bifnh tieesn"
  ],
  "Bình Trưng": [
    "bình trưng",
    "bifnh truwng"
  ],
  "Bình Tịnh": [
    "bình tịnh",
    "bifnh tijnh"
  ],
  "Bình Xuyên": [
    "bình xuyên",
    "bifnh xuyeen"
  ],
  "Bình Đông": [
    "bình đông",
    "bifnh ddoong"
  ],
  "Bình Đại": [
    "bình đại",
    "bifnh ddaji"
  ],
  "Bình Đức": [
    "bình đức",
    "bifnh dduwsc"
  ],
  "Bạch Hạc": [
    "bạch hạc",
    "bajch hajc"
  ],
  "Bản Liền": [
    "bản liền",
    "barn lieefn"
  ],
  "Bản Luốc": [
    "bản luốc",
    "barn luoosc"
  ],
  "Bản Nhùng": [
    "bản nhùng",
    "barn nhufng"
  ],
  "Bản Phùng": [
    "bản phùng",
    "barn phufng"
  ],
  "Bảo Hiệu": [
    "bảo hiệu",
    "baro hieeju"
  ],
  "Bảo Thành": [
    "bảo thành",
    "baro thafnh"
  ],
  "Bắc Hồng": [
    "bắc hồng",
    "bawsc hoofng"
  ],
  "Bắc Lệnh": [
    "bắc lệnh",
    "bawsc leejnh"
  ],
  "Bắc Nghĩa": [
    "bắc nghĩa",
    "bawsc nghixa"
  ],
  "Bắc Thành": [
    "bắc thành",
    "bawsc thafnh"
  ],
  "Bắc Thủy": [
    "bắc thủy",
    "bawsc thury"
  ],
  "Bắc Việt": [
    "bắc việt",
    "bawsc vieejt"
  ],
  "Bằng Cốc": [
    "bằng cốc",
    "bawfng coosc"
  ],
  "Bằng Doãn": [
    "bằng doãn",
    "bawfng doaxn"
  ],
  "Bằng Hành": [
    "bằng hành",
    "bawfng hafnh"
  ],
  "Bằng Hữu": [
    "bằng hữu",
    "bawfng huwxu"
  ],
  "Bằng Luân": [
    "bằng luân",
    "bawfng luaan"
  ],
  "Bằng Lãng": [
    "bằng lãng",
    "bawfng laxng"
  ],
  "Bằng Lũng": [
    "bằng lũng",
    "bawfng luxng"
  ],
  "Bằng Mạc": [
    "bằng mạc",
    "bawfng majc"
  ],
  "Bằng Phúc": [
    "bằng phúc",
    "bawfng phusc"
  ],
  "Bến Thành": [
    "bến thành",
    "beesn thafnh"
  ],
  "Bến Thủy": [
    "bến thủy",
    "beesn thury"
  ],
  "Bố Trạch": [
    "bố trạch",
    "boos trajch"
  ],
  "Bộc Nhiêu": [
    "bộc nhiêu",
    "boojc nhieeu"
  ],
  "Bột Xuyên": [
    "bột xuyên",
    "boojt xuyeen"
  ],
  "Cam An Bắc": [
    "cam an bắc",
    "cam an bawsc"
  ],
  "Canh Thuận": [
    "canh thuận",
    "canh thuaajn"
  ],
  "Cao Chương": [
    "cao chương",
    "cao chuwowng"
  ],
  "Cao Mã Pờ": [
    "cao mã pờ",
    "cao max powf"
  ],
  "Chiềng Ban": [
    "chiềng ban",
    "chieefng ban"
  ],
  "Chiềng Hoa": [
    "chiềng hoa",
    "chieefng hoa"
  ],
  "Chiềng Ken": [
    "chiềng ken",
    "chieefng ken"
  ],
  "Chiềng Lao": [
    "chiềng lao",
    "chieefng lao"
  ],
  "Chiềng Mai": [
    "chiềng mai",
    "chieefng mai"
  ],
  "Chiềng Pha": [
    "chiềng pha",
    "chieefng pha"
  ],
  "Chiềng San": [
    "chiềng san",
    "chieefng san"
  ],
  "Chiềng Sơ": [
    "chiềng sơ",
    "chieefng sow"
  ],
  "Chiềng Ân": [
    "chiềng ân",
    "chieefng aan"
  ],
  "Chiềng Ơn": [
    "chiềng ơn",
    "chieefng own"
  ],
  "Chung Chải": [
    "chung chải",
    "chung chari"
  ],
  "Chuyên Mỹ": [
    "chuyên mỹ",
    "chuyeen myx"
  ],
  "Chân Mộng": [
    "chân mộng",
    "chaan moojng"
  ],
  "Châu Hạnh": [
    "châu hạnh",
    "chaau hajnh"
  ],
  "Châu Hồng": [
    "châu hồng",
    "chaau hoofng"
  ],
  "Châu Khánh": [
    "châu khánh",
    "chaau khasnh"
  ],
  "Châu Phú A": [
    "châu phú a",
    "chaau phus a"
  ],
  "Châu Phú B": [
    "châu phú b",
    "chaau phus b"
  ],
  "Châu Thành": [
    "châu thành",
    "chaau thafnh"
  ],
  "Châu Thới": [
    "châu thới",
    "chaau thowsi"
  ],
  "Châu Tiến": [
    "châu tiến",
    "chaau tieesn"
  ],
  "Châu Đình": [
    "châu đình",
    "chaau ddifnh"
  ],
  "Châu Đốc": [
    "châu đốc",
    "chaau ddoosc"
  ],
  "Châu Đức": [
    "châu đức",
    "chaau dduwsc"
  ],
  "Chí Thạnh": [
    "chí thạnh",
    "chis thajnh"
  ],
  "Chính Gián": [
    "chính gián",
    "chisnh giasn"
  ],
  "Chơn Thành": [
    "chơn thành",
    "chown thafnh"
  ],
  "Chương Xá": [
    "chương xá",
    "chuwowng xas"
  ],
  "Chấn Hưng": [
    "chấn hưng",
    "chaasn huwng"
  ],
  "Chất Bình": [
    "chất bình",
    "chaast bifnh"
  ],
  "Chế Cu Nha": [
    "chế cu nha",
    "chees cu nha"
  ],
  "Chỉ Đạo": [
    "chỉ đạo",
    "chir ddajo"
  ],
  "Chợ Đồn": [
    "chợ đồn",
    "chowj ddoofn"
  ],
  "Cái Nước": [
    "cái nước",
    "casi nuwowsc"
  ],
  "Cát Thắng": [
    "cát thắng",
    "cast thawsng"
  ],
  "Cát Thịnh": [
    "cát thịnh",
    "cast thijnh"
  ],
  "Cây Dương": [
    "cây dương",
    "caay duwowng"
  ],
  "Công Bằng": [
    "công bằng",
    "coong bawfng"
  ],
  "Công Chính": [
    "công chính",
    "coong chisnh"
  ],
  "Công Thành": [
    "công thành",
    "coong thafnh"
  ],
  "Cù Lao Dung": [
    "cù lao dung",
    "cuf lao dung"
  ],
  "Cương Sơn": [
    "cương sơn",
    "cuwowng sown"
  ],
  "Cảnh Hưng": [
    "cảnh hưng",
    "carnh huwng"
  ],
  "Cấp Tiến": [
    "cấp tiến",
    "caasp tieesn"
  ],
  "Cần Kiệm": [
    "cần kiệm",
    "caafn kieejm"
  ],
  "Cần Đăng": [
    "cần đăng",
    "caafn ddawng"
  ],
  "Cầu Diễn": [
    "cầu diễn",
    "caafu dieexn"
  ],
  "Cầu Giấy": [
    "cầu giấy",
    "caafu giaasy"
  ],
  "Cầu Khởi": [
    "cầu khởi",
    "caafu khowri"
  ],
  "Cầu Đất": [
    "cầu đất",
    "caafu ddaast"
  ],
  "Cẩm Giàng": [
    "cẩm giàng",
    "caarm giafng"
  ],
  "Cẩm Hoàng": [
    "cẩm hoàng",
    "caarm hoafng"
  ],
  "Cẩm Ngọc": [
    "cẩm ngọc",
    "caarm ngojc"
  ],
  "Cẩm Thành": [
    "cẩm thành",
    "caarm thafnh"
  ],
  "Cẩm Thủy": [
    "cẩm thủy",
    "caarm thury"
  ],
  "Cẩm Xuyên": [
    "cẩm xuyên",
    "caarm xuyeen"
  ],
  "Cẩm Đoài": [
    "cẩm đoài",
    "caarm ddoafi"
  ],
  "Cẩm Đông": [
    "cẩm đông",
    "caarm ddoong"
  ],
  "Cộng Lạc": [
    "cộng lạc",
    "coojng lajc"
  ],
  "Cửa Việt": [
    "cửa việt",
    "cuwra vieejt"
  ],
  "Cửa Đông": [
    "cửa đông",
    "cuwra ddoong"
  ],
  "Cửa Đại": [
    "cửa đại",
    "cuwra ddaji"
  ],
  "Cự Thắng": [
    "cự thắng",
    "cuwj thawsng"
  ],
  "Cự Đồng": [
    "cự đồng",
    "cuwj ddoofng"
  ],
  "Danh Thắng": [
    "danh thắng",
    "danh thawsng"
  ],
  "Diên Hồng": [
    "diên hồng",
    "dieen hoofng"
  ],
  "Diên Khánh": [
    "diên khánh",
    "dieen khasnh"
  ],
  "Diễn Bích": [
    "diễn bích",
    "dieexn bisch"
  ],
  "Diễn Châu": [
    "diễn châu",
    "dieexn chaau"
  ],
  "Diễn Hùng": [
    "diễn hùng",
    "dieexn hufng"
  ],
  "Diễn Hải": [
    "diễn hải",
    "dieexn hari"
  ],
  "Diễn Liên": [
    "diễn liên",
    "dieexn lieen"
  ],
  "Diễn Lộc": [
    "diễn lộc",
    "dieexn loojc"
  ],
  "Diễn Lợi": [
    "diễn lợi",
    "dieexn lowji"
  ],
  "Diễn Phong": [
    "diễn phong",
    "dieexn phong"
  ],
  "Diễn Phúc": [
    "diễn phúc",
    "dieexn phusc"
  ],
  "Diễn Thái": [
    "diễn thái",
    "dieexn thasi"
  ],
  "Diễn Tháp": [
    "diễn tháp",
    "dieexn thasp"
  ],
  "Diễn Thọ": [
    "diễn thọ",
    "dieexn thoj"
  ],
  "Diễn Trung": [
    "diễn trung",
    "dieexn trung"
  ],
  "Diễn Vạn": [
    "diễn vạn",
    "dieexn vajn"
  ],
  "Diễn Xuân": [
    "diễn xuân",
    "dieexn xuaan"
  ],
  "Duy Phước": [
    "duy phước",
    "duy phuwowsc"
  ],
  "Duyên Hải": [
    "duyên hải",
    "duyeen hari"
  ],
  "Duyên Thái": [
    "duyên thái",
    "duyeen thasi"
  ],
  "Dân Quyền": [
    "dân quyền",
    "daan quyeefn"
  ],
  "Dũng Liệt": [
    "dũng liệt",
    "duxng lieejt"
  ],
  "Dũng Nghĩa": [
    "dũng nghĩa",
    "duxng nghixa"
  ],
  "Dũng Tiến": [
    "dũng tiến",
    "duxng tieesn"
  ],
  "Dương Hòa": [
    "dương hòa",
    "duwowng hofa"
  ],
  "Dương Hưu": [
    "dương hưu",
    "duwowng huwu"
  ],
  "Dương Kinh": [
    "dương kinh",
    "duwowng kinh"
  ],
  "Dương Quan": [
    "dương quan",
    "duwowng quan"
  ],
  "Dương Sơn": [
    "dương sơn",
    "duwowng sown"
  ],
  "Dạ Trạch": [
    "dạ trạch",
    "daj trajch"
  ],
  "Dần Thàng": [
    "dần thàng",
    "daafn thafng"
  ],
  "Dền Thàng": [
    "dền thàng",
    "deefn thafng"
  ],
  "Gia Phương": [
    "gia phương",
    "gia phuwowng"
  ],
  "Gia Tường": [
    "gia tường",
    "gia tuwowfng"
  ],
  "Gia Vượng": [
    "gia vượng",
    "gia vuwowjng"
  ],
  "Giang Thành": [
    "giang thành",
    "giang thafnh"
  ],
  "Giao Hương": [
    "giao hương",
    "giao huwowng"
  ],
  "Giao Thiện": [
    "giao thiện",
    "giao thieejn"
  ],
  "Giao Thạnh": [
    "giao thạnh",
    "giao thajnh"
  ],
  "Giao Thịnh": [
    "giao thịnh",
    "giao thijnh"
  ],
  "Giáo Hiệu": [
    "giáo hiệu",
    "giaso hieeju"
  ],
  "Giáp Đắt": [
    "giáp đắt",
    "giasp ddawst"
  ],
  "Gáo Giồng": [
    "gáo giồng",
    "gaso gioofng"
  ],
  "Hiếu Liêm": [
    "hiếu liêm",
    "hieesu lieem"
  ],
  "Hiếu Nhơn": [
    "hiếu nhơn",
    "hieesu nhown"
  ],
  "Hiếu Trung": [
    "hiếu trung",
    "hieesu trung"
  ],
  "Hiền Chung": [
    "hiền chung",
    "hieefn chung"
  ],
  "Hiền Giang": [
    "hiền giang",
    "hieefn giang"
  ],
  "Hiệp Hưng": [
    "hiệp hưng",
    "hieejp huwng"
  ],
  "Hiệp Lợi": [
    "hiệp lợi",
    "hieejp lowji"
  ],
  "Hiệp Lực": [
    "hiệp lực",
    "hieejp luwjc"
  ],
  "Hiệp Tùng": [
    "hiệp tùng",
    "hieejp tufng"
  ],
  "Hoà Thuận": [
    "hoà thuận",
    "hoaf thuaajn"
  ],
  "Hoài Đức": [
    "hoài đức",
    "hoafi dduwsc"
  ],
  "Hoàn Kiếm": [
    "hoàn kiếm",
    "hoafn kieesm"
  ],
  "Hoàng Châu": [
    "hoàng châu",
    "hoafng chaau"
  ],
  "Hoàng Giang": [
    "hoàng giang",
    "hoafng giang"
  ],
  "Hoàng Liên": [
    "hoàng liên",
    "hoafng lieen"
  ],
  "Hoàng Nông": [
    "hoàng nông",
    "hoafng noong"
  ],
  "Hoàng Quế": [
    "hoàng quế",
    "hoafng quees"
  ],
  "Hoàng Thanh": [
    "hoàng thanh",
    "hoafng thanh"
  ],
  "Hoạt Giang": [
    "hoạt giang",
    "hoajt giang"
  ],
  "Hoả Tiến": [
    "hoả tiến",
    "hoar tieesn"
  ],
  "Hoằng Cát": [
    "hoằng cát",
    "hoawfng cast"
  ],
  "Hoằng Hóa": [
    "hoằng hóa",
    "hoawfng hosa"
  ],
  "Hoằng Lưu": [
    "hoằng lưu",
    "hoawfng luwu"
  ],
  "Hoằng Phú": [
    "hoằng phú",
    "hoawfng phus"
  ],
  "Hoằng Quý": [
    "hoằng quý",
    "hoawfng quys"
  ],
  "Hoằng Sơn": [
    "hoằng sơn",
    "hoawfng sown"
  ],
  "Hoằng Tân": [
    "hoằng tân",
    "hoawfng taan"
  ],
  "Huy Tường": [
    "huy tường",
    "huy tuwowfng"
  ],
  "Huyền Sơn": [
    "huyền sơn",
    "huyeefn sown"
  ],
  "Huổi Lèng": [
    "huổi lèng",
    "huoori lefng"
  ],
  "Huổi Một": [
    "huổi một",
    "huoori moojt"
  ],
  "Hàm Thạnh": [
    "hàm thạnh",
    "hafm thajnh"
  ],
  "Hàm Thắng": [
    "hàm thắng",
    "hafm thawsng"
  ],
  "Hàng Buồm": [
    "hàng buồm",
    "hafng buoofm"
  ],
  "Hàng Trạm": [
    "hàng trạm",
    "hafng trajm"
  ],
  "Hàng Vịnh": [
    "hàng vịnh",
    "hafng vijnh"
  ],
  "Hành Đức": [
    "hành đức",
    "hafnh dduwsc"
  ],
  "Hán Quảng": [
    "hán quảng",
    "hasn quarng"
  ],
  "Hòa Bình 1": [
    "hòa bình 1",
    "hofa bifnh 1"
  ],
  "Hòa Hương": [
    "hòa hương",
    "hofa huwowng"
  ],
  "Hòa Thuận": [
    "hòa thuận",
    "hofa thuaajn"
  ],
  "Hòa Thạch": [
    "hòa thạch",
    "hofa thajch"
  ],
  "Hòa Thạnh": [
    "hòa thạnh",
    "hofa thajnh"
  ],
  "Hòa Thắng": [
    "hòa thắng",
    "hofa thawsng"
  ],
  "Hòa Thịnh": [
    "hòa thịnh",
    "hofa thijnh"
  ],
  "Hòa Trạch": [
    "hòa trạch",
    "hofa trajch"
  ],
  "Hòa Điền": [
    "hòa điền",
    "hofa ddieefn"
  ],
  "Hòa Định": [
    "hòa định",
    "hofa ddijnh"
  ],
  "Hòa Đồng": [
    "hòa đồng",
    "hofa ddoofng"
  ],
  "Hùng Thành": [
    "hùng thành",
    "hufng thafnh"
  ],
  "Hùng Tiến": [
    "hùng tiến",
    "hufng tieesn"
  ],
  "Hùng Việt": [
    "hùng việt",
    "hufng vieejt"
  ],
  "Hùng Xuyên": [
    "hùng xuyên",
    "hufng xuyeen"
  ],
  "Hùng Đức": [
    "hùng đức",
    "hufng dduwsc"
  ],
  "Húc Động": [
    "húc động",
    "husc ddoojng"
  ],
  "Hưng Chính": [
    "hưng chính",
    "huwng chisnh"
  ],
  "Hưng Khánh": [
    "hưng khánh",
    "huwng khasnh"
  ],
  "Hưng Nghĩa": [
    "hưng nghĩa",
    "huwng nghixa"
  ],
  "Hưng Thành": [
    "hưng thành",
    "huwng thafnh"
  ],
  "Hưng Thông": [
    "hưng thông",
    "huwng thoong"
  ],
  "Hưng Thủy": [
    "hưng thủy",
    "huwng thury"
  ],
  "Hưng Đông": [
    "hưng đông",
    "huwng ddoong"
  ],
  "Hưng Đạo": [
    "hưng đạo",
    "huwng ddajo"
  ],
  "Hương Canh": [
    "hương canh",
    "huwowng canh"
  ],
  "Hương Hóa": [
    "hương hóa",
    "huwowng hosa"
  ],
  "Hương Hồ": [
    "hương hồ",
    "huwowng hoof"
  ],
  "Hương Khê": [
    "hương khê",
    "huwowng khee"
  ],
  "Hương Long": [
    "hương long",
    "huwowng long"
  ],
  "Hương Lung": [
    "hương lung",
    "huwowng lung"
  ],
  "Hương Lâm": [
    "hương lâm",
    "huwowng laam"
  ],
  "Hương Minh": [
    "hương minh",
    "huwowng minh"
  ],
  "Hương Mỹ": [
    "hương mỹ",
    "huwowng myx"
  ],
  "Hương Phú": [
    "hương phú",
    "huwowng phus"
  ],
  "Hương Sơn": [
    "hương sơn",
    "huwowng sown"
  ],
  "Hương Trà": [
    "hương trà",
    "huwowng traf"
  ],
  "Hương Vinh": [
    "hương vinh",
    "huwowng vinh"
  ],
  "Hương Vân": [
    "hương vân",
    "huwowng vaan"
  ],
  "Hương Văn": [
    "hương văn",
    "huwowng vawn"
  ],
  "Hương Xạ": [
    "hương xạ",
    "huwowng xaj"
  ],
  "Hương Đô": [
    "hương đô",
    "huwowng ddoo"
  ],
  "Hạ Trạch": [
    "hạ trạch",
    "haj trajch"
  ],
  "Hạnh Phúc": [
    "hạnh phúc",
    "hajnh phusc"
  ],
  "Hải Chánh": [
    "hải chánh",
    "hari chasnh"
  ],
  "Hải Chính": [
    "hải chính",
    "hari chisnh"
  ],
  "Hải Cảng": [
    "hải cảng",
    "hari carng"
  ],
  "Hải Lạng": [
    "hải lạng",
    "hari lajng"
  ],
  "Hải Phòng": [
    "hải phòng",
    "hari phofng"
  ],
  "Hải Thành": [
    "hải thành",
    "hari thafnh"
  ],
  "Hải Tiến": [
    "hải tiến",
    "hari tieesn"
  ],
  "Hải Đông": [
    "hải đông",
    "hari ddoong"
  ],
  "Hậu Nghĩa": [
    "hậu nghĩa",
    "haaju nghixa"
  ],
  "Hậu Thành": [
    "hậu thành",
    "haaju thafnh"
  ],
  "Hắc Dịch": [
    "hắc dịch",
    "hawsc dijch"
  ],
  "Hồng Bàng": [
    "hồng bàng",
    "hoofng bafng"
  ],
  "Hồng Bắc": [
    "hồng bắc",
    "hoofng bawsc"
  ],
  "Hồng Châu": [
    "hồng châu",
    "hoofng chaau"
  ],
  "Hồng Dũng": [
    "hồng dũng",
    "hoofng duxng"
  ],
  "Hồng Giang": [
    "hồng giang",
    "hoofng giang"
  ],
  "Hồng Hưng": [
    "hồng hưng",
    "hoofng huwng"
  ],
  "Hồng Hải": [
    "hồng hải",
    "hoofng hari"
  ],
  "Hồng Liêm": [
    "hồng liêm",
    "hoofng lieem"
  ],
  "Hồng Lĩnh": [
    "hồng lĩnh",
    "hoofng lixnh"
  ],
  "Hồng Lạc": [
    "hồng lạc",
    "hoofng lajc"
  ],
  "Hồng Lộc": [
    "hồng lộc",
    "hoofng loojc"
  ],
  "Hồng Ngài": [
    "hồng ngài",
    "hoofng ngafi"
  ],
  "Hồng Ngự": [
    "hồng ngự",
    "hoofng nguwj"
  ],
  "Hồng Phong": [
    "hồng phong",
    "hoofng phong"
  ],
  "Hồng Phúc": [
    "hồng phúc",
    "hoofng phusc"
  ],
  "Hồng Quang": [
    "hồng quang",
    "hoofng quang"
  ],
  "Hồng Thái": [
    "hồng thái",
    "hoofng thasi"
  ],
  "Hồng Trị": [
    "hồng trị",
    "hoofng trij"
  ],
  "Hội Nghĩa": [
    "hội nghĩa",
    "hooji nghixa"
  ],
  "Hớn Quản": [
    "hớn quản",
    "howsn quarn"
  ],
  "Hợp Nhất": [
    "hợp nhất",
    "howjp nhaast"
  ],
  "Hợp Thành": [
    "hợp thành",
    "howjp thafnh"
  ],
  "Hợp Tiến": [
    "hợp tiến",
    "howjp tieesn"
  ],
  "Hợp Đức": [
    "hợp đức",
    "howjp dduwsc"
  ],
  "Hữu Bằng": [
    "hữu bằng",
    "huwxu bawfng"
  ],
  "Hữu Khánh": [
    "hữu khánh",
    "huwxu khasnh"
  ],
  "Hữu Kiệm": [
    "hữu kiệm",
    "huwxu kieejm"
  ],
  "Hữu Nghị": [
    "hữu nghị",
    "huwxu nghij"
  ],
  "Hữu Đạo": [
    "hữu đạo",
    "huwxu ddajo"
  ],
  "Hựu Thành": [
    "hựu thành",
    "huwju thafnh"
  ],
  "Ia Mơ Nông": [
    "ia mơ nông",
    "ia mow noong"
  ],
  "Khoái Châu": [
    "khoái châu",
    "khoasi chaau"
  ],
  "Khuôn Lùng": [
    "khuôn lùng",
    "khuoon lufng"
  ],
  "Khám Lạng": [
    "khám lạng",
    "khasm lajng"
  ],
  "Khánh Bình": [
    "khánh bình",
    "khasnh bifnh"
  ],
  "Khánh Công": [
    "khánh công",
    "khasnh coong"
  ],
  "Khánh Hưng": [
    "khánh hưng",
    "khasnh huwng"
  ],
  "Khánh Hải": [
    "khánh hải",
    "khasnh hari"
  ],
  "Khánh Hậu": [
    "khánh hậu",
    "khasnh haaju"
  ],
  "Khánh Hội": [
    "khánh hội",
    "khasnh hooji"
  ],
  "Khánh Hợp": [
    "khánh hợp",
    "khasnh howjp"
  ],
  "Khánh Lộc": [
    "khánh lộc",
    "khasnh loojc"
  ],
  "Khánh Lợi": [
    "khánh lợi",
    "khasnh lowji"
  ],
  "Khánh Mậu": [
    "khánh mậu",
    "khasnh maaju"
  ],
  "Khánh Tiên": [
    "khánh tiên",
    "khasnh tieen"
  ],
  "Khánh Trung": [
    "khánh trung",
    "khasnh trung"
  ],
  "Khánh Vĩnh": [
    "khánh vĩnh",
    "khasnh vixnh"
  ],
  "Khánh Xuân": [
    "khánh xuân",
    "khasnh xuaan"
  ],
  "Khâm Thiên": [
    "khâm thiên",
    "khaam thieen"
  ],
  "Khâm Thành": [
    "khâm thành",
    "khaam thafnh"
  ],
  "Khâm Đức": [
    "khâm đức",
    "khaam dduwsc"
  ],
  "Khúc Xuyên": [
    "khúc xuyên",
    "khusc xuyeen"
  ],
  "Khương Mai": [
    "khương mai",
    "khuwowng mai"
  ],
  "Khải Xuân": [
    "khải xuân",
    "khari xuaan"
  ],
  "Khổng Lào": [
    "khổng lào",
    "khoorng lafo"
  ],
  "Kiên Thành": [
    "kiên thành",
    "kieen thafnh"
  ],
  "Kiến Bình": [
    "kiến bình",
    "kieesn bifnh"
  ],
  "Kiến Giang": [
    "kiến giang",
    "kieesn giang"
  ],
  "Kiến Hưng": [
    "kiến hưng",
    "kieesn huwng"
  ],
  "Krông Bông": [
    "krông bông",
    "kroong boong"
  ],
  "Krông Klang": [
    "krông klang",
    "kroong klang"
  ],
  "Krông Năng": [
    "krông năng",
    "kroong nawng"
  ],
  "Krông Pắc": [
    "krông pắc",
    "kroong pawsc"
  ],
  "Kỳ Thịnh": [
    "kỳ thịnh",
    "kyf thijnh"
  ],
  "Kỳ Đồng": [
    "kỳ đồng",
    "kyf ddoofng"
  ],
  "La Pan Tẩn": [
    "la pan tẩn",
    "la pan taarn"
  ],
  "Leng Su Sìn": [
    "leng su sìn",
    "leng su sifn"
  ],
  "Linh Chiểu": [
    "linh chiểu",
    "linh chieeru"
  ],
  "Liêm Chính": [
    "liêm chính",
    "lieem chisnh"
  ],
  "Liêm Thuỷ": [
    "liêm thuỷ",
    "lieem thuyr"
  ],
  "Liêm Tiết": [
    "liêm tiết",
    "lieem tieest"
  ],
  "Liên Hiệp": [
    "liên hiệp",
    "lieen hieejp"
  ],
  "Liên Hồng": [
    "liên hồng",
    "lieen hoofng"
  ],
  "Liên Nghĩa": [
    "liên nghĩa",
    "lieen nghixa"
  ],
  "Liên Thành": [
    "liên thành",
    "lieen thafnh"
  ],
  "Liên Thủy": [
    "liên thủy",
    "lieen thury"
  ],
  "Liên Đầm": [
    "liên đầm",
    "lieen ddaafm"
  ],
  "Liễu Đề": [
    "liễu đề",
    "lieexu ddeef"
  ],
  "Long Hưng A": [
    "long hưng a",
    "long huwng a"
  ],
  "Long Hưng B": [
    "long hưng b",
    "long huwng b"
  ],
  "Long Hương": [
    "long hương",
    "long huwowng"
  ],
  "Long Nguyên": [
    "long nguyên",
    "long nguyeen"
  ],
  "Long Phụng": [
    "long phụng",
    "long phujng"
  ],
  "Long Thuận": [
    "long thuận",
    "long thuaajn"
  ],
  "Long Thạnh": [
    "long thạnh",
    "long thajnh"
  ],
  "Long Thắng": [
    "long thắng",
    "long thawsng"
  ],
  "Long Trạch": [
    "long trạch",
    "long trajch"
  ],
  "Long Trị A": [
    "long trị a",
    "long trij a"
  ],
  "Long Tuyền": [
    "long tuyền",
    "long tuyeefn"
  ],
  "Long Điền": [
    "long điền",
    "long ddieefn"
  ],
  "Long Định": [
    "long định",
    "long ddijnh"
  ],
  "Long Đống": [
    "long đống",
    "long ddoosng"
  ],
  "Luân Giới": [
    "luân giới",
    "luaan giowsi"
  ],
  "Làng Chếu": [
    "làng chếu",
    "lafng cheesu"
  ],
  "Làng Giàng": [
    "làng giàng",
    "lafng giafng"
  ],
  "Láng Biển": [
    "láng biển",
    "lasng bieern"
  ],
  "Lâm Trạch": [
    "lâm trạch",
    "laam trajch"
  ],
  "Lâm Đồng": [
    "lâm đồng",
    "laam ddoofng"
  ],
  "Lâm Động": [
    "lâm động",
    "laam ddoojng"
  ],
  "Lóng Luông": [
    "lóng luông",
    "losng luoong"
  ],
  "Lùng Phình": [
    "lùng phình",
    "lufng phifnh"
  ],
  "Lùng Thàng": [
    "lùng thàng",
    "lufng thafng"
  ],
  "Lùng Thẩn": [
    "lùng thẩn",
    "lufng thaarn"
  ],
  "Lăng Hiếu": [
    "lăng hiếu",
    "lawng hieesu"
  ],
  "Lăng Thành": [
    "lăng thành",
    "lawng thafnh"
  ],
  "Lĩnh Toại": [
    "lĩnh toại",
    "lixnh toaji"
  ],
  "Lũng Thầu": [
    "lũng thầu",
    "luxng thaafu"
  ],
  "Lương Hòa": [
    "lương hòa",
    "luwowng hofa"
  ],
  "Lương Lỗ": [
    "lương lỗ",
    "luwowng loox"
  ],
  "Lương Ninh": [
    "lương ninh",
    "luwowng ninh"
  ],
  "Lương Phú": [
    "lương phú",
    "luwowng phus"
  ],
  "Lương Sơn": [
    "lương sơn",
    "luwowng sown"
  ],
  "Lương Tài": [
    "lương tài",
    "luwowng tafi"
  ],
  "Lương Tâm": [
    "lương tâm",
    "luwowng taam"
  ],
  "Lạc Hồng": [
    "lạc hồng",
    "lajc hoofng"
  ],
  "Lạc Quới": [
    "lạc quới",
    "lajc quowsi"
  ],
  "Lạc Thủy": [
    "lạc thủy",
    "lajc thury"
  ],
  "Lạc Đạo": [
    "lạc đạo",
    "lajc ddajo"
  ],
  "Lạng Giang": [
    "lạng giang",
    "lajng giang"
  ],
  "Lạng Phong": [
    "lạng phong",
    "lajng phong"
  ],
  "Lộc Hiệp": [
    "lộc hiệp",
    "loojc hieejp"
  ],
  "Lộc Khánh": [
    "lộc khánh",
    "loojc khasnh"
  ],
  "Lộc Thành": [
    "lộc thành",
    "loojc thafnh"
  ],
  "Lộc Thủy": [
    "lộc thủy",
    "loojc thury"
  ],
  "Lộc Tiến": [
    "lộc tiến",
    "loojc tieesn"
  ],
  "Lộc Đức": [
    "lộc đức",
    "loojc dduwsc"
  ],
  "Lục Ngạn": [
    "lục ngạn",
    "lujc ngajn"
  ],
  "Ma Thì Hồ": [
    "ma thì hồ",
    "ma thif hoof"
  ],
  "Ma Đa Guôi": [
    "ma đa guôi",
    "ma dda guooi"
  ],
  "Minh Chuẩn": [
    "minh chuẩn",
    "minh chuaarn"
  ],
  "Minh Hương": [
    "minh hương",
    "minh huwowng"
  ],
  "Minh Lương": [
    "minh lương",
    "minh luwowng"
  ],
  "Minh Thuận": [
    "minh thuận",
    "minh thuaajn"
  ],
  "Minh Thạnh": [
    "minh thạnh",
    "minh thajnh"
  ],
  "Minh Thắng": [
    "minh thắng",
    "minh thawsng"
  ],
  "Mong Thọ A": [
    "mong thọ a",
    "mong thoj a"
  ],
  "Mong Thọ B": [
    "mong thọ b",
    "mong thoj b"
  ],
  "Muổi Nọi": [
    "muổi nọi",
    "muoori noji"
  ],
  "Mão Điền": [
    "mão điền",
    "maxo ddieefn"
  ],
  "Mương Mán": [
    "mương mán",
    "muwowng masn"
  ],
  "Mường Bon": [
    "mường bon",
    "muwowfng bon"
  ],
  "Mường Bú": [
    "mường bú",
    "muwowfng bus"
  ],
  "Mường Cai": [
    "mường cai",
    "muwowfng cai"
  ],
  "Mường Hoa": [
    "mường hoa",
    "muwowfng hoa"
  ],
  "Mường Hum": [
    "mường hum",
    "muwowfng hum"
  ],
  "Mường Kim": [
    "mường kim",
    "muwowfng kim"
  ],
  "Mường Lai": [
    "mường lai",
    "muwowfng lai"
  ],
  "Mường Lay": [
    "mường lay",
    "muwowfng lay"
  ],
  "Mường Lý": [
    "mường lý",
    "muwowfng lys"
  ],
  "Mường Men": [
    "mường men",
    "muwowfng men"
  ],
  "Mường Mô": [
    "mường mô",
    "muwowfng moo"
  ],
  "Mường Sai": [
    "mường sai",
    "muwowfng sai"
  ],
  "Mường Tè": [
    "mường tè",
    "muwowfng tef"
  ],
  "Mường Và": [
    "mường và",
    "muwowfng vaf"
  ],
  "Mậu Đông": [
    "mậu đông",
    "maaju ddoong"
  ],
  "Mậu Đức": [
    "mậu đức",
    "maaju dduwsc"
  ],
  "Mồ Sì San": [
    "mồ sì san",
    "moof sif san"
  ],
  "Mỹ Hương": [
    "mỹ hương",
    "myx huwowng"
  ],
  "Mỹ Lương": [
    "mỹ lương",
    "myx luwowng"
  ],
  "Mỹ Lợi A": [
    "mỹ lợi a",
    "myx lowji a"
  ],
  "Mỹ Lợi B": [
    "mỹ lợi b",
    "myx lowji b"
  ],
  "Mỹ Thuận": [
    "mỹ thuận",
    "myx thuaajn"
  ],
  "Mỹ Thạnh": [
    "mỹ thạnh",
    "myx thajnh"
  ],
  "Mỹ Thắng": [
    "mỹ thắng",
    "myx thawsng"
  ],
  "Mỹ Thịnh": [
    "mỹ thịnh",
    "myx thijnh"
  ],
  "Mỹ Trạch": [
    "mỹ trạch",
    "myx trajch"
  ],
  "Mỹ Xương": [
    "mỹ xương",
    "myx xuwowng"
  ],
  "Mỹ Đồng": [
    "mỹ đồng",
    "myx ddoofng"
  ],
  "NT Lệ Ninh": [
    "nt lệ ninh",
    "nt leej ninh"
  ],
  "Nam Cường": [
    "nam cường",
    "nam cuwowfng"
  ],
  "Nam Phước": [
    "nam phước",
    "nam phuwowsc"
  ],
  "Nghi Hương": [
    "nghi hương",
    "nghi huwowng"
  ],
  "Nghi Thiết": [
    "nghi thiết",
    "nghi thieest"
  ],
  "Nghi Thuận": [
    "nghi thuận",
    "nghi thuaajn"
  ],
  "Nghi Thạch": [
    "nghi thạch",
    "nghi thajch"
  ],
  "Nghi Thịnh": [
    "nghi thịnh",
    "nghi thijnh"
  ],
  "Nghi Đồng": [
    "nghi đồng",
    "nghi ddoofng"
  ],
  "Nghiên Loan": [
    "nghiên loan",
    "nghieen loan"
  ],
  "Nghĩa Bình": [
    "nghĩa bình",
    "nghixa bifnh"
  ],
  "Nghĩa Châu": [
    "nghĩa châu",
    "nghixa chaau"
  ],
  "Nghĩa Dõng": [
    "nghĩa dõng",
    "nghixa doxng"
  ],
  "Nghĩa Dũng": [
    "nghĩa dũng",
    "nghixa duxng"
  ],
  "Nghĩa Hoàn": [
    "nghĩa hoàn",
    "nghixa hoafn"
  ],
  "Nghĩa Hành": [
    "nghĩa hành",
    "nghixa hafnh"
  ],
  "Nghĩa Hùng": [
    "nghĩa hùng",
    "nghixa hufng"
  ],
  "Nghĩa Hưng": [
    "nghĩa hưng",
    "nghixa huwng"
  ],
  "Nghĩa Hải": [
    "nghĩa hải",
    "nghixa hari"
  ],
  "Nghĩa Hội": [
    "nghĩa hội",
    "nghixa hooji"
  ],
  "Nghĩa Hợp": [
    "nghĩa hợp",
    "nghixa howjp"
  ],
  "Nghĩa Lạc": [
    "nghĩa lạc",
    "nghixa lajc"
  ],
  "Nghĩa Lộc": [
    "nghĩa lộc",
    "nghixa loojc"
  ],
  "Nghĩa Lợi": [
    "nghĩa lợi",
    "nghixa lowji"
  ],
  "Nghĩa Phong": [
    "nghĩa phong",
    "nghixa phong"
  ],
  "Nghĩa Phúc": [
    "nghĩa phúc",
    "nghixa phusc"
  ],
  "Nghĩa Thái": [
    "nghĩa thái",
    "nghixa thasi"
  ],
  "Nghĩa Thọ": [
    "nghĩa thọ",
    "nghixa thoj"
  ],
  "Nghĩa Trung": [
    "nghĩa trung",
    "nghixa trung"
  ],
  "Nghĩa Trụ": [
    "nghĩa trụ",
    "nghixa truj"
  ],
  "Nghĩa Xuân": [
    "nghĩa xuân",
    "nghixa xuaan"
  ],
  "Nghĩa Đàn": [
    "nghĩa đàn",
    "nghixa ddafn"
  ],
  "Nguyên Hòa": [
    "nguyên hòa",
    "nguyeen hofa"
  ],
  "Nguyên Khê": [
    "nguyên khê",
    "nguyeen khee"
  ],
  "Nguyễn Úy": [
    "nguyễn úy",
    "nguyeexn usy"
  ],
  "Ngân Thủy": [
    "ngân thủy",
    "ngaan thury"
  ],
  "Ngãi Xuyên": [
    "ngãi xuyên",
    "ngaxi xuyeen"
  ],
  "Ngãi Đăng": [
    "ngãi đăng",
    "ngaxi ddawng"
  ],
  "Ngô Quyền": [
    "ngô quyền",
    "ngoo quyeefn"
  ],
  "Ngô Đồng": [
    "ngô đồng",
    "ngoo ddoofng"
  ],
  "Ngũ Phụng": [
    "ngũ phụng",
    "ngux phujng"
  ],
  "Ngư Thủy ": [
    "ngư thủy ",
    "nguw thury "
  ],
  "Ngọc Biên": [
    "ngọc biên",
    "ngojc bieen"
  ],
  "Ngọc Châu": [
    "ngọc châu",
    "ngojc chaau"
  ],
  "Ngọc Chúc": [
    "ngọc chúc",
    "ngojc chusc"
  ],
  "Ngọc Hồi": [
    "ngọc hồi",
    "ngojc hoofi"
  ],
  "Ngọc Hội": [
    "ngọc hội",
    "ngojc hooji"
  ],
  "Ngọc Liên": [
    "ngọc liên",
    "ngojc lieen"
  ],
  "Ngọc Lĩnh": [
    "ngọc lĩnh",
    "ngojc lixnh"
  ],
  "Ngọc Lập": [
    "ngọc lập",
    "ngojc laajp"
  ],
  "Ngọc Lặc": [
    "ngọc lặc",
    "ngojc lawjc"
  ],
  "Ngọc Phái": [
    "ngọc phái",
    "ngojc phasi"
  ],
  "Ngọc Thanh": [
    "ngọc thanh",
    "ngojc thanh"
  ],
  "Ngọc Trung": [
    "ngọc trung",
    "ngojc trung"
  ],
  "Ngọc Tảo": [
    "ngọc tảo",
    "ngojc taro"
  ],
  "Ngọc Xuân": [
    "ngọc xuân",
    "ngojc xuaan"
  ],
  "Ngọc Đào": [
    "ngọc đào",
    "ngojc ddafo"
  ],
  "Ngổ Luông": [
    "ngổ luông",
    "ngoor luoong"
  ],
  "Nhân Chính": [
    "nhân chính",
    "nhaan chisnh"
  ],
  "Nhân Nghĩa": [
    "nhân nghĩa",
    "nhaan nghixa"
  ],
  "Nhân Thành": [
    "nhân thành",
    "nhaan thafnh"
  ],
  "Nhân Đạo": [
    "nhân đạo",
    "nhaan ddajo"
  ],
  "Nhơn Hạnh": [
    "nhơn hạnh",
    "nhown hajnh"
  ],
  "Nhơn Khánh": [
    "nhơn khánh",
    "nhown khasnh"
  ],
  "Nhơn Nghĩa": [
    "nhơn nghĩa",
    "nhown nghixa"
  ],
  "Nhơn Thành": [
    "nhơn thành",
    "nhown thafnh"
  ],
  "Nhơn Đức": [
    "nhơn đức",
    "nhown dduwsc"
  ],
  "Như Quỳnh": [
    "như quỳnh",
    "nhuw quyfnh"
  ],
  "Nhật Quang": [
    "nhật quang",
    "nhaajt quang"
  ],
  "Nhật Tựu": [
    "nhật tựu",
    "nhaajt tuwju"
  ],
  "Nhị Thành": [
    "nhị thành",
    "nhij thafnh"
  ],
  "Ninh Dương": [
    "ninh dương",
    "ninh duwowng"
  ],
  "Ninh Phụng": [
    "ninh phụng",
    "ninh phujng"
  ],
  "Ninh Thuận": [
    "ninh thuận",
    "ninh thuaajn"
  ],
  "Ninh Thạnh": [
    "ninh thạnh",
    "ninh thajnh"
  ],
  "Ninh Thắng": [
    "ninh thắng",
    "ninh thawsng"
  ],
  "Ninh Điền": [
    "ninh điền",
    "ninh ddieefn"
  ],
  "Nà Khương": [
    "nà khương",
    "naf khuwowng"
  ],
  "Nà Mường": [
    "nà mường",
    "naf muwowfng"
  ],
  "Nông Cống": [
    "nông cống",
    "noong coosng"
  ],
  "Nông Tiến": [
    "nông tiến",
    "noong tieesn"
  ],
  "Nậm Chạc": [
    "nậm chạc",
    "naajm chajc"
  ],
  "Nậm Chảy": [
    "nậm chảy",
    "naajm chary"
  ],
  "Nậm Chầy": [
    "nậm chầy",
    "naajm chaafy"
  ],
  "Nậm Cuổi": [
    "nậm cuổi",
    "naajm cuoori"
  ],
  "Nậm Dịch": [
    "nậm dịch",
    "naajm dijch"
  ],
  "Nậm Giải": [
    "nậm giải",
    "naajm giari"
  ],
  "Nậm Khánh": [
    "nậm khánh",
    "naajm khasnh"
  ],
  "Nậm Khắt": [
    "nậm khắt",
    "naajm khawst"
  ],
  "Nậm Lạnh": [
    "nậm lạnh",
    "naajm lajnh"
  ],
  "Nậm Rạng": [
    "nậm rạng",
    "naajm rajng"
  ],
  "Nặm Lịch": [
    "nặm lịch",
    "nawjm lijch"
  ],
  "Nội Hoàng": [
    "nội hoàng",
    "nooji hoafng"
  ],
  "Pa Vây Sử": [
    "pa vây sử",
    "pa vaay suwr"
  ],
  "Pa Vệ Sử": [
    "pa vệ sử",
    "pa veej suwr"
  ],
  "Phan Thiết": [
    "phan thiết",
    "phan thieest"
  ],
  "Phan Điền": [
    "phan điền",
    "phan ddieefn"
  ],
  "Phiêng Côn": [
    "phiêng côn",
    "phieeng coon"
  ],
  "Phong Hiền": [
    "phong hiền",
    "phong hieefn"
  ],
  "Phong Thủy": [
    "phong thủy",
    "phong thury"
  ],
  "Phong Đông": [
    "phong đông",
    "phong ddoong"
  ],
  "Phát Diệm": [
    "phát diệm",
    "phast dieejm"
  ],
  "Phì Điền": [
    "phì điền",
    "phif ddieefn"
  ],
  "Phình Sáng": [
    "phình sáng",
    "phifnh sasng"
  ],
  "Phù Lương": [
    "phù lương",
    "phuf luwowng"
  ],
  "Phù Đổng": [
    "phù đổng",
    "phuf ddoorng"
  ],
  "Phùng Giáo": [
    "phùng giáo",
    "phufng giaso"
  ],
  "Phùng Hưng": [
    "phùng hưng",
    "phufng huwng"
  ],
  "Phú An Hòa": [
    "phú an hòa",
    "phus an hofa"
  ],
  "Phú Dương": [
    "phú dương",
    "phus duwowng"
  ],
  "Phú Lương": [
    "phú lương",
    "phus luwowng"
  ],
  "Phú Nghiêm": [
    "phú nghiêm",
    "phus nghieem"
  ],
  "Phú Nhuận": [
    "phú nhuận",
    "phus nhuaajn"
  ],
  "Phú Phụng": [
    "phú phụng",
    "phus phujng"
  ],
  "Phú Riềng": [
    "phú riềng",
    "phus rieefng"
  ],
  "Phú Thiện": [
    "phú thiện",
    "phus thieejn"
  ],
  "Phú Thuận": [
    "phú thuận",
    "phus thuaajn"
  ],
  "Phú Thạnh": [
    "phú thạnh",
    "phus thajnh"
  ],
  "Phú Thịnh": [
    "phú thịnh",
    "phus thijnh"
  ],
  "Phú Điền": [
    "phú điền",
    "phus ddieefn"
  ],
  "Phú Định": [
    "phú định",
    "phus ddijnh"
  ],
  "Phúc Diễn": [
    "phúc diễn",
    "phusc dieexn"
  ],
  "Phúc Khánh": [
    "phúc khánh",
    "phusc khasnh"
  ],
  "Phúc Thành": [
    "phúc thành",
    "phusc thafnh"
  ],
  "Phúc Tiến": [
    "phúc tiến",
    "phusc tieesn"
  ],
  "Phương Mai": [
    "phương mai",
    "phuwowng mai"
  ],
  "Phương Nam": [
    "phương nam",
    "phuwowng nam"
  ],
  "Phương Tú": [
    "phương tú",
    "phuwowng tus"
  ],
  "Phước Gia": [
    "phước gia",
    "phuwowsc gia"
  ],
  "Phước Hà": [
    "phước hà",
    "phuwowsc haf"
  ],
  "Phước Kim": [
    "phước kim",
    "phuwowsc kim"
  ],
  "Phước Lý": [
    "phước lý",
    "phuwowsc lys"
  ],
  "Phước Nam": [
    "phước nam",
    "phuwowsc nam"
  ],
  "Phước Tuy": [
    "phước tuy",
    "phuwowsc tuy"
  ],
  "Phường 01": [
    "phường 01",
    "phuwowfng 01"
  ],
  "Phường 02": [
    "phường 02",
    "phuwowfng 02"
  ],
  "Phường 03": [
    "phường 03",
    "phuwowfng 03"
  ],
  "Phường 04": [
    "phường 04",
    "phuwowfng 04"
  ],
  "Phường 05": [
    "phường 05",
    "phuwowfng 05"
  ],
  "Phường 06": [
    "phường 06",
    "phuwowfng 06"
  ],
  "Phường 07": [
    "phường 07",
    "phuwowfng 07"
  ],
  "Phường 08": [
    "phường 08",
    "phuwowfng 08"
  ],
  "Phường 09": [
    "phường 09",
    "phuwowfng 09"
  ],
  "Phường 10": [
    "phường 10",
    "phuwowfng 10"
  ],
  "Phường 11": [
    "phường 11",
    "phuwowfng 11"
  ],
  "Phường 12": [
    "phường 12",
    "phuwowfng 12"
  ],
  "Phường 13": [
    "phường 13",
    "phuwowfng 13"
  ],
  "Phường 14": [
    "phường 14",
    "phuwowfng 14"
  ],
  "Phường 15": [
    "phường 15",
    "phuwowfng 15"
  ],
  "Phường 16": [
    "phường 16",
    "phuwowfng 16"
  ],
  "Phường 17": [
    "phường 17",
    "phuwowfng 17"
  ],
  "Phường 18": [
    "phường 18",
    "phuwowfng 18"
  ],
  "Phường 19": [
    "phường 19",
    "phuwowfng 19"
  ],
  "Phường 21": [
    "phường 21",
    "phuwowfng 21"
  ],
  "Phường 22": [
    "phường 22",
    "phuwowfng 22"
  ],
  "Phường 24": [
    "phường 24",
    "phuwowfng 24"
  ],
  "Phường 25": [
    "phường 25",
    "phuwowfng 25"
  ],
  "Phường 26": [
    "phường 26",
    "phuwowfng 26"
  ],
  "Phường 27": [
    "phường 27",
    "phuwowfng 27"
  ],
  "Phường 28": [
    "phường 28",
    "phuwowfng 28"
  ],
  "Phạm Thái": [
    "phạm thái",
    "phajm thasi"
  ],
  "Phật Tích": [
    "phật tích",
    "phaajt tisch"
  ],
  "Phổ Khánh": [
    "phổ khánh",
    "phoor khasnh"
  ],
  "Phổng Lái": [
    "phổng lái",
    "phoorng lasi"
  ],
  "Phủ Thông": [
    "phủ thông",
    "phur thoong"
  ],
  "Púng Luông": [
    "púng luông",
    "pusng luoong"
  ],
  "Pải Lủng": [
    "pải lủng",
    "pari lurng"
  ],
  "Quang Diệm": [
    "quang diệm",
    "quang dieejm"
  ],
  "Quang Khải": [
    "quang khải",
    "quang khari"
  ],
  "Quang Lịch": [
    "quang lịch",
    "quang lijch"
  ],
  "Quang Phục": [
    "quang phục",
    "quang phujc"
  ],
  "Quang Thành": [
    "quang thành",
    "quang thafnh"
  ],
  "Quang Tiến": [
    "quang tiến",
    "quang tieesn"
  ],
  "Qui Hướng": [
    "qui hướng",
    "qui huwowsng"
  ],
  "Quyết Tâm": [
    "quyết tâm",
    "quyeest taam"
  ],
  "Quán Thánh": [
    "quán thánh",
    "quasn thasnh"
  ],
  "Quảng Bị": [
    "quảng bị",
    "quarng bij"
  ],
  "Quảng Cát": [
    "quảng cát",
    "quarng cast"
  ],
  "Quảng Giao": [
    "quảng giao",
    "quarng giao"
  ],
  "Quảng Hoà": [
    "quảng hoà",
    "quarng hoaf"
  ],
  "Quảng Hòa": [
    "quảng hòa",
    "quarng hofa"
  ],
  "Quảng Khê": [
    "quảng khê",
    "quarng khee"
  ],
  "Quảng Long": [
    "quảng long",
    "quarng long"
  ],
  "Quảng Lâm": [
    "quảng lâm",
    "quarng laam"
  ],
  "Quảng Lưu": [
    "quảng lưu",
    "quarng luwu"
  ],
  "Quảng Minh": [
    "quảng minh",
    "quarng minh"
  ],
  "Quảng Nham": [
    "quảng nham",
    "quarng nham"
  ],
  "Quảng Ninh": [
    "quảng ninh",
    "quarng ninh"
  ],
  "Quảng Phú": [
    "quảng phú",
    "quarng phus"
  ],
  "Quảng Sơn": [
    "quảng sơn",
    "quarng sown"
  ],
  "Quảng Tâm": [
    "quảng tâm",
    "quarng taam"
  ],
  "Quảng Tân": [
    "quảng tân",
    "quarng taan"
  ],
  "Quảng Tín": [
    "quảng tín",
    "quarng tisn"
  ],
  "Quảng Vinh": [
    "quảng vinh",
    "quarng vinh"
  ],
  "Quảng Văn": [
    "quảng văn",
    "quarng vawn"
  ],
  "Quảng Yên": [
    "quảng yên",
    "quarng yeen"
  ],
  "Quế Hiệp": [
    "quế hiệp",
    "quees hieejp"
  ],
  "Quốc Thái": [
    "quốc thái",
    "quoosc thasi"
  ],
  "Quỳnh Côi": [
    "quỳnh côi",
    "quyfnh cooi"
  ],
  "Quỳnh Dị": [
    "quỳnh dị",
    "quyfnh dij"
  ],
  "Quỳnh Giao": [
    "quỳnh giao",
    "quyfnh giao"
  ],
  "Quỳnh Khê": [
    "quỳnh khê",
    "quyfnh khee"
  ],
  "Quỳnh Long": [
    "quỳnh long",
    "quyfnh long"
  ],
  "Quỳnh Lâm": [
    "quỳnh lâm",
    "quyfnh laam"
  ],
  "Quỳnh Lôi": [
    "quỳnh lôi",
    "quyfnh looi"
  ],
  "Quỳnh Lưu": [
    "quỳnh lưu",
    "quyfnh luwu"
  ],
  "Quỳnh Minh": [
    "quỳnh minh",
    "quyfnh minh"
  ],
  "Quỳnh Mỹ": [
    "quỳnh mỹ",
    "quyfnh myx"
  ],
  "Quỳnh Nhai": [
    "quỳnh nhai",
    "quyfnh nhai"
  ],
  "Quỳnh Phú": [
    "quỳnh phú",
    "quyfnh phus"
  ],
  "Quỳnh Sơn": [
    "quỳnh sơn",
    "quyfnh sown"
  ],
  "Quỳnh Tân": [
    "quỳnh tân",
    "quyfnh taan"
  ],
  "Quỳnh Vinh": [
    "quỳnh vinh",
    "quyfnh vinh"
  ],
  "Quỳnh Văn": [
    "quỳnh văn",
    "quyfnh vawn"
  ],
  "Quỳnh Yên": [
    "quỳnh yên",
    "quyfnh yeen"
  ],
  "Quỹ Nhất": [
    "quỹ nhất",
    "quyx nhaast"
  ],
  "Qưới Sơn": [
    "qưới sơn",
    "quwowsi sown"
  ],
  "Rạch Chèo": [
    "rạch chèo",
    "rajch chefo"
  ],
  "Rạch Dừa": [
    "rạch dừa",
    "rajch duwfa"
  ],
  "Rạch Gốc": [
    "rạch gốc",
    "rajch goosc"
  ],
  "Rạch Sỏi": [
    "rạch sỏi",
    "rajch sori"
  ],
  "Sen Phương": [
    "sen phương",
    "sen phuwowng"
  ],
  "Song Phụng": [
    "song phụng",
    "song phujng"
  ],
  "Song Thuận": [
    "song thuận",
    "song thuaajn"
  ],
  "Suối Bàng": [
    "suối bàng",
    "suoosi bafng"
  ],
  "Suối Bạc": [
    "suối bạc",
    "suoosi bajc"
  ],
  "Suối Tiên": [
    "suối tiên",
    "suoosi tieen"
  ],
  "Sài Đồng": [
    "sài đồng",
    "safi ddoofng"
  ],
  "Sính Lủng": [
    "sính lủng",
    "sisnh lurng"
  ],
  "Sính Phình": [
    "sính phình",
    "sisnh phifnh"
  ],
  "Sông Bằng": [
    "sông bằng",
    "soong bawfng"
  ],
  "Sông Hiến": [
    "sông hiến",
    "soong hieesn"
  ],
  "Sông Nhạn": [
    "sông nhạn",
    "soong nhajn"
  ],
  "Sông Trầu": [
    "sông trầu",
    "soong traafu"
  ],
  "Sông Đốc": [
    "sông đốc",
    "soong ddoosc"
  ],
  "Sơn Cương": [
    "sơn cương",
    "sown cuwowng"
  ],
  "Sơn Dương": [
    "sơn dương",
    "sown duwowng"
  ],
  "Sơn Lương": [
    "sơn lương",
    "sown luwowng"
  ],
  "Sơn Nguyên": [
    "sơn nguyên",
    "sown nguyeen"
  ],
  "Sơn Thịnh": [
    "sơn thịnh",
    "sown thijnh"
  ],
  "Sơn Điền": [
    "sơn điền",
    "sown ddieefn"
  ],
  "Sơn Điện": [
    "sơn điện",
    "sown ddieejn"
  ],
  "Sơn Định": [
    "sơn định",
    "sown ddijnh"
  ],
  "Sơn Đồng": [
    "sơn đồng",
    "sown ddoofng"
  ],
  "Sơn Động": [
    "sơn động",
    "sown ddoojng"
  ],
  "Sảng Mộc": [
    "sảng mộc",
    "sarng moojc"
  ],
  "Sủng Máng": [
    "sủng máng",
    "surng masng"
  ],
  "Sủng Thài": [
    "sủng thài",
    "surng thafi"
  ],
  "Sủng Trái": [
    "sủng trái",
    "surng trasi"
  ],
  "Tam Cường": [
    "tam cường",
    "tam cuwowfng"
  ],
  "Tam Phước": [
    "tam phước",
    "tam phuwowsc"
  ],
  "Tam Quan Nam": [
    "tam quan nam",
    "tam quan nam"
  ],
  "Tam Xuân II": [
    "tam xuân ii",
    "tam xuaan ii"
  ],
  "Thanh Hồng": [
    "thanh hồng",
    "thanh hoofng"
  ],
  "Thanh Liệt": [
    "thanh liệt",
    "thanh lieejt"
  ],
  "Thanh Luông": [
    "thanh luông",
    "thanh luoong"
  ],
  "Thanh Luận": [
    "thanh luận",
    "thanh luaajn"
  ],
  "Thanh Miếu": [
    "thanh miếu",
    "thanh mieesu"
  ],
  "Thanh Miện": [
    "thanh miện",
    "thanh mieejn"
  ],
  "Thanh Nghị": [
    "thanh nghị",
    "thanh nghij"
  ],
  "Thanh Ngọc": [
    "thanh ngọc",
    "thanh ngojc"
  ],
  "Thanh Nhật": [
    "thanh nhật",
    "thanh nhaajt"
  ],
  "Thanh Thuỷ": [
    "thanh thuỷ",
    "thanh thuyr"
  ],
  "Thanh Thủy": [
    "thanh thủy",
    "thanh thury"
  ],
  "Thanh Đình": [
    "thanh đình",
    "thanh ddifnh"
  ],
  "Thanh Đức": [
    "thanh đức",
    "thanh dduwsc"
  ],
  "Thiên Cầm": [
    "thiên cầm",
    "thieen caafm"
  ],
  "Thiên Lộc": [
    "thiên lộc",
    "thieen loojc"
  ],
  "Thiên Phủ": [
    "thiên phủ",
    "thieen phur"
  ],
  "Thiết Kế": [
    "thiết kế",
    "thieest kees"
  ],
  "Thiện Hòa": [
    "thiện hòa",
    "thieejn hofa"
  ],
  "Thiện Kế": [
    "thiện kế",
    "thieejn kees"
  ],
  "Thiện Long": [
    "thiện long",
    "thieejn long"
  ],
  "Thiện Mỹ": [
    "thiện mỹ",
    "thieejn myx"
  ],
  "Thiện Trí": [
    "thiện trí",
    "thieejn tris"
  ],
  "Thiện Tân": [
    "thiện tân",
    "thieejn taan"
  ],
  "Thiệu Giao": [
    "thiệu giao",
    "thieeju giao"
  ],
  "Thiệu Hòa": [
    "thiệu hòa",
    "thieeju hofa"
  ],
  "Thiệu Hóa": [
    "thiệu hóa",
    "thieeju hosa"
  ],
  "Thiệu Long": [
    "thiệu long",
    "thieeju long"
  ],
  "Thiệu Phú": [
    "thiệu phú",
    "thieeju phus"
  ],
  "Thiệu Vân": [
    "thiệu vân",
    "thieeju vaan"
  ],
  "Thoại Sơn": [
    "thoại sơn",
    "thoaji sown"
  ],
  "Thuần Mang": [
    "thuần mang",
    "thuaafn mang"
  ],
  "Thuần Mỹ": [
    "thuần mỹ",
    "thuaafn myx"
  ],
  "Thuận Giao": [
    "thuận giao",
    "thuaajn giao"
  ],
  "Thuận Hoà": [
    "thuận hoà",
    "thuaajn hoaf"
  ],
  "Thuận Hòa": [
    "thuận hòa",
    "thuaajn hofa"
  ],
  "Thuận Hóa": [
    "thuận hóa",
    "thuaajn hosa"
  ],
  "Thuận Minh": [
    "thuận minh",
    "thuaajn minh"
  ],
  "Thuận Mỹ": [
    "thuận mỹ",
    "thuaajn myx"
  ],
  "Thuận Phú": [
    "thuận phú",
    "thuaajn phus"
  ],
  "Thuận Quí": [
    "thuận quí",
    "thuaajn quis"
  ],
  "Thuận Sơn": [
    "thuận sơn",
    "thuaajn sown"
  ],
  "Thuận Yên": [
    "thuận yên",
    "thuaajn yeen"
  ],
  "Thuỷ Xuân": [
    "thuỷ xuân",
    "thuyr xuaan"
  ],
  "Thành Công": [
    "thành công",
    "thafnh coong"
  ],
  "Thành Hưng": [
    "thành hưng",
    "thafnh huwng"
  ],
  "Thành Hải": [
    "thành hải",
    "thafnh hari"
  ],
  "Thành Lộc": [
    "thành lộc",
    "thafnh loojc"
  ],
  "Thành Lợi": [
    "thành lợi",
    "thafnh lowji"
  ],
  "Thành Thọ": [
    "thành thọ",
    "thafnh thoj"
  ],
  "Thành Trung": [
    "thành trung",
    "thafnh trung"
  ],
  "Thái Thụy": [
    "thái thụy",
    "thasi thujy"
  ],
  "Thái Thủy": [
    "thái thủy",
    "thasi thury"
  ],
  "Thái Xuyên": [
    "thái xuyên",
    "thasi xuyeen"
  ],
  "Thèn Phàng": [
    "thèn phàng",
    "thefn phafng"
  ],
  "Thông Bình": [
    "thông bình",
    "thoong bifnh"
  ],
  "Thông Nông": [
    "thông nông",
    "thoong noong"
  ],
  "Thông Thụ": [
    "thông thụ",
    "thoong thuj"
  ],
  "Thúc Kháng": [
    "thúc kháng",
    "thusc khasng"
  ],
  "Thăng Bình": [
    "thăng bình",
    "thawng bifnh"
  ],
  "Thăng Hưng": [
    "thăng hưng",
    "thawng huwng"
  ],
  "Thăng Thọ": [
    "thăng thọ",
    "thawng thoj"
  ],
  "Thạc Gián": [
    "thạc gián",
    "thajc giasn"
  ],
  "Thạch Bàn": [
    "thạch bàn",
    "thajch bafn"
  ],
  "Thạch Hoà": [
    "thạch hoà",
    "thajch hoaf"
  ],
  "Thạch Hóa": [
    "thạch hóa",
    "thajch hosa"
  ],
  "Thạch Hạ": [
    "thạch hạ",
    "thajch haj"
  ],
  "Thạch Khê": [
    "thạch khê",
    "thajch khee"
  ],
  "Thạch Linh": [
    "thạch linh",
    "thajch linh"
  ],
  "Thạch Long": [
    "thạch long",
    "thajch long"
  ],
  "Thạch Lâm": [
    "thạch lâm",
    "thajch laam"
  ],
  "Thạch Mỹ": [
    "thạch mỹ",
    "thajch myx"
  ],
  "Thạch Quý": [
    "thạch quý",
    "thajch quys"
  ],
  "Thạch Sơn": [
    "thạch sơn",
    "thajch sown"
  ],
  "Thạch Văn": [
    "thạch văn",
    "thajch vawn"
  ],
  "Thạch Yên": [
    "thạch yên",
    "thajch yeen"
  ],
  "Thạch Đà": [
    "thạch đà",
    "thajch ddaf"
  ],
  "Thạnh Hoà": [
    "thạnh hoà",
    "thajnh hoaf"
  ],
  "Thạnh Hòa": [
    "thạnh hòa",
    "thajnh hofa"
  ],
  "Thạnh Hóa": [
    "thạnh hóa",
    "thajnh hosa"
  ],
  "Thạnh Mỹ": [
    "thạnh mỹ",
    "thajnh myx"
  ],
  "Thạnh Phú": [
    "thạnh phú",
    "thajnh phus"
  ],
  "Thạnh Tân": [
    "thạnh tân",
    "thajnh taan"
  ],
  "Thạnh Tây": [
    "thạnh tây",
    "thajnh taay"
  ],
  "Thạnh Yên": [
    "thạnh yên",
    "thajnh yeen"
  ],
  "Thất Hùng": [
    "thất hùng",
    "thaast hufng"
  ],
  "Thắng Mố": [
    "thắng mố",
    "thawsng moos"
  ],
  "Thắng Nhì": [
    "thắng nhì",
    "thawsng nhif"
  ],
  "Thắng Sơn": [
    "thắng sơn",
    "thawsng sown"
  ],
  "Thịnh Lang": [
    "thịnh lang",
    "thijnh lang"
  ],
  "Thịnh Long": [
    "thịnh long",
    "thijnh long"
  ],
  "Thịnh Minh": [
    "thịnh minh",
    "thijnh minh"
  ],
  "Thịnh Sơn": [
    "thịnh sơn",
    "thijnh sown"
  ],
  "Thọ Ngọc": [
    "thọ ngọc",
    "thoj ngojc"
  ],
  "Thọ Thành": [
    "thọ thành",
    "thoj thafnh"
  ],
  "Thọ Tiến": [
    "thọ tiến",
    "thoj tieesn"
  ],
  "Thốt Nốt": [
    "thốt nốt",
    "thoost noost"
  ],
  "Thới Bình": [
    "thới bình",
    "thowsi bifnh"
  ],
  "Thới Hưng": [
    "thới hưng",
    "thowsi huwng"
  ],
  "Thới Xuân": [
    "thới xuân",
    "thowsi xuaan"
  ],
  "Thụy Bình": [
    "thụy bình",
    "thujy bifnh"
  ],
  "Thụy Hùng": [
    "thụy hùng",
    "thujy hufng"
  ],
  "Thụy Hưng": [
    "thụy hưng",
    "thujy huwng"
  ],
  "Thụy Hải": [
    "thụy hải",
    "thujy hari"
  ],
  "Thụy Khuê": [
    "thụy khuê",
    "thujy khuee"
  ],
  "Thụy Liên": [
    "thụy liên",
    "thujy lieen"
  ],
  "Thụy Phong": [
    "thụy phong",
    "thujy phong"
  ],
  "Thụy Thanh": [
    "thụy thanh",
    "thujy thanh"
  ],
  "Thụy Xuân": [
    "thụy xuân",
    "thujy xuaan"
  ],
  "Thủ Thiêm": [
    "thủ thiêm",
    "thur thieem"
  ],
  "Thủ Thừa": [
    "thủ thừa",
    "thur thuwfa"
  ],
  "Thủ Đức": [
    "thủ đức",
    "thur dduwsc"
  ],
  "Thủy Châu": [
    "thủy châu",
    "thury chaau"
  ],
  "Thủy Thanh": [
    "thủy thanh",
    "thury thanh"
  ],
  "Tiên Cảnh": [
    "tiên cảnh",
    "tieen carnh"
  ],
  "Tiên Hiệp": [
    "tiên hiệp",
    "tieen hieejp"
  ],
  "Tiên Hoàng": [
    "tiên hoàng",
    "tieen hoafng"
  ],
  "Tiên Kiều": [
    "tiên kiều",
    "tieen kieefu"
  ],
  "Tiên Ngọc": [
    "tiên ngọc",
    "tieen ngojc"
  ],
  "Tiên Thành": [
    "tiên thành",
    "tieen thafnh"
  ],
  "Tiên Thủy": [
    "tiên thủy",
    "tieen thury"
  ],
  "Tiến Dũng": [
    "tiến dũng",
    "tieesn duxng"
  ],
  "Tiến Hưng": [
    "tiến hưng",
    "tieesn huwng"
  ],
  "Tiến Lộc": [
    "tiến lộc",
    "tieesn loojc"
  ],
  "Tiến Lợi": [
    "tiến lợi",
    "tieesn lowji"
  ],
  "Tiến Nông": [
    "tiến nông",
    "tieesn noong"
  ],
  "Tiến Xuân": [
    "tiến xuân",
    "tieesn xuaan"
  ],
  "Tiền Châu": [
    "tiền châu",
    "tieefn chaau"
  ],
  "Tiền Giang": [
    "tiền giang",
    "tieefn giang"
  ],
  "Tiền Hải": [
    "tiền hải",
    "tieefn hari"
  ],
  "Tiền Phong": [
    "tiền phong",
    "tieefn phong"
  ],
  "Tiểu Cần": [
    "tiểu cần",
    "tieeru caafn"
  ],
  "Tri Phương": [
    "tri phương",
    "tri phuwowng"
  ],
  "Triệu Hòa": [
    "triệu hòa",
    "trieeju hofa"
  ],
  "Triệu Long": [
    "triệu long",
    "trieeju long"
  ],
  "Triệu Sơn": [
    "triệu sơn",
    "trieeju sown"
  ],
  "Triệu Tài": [
    "triệu tài",
    "trieeju tafi"
  ],
  "Triệu Vân": [
    "triệu vân",
    "trieeju vaan"
  ],
  "Trung Chánh": [
    "trung chánh",
    "trung chasnh"
  ],
  "Trung Chính": [
    "trung chính",
    "trung chisnh"
  ],
  "Trung Chải": [
    "trung chải",
    "trung chari"
  ],
  "Trung Hiếu": [
    "trung hiếu",
    "trung hieesu"
  ],
  "Trung Hiệp": [
    "trung hiệp",
    "trung hieejp"
  ],
  "Trung Liệt": [
    "trung liệt",
    "trung lieejt"
  ],
  "Trung Nghĩa": [
    "trung nghĩa",
    "trung nghixa"
  ],
  "Trung Nhứt": [
    "trung nhứt",
    "trung nhuwst"
  ],
  "Trung Thành": [
    "trung thành",
    "trung thafnh"
  ],
  "Trung Tiến": [
    "trung tiến",
    "trung tieesn"
  ],
  "Trung Trực": [
    "trung trực",
    "trung truwjc"
  ],
  "Trung Đông": [
    "trung đông",
    "trung ddoong"
  ],
  "Truông Mít": [
    "truông mít",
    "truoong mist"
  ],
  "Trà Dương": [
    "trà dương",
    "traf duwowng"
  ],
  "Tràng Phái": [
    "tràng phái",
    "trafng phasi"
  ],
  "Trúc Bạch": [
    "trúc bạch",
    "trusc bajch"
  ],
  "Trưng Nhị": [
    "trưng nhị",
    "truwng nhij"
  ],
  "Trường An": [
    "trường an",
    "truwowfng an"
  ],
  "Trường Sa": [
    "trường sa",
    "truwowfng sa"
  ],
  "Trạm Hành": [
    "trạm hành",
    "trajm hafnh"
  ],
  "Trạm Trôi": [
    "trạm trôi",
    "trajm trooi"
  ],
  "Trạm Tấu": [
    "trạm tấu",
    "trajm taasu"
  ],
  "Trảng Dài": [
    "trảng dài",
    "trarng dafi"
  ],
  "Trần Hợi": [
    "trần hợi",
    "traafn howji"
  ],
  "Trần Phán": [
    "trần phán",
    "traafn phasn"
  ],
  "Trần Đề": [
    "trần đề",
    "traafn ddeef"
  ],
  "Trị Quận": [
    "trị quận",
    "trij quaajn"
  ],
  "Trọng Hóa": [
    "trọng hóa",
    "trojng hosa"
  ],
  "Trọng Quan": [
    "trọng quan",
    "trojng quan"
  ],
  "Trực Hùng": [
    "trực hùng",
    "truwjc hufng"
  ],
  "Trực Hưng": [
    "trực hưng",
    "truwjc huwng"
  ],
  "Trực Khang": [
    "trực khang",
    "truwjc khang"
  ],
  "Trực Nội": [
    "trực nội",
    "truwjc nooji"
  ],
  "Trực Thanh": [
    "trực thanh",
    "truwjc thanh"
  ],
  "Trực Thái": [
    "trực thái",
    "truwjc thasi"
  ],
  "Tu Mơ Rông": [
    "tu mơ rông",
    "tu mow roong"
  ],
  "Tuy Phước": [
    "tuy phước",
    "tuy phuwowsc"
  ],
  "Tuyên Bình": [
    "tuyên bình",
    "tuyeen bifnh"
  ],
  "Tuyên Quang": [
    "tuyên quang",
    "tuyeen quang"
  ],
  "Tuân Chính": [
    "tuân chính",
    "tuaan chisnh"
  ],
  "Tuân Đạo": [
    "tuân đạo",
    "tuaan ddajo"
  ],
  "Tuần Châu": [
    "tuần châu",
    "tuaafn chaau"
  ],
  "Tuần Giáo": [
    "tuần giáo",
    "tuaafn giaso"
  ],
  "Tà Si Láng": [
    "tà si láng",
    "taf si lasng"
  ],
  "Tâm Thắng": [
    "tâm thắng",
    "taam thawsng"
  ],
  "Tân Cương": [
    "tân cương",
    "taan cuwowng"
  ],
  "Tân Duyệt": [
    "tân duyệt",
    "taan duyeejt"
  ],
  "Tân Dương": [
    "tân dương",
    "taan duwowng"
  ],
  "Tân Hương": [
    "tân hương",
    "taan huwowng"
  ],
  "Tân Kiểng": [
    "tân kiểng",
    "taan kieerng"
  ],
  "Tân Lược": [
    "tân lược",
    "taan luwowjc"
  ],
  "Tân Lập 1": [
    "tân lập 1",
    "taan laajp 1"
  ],
  "Tân Lập 2": [
    "tân lập 2",
    "taan laajp 2"
  ],
  "Tân Nguyên": [
    "tân nguyên",
    "taan nguyeen"
  ],
  "Tân Thiện": [
    "tân thiện",
    "taan thieejn"
  ],
  "Tân Thuận": [
    "tân thuận",
    "taan thuaajn"
  ],
  "Tân Thạch": [
    "tân thạch",
    "taan thajch"
  ],
  "Tân Thạnh": [
    "tân thạnh",
    "taan thajnh"
  ],
  "Tân Thắng": [
    "tân thắng",
    "taan thawsng"
  ],
  "Tân Thịnh": [
    "tân thịnh",
    "taan thijnh"
  ],
  "Tân Triều": [
    "tân triều",
    "taan trieefu"
  ],
  "Tân Trạch": [
    "tân trạch",
    "taan trajch"
  ],
  "Tân Trịnh": [
    "tân trịnh",
    "taan trijnh"
  ],
  "Tân Tuyến": [
    "tân tuyến",
    "taan tuyeesn"
  ],
  "Tân Tạo A": [
    "tân tạo a",
    "taan tajo a"
  ],
  "Tân Điền": [
    "tân điền",
    "taan ddieefn"
  ],
  "Tân Định": [
    "tân định",
    "taan ddijnh"
  ],
  "Tân Đồng": [
    "tân đồng",
    "taan ddoofng"
  ],
  "Tây Lương": [
    "tây lương",
    "taay luwowng"
  ],
  "Tây Thuận": [
    "tây thuận",
    "taay thuaajn"
  ],
  "Tây Thạnh": [
    "tây thạnh",
    "taay thajnh"
  ],
  "Tây Trạch": [
    "tây trạch",
    "taay trajch"
  ],
  "Tây Đằng": [
    "tây đằng",
    "taay ddawfng"
  ],
  "Tênh Phông": [
    "tênh phông",
    "teenh phoong"
  ],
  "Tòng Đậu": [
    "tòng đậu",
    "tofng ddaaju"
  ],
  "Tông Lạnh": [
    "tông lạnh",
    "toong lajnh"
  ],
  "Tăng Thành": [
    "tăng thành",
    "tawng thafnh"
  ],
  "Tăng Tiến": [
    "tăng tiến",
    "tawng tieesn"
  ],
  "Tường Đa": [
    "tường đa",
    "tuwowfng dda"
  ],
  "Tản Hồng": [
    "tản hồng",
    "tarn hoofng"
  ],
  "Tế Thắng": [
    "tế thắng",
    "tees thawsng"
  ],
  "Tịnh Biên": [
    "tịnh biên",
    "tijnh bieen"
  ],
  "Tịnh Bình": [
    "tịnh bình",
    "tijnh bifnh"
  ],
  "Tịnh Bắc": [
    "tịnh bắc",
    "tijnh bawsc"
  ],
  "Tịnh Châu": [
    "tịnh châu",
    "tijnh chaau"
  ],
  "Tịnh Giang": [
    "tịnh giang",
    "tijnh giang"
  ],
  "Tịnh Phong": [
    "tịnh phong",
    "tijnh phong"
  ],
  "Tịnh Thọ": [
    "tịnh thọ",
    "tijnh thoj"
  ],
  "Tống Trân": [
    "tống trân",
    "toosng traan"
  ],
  "Tổng Cọt": [
    "tổng cọt",
    "toorng cojt"
  ],
  "Tủa Thàng": [
    "tủa thàng",
    "tura thafng"
  ],
  "Viên Thành": [
    "viên thành",
    "vieen thafnh"
  ],
  "Việt Hùng": [
    "việt hùng",
    "vieejt hufng"
  ],
  "Việt Hưng": [
    "việt hưng",
    "vieejt huwng"
  ],
  "Việt Hải": [
    "việt hải",
    "vieejt hari"
  ],
  "Việt Lập": [
    "việt lập",
    "vieejt laajp"
  ],
  "Việt Quang": [
    "việt quang",
    "vieejt quang"
  ],
  "Việt Xuân": [
    "việt xuân",
    "vieejt xuaan"
  ],
  "Vân Dương": [
    "vân dương",
    "vaan duwowng"
  ],
  "Võ Cường": [
    "võ cường",
    "vox cuwowfng"
  ],
  "Võng Xuyên": [
    "võng xuyên",
    "voxng xuyeen"
  ],
  "Văn Điển": [
    "văn điển",
    "vawn ddieern"
  ],
  "Vĩnh Chánh": [
    "vĩnh chánh",
    "vixnh chasnh"
  ],
  "Vĩnh Chấp": [
    "vĩnh chấp",
    "vixnh chaasp"
  ],
  "Vĩnh Hiệp": [
    "vĩnh hiệp",
    "vixnh hieejp"
  ],
  "Vĩnh Hồng": [
    "vĩnh hồng",
    "vixnh hoofng"
  ],
  "Vĩnh Khánh": [
    "vĩnh khánh",
    "vixnh khasnh"
  ],
  "Vĩnh Mỹ A": [
    "vĩnh mỹ a",
    "vixnh myx a"
  ],
  "Vĩnh Mỹ B": [
    "vĩnh mỹ b",
    "vixnh myx b"
  ],
  "Vĩnh Ngọc": [
    "vĩnh ngọc",
    "vixnh ngojc"
  ],
  "Vĩnh Niệm": [
    "vĩnh niệm",
    "vixnh nieejm"
  ],
  "Vĩnh Quới": [
    "vĩnh quới",
    "vixnh quowsi"
  ],
  "Vĩnh Thành": [
    "vĩnh thành",
    "vixnh thafnh"
  ],
  "Vĩnh Thông": [
    "vĩnh thông",
    "vixnh thoong"
  ],
  "Vĩnh Thới": [
    "vĩnh thới",
    "vixnh thowsi"
  ],
  "Vĩnh Thủy": [
    "vĩnh thủy",
    "vixnh thury"
  ],
  "Vĩnh Thực": [
    "vĩnh thực",
    "vixnh thuwjc"
  ],
  "Vĩnh Tiến": [
    "vĩnh tiến",
    "vixnh tieesn"
  ],
  "Vĩnh Trại": [
    "vĩnh trại",
    "vixnh traji"
  ],
  "Vĩnh Viễn": [
    "vĩnh viễn",
    "vixnh vieexn"
  ],
  "Vĩnh Đại": [
    "vĩnh đại",
    "vixnh ddaji"
  ],
  "Vạn Khánh": [
    "vạn khánh",
    "vajn khasnh"
  ],
  "Vạn Thủy": [
    "vạn thủy",
    "vajn thury"
  ],
  "Vần Chải": [
    "vần chải",
    "vaafn chari"
  ],
  "Vị Thắng": [
    "vị thắng",
    "vij thawsng"
  ],
  "Xuyên Mộc": [
    "xuyên mộc",
    "xuyeen moojc"
  ],
  "Xuân Chính": [
    "xuân chính",
    "xuaan chisnh"
  ],
  "Xuân Cảnh": [
    "xuân cảnh",
    "xuaan carnh"
  ],
  "Xuân Hiệp": [
    "xuân hiệp",
    "xuaan hieejp"
  ],
  "Xuân Hồng": [
    "xuân hồng",
    "xuaan hoofng"
  ],
  "Xuân Khánh": [
    "xuân khánh",
    "xuaan khasnh"
  ],
  "Xuân Ngọc": [
    "xuân ngọc",
    "xuaan ngojc"
  ],
  "Xuân Thiên": [
    "xuân thiên",
    "xuaan thieen"
  ],
  "Xuân Thành": [
    "xuân thành",
    "xuaan thafnh"
  ],
  "Xuân Thủy": [
    "xuân thủy",
    "xuaan thury"
  ],
  "Xuân Tiến": [
    "xuân tiến",
    "xuaan tieesn"
  ],
  "Xuân Đình": [
    "xuân đình",
    "xuaan ddifnh"
  ],
  "Xuân Đông": [
    "xuân đông",
    "xuaan ddoong"
  ],
  "Xá Lượng": [
    "xá lượng",
    "xas luwowjng"
  ],
  "Xương Lâm": [
    "xương lâm",
    "xuwowng laam"
  ],
  "Yên Dương": [
    "yên dương",
    "yeen duwowng"
  ],
  "Yên Lương": [
    "yên lương",
    "yeen luwowng"
  ],
  "Yên Nguyên": [
    "yên nguyên",
    "yeen nguyeen"
  ],
  "Yên Thuận": [
    "yên thuận",
    "yeen thuaajn"
  ],
  "Yên Thạch": [
    "yên thạch",
    "yeen thajch"
  ],
  "Yên Thắng": [
    "yên thắng",
    "yeen thawsng"
  ],
  "Yên Thịnh": [
    "yên thịnh",
    "yeen thijnh"
  ],
  "Yên Trạch": [
    "yên trạch",
    "yeen trajch"
  ],
  "Yên Định": [
    "yên định",
    "yeen ddijnh"
  ],
  "Yên Đồng": [
    "yên đồng",
    "yeen ddoofng"
  ],
  "Ô Long Vỹ": [
    "ô long vỹ",
    "oo long vyx"
  ],
  "Ô Quý Hồ": [
    "ô quý hồ",
    "oo quys hoof"
  ],
  "Đa Phước": [
    "đa phước",
    "dda phuwowsc"
  ],
  "Điền Hòa": [
    "điền hòa",
    "ddieefn hofa"
  ],
  "Điền Hạ": [
    "điền hạ",
    "ddieefn haj"
  ],
  "Điền Môn": [
    "điền môn",
    "ddieefn moon"
  ],
  "Điền Mỹ": [
    "điền mỹ",
    "ddieefn myx"
  ],
  "Điện Bàn": [
    "điện bàn",
    "ddieejn bafn"
  ],
  "Điện Hòa": [
    "điện hòa",
    "ddieejn hofa"
  ],
  "Điện Minh": [
    "điện minh",
    "ddieejn minh"
  ],
  "Điện Quan": [
    "điện quan",
    "ddieejn quan"
  ],
  "Đoàn Kết": [
    "đoàn kết",
    "ddoafn keest"
  ],
  "Đoàn Lập": [
    "đoàn lập",
    "ddoafn laajp"
  ],
  "Đoàn Tùng": [
    "đoàn tùng",
    "ddoafn tufng"
  ],
  "Đoàn Đào": [
    "đoàn đào",
    "ddoafn ddafo"
  ],
  "Đài Xuyên": [
    "đài xuyên",
    "ddafi xuyeen"
  ],
  "Đàm Thuỷ": [
    "đàm thuỷ",
    "ddafm thuyr"
  ],
  "Đình Lập": [
    "đình lập",
    "ddifnh laajp"
  ],
  "Đình Phong": [
    "đình phong",
    "ddifnh phong"
  ],
  "Đô Lương": [
    "đô lương",
    "ddoo luwowng"
  ],
  "Đôn Phục": [
    "đôn phục",
    "ddoon phujc"
  ],
  "Đông Bình": [
    "đông bình",
    "ddoong bifnh"
  ],
  "Đông Bắc": [
    "đông bắc",
    "ddoong bawsc"
  ],
  "Đông Cứu": [
    "đông cứu",
    "ddoong cuwsu"
  ],
  "Đông Cửu": [
    "đông cửu",
    "ddoong cuwru"
  ],
  "Đông Giang": [
    "đông giang",
    "ddoong giang"
  ],
  "Đông Hưng": [
    "đông hưng",
    "ddoong huwng"
  ],
  "Đông Hải": [
    "đông hải",
    "ddoong hari"
  ],
  "Đông Hội": [
    "đông hội",
    "ddoong hooji"
  ],
  "Đông Hợp": [
    "đông hợp",
    "ddoong howjp"
  ],
  "Đông Kết": [
    "đông kết",
    "ddoong keest"
  ],
  "Đông Lĩnh": [
    "đông lĩnh",
    "ddoong lixnh"
  ],
  "Đông Lợi": [
    "đông lợi",
    "ddoong lowji"
  ],
  "Đông Ngàn": [
    "đông ngàn",
    "ddoong ngafn"
  ],
  "Đông Phong": [
    "đông phong",
    "ddoong phong"
  ],
  "Đông Quang": [
    "đông quang",
    "ddoong quang"
  ],
  "Đông Thanh": [
    "đông thanh",
    "ddoong thanh"
  ],
  "Đông Thái": [
    "đông thái",
    "ddoong thasi"
  ],
  "Đông Thọ": [
    "đông thọ",
    "ddoong thoj"
  ],
  "Đông Trung": [
    "đông trung",
    "ddoong trung"
  ],
  "Đông Tảo": [
    "đông tảo",
    "ddoong taro"
  ],
  "Đông Vĩnh": [
    "đông vĩnh",
    "ddoong vixnh"
  ],
  "Đông Xuân": [
    "đông xuân",
    "ddoong xuaan"
  ],
  "Đăk Ngọk": [
    "đăk ngọk",
    "ddawk ngojk"
  ],
  "Đăk R'Moan": [
    "đăk r'moan",
    "ddawk r'moan"
  ],
  "Đăk Sơmei": [
    "đăk sơmei",
    "ddawk sowmei"
  ],
  "Đưng KNớ": [
    "đưng knớ",
    "dduwng knows"
  ],
  "Đường 10": [
    "đường 10",
    "dduwowfng 10"
  ],
  "Đạ Đờn": [
    "đạ đờn",
    "ddaj ddowfn"
  ],
  "Đại Bình": [
    "đại bình",
    "ddaji bifnh"
  ],
  "Đại Bản": [
    "đại bản",
    "ddaji barn"
  ],
  "Đại Dực": [
    "đại dực",
    "ddaji duwjc"
  ],
  "Đại Hùng": [
    "đại hùng",
    "ddaji hufng"
  ],
  "Đại Hưng": [
    "đại hưng",
    "ddaji huwng"
  ],
  "Đại Hải": [
    "đại hải",
    "ddaji hari"
  ],
  "Đại Hợp": [
    "đại hợp",
    "ddaji howjp"
  ],
  "Đại Lãnh": [
    "đại lãnh",
    "ddaji laxnh"
  ],
  "Đại Lộc": [
    "đại lộc",
    "ddaji loojc"
  ],
  "Đại Ngãi": [
    "đại ngãi",
    "ddaji ngaxi"
  ],
  "Đại Phong": [
    "đại phong",
    "ddaji phong"
  ],
  "Đại Phác": [
    "đại phác",
    "ddaji phasc"
  ],
  "Đại Phúc": [
    "đại phúc",
    "ddaji phusc"
  ],
  "Đại Quang": [
    "đại quang",
    "ddaji quang"
  ],
  "Đại Sảo": [
    "đại sảo",
    "ddaji saro"
  ],
  "Đại Tập": [
    "đại tập",
    "ddaji taajp"
  ],
  "Đại Xuân": [
    "đại xuân",
    "ddaji xuaan"
  ],
  "Đại Ân 1": [
    "đại ân 1",
    "ddaji aan 1"
  ],
  "Đạp Thanh": [
    "đạp thanh",
    "ddajp thanh"
  ],
  "Đất Mới": [
    "đất mới",
    "ddaast mowsi"
  ],
  "Đất Đỏ": [
    "đất đỏ",
    "ddaast ddor"
  ],
  "Đậu Liêu": [
    "đậu liêu",
    "ddaaju lieeu"
  ],
  "Đắc Pring": [
    "đắc pring",
    "ddawsc pring"
  ],
  "Đắk Cấm": [
    "đắk cấm",
    "ddawsk caasm"
  ],
  "Đắk Dục": [
    "đắk dục",
    "ddawsk dujc"
  ],
  "Đắk Gằn": [
    "đắk gằn",
    "ddawsk gawfn"
  ],
  "Đắk HRing": [
    "đắk hring",
    "ddawsk hring"
  ],
  "Đắk Lắk": [
    "đắk lắk",
    "ddawsk lawsk"
  ],
  "Đắk Nông": [
    "đắk nông",
    "ddawsk noong"
  ],
  "Đắk Phơi": [
    "đắk phơi",
    "ddawsk phowi"
  ],
  "Đắk Sắk": [
    "đắk sắk",
    "ddawsk sawsk"
  ],
  "Đắk Trăm": [
    "đắk trăm",
    "ddawsk trawm"
  ],
  "Đắk Tăng": [
    "đắk tăng",
    "ddawsk tawng"
  ],
  "Đằng Lâm": [
    "đằng lâm",
    "ddawfng laam"
  ],
  "Đặng Lễ": [
    "đặng lễ",
    "ddawjng leex"
  ],
  "Đặng Sơn": [
    "đặng sơn",
    "ddawjng sown"
  ],
  "Đỉnh Bàn": [
    "đỉnh bàn",
    "ddirnh bafn"
  ],
  "Đỉnh Sơn": [
    "đỉnh sơn",
    "ddirnh sown"
  ],
  "Định Hoà": [
    "định hoà",
    "ddijnh hoaf"
  ],
  "Định Hòa": [
    "định hòa",
    "ddijnh hofa"
  ],
  "Định Hóa": [
    "định hóa",
    "ddijnh hosa"
  ],
  "Định Long": [
    "định long",
    "ddijnh long"
  ],
  "Định Môn": [
    "định môn",
    "ddijnh moon"
  ],
  "Định Mỹ": [
    "định mỹ",
    "ddijnh myx"
  ],
  "Định Sơn": [
    "định sơn",
    "ddijnh sown"
  ],
  "Định Tân": [
    "định tân",
    "ddijnh taan"
  ],
  "Định Yên": [
    "định yên",
    "ddijnh yeen"
  ],
  "Đống Mác": [
    "đống mác",
    "ddoosng masc"
  ],
  "Đồng Bài": [
    "đồng bài",
    "ddoofng bafi"
  ],
  "Đồng Chum": [
    "đồng chum",
    "ddoofng chum"
  ],
  "Đồng Hoà": [
    "đồng hoà",
    "ddoofng hoaf"
  ],
  "Đồng Hóa": [
    "đồng hóa",
    "ddoofng hosa"
  ],
  "Đồng Hưu": [
    "đồng hưu",
    "ddoofng huwu"
  ],
  "Đồng Hỷ": [
    "đồng hỷ",
    "ddoofng hyr"
  ],
  "Đồng Khê": [
    "đồng khê",
    "ddoofng khee"
  ],
  "Đồng Kỳ": [
    "đồng kỳ",
    "ddoofng kyf"
  ],
  "Đồng Kỵ": [
    "đồng kỵ",
    "ddoofng kyj"
  ],
  "Đồng Loan": [
    "đồng loan",
    "ddoofng loan"
  ],
  "Đồng Lâm": [
    "đồng lâm",
    "ddoofng laam"
  ],
  "Đồng Minh": [
    "đồng minh",
    "ddoofng minh"
  ],
  "Đồng Môn": [
    "đồng môn",
    "ddoofng moon"
  ],
  "Đồng Mỏ": [
    "đồng mỏ",
    "ddoofng mor"
  ],
  "Đồng Phú": [
    "đồng phú",
    "ddoofng phus"
  ],
  "Đồng Quý": [
    "đồng quý",
    "ddoofng quys"
  ],
  "Đồng Sơn": [
    "đồng sơn",
    "ddoofng sown"
  ],
  "Đồng Than": [
    "đồng than",
    "ddoofng than"
  ],
  "Đồng Tâm": [
    "đồng tâm",
    "ddoofng taam"
  ],
  "Đồng Tân": [
    "đồng tân",
    "ddoofng taan"
  ],
  "Đồng Văn": [
    "đồng văn",
    "ddoofng vawn"
  ],
  "Đồng Yên": [
    "đồng yên",
    "ddoofng yeen"
  ],
  "Đồng Ích": [
    "đồng ích",
    "ddoofng isch"
  ],
  "Đỗ Xuyên": [
    "đỗ xuyên",
    "ddoox xuyeen"
  ],
  "Độc Lập": [
    "độc lập",
    "ddoojc laajp"
  ],
  "Đội Bình": [
    "đội bình",
    "ddooji bifnh"
  ],
  "Đội Cấn": [
    "đội cấn",
    "ddooji caasn"
  ],
  "Động Quan": [
    "động quan",
    "ddoojng quan"
  ],
  "Đức Bình": [
    "đức bình",
    "dduwsc bifnh"
  ],
  "Đức Giang": [
    "đức giang",
    "dduwsc giang"
  ],
  "Đức Huệ": [
    "đức huệ",
    "dduwsc hueej"
  ],
  "Đức Hợp": [
    "đức hợp",
    "dduwsc howjp"
  ],
  "Đức Liên": [
    "đức liên",
    "dduwsc lieen"
  ],
  "Đức Lĩnh": [
    "đức lĩnh",
    "dduwsc lixnh"
  ],
  "Đức Lợi": [
    "đức lợi",
    "dduwsc lowji"
  ],
  "Đức Phong": [
    "đức phong",
    "dduwsc phong"
  ],
  "Đức Phổ": [
    "đức phổ",
    "dduwsc phoor"
  ],
  "Đức Quang": [
    "đức quang",
    "dduwsc quang"
  ],
  "Đức Thọ": [
    "đức thọ",
    "dduwsc thoj"
  ],
  "Đức Xuân": [
    "đức xuân",
    "dduwsc xuaan"
  ],
  " Hòa Thuận": [
    " hòa thuận",
    " hofa thuaajn"
  ],
  "An Bình Tây": [
    "an bình tây",
    "an bifnh taay"
  ],
  "An Hòa Hải": [
    "an hòa hải",
    "an hofa hari"
  ],
  "An Hải Tây": [
    "an hải tây",
    "an hari taay"
  ],
  "An Lạc Tây": [
    "an lạc tây",
    "an lajc taay"
  ],
  "An Lục Long": [
    "an lục long",
    "an lujc long"
  ],
  "An Minh Bắc": [
    "an minh bắc",
    "an minh bawsc"
  ],
  "An Ngãi Tây": [
    "an ngãi tây",
    "an ngaxi taay"
  ],
  "An Nhơn Tây": [
    "an nhơn tây",
    "an nhown taay"
  ],
  "An Phú Trung": [
    "an phú trung",
    "an phus trung"
  ],
  "Biển Bạch": [
    "biển bạch",
    "bieern bajch"
  ],
  "Buôn Triết": [
    "buôn triết",
    "buoon trieest"
  ],
  "Bành Trạch": [
    "bành trạch",
    "bafnh trajch"
  ],
  "Bách Thuận": [
    "bách thuận",
    "basch thuaajn"
  ],
  "Bình Chiểu": [
    "bình chiểu",
    "bifnh chieeru"
  ],
  "Bình Chuẩn": [
    "bình chuẩn",
    "bifnh chuaarn"
  ],
  "Bình Dương": [
    "bình dương",
    "bifnh duwowng"
  ],
  "Bình Khánh ": [
    "bình khánh ",
    "bifnh khasnh "
  ],
  "Bình Lương": [
    "bình lương",
    "bifnh luwowng"
  ],
  "Bình Nguyên": [
    "bình nguyên",
    "bifnh nguyeen"
  ],
  "Bình Thuận": [
    "bình thuận",
    "bifnh thuaajn"
  ],
  "Bình Thạnh": [
    "bình thạnh",
    "bifnh thajnh"
  ],
  "Bình Thắng": [
    "bình thắng",
    "bifnh thawsng"
  ],
  "Bình Triều": [
    "bình triều",
    "bifnh trieefu"
  ],
  "Bình Định": [
    "bình định",
    "bifnh ddijnh"
  ],
  "Bích Động": [
    "bích động",
    "bisch ddoojng"
  ],
  "Bù Gia Mập": [
    "bù gia mập",
    "buf gia maajp"
  ],
  "Bùi La Nhân": [
    "bùi la nhân",
    "bufi la nhaan"
  ],
  "Bưng Riềng": [
    "bưng riềng",
    "buwng rieefng"
  ],
  "Bạch Ngọc": [
    "bạch ngọc",
    "bajch ngojc"
  ],
  "Bạch Thông": [
    "bạch thông",
    "bajch thoong"
  ],
  "Bạch Đích": [
    "bạch đích",
    "bajch ddisch"
  ],
  "Bản Ngoại": [
    "bản ngoại",
    "barn ngoaji"
  ],
  "Bản Nguyên": [
    "bản nguyên",
    "barn nguyeen"
  ],
  "Bản Phiệt": [
    "bản phiệt",
    "barn phieejt"
  ],
  "Bản Vược": [
    "bản vược",
    "barn vuwowjc"
  ],
  "Bảo Thuận": [
    "bảo thuận",
    "baro thuaajn"
  ],
  "Bảo Thạnh": [
    "bảo thạnh",
    "baro thajnh"
  ],
  "Bảo Thắng": [
    "bảo thắng",
    "baro thawsng"
  ],
  "Bắc Lương": [
    "bắc lương",
    "bawsc luwowng"
  ],
  "Bắc Quỳnh": [
    "bắc quỳnh",
    "bawsc quyfnh"
  ],
  "Bắc Ruộng": [
    "bắc ruộng",
    "bawsc ruoojng"
  ],
  "Bắc Trà My": [
    "bắc trà my",
    "bawsc traf my"
  ],
  "Bắc Trạch": [
    "bắc trạch",
    "bawsc trajch"
  ],
  "Bằng Thành": [
    "bằng thành",
    "bawfng thafnh"
  ],
  "Cam Phúc Nam": [
    "cam phúc nam",
    "cam phusc nam"
  ],
  "Cam Thượng": [
    "cam thượng",
    "cam thuwowjng"
  ],
  "Cam Đường": [
    "cam đường",
    "cam dduwowfng"
  ],
  "Cao Thượng": [
    "cao thượng",
    "cao thuwowjng"
  ],
  "Chi Lăng Nam": [
    "chi lăng nam",
    "chi lawng nam"
  ],
  "Chiến Phố": [
    "chiến phố",
    "chieesn phoos"
  ],
  "Chiềng Bôm": [
    "chiềng bôm",
    "chieefng boom"
  ],
  "Chiềng Cang": [
    "chiềng cang",
    "chieefng cang"
  ],
  "Chiềng Cơi": [
    "chiềng cơi",
    "chieefng cowi"
  ],
  "Chiềng Cọ": [
    "chiềng cọ",
    "chieefng coj"
  ],
  "Chiềng Dong": [
    "chiềng dong",
    "chieefng dong"
  ],
  "Chiềng Khay": [
    "chiềng khay",
    "chieefng khay"
  ],
  "Chiềng Kheo": [
    "chiềng kheo",
    "chieefng kheo"
  ],
  "Chiềng Khoa": [
    "chiềng khoa",
    "chieefng khoa"
  ],
  "Chiềng Khoi": [
    "chiềng khoi",
    "chieefng khoi"
  ],
  "Chiềng Lề": [
    "chiềng lề",
    "chieefng leef"
  ],
  "Chiềng Mung": [
    "chiềng mung",
    "chieefng mung"
  ],
  "Chiềng Nơi": [
    "chiềng nơi",
    "chieefng nowi"
  ],
  "Chiềng Sinh": [
    "chiềng sinh",
    "chieefng sinh"
  ],
  "Chiềng Sung": [
    "chiềng sung",
    "chieefng sung"
  ],
  "Chiềng Sơn": [
    "chiềng sơn",
    "chieefng sown"
  ],
  "Chiềng Xôm": [
    "chiềng xôm",
    "chieefng xoom"
  ],
  "Chiềng Yên": [
    "chiềng yên",
    "chieefng yeen"
  ],
  "Chiềng Đen": [
    "chiềng đen",
    "chieefng dden"
  ],
  "Chrôh Pơnan": [
    "chrôh pơnan",
    "chrooh pownan"
  ],
  "Chánh Nghĩa": [
    "chánh nghĩa",
    "chasnh nghixa"
  ],
  "Châu Hưng A": [
    "châu hưng a",
    "chaau huwng a"
  ],
  "Châu Thuận": [
    "châu thuận",
    "chaau thuaajn"
  ],
  "Châu Thắng": [
    "châu thắng",
    "chaau thawsng"
  ],
  "Châu Điền": [
    "châu điền",
    "chaau ddieefn"
  ],
  "Chính Nghĩa": [
    "chính nghĩa",
    "chisnh nghixa"
  ],
  "Chương Mỹ": [
    "chương mỹ",
    "chuwowng myx"
  ],
  "Cát Tường": [
    "cát tường",
    "cast tuwowfng"
  ],
  "Cúc Phương": [
    "cúc phương",
    "cusc phuwowng"
  ],
  "Cương Gián": [
    "cương gián",
    "cuwowng giasn"
  ],
  "Cảnh Thụy": [
    "cảnh thụy",
    "carnh thujy"
  ],
  "Cần Giuộc": [
    "cần giuộc",
    "caafn giuoojc"
  ],
  "Cần Thạnh": [
    "cần thạnh",
    "caafn thajnh"
  ],
  "Cẩm Dương": [
    "cẩm dương",
    "caarm duwowng"
  ],
  "Cẩm Lương": [
    "cẩm lương",
    "caarm luwowng"
  ],
  "Cẩm Thạch": [
    "cẩm thạch",
    "caarm thajch"
  ],
  "Cẩm Thịnh": [
    "cẩm thịnh",
    "caarm thijnh"
  ],
  "Cẩm Điền": [
    "cẩm điền",
    "caarm ddieefn"
  ],
  "Cổ Nhuế 1": [
    "cổ nhuế 1",
    "coor nhuees 1"
  ],
  "Cổ Nhuế 2": [
    "cổ nhuế 2",
    "coor nhuees 2"
  ],
  "Cộng Hiền": [
    "cộng hiền",
    "coojng hieefn"
  ],
  "Cửa Dương": [
    "cửa dương",
    "cuwra duwowng"
  ],
  "Diêm Điền": [
    "diêm điền",
    "dieem ddieefn"
  ],
  "Diên Thạnh": [
    "diên thạnh",
    "dieen thajnh"
  ],
  "Diên Điền": [
    "diên điền",
    "dieen ddieefn"
  ],
  "Diên Đồng": [
    "diên đồng",
    "dieen ddoofng"
  ],
  "Diễn Hoàng": [
    "diễn hoàng",
    "dieexn hoafng"
  ],
  "Diễn Hạnh": [
    "diễn hạnh",
    "dieexn hajnh"
  ],
  "Diễn Hồng": [
    "diễn hồng",
    "dieexn hoofng"
  ],
  "Diễn Ngọc": [
    "diễn ngọc",
    "dieexn ngojc"
  ],
  "Diễn Thành": [
    "diễn thành",
    "dieexn thafnh"
  ],
  "Diễn Đoài": [
    "diễn đoài",
    "dieexn ddoafi"
  ],
  "Duyệt Trung": [
    "duyệt trung",
    "duyeejt trung"
  ],
  "Dương Nội": [
    "dương nội",
    "duwowng nooji"
  ],
  "Dương Phong": [
    "dương phong",
    "duwowng phong"
  ],
  "Dương Phúc": [
    "dương phúc",
    "duwowng phusc"
  ],
  "Dương Quang": [
    "dương quang",
    "duwowng quang"
  ],
  "Dương Quỳ": [
    "dương quỳ",
    "duwowng quyf"
  ],
  "Dầu Tiếng": [
    "dầu tiếng",
    "daafu tieesng"
  ],
  "Dịch Vọng": [
    "dịch vọng",
    "dijch vojng"
  ],
  "Ghềnh Ráng": [
    "ghềnh ráng",
    "gheefnh rasng"
  ],
  "Giang Điền": [
    "giang điền",
    "giang ddieefn"
  ],
  "Giếng Đáy": [
    "giếng đáy",
    "gieesng ddasy"
  ],
  "Giồng Trôm": [
    "giồng trôm",
    "gioofng troom"
  ],
  "Giới Phiên": [
    "giới phiên",
    "giowsi phieen"
  ],
  "Hiến Thành": [
    "hiến thành",
    "hieesn thafnh"
  ],
  "Hiếu Nghĩa": [
    "hiếu nghĩa",
    "hieesu nghixa"
  ],
  "Hiếu Thành": [
    "hiếu thành",
    "hieesu thafnh"
  ],
  "Hiền Kiệt": [
    "hiền kiệt",
    "hieefn kieejt"
  ],
  "Hiền Thành": [
    "hiền thành",
    "hieefn thafnh"
  ],
  "Hiển Khánh": [
    "hiển khánh",
    "hieern khasnh"
  ],
  "Hiệp Thành": [
    "hiệp thành",
    "hieejp thafnh"
  ],
  "Hiệp Đức": [
    "hiệp đức",
    "hieejp dduwsc"
  ],
  "Hoài Hương": [
    "hoài hương",
    "hoafi huwowng"
  ],
  "Hoàng Diệu": [
    "hoàng diệu",
    "hoafng dieeju"
  ],
  "Hoàng Liệt": [
    "hoàng liệt",
    "hoafng lieejt"
  ],
  "Hoàng Tiến": [
    "hoàng tiến",
    "hoafng tieesn"
  ],
  "Hoàng Việt": [
    "hoàng việt",
    "hoafng vieejt"
  ],
  "Hoàng Đông": [
    "hoàng đông",
    "hoafng ddoong"
  ],
  "Hoằng Châu": [
    "hoằng châu",
    "hoawfng chaau"
  ],
  "Hoằng Giang": [
    "hoằng giang",
    "hoawfng giang"
  ],
  "Hoằng Hải": [
    "hoằng hải",
    "hoawfng hari"
  ],
  "Hoằng Hợp": [
    "hoằng hợp",
    "hoawfng howjp"
  ],
  "Hoằng Lộc": [
    "hoằng lộc",
    "hoawfng loojc"
  ],
  "Hoằng Phong": [
    "hoằng phong",
    "hoawfng phong"
  ],
  "Hoằng Phụ": [
    "hoằng phụ",
    "hoawfng phuj"
  ],
  "Hoằng Quang": [
    "hoằng quang",
    "hoawfng quang"
  ],
  "Hoằng Quỳ": [
    "hoằng quỳ",
    "hoawfng quyf"
  ],
  "Hoằng Thanh": [
    "hoằng thanh",
    "hoawfng thanh"
  ],
  "Hoằng Thái": [
    "hoằng thái",
    "hoawfng thasi"
  ],
  "Hoằng Trinh": [
    "hoằng trinh",
    "hoawfng trinh"
  ],
  "Hoằng Trung": [
    "hoằng trung",
    "hoawfng trung"
  ],
  "Hoằng Xuân": [
    "hoằng xuân",
    "hoawfng xuaan"
  ],
  "Hoằng Yến": [
    "hoằng yến",
    "hoawfng yeesn"
  ],
  "Huy Thượng": [
    "huy thượng",
    "huy thuwowjng"
  ],
  "Huyền Hội": [
    "huyền hội",
    "huyeefn hooji"
  ],
  "Huổi Luông": [
    "huổi luông",
    "huoori luoong"
  ],
  "Huổi Lếnh": [
    "huổi lếnh",
    "huoori leesnh"
  ],
  "Hà Huy Tập": [
    "hà huy tập",
    "haf huy taajp"
  ],
  "Hà Thượng": [
    "hà thượng",
    "haf thuwowjng"
  ],
  "Hàm Cường": [
    "hàm cường",
    "hafm cuwowfng"
  ],
  "Hàng Trống": [
    "hàng trống",
    "hafng troosng"
  ],
  "Hành Thiện": [
    "hành thiện",
    "hafnh thieejn"
  ],
  "Hành Thuận": [
    "hành thuận",
    "hafnh thuaajn"
  ],
  "Hành Thịnh": [
    "hành thịnh",
    "hafnh thijnh"
  ],
  "Háng Đồng": [
    "háng đồng",
    "hasng ddoofng"
  ],
  "Hòa Khương": [
    "hòa khương",
    "hofa khuwowng"
  ],
  "Hòa Phước": [
    "hòa phước",
    "hofa phuwowsc"
  ],
  "Hùng Thắng": [
    "hùng thắng",
    "hufng thawsng"
  ],
  "Hùng Vương": [
    "hùng vương",
    "hufng vuwowng"
  ],
  "Hưng Chiến": [
    "hưng chiến",
    "huwng chieesn"
  ],
  "Hưng Nguyên": [
    "hưng nguyên",
    "huwng nguyeen"
  ],
  "Hưng Thuận": [
    "hưng thuận",
    "huwng thuaajn"
  ],
  "Hưng Thạnh": [
    "hưng thạnh",
    "huwng thajnh"
  ],
  "Hưng Thịnh": [
    "hưng thịnh",
    "huwng thijnh"
  ],
  "Hưng Trạch": [
    "hưng trạch",
    "huwng trajch"
  ],
  "Hưng Điền": [
    "hưng điền",
    "huwng ddieefn"
  ],
  "Hưng Định": [
    "hưng định",
    "huwng ddijnh"
  ],
  "Hương Bình": [
    "hương bình",
    "huwowng bifnh"
  ],
  "Hương Chữ": [
    "hương chữ",
    "huwowng chuwx"
  ],
  "Hương Cần": [
    "hương cần",
    "huwowng caafn"
  ],
  "Hương Giang": [
    "hương giang",
    "huwowng giang"
  ],
  "Hương Gián": [
    "hương gián",
    "huwowng giasn"
  ],
  "Hương Hữu": [
    "hương hữu",
    "huwowng huwxu"
  ],
  "Hương Liên": [
    "hương liên",
    "huwowng lieen"
  ],
  "Hương Lạc": [
    "hương lạc",
    "huwowng lajc"
  ],
  "Hương Lộc": [
    "hương lộc",
    "huwowng loojc"
  ],
  "Hương Mạc": [
    "hương mạc",
    "huwowng majc"
  ],
  "Hương Nộn": [
    "hương nộn",
    "huwowng noojn"
  ],
  "Hương Phong": [
    "hương phong",
    "huwowng phong"
  ],
  "Hương Thọ": [
    "hương thọ",
    "huwowng thoj"
  ],
  "Hương Toàn": [
    "hương toàn",
    "huwowng toafn"
  ],
  "Hương Vĩnh": [
    "hương vĩnh",
    "huwowng vixnh"
  ],
  "Hương Xuân": [
    "hương xuân",
    "huwowng xuaan"
  ],
  "Hướng Hóa": [
    "hướng hóa",
    "huwowsng hosa"
  ],
  "Hướng Linh": [
    "hướng linh",
    "huwowsng linh"
  ],
  "Hướng Sơn": [
    "hướng sơn",
    "huwowsng sown"
  ],
  "Hướng Tân": [
    "hướng tân",
    "huwowsng taan"
  ],
  "Hạnh Dịch": [
    "hạnh dịch",
    "hajnh dijch"
  ],
  "Hải Dương": [
    "hải dương",
    "hari duwowng"
  ],
  "Hải Triều": [
    "hải triều",
    "hari trieefu"
  ],
  "Hải Định": [
    "hải định",
    "hari ddijnh"
  ],
  "Hậu Thạnh": [
    "hậu thạnh",
    "haaju thajnh"
  ],
  "Hồng Bạch": [
    "hồng bạch",
    "hoofng bajch"
  ],
  "Hồng Thành": [
    "hồng thành",
    "hoofng thafnh"
  ],
  "Hồng Thủy": [
    "hồng thủy",
    "hoofng thury"
  ],
  "Hồng Tiến": [
    "hồng tiến",
    "hoofng tieesn"
  ],
  "Hồng Việt": [
    "hồng việt",
    "hoofng vieejt"
  ],
  "Hồng Đức": [
    "hồng đức",
    "hoofng dduwsc"
  ],
  "Hợp Thắng": [
    "hợp thắng",
    "howjp thawsng"
  ],
  "Hợp Thịnh": [
    "hợp thịnh",
    "howjp thijnh"
  ],
  "Hợp Đồng": [
    "hợp đồng",
    "howjp ddoofng"
  ],
  "Hữu Khuông": [
    "hữu khuông",
    "huwxu khuoong"
  ],
  "Hữu Định": [
    "hữu định",
    "huwxu ddijnh"
  ],
  "Hựu Thạnh": [
    "hựu thạnh",
    "huwju thajnh"
  ],
  "Kháng Nhật": [
    "kháng nhật",
    "khasng nhaajt"
  ],
  "Khánh Hiệp": [
    "khánh hiệp",
    "khasnh hieejp"
  ],
  "Khánh Hồng": [
    "khánh hồng",
    "khasnh hoofng"
  ],
  "Khánh Nhạc": [
    "khánh nhạc",
    "khasnh nhajc"
  ],
  "Khánh Thành": [
    "khánh thành",
    "khasnh thafnh"
  ],
  "Khánh Thủy": [
    "khánh thủy",
    "khasnh thury"
  ],
  "Khánh Tiến": [
    "khánh tiến",
    "khasnh tieesn"
  ],
  "Khánh Đông": [
    "khánh đông",
    "khasnh ddoong"
  ],
  "Khắc Niệm": [
    "khắc niệm",
    "khawsc nieejm"
  ],
  "Khởi Nghĩa": [
    "khởi nghĩa",
    "khowri nghixa"
  ],
  "Kim Phượng": [
    "kim phượng",
    "kim phuwowjng"
  ],
  "Kim Thượng": [
    "kim thượng",
    "kim thuwowjng"
  ],
  "Kim Đường": [
    "kim đường",
    "kim dduwowfng"
  ],
  "Kiên Lương": [
    "kiên lương",
    "kieen luwowng"
  ],
  "Kiến Quốc": [
    "kiến quốc",
    "kieesn quoosc"
  ],
  "Kiến Thuỵ": [
    "kiến thuỵ",
    "kieesn thuyj"
  ],
  "Kiến Thành": [
    "kiến thành",
    "kieesn thafnh"
  ],
  "Kiến Đức": [
    "kiến đức",
    "kieesn dduwsc"
  ],
  "Kênh Dương": [
    "kênh dương",
    "keenh duwowng"
  ],
  "Kỳ Phương": [
    "kỳ phương",
    "kyf phuwowng"
  ],
  "La Pán Tẩn": [
    "la pán tẩn",
    "la pasn taarn"
  ],
  "Liêm Thuận": [
    "liêm thuận",
    "lieem thuaajn"
  ],
  "Liêm Tuyền": [
    "liêm tuyền",
    "lieem tuyeefn"
  ],
  "Liên Chiểu": [
    "liên chiểu",
    "lieen chieeru"
  ],
  "Liên Hương": [
    "liên hương",
    "lieen huwowng"
  ],
  "Liên Trạch": [
    "liên trạch",
    "lieen trajch"
  ],
  "Liêng Srônh": [
    "liêng srônh",
    "lieeng sroonh"
  ],
  "Long Khánh A": [
    "long khánh a",
    "long khasnh a"
  ],
  "Long Khánh B": [
    "long khánh b",
    "long khasnh b"
  ],
  "Long Phước": [
    "long phước",
    "long phuwowsc"
  ],
  "Luận Thành": [
    "luận thành",
    "luaajn thafnh"
  ],
  "Lình Huỳnh": [
    "lình huỳnh",
    "lifnh huyfnh"
  ],
  "Lóng Phiêng": [
    "lóng phiêng",
    "losng phieeng"
  ],
  "Lý Văn Lâm": [
    "lý văn lâm",
    "lys vawn laam"
  ],
  "Lưu Phương": [
    "lưu phương",
    "luwu phuwowng"
  ],
  "Lương Bình": [
    "lương bình",
    "luwowng bifnh"
  ],
  "Lương Mông": [
    "lương mông",
    "luwowng moong"
  ],
  "Lương Năng": [
    "lương năng",
    "luwowng nawng"
  ],
  "Lương Nội": [
    "lương nội",
    "luwowng nooji"
  ],
  "Lương Phong": [
    "lương phong",
    "luwowng phong"
  ],
  "Lương Trung": [
    "lương trung",
    "luwowng trung"
  ],
  "Lưỡng Minh": [
    "lưỡng minh",
    "luwowxng minh"
  ],
  "Lạc Dương": [
    "lạc dương",
    "lajc duwowng"
  ],
  "Lạc Lương": [
    "lạc lương",
    "lajc luwowng"
  ],
  "Lạc Thịnh": [
    "lạc thịnh",
    "lajc thijnh"
  ],
  "Lập Thạch": [
    "lập thạch",
    "laajp thajch"
  ],
  "Lộc Quảng": [
    "lộc quảng",
    "loojc quarng"
  ],
  "Lộc Thiện": [
    "lộc thiện",
    "loojc thieejn"
  ],
  "Lộc Thuận": [
    "lộc thuận",
    "loojc thuaajn"
  ],
  "Lộc Thạnh": [
    "lộc thạnh",
    "loojc thajnh"
  ],
  "Lộc Thắng": [
    "lộc thắng",
    "loojc thawsng"
  ],
  "Lộc Thịnh": [
    "lộc thịnh",
    "loojc thijnh"
  ],
  "Lộc Điền": [
    "lộc điền",
    "loojc ddieefn"
  ],
  "Lợi Thuận": [
    "lợi thuận",
    "lowji thuaajn"
  ],
  "Minh Cường": [
    "minh cường",
    "minh cuwowfng"
  ],
  "Minh Khương": [
    "minh khương",
    "minh khuwowng"
  ],
  "Minh Phương": [
    "minh phương",
    "minh phuwowng"
  ],
  "Miền Đồi": [
    "miền đồi",
    "mieefn ddoofi"
  ],
  "Mông Dương": [
    "mông dương",
    "moong duwowng"
  ],
  "Mương Chanh": [
    "mương chanh",
    "muwowng chanh"
  ],
  "Mường Bang": [
    "mường bang",
    "muwowfng bang"
  ],
  "Mường Bám": [
    "mường bám",
    "muwowfng basm"
  ],
  "Mường Cang": [
    "mường cang",
    "muwowfng cang"
  ],
  "Mường Chà": [
    "mường chà",
    "muwowfng chaf"
  ],
  "Mường Cơi": [
    "mường cơi",
    "muwowfng cowi"
  ],
  "Mường Hung": [
    "mường hung",
    "muwowfng hung"
  ],
  "Mường Khoa": [
    "mường khoa",
    "muwowfng khoa"
  ],
  "Mường Lang": [
    "mường lang",
    "muwowfng lang"
  ],
  "Mường Lát": [
    "mường lát",
    "muwowfng last"
  ],
  "Mường Lèo": [
    "mường lèo",
    "muwowfng lefo"
  ],
  "Mường Lói": [
    "mường lói",
    "muwowfng losi"
  ],
  "Mường Mìn": [
    "mường mìn",
    "muwowfng mifn"
  ],
  "Mường Mít": [
    "mường mít",
    "muwowfng mist"
  ],
  "Mường Mùn": [
    "mường mùn",
    "muwowfng mufn"
  ],
  "Mường Nhà": [
    "mường nhà",
    "muwowfng nhaf"
  ],
  "Mường Nhé": [
    "mường nhé",
    "muwowfng nhes"
  ],
  "Mường Sang": [
    "mường sang",
    "muwowfng sang"
  ],
  "Mường Than": [
    "mường than",
    "muwowfng than"
  ],
  "Mường Trai": [
    "mường trai",
    "muwowfng trai"
  ],
  "Mường Típ": [
    "mường típ",
    "muwowfng tisp"
  ],
  "Mường Xén": [
    "mường xén",
    "muwowfng xesn"
  ],
  "Mường Đun": [
    "mường đun",
    "muwowfng ddun"
  ],
  "Mường Ải": [
    "mường ải",
    "muwowfng ari"
  ],
  "Mỏ Cày Nam": [
    "mỏ cày nam",
    "mor cafy nam"
  ],
  "Mỹ Long Nam": [
    "mỹ long nam",
    "myx long nam"
  ],
  "Mỹ Phương": [
    "mỹ phương",
    "myx phuwowng"
  ],
  "Mỹ Phước": [
    "mỹ phước",
    "myx phuwowsc"
  ],
  "Mỹ Đình 1": [
    "mỹ đình 1",
    "myx ddifnh 1"
  ],
  "Mỹ Đình 2": [
    "mỹ đình 2",
    "myx ddifnh 2"
  ],
  "NT Liên Sơn": [
    "nt liên sơn",
    "nt lieen sown"
  ],
  "Nam Thượng": [
    "nam thượng",
    "nam thuwowjng"
  ],
  "Nga Phượng": [
    "nga phượng",
    "nga phuwowjng"
  ],
  "Nga Trường": [
    "nga trường",
    "nga truwowfng"
  ],
  "Nghi Phương": [
    "nghi phương",
    "nghi phuwowng"
  ],
  "Nghĩa Chánh": [
    "nghĩa chánh",
    "nghixa chasnh"
  ],
  "Nghĩa Hiếu": [
    "nghĩa hiếu",
    "nghixa hieesu"
  ],
  "Nghĩa Hiệp": [
    "nghĩa hiệp",
    "nghixa hieejp"
  ],
  "Nghĩa Hồng": [
    "nghĩa hồng",
    "nghixa hoofng"
  ],
  "Nghĩa Khánh": [
    "nghĩa khánh",
    "nghixa khasnh"
  ],
  "Nghĩa Thành": [
    "nghĩa thành",
    "nghixa thafnh"
  ],
  "Nghĩa Tiến": [
    "nghĩa tiến",
    "nghixa tieesn"
  ],
  "Nghĩa Đạo": [
    "nghĩa đạo",
    "nghixa ddajo"
  ],
  "Nghĩa Đức": [
    "nghĩa đức",
    "nghixa dduwsc"
  ],
  "Nghị Đức": [
    "nghị đức",
    "nghij dduwsc"
  ],
  "Nguyên Bình": [
    "nguyên bình",
    "nguyeen bifnh"
  ],
  "Nguyên Giáp": [
    "nguyên giáp",
    "nguyeen giasp"
  ],
  "Nguyên Phúc": [
    "nguyên phúc",
    "nguyeen phusc"
  ],
  "Nguyệt Hóa": [
    "nguyệt hóa",
    "nguyeejt hosa"
  ],
  "Nguyệt Ấn": [
    "nguyệt ấn",
    "nguyeejt aasn"
  ],
  "Ngã Tư Sở": [
    "ngã tư sở",
    "ngax tuw sowr"
  ],
  "Ngọc Chánh": [
    "ngọc chánh",
    "ngojc chasnh"
  ],
  "Ngọc Chấn": [
    "ngọc chấn",
    "ngojc chaasn"
  ],
  "Ngọc Hiển": [
    "ngọc hiển",
    "ngojc hieern"
  ],
  "Ngọc Hiệp": [
    "ngọc hiệp",
    "ngojc hieejp"
  ],
  "Ngọc Khánh": [
    "ngọc khánh",
    "ngojc khasnh"
  ],
  "Ngọc Liệp": [
    "ngọc liệp",
    "ngojc lieejp"
  ],
  "Ngọc Thành": [
    "ngọc thành",
    "ngojc thafnh"
  ],
  "Ngọc Thụy": [
    "ngọc thụy",
    "ngojc thujy"
  ],
  "Ngọc Trạo": [
    "ngọc trạo",
    "ngojc trajo"
  ],
  "Ngọc Vừng": [
    "ngọc vừng",
    "ngojc vuwfng"
  ],
  "Ngọc Xuyên": [
    "ngọc xuyên",
    "ngojc xuyeen"
  ],
  "Ngọc Đông": [
    "ngọc đông",
    "ngojc ddoong"
  ],
  "Nhân Quyền": [
    "nhân quyền",
    "nhaan quyeefn"
  ],
  "Nhân Thắng": [
    "nhân thắng",
    "nhaan thawsng"
  ],
  "Nhân Thịnh": [
    "nhân thịnh",
    "nhaan thijnh"
  ],
  "Nhân Trạch": [
    "nhân trạch",
    "nhaan trajch"
  ],
  "Nhơn Thạnh": [
    "nhơn thạnh",
    "nhown thajnh"
  ],
  "Nhơn Trạch": [
    "nhơn trạch",
    "nhown trajch"
  ],
  "Nhất Tiến": [
    "nhất tiến",
    "nhaast tieesn"
  ],
  "Nhật Tiến": [
    "nhật tiến",
    "nhaajt tieesn"
  ],
  "Nhựt Chánh": [
    "nhựt chánh",
    "nhuwjt chasnh"
  ],
  "Ninh Cường": [
    "ninh cường",
    "ninh cuwowfng"
  ],
  "Ninh Phước": [
    "ninh phước",
    "ninh phuwowsc"
  ],
  "Ninh Quới A": [
    "ninh quới a",
    "ninh quowsi a"
  ],
  "Niệm Nghĩa": [
    "niệm nghĩa",
    "nieejm nghixa"
  ],
  "Noong Luống": [
    "noong luống",
    "noong luoosng"
  ],
  "Noọng Hẹt": [
    "noọng hẹt",
    "noojng hejt"
  ],
  "Núi Tượng": [
    "núi tượng",
    "nusi tuwowjng"
  ],
  "Nậm Mười": [
    "nậm mười",
    "naajm muwowfi"
  ],
  "Nậm Nhoóng": [
    "nậm nhoóng",
    "naajm nhoosng"
  ],
  "Phan Si Păng": [
    "phan si păng",
    "phan si pawng"
  ],
  "Phan Sào Nam": [
    "phan sào nam",
    "phan safo nam"
  ],
  "Phiêng Cằm": [
    "phiêng cằm",
    "phieeng cawfm"
  ],
  "Phiêng Pằn": [
    "phiêng pằn",
    "phieeng pawfn"
  ],
  "Phong Thạnh": [
    "phong thạnh",
    "phong thajnh"
  ],
  "Phong Thịnh": [
    "phong thịnh",
    "phong thijnh"
  ],
  "Phong Điền": [
    "phong điền",
    "phong ddieefn"
  ],
  "Phình Giàng": [
    "phình giàng",
    "phifnh giafng"
  ],
  "Phú Cường": [
    "phú cường",
    "phus cuwowfng"
  ],
  "Phú Khương": [
    "phú khương",
    "phus khuwowng"
  ],
  "Phú Phương": [
    "phú phương",
    "phus phuwowng"
  ],
  "Phú Thành A": [
    "phú thành a",
    "phus thafnh a"
  ],
  "Phú Thành B": [
    "phú thành b",
    "phus thafnh b"
  ],
  "Phúc Lương": [
    "phúc lương",
    "phusc luwowng"
  ],
  "Phúc Thuận": [
    "phúc thuận",
    "phusc thuaajn"
  ],
  "Phúc Thắng": [
    "phúc thắng",
    "phusc thawsng"
  ],
  "Phúc Thịnh": [
    "phúc thịnh",
    "phusc thijnh"
  ],
  "Phúc Trạch": [
    "phúc trạch",
    "phusc trajch"
  ],
  "Phúc Đồng": [
    "phúc đồng",
    "phusc ddoofng"
  ],
  "Phương Canh": [
    "phương canh",
    "phuwowng canh"
  ],
  "Phương Giao": [
    "phương giao",
    "phuwowng giao"
  ],
  "Phương Lâm": [
    "phương lâm",
    "phuwowng laam"
  ],
  "Phương Phú": [
    "phương phú",
    "phuwowng phus"
  ],
  "Phương Sài": [
    "phương sài",
    "phuwowng safi"
  ],
  "Phương Sơn": [
    "phương sơn",
    "phuwowng sown"
  ],
  "Phương Trà": [
    "phương trà",
    "phuwowng traf"
  ],
  "Phước Dinh": [
    "phước dinh",
    "phuwowsc dinh"
  ],
  "Phước Dân": [
    "phước dân",
    "phuwowsc daan"
  ],
  "Phước Hoà": [
    "phước hoà",
    "phuwowsc hoaf"
  ],
  "Phước Hòa": [
    "phước hòa",
    "phuwowsc hofa"
  ],
  "Phước Long": [
    "phước long",
    "phuwowsc long"
  ],
  "Phước Lâm": [
    "phước lâm",
    "phuwowsc laam"
  ],
  "Phước Minh": [
    "phước minh",
    "phuwowsc minh"
  ],
  "Phước Mỹ": [
    "phước mỹ",
    "phuwowsc myx"
  ],
  "Phước Ninh": [
    "phước ninh",
    "phuwowsc ninh"
  ],
  "Phước Sang": [
    "phước sang",
    "phuwowsc sang"
  ],
  "Phước Sơn": [
    "phước sơn",
    "phuwowsc sown"
  ],
  "Phước Trà": [
    "phước trà",
    "phuwowsc traf"
  ],
  "Phước Tân": [
    "phước tân",
    "phuwowsc taan"
  ],
  "Phước Tín": [
    "phước tín",
    "phuwowsc tisn"
  ],
  "Phước Vinh": [
    "phước vinh",
    "phuwowsc vinh"
  ],
  "Phước Vân": [
    "phước vân",
    "phuwowsc vaan"
  ],
  "Phượng Mao": [
    "phượng mao",
    "phuwowjng mao"
  ],
  "Phượng Vĩ": [
    "phượng vĩ",
    "phuwowjng vix"
  ],
  "Phạm Trấn": [
    "phạm trấn",
    "phajm traasn"
  ],
  "Phổ Thuận": [
    "phổ thuận",
    "phoor thuaajn"
  ],
  "Phổ Thạnh": [
    "phổ thạnh",
    "phoor thajnh"
  ],
  "Phổng Lăng": [
    "phổng lăng",
    "phoorng lawng"
  ],
  "Phổng Lập": [
    "phổng lập",
    "phoorng laajp"
  ],
  "Phụng Châu": [
    "phụng châu",
    "phujng chaau"
  ],
  "Phụng Công": [
    "phụng công",
    "phujng coong"
  ],
  "Pờ Ly Ngài": [
    "pờ ly ngài",
    "powf ly ngafi"
  ],
  "Quang Chiểu": [
    "quang chiểu",
    "quang chieeru"
  ],
  "Quang Thiện": [
    "quang thiện",
    "quang thieejn"
  ],
  "Quang Thuận": [
    "quang thuận",
    "quang thuaajn"
  ],
  "Quang Thịnh": [
    "quang thịnh",
    "quang thijnh"
  ],
  "Quang Trọng": [
    "quang trọng",
    "quang trojng"
  ],
  "Quách Phẩm": [
    "quách phẩm",
    "quasch phaarm"
  ],
  "Quán Triều": [
    "quán triều",
    "quasn trieefu"
  ],
  "Quảng Bình": [
    "quảng bình",
    "quarng bifnh"
  ],
  "Quảng Châu": [
    "quảng châu",
    "quarng chaau"
  ],
  "Quảng Công": [
    "quảng công",
    "quarng coong"
  ],
  "Quảng Hùng": [
    "quảng hùng",
    "quarng hufng"
  ],
  "Quảng Hưng": [
    "quảng hưng",
    "quarng huwng"
  ],
  "Quảng Hải": [
    "quảng hải",
    "quarng hari"
  ],
  "Quảng Hợp": [
    "quảng hợp",
    "quarng howjp"
  ],
  "Quảng Lãng": [
    "quảng lãng",
    "quarng laxng"
  ],
  "Quảng Lạc": [
    "quảng lạc",
    "quarng lajc"
  ],
  "Quảng Lập": [
    "quảng lập",
    "quarng laajp"
  ],
  "Quảng Lộc": [
    "quảng lộc",
    "quarng loojc"
  ],
  "Quảng Lợi": [
    "quảng lợi",
    "quarng lowji"
  ],
  "Quảng Ngãi": [
    "quảng ngãi",
    "quarng ngaxi"
  ],
  "Quảng Nhâm": [
    "quảng nhâm",
    "quarng nhaam"
  ],
  "Quảng Nhân": [
    "quảng nhân",
    "quarng nhaan"
  ],
  "Quảng Phong": [
    "quảng phong",
    "quarng phong"
  ],
  "Quảng Phúc": [
    "quảng phúc",
    "quarng phusc"
  ],
  "Quảng Thanh": [
    "quảng thanh",
    "quarng thanh"
  ],
  "Quảng Thái": [
    "quảng thái",
    "quarng thasi"
  ],
  "Quảng Thọ": [
    "quảng thọ",
    "quarng thoj"
  ],
  "Quảng Tiên": [
    "quảng tiên",
    "quarng tieen"
  ],
  "Quảng Trung": [
    "quảng trung",
    "quarng trung"
  ],
  "Quảng Trị": [
    "quảng trị",
    "quarng trij"
  ],
  "Quảng Tùng": [
    "quảng tùng",
    "quarng tufng"
  ],
  "Quảng Uyên": [
    "quảng uyên",
    "quarng uyeen"
  ],
  "Quảng Xuân": [
    "quảng xuân",
    "quarng xuaan"
  ],
  "Quế Thuận": [
    "quế thuận",
    "quees thuaajn"
  ],
  "Quế Xuân 1": [
    "quế xuân 1",
    "quees xuaan 1"
  ],
  "Quế Xuân 2": [
    "quế xuân 2",
    "quees xuaan 2"
  ],
  "Quốc Khánh": [
    "quốc khánh",
    "quoosc khasnh"
  ],
  "Quốc Toản": [
    "quốc toản",
    "quoosc toarn"
  ],
  "Quốc Tuấn": [
    "quốc tuấn",
    "quoosc tuaasn"
  ],
  "Quốc Việt": [
    "quốc việt",
    "quoosc vieejt"
  ],
  "Quới Thành": [
    "quới thành",
    "quowsi thafnh"
  ],
  "Quỳnh Bảo": [
    "quỳnh bảo",
    "quyfnh baro"
  ],
  "Quỳnh Châu": [
    "quỳnh châu",
    "quyfnh chaau"
  ],
  "Quỳnh Giang": [
    "quỳnh giang",
    "quyfnh giang"
  ],
  "Quỳnh Hưng": [
    "quỳnh hưng",
    "quyfnh huwng"
  ],
  "Quỳnh Hải": [
    "quỳnh hải",
    "quyfnh hari"
  ],
  "Quỳnh Hậu": [
    "quỳnh hậu",
    "quyfnh haaju"
  ],
  "Quỳnh Hội": [
    "quỳnh hội",
    "quyfnh hooji"
  ],
  "Quỳnh Liên": [
    "quỳnh liên",
    "quyfnh lieen"
  ],
  "Quỳnh Lập": [
    "quỳnh lập",
    "quyfnh laajp"
  ],
  "Quỳnh Lộc": [
    "quỳnh lộc",
    "quyfnh loojc"
  ],
  "Quỳnh Phụ": [
    "quỳnh phụ",
    "quyfnh phuj"
  ],
  "Quỳnh Thanh": [
    "quỳnh thanh",
    "quyfnh thanh"
  ],
  "Quỳnh Thọ": [
    "quỳnh thọ",
    "quyfnh thoj"
  ],
  "Quỳnh Trang": [
    "quỳnh trang",
    "quyfnh trang"
  ],
  "Quỳnh Xuân": [
    "quỳnh xuân",
    "quyfnh xuaan"
  ],
  "Quỳnh Đôi": [
    "quỳnh đôi",
    "quyfnh ddooi"
  ],
  "Rạng Đông": [
    "rạng đông",
    "rajng ddoong"
  ],
  "Rừng Thông": [
    "rừng thông",
    "ruwfng thoong"
  ],
  "Sen Thượng": [
    "sen thượng",
    "sen thuwowjng"
  ],
  "Song Phương": [
    "song phương",
    "song phuwowng"
  ],
  "Suối Giàng": [
    "suối giàng",
    "suoosi giafng"
  ],
  "Suối Hiệp": [
    "suối hiệp",
    "suoosi hieejp"
  ],
  "Suối Kiết": [
    "suối kiết",
    "suoosi kieest"
  ],
  "Suối Nghệ": [
    "suối nghệ",
    "suoosi ngheej"
  ],
  "Sàng Ma Sáo": [
    "sàng ma sáo",
    "safng ma saso"
  ],
  "Sơn Phước": [
    "sơn phước",
    "sown phuwowsc"
  ],
  "Sảng Tủng": [
    "sảng tủng",
    "sarng turng"
  ],
  "Sủng Tráng": [
    "sủng tráng",
    "surng trasng"
  ],
  "Tam Anh Bắc": [
    "tam anh bắc",
    "tam anh bawsc"
  ],
  "Tam Mỹ Tây": [
    "tam mỹ tây",
    "tam myx taay"
  ],
  "Tam Đường": [
    "tam đường",
    "tam dduwowfng"
  ],
  "Thanh Dương": [
    "thanh dương",
    "thanh duwowng"
  ],
  "Thanh Hương": [
    "thanh hương",
    "thanh huwowng"
  ],
  "Thanh Lương": [
    "thanh lương",
    "thanh luwowng"
  ],
  "Thanh Nguyên": [
    "thanh nguyên",
    "thanh nguyeen"
  ],
  "Thanh Thạch": [
    "thanh thạch",
    "thanh thajch"
  ],
  "Thanh Thịnh": [
    "thanh thịnh",
    "thanh thijnh"
  ],
  "Thanh Trạch": [
    "thanh trạch",
    "thanh trajch"
  ],
  "Thanh Tuyền": [
    "thanh tuyền",
    "thanh tuyeefn"
  ],
  "Thanh Tương": [
    "thanh tương",
    "thanh tuwowng"
  ],
  "Thanh Xương": [
    "thanh xương",
    "thanh xuwowng"
  ],
  "Thanh Điền": [
    "thanh điền",
    "thanh ddieefn"
  ],
  "Thanh Định": [
    "thanh định",
    "thanh ddijnh"
  ],
  "Thanh Đồng": [
    "thanh đồng",
    "thanh ddoofng"
  ],
  "Thiết Ống": [
    "thiết ống",
    "thieest oosng"
  ],
  "Thiện Hưng": [
    "thiện hưng",
    "thieejn huwng"
  ],
  "Thiện Trung": [
    "thiện trung",
    "thieejn trung"
  ],
  "Thiệu Công": [
    "thiệu công",
    "thieeju coong"
  ],
  "Thiệu Giang": [
    "thiệu giang",
    "thieeju giang"
  ],
  "Thiệu Hợp": [
    "thiệu hợp",
    "thieeju howjp"
  ],
  "Thiệu Phúc": [
    "thiệu phúc",
    "thieeju phusc"
  ],
  "Thiệu Quang": [
    "thiệu quang",
    "thieeju quang"
  ],
  "Thiệu Toán": [
    "thiệu toán",
    "thieeju toasn"
  ],
  "Thiệu Trung": [
    "thiệu trung",
    "thieeju trung"
  ],
  "Thiệu Viên": [
    "thiệu viên",
    "thieeju vieen"
  ],
  "Thiệu Vận": [
    "thiệu vận",
    "thieeju vaajn"
  ],
  "Thoại Giang": [
    "thoại giang",
    "thoaji giang"
  ],
  "Thuần Hưng": [
    "thuần hưng",
    "thuaafn huwng"
  ],
  "Thuần Lộc": [
    "thuần lộc",
    "thuaafn loojc"
  ],
  "Thuận Bình": [
    "thuận bình",
    "thuaajn bifnh"
  ],
  "Thuận Bắc": [
    "thuận bắc",
    "thuaajn bawsc"
  ],
  "Thuận Châu": [
    "thuận châu",
    "thuaajn chaau"
  ],
  "Thuận Hưng": [
    "thuận hưng",
    "thuaajn huwng"
  ],
  "Thuận Lộc": [
    "thuận lộc",
    "thuaajn loojc"
  ],
  "Thuận Lợi": [
    "thuận lợi",
    "thuaajn lowji"
  ],
  "Thuỷ Biều": [
    "thuỷ biều",
    "thuyr bieefu"
  ],
  "Thành Nhất": [
    "thành nhất",
    "thafnh nhaast"
  ],
  "Thành Tiến": [
    "thành tiến",
    "thafnh tieesn"
  ],
  "Thành Trực": [
    "thành trực",
    "thafnh truwjc"
  ],
  "Thái Dương": [
    "thái dương",
    "thasi duwowng"
  ],
  "Thái Nguyên": [
    "thái nguyên",
    "thasi nguyeen"
  ],
  "Thái Thịnh": [
    "thái thịnh",
    "thasi thijnh"
  ],
  "Tháp Mười": [
    "tháp mười",
    "thasp muwowfi"
  ],
  "Thân Thuộc": [
    "thân thuộc",
    "thaan thuoojc"
  ],
  "Thường Nga": [
    "thường nga",
    "thuwowfng nga"
  ],
  "Thượng Hà": [
    "thượng hà",
    "thuwowjng haf"
  ],
  "Thượng Lan": [
    "thượng lan",
    "thuwowjng lan"
  ],
  "Thượng Lý": [
    "thượng lý",
    "thuwowjng lys"
  ],
  "Thượng Vũ": [
    "thượng vũ",
    "thuwowjng vux"
  ],
  "Thượng Ân": [
    "thượng ân",
    "thuwowjng aan"
  ],
  "Thạch Bình": [
    "thạch bình",
    "thajch bifnh"
  ],
  "Thạch Châu": [
    "thạch châu",
    "thajch chaau"
  ],
  "Thạch Cẩm": [
    "thạch cẩm",
    "thajch caarm"
  ],
  "Thạch Giám": [
    "thạch giám",
    "thajch giasm"
  ],
  "Thạch Hưng": [
    "thạch hưng",
    "thajch huwng"
  ],
  "Thạch Hải": [
    "thạch hải",
    "thajch hari"
  ],
  "Thạch Hội": [
    "thạch hội",
    "thajch hooji"
  ],
  "Thạch Khôi": [
    "thạch khôi",
    "thajch khooi"
  ],
  "Thạch Kênh": [
    "thạch kênh",
    "thajch keenh"
  ],
  "Thạch Liên": [
    "thạch liên",
    "thajch lieen"
  ],
  "Thạch Lạc": [
    "thạch lạc",
    "thajch lajc"
  ],
  "Thạch Lập": [
    "thạch lập",
    "thajch laajp"
  ],
  "Thạch Lỗi": [
    "thạch lỗi",
    "thajch looxi"
  ],
  "Thạch Ngàn": [
    "thạch ngàn",
    "thajch ngafn"
  ],
  "Thạch Thang": [
    "thạch thang",
    "thajch thang"
  ],
  "Thạch Thán": [
    "thạch thán",
    "thajch thasn"
  ],
  "Thạch Trung": [
    "thạch trung",
    "thajch trung"
  ],
  "Thạch Trị": [
    "thạch trị",
    "thajch trij"
  ],
  "Thạch Xuân": [
    "thạch xuân",
    "thajch xuaan"
  ],
  "Thạch Đài": [
    "thạch đài",
    "thajch ddafi"
  ],
  "Thạnh Bình": [
    "thạnh bình",
    "thajnh bifnh"
  ],
  "Thạnh Bắc": [
    "thạnh bắc",
    "thajnh bawsc"
  ],
  "Thạnh Hưng": [
    "thạnh hưng",
    "thajnh huwng"
  ],
  "Thạnh Hải": [
    "thạnh hải",
    "thajnh hari"
  ],
  "Thạnh Hội": [
    "thạnh hội",
    "thajnh hooji"
  ],
  "Thạnh Lộc": [
    "thạnh lộc",
    "thajnh loojc"
  ],
  "Thạnh Lợi": [
    "thạnh lợi",
    "thajnh lowji"
  ],
  "Thạnh Ngãi": [
    "thạnh ngãi",
    "thajnh ngaxi"
  ],
  "Thạnh Phong": [
    "thạnh phong",
    "thajnh phong"
  ],
  "Thạnh Trị": [
    "thạnh trị",
    "thajnh trij"
  ],
  "Thạnh Xuân": [
    "thạnh xuân",
    "thajnh xuaan"
  ],
  "Thắng Hải": [
    "thắng hải",
    "thawsng hari"
  ],
  "Thắng Lợi": [
    "thắng lợi",
    "thawsng lowji"
  ],
  "Thắng Quân": [
    "thắng quân",
    "thawsng quaan"
  ],
  "Thịnh Hưng": [
    "thịnh hưng",
    "thijnh huwng"
  ],
  "Thịnh Lộc": [
    "thịnh lộc",
    "thijnh loojc"
  ],
  "Thịnh Quang": [
    "thịnh quang",
    "thijnh quang"
  ],
  "Thịnh Đán": [
    "thịnh đán",
    "thijnh ddasn"
  ],
  "Thọ Xương": [
    "thọ xương",
    "thoj xuwowng"
  ],
  "Thọ Điền": [
    "thọ điền",
    "thoj ddieefn"
  ],
  "Thống Kênh": [
    "thống kênh",
    "thoosng keenh"
  ],
  "Thới Quản": [
    "thới quản",
    "thowsi quarn"
  ],
  "Thới Đông": [
    "thới đông",
    "thowsi ddoong"
  ],
  "Thụy Chính": [
    "thụy chính",
    "thujy chisnh"
  ],
  "Thụy Duyên": [
    "thụy duyên",
    "thujy duyeen"
  ],
  "Thụy Liễu": [
    "thụy liễu",
    "thujy lieexu"
  ],
  "Thụy Trình": [
    "thụy trình",
    "thujy trifnh"
  ],
  "Thụy Việt": [
    "thụy việt",
    "thujy vieejt"
  ],
  "Thủy Bằng": [
    "thủy bằng",
    "thury bawfng"
  ],
  "Thủy Liễu": [
    "thủy liễu",
    "thury lieexu"
  ],
  "Thủy Đông": [
    "thủy đông",
    "thury ddoong"
  ],
  "Thừa Đức": [
    "thừa đức",
    "thuwfa dduwsc"
  ],
  "Tiên Dương": [
    "tiên dương",
    "tieen duwowng"
  ],
  "Tiên Dược": [
    "tiên dược",
    "tieen duwowjc"
  ],
  "Tiên Lương": [
    "tiên lương",
    "tieen luwowng"
  ],
  "Tiên Ngoại": [
    "tiên ngoại",
    "tieen ngoaji"
  ],
  "Tiên Nguyên": [
    "tiên nguyên",
    "tieen nguyeen"
  ],
  "Tiên Thuận": [
    "tiên thuận",
    "tieen thuaajn"
  ],
  "Tiên Thắng": [
    "tiên thắng",
    "tieen thawsng"
  ],
  "Tiên Điền": [
    "tiên điền",
    "tieen ddieefn"
  ],
  "Tiên Động": [
    "tiên động",
    "tieen ddoojng"
  ],
  "Tiêu Động": [
    "tiêu động",
    "tieeu ddoojng"
  ],
  "Tiến Thành": [
    "tiến thành",
    "tieesn thafnh"
  ],
  "Tiến Thủy": [
    "tiến thủy",
    "tieesn thury"
  ],
  "Tiến Đức": [
    "tiến đức",
    "tieesn dduwsc"
  ],
  "Tiền Tiến": [
    "tiền tiến",
    "tieefn tieesn"
  ],
  "Toàn Thắng": [
    "toàn thắng",
    "toafn thawsng"
  ],
  "Triệu Giang": [
    "triệu giang",
    "trieeju giang"
  ],
  "Triệu Hải": [
    "triệu hải",
    "trieeju hari"
  ],
  "Triệu Lăng": [
    "triệu lăng",
    "trieeju lawng"
  ],
  "Triệu Lộc": [
    "triệu lộc",
    "trieeju loojc"
  ],
  "Triệu Phong": [
    "triệu phong",
    "trieeju phong"
  ],
  "Triệu Trung": [
    "triệu trung",
    "trieeju trung"
  ],
  "Triệu Đề": [
    "triệu đề",
    "trieeju ddeef"
  ],
  "Triệu Độ": [
    "triệu độ",
    "trieeju ddooj"
  ],
  "Trung Lương": [
    "trung lương",
    "trung luwowng"
  ],
  "Trung Nguyên": [
    "trung nguyên",
    "trung nguyeen"
  ],
  "Trung Phụng": [
    "trung phụng",
    "trung phujng"
  ],
  "Trung Thạnh": [
    "trung thạnh",
    "trung thajnh"
  ],
  "Trung Thịnh": [
    "trung thịnh",
    "trung thijnh"
  ],
  "Trung Trạch": [
    "trung trạch",
    "trung trajch"
  ],
  "Trung Đồng": [
    "trung đồng",
    "trung ddoofng"
  ],
  "Tràng Tiền": [
    "tràng tiền",
    "trafng tieefn"
  ],
  "Tráng Việt": [
    "tráng việt",
    "trasng vieejt"
  ],
  "Trùng Khánh": [
    "trùng khánh",
    "trufng khasnh"
  ],
  "Trưng Trắc": [
    "trưng trắc",
    "truwng trawsc"
  ],
  "Trường Hà": [
    "trường hà",
    "truwowfng haf"
  ],
  "Trường Thi": [
    "trường thi",
    "truwowfng thi"
  ],
  "Trạm Thản": [
    "trạm thản",
    "trajm tharn"
  ],
  "Trảng Bàng": [
    "trảng bàng",
    "trarng bafng"
  ],
  "Trầm Lộng": [
    "trầm lộng",
    "traafm loojng"
  ],
  "Trần Thới": [
    "trần thới",
    "traafn thowsi"
  ],
  "Trực Chính": [
    "trực chính",
    "truwjc chisnh"
  ],
  "Trực Tuấn": [
    "trực tuấn",
    "truwjc tuaasn"
  ],
  "Trực Đại": [
    "trực đại",
    "truwjc ddaji"
  ],
  "Trực Đạo": [
    "trực đạo",
    "truwjc ddajo"
  ],
  "Tuấn Việt": [
    "tuấn việt",
    "tuaasn vieejt"
  ],
  "Tuấn Đạo": [
    "tuấn đạo",
    "tuaasn ddajo"
  ],
  "Tân An Hội": [
    "tân an hội",
    "taan an hooji"
  ],
  "Tân Hiệp A": [
    "tân hiệp a",
    "taan hieejp a"
  ],
  "Tân Hiệp B": [
    "tân hiệp b",
    "taan hieejp b"
  ],
  "Tân Hộ Cơ": [
    "tân hộ cơ",
    "taan hooj cow"
  ],
  "Tân Lý Tây": [
    "tân lý tây",
    "taan lys taay"
  ],
  "Tân Mỹ Hà": [
    "tân mỹ hà",
    "taan myx haf"
  ],
  "Tân Phương": [
    "tân phương",
    "taan phuwowng"
  ],
  "Tân Phước": [
    "tân phước",
    "taan phuwowsc"
  ],
  "Tân Quy Tây": [
    "tân quy tây",
    "taan quy taay"
  ],
  "Tân Thiềng": [
    "tân thiềng",
    "taan thieefng"
  ],
  "Tân Thành A": [
    "tân thành a",
    "taan thafnh a"
  ],
  "Tân Thành B": [
    "tân thành b",
    "taan thafnh b"
  ],
  "Tân Ân Tây": [
    "tân ân tây",
    "taan aan taay"
  ],
  "Tích Lương": [
    "tích lương",
    "tisch luwowng"
  ],
  "Tích Thiện": [
    "tích thiện",
    "tisch thieejn"
  ],
  "Tương Giang": [
    "tương giang",
    "tuwowng giang"
  ],
  "Tường Hạ": [
    "tường hạ",
    "tuwowfng haj"
  ],
  "Tường Phù": [
    "tường phù",
    "tuwowfng phuf"
  ],
  "Tường Sơn": [
    "tường sơn",
    "tuwowfng sown"
  ],
  "Tượng Sơn": [
    "tượng sơn",
    "tuwowjng sown"
  ],
  "Tượng Văn": [
    "tượng văn",
    "tuwowjng vawn"
  ],
  "Tả Van Chư": [
    "tả van chư",
    "tar van chuw"
  ],
  "Tất Thắng": [
    "tất thắng",
    "taast thawsng"
  ],
  "Tịnh Hiệp": [
    "tịnh hiệp",
    "tijnh hieejp"
  ],
  "Tịnh Thới": [
    "tịnh thới",
    "tijnh thowsi"
  ],
  "Tịnh Đông": [
    "tịnh đông",
    "tijnh ddoong"
  ],
  "Tốt Động": [
    "tốt động",
    "toost ddoojng"
  ],
  "Tứ Cường": [
    "tứ cường",
    "tuws cuwowfng"
  ],
  "Tự Cường": [
    "tự cường",
    "tuwj cuwowfng"
  ],
  "Việt Hồng": [
    "việt hồng",
    "vieejt hoofng"
  ],
  "Việt Ngọc": [
    "việt ngọc",
    "vieejt ngojc"
  ],
  "Việt Thành": [
    "việt thành",
    "vieejt thafnh"
  ],
  "Việt Tiến": [
    "việt tiến",
    "vieejt tieesn"
  ],
  "Việt Đoàn": [
    "việt đoàn",
    "vieejt ddoafn"
  ],
  "Văn Chương": [
    "văn chương",
    "vawn chuwowng"
  ],
  "Văn Phương": [
    "văn phương",
    "vawn phuwowng"
  ],
  "Vĩ Thượng": [
    "vĩ thượng",
    "vix thuwowjng"
  ],
  "Vĩnh Châu A": [
    "vĩnh châu a",
    "vixnh chaau a"
  ],
  "Vĩnh Châu B": [
    "vĩnh châu b",
    "vixnh chaau b"
  ],
  "Vĩnh Hưng A": [
    "vĩnh hưng a",
    "vixnh huwng a"
  ],
  "Vĩnh Hậu A": [
    "vĩnh hậu a",
    "vixnh haaju a"
  ],
  "Vĩnh Lương": [
    "vĩnh lương",
    "vixnh luwowng"
  ],
  "Vĩnh Lộc A": [
    "vĩnh lộc a",
    "vixnh loojc a"
  ],
  "Vĩnh Lộc B": [
    "vĩnh lộc b",
    "vixnh loojc b"
  ],
  "Vĩnh Nguyên": [
    "vĩnh nguyên",
    "vixnh nguyeen"
  ],
  "Vĩnh Ngươn": [
    "vĩnh ngươn",
    "vixnh nguwown"
  ],
  "Vĩnh Nhuận": [
    "vĩnh nhuận",
    "vixnh nhuaajn"
  ],
  "Vĩnh Quỳnh": [
    "vĩnh quỳnh",
    "vixnh quyfnh"
  ],
  "Vĩnh Thuận": [
    "vĩnh thuận",
    "vixnh thuaajn"
  ],
  "Vĩnh Thạnh": [
    "vĩnh thạnh",
    "vixnh thajnh"
  ],
  "Vĩnh Thắng": [
    "vĩnh thắng",
    "vixnh thawsng"
  ],
  "Vĩnh Thịnh": [
    "vĩnh thịnh",
    "vixnh thijnh"
  ],
  "Vĩnh Trạch": [
    "vĩnh trạch",
    "vixnh trajch"
  ],
  "Vĩnh Xương": [
    "vĩnh xương",
    "vixnh xuwowng"
  ],
  "Vĩnh Điều": [
    "vĩnh điều",
    "vixnh ddieefu"
  ],
  "Vĩnh Điện": [
    "vĩnh điện",
    "vixnh ddieejn"
  ],
  "Vĩnh Đồng": [
    "vĩnh đồng",
    "vixnh ddoofng"
  ],
  "Vạn Hương": [
    "vạn hương",
    "vajn huwowng"
  ],
  "Vạn Lương": [
    "vạn lương",
    "vajn luwowng"
  ],
  "Vạn Thiện": [
    "vạn thiện",
    "vajn thieejn"
  ],
  "Vạn Thạnh": [
    "vạn thạnh",
    "vajn thajnh"
  ],
  "Vạn Thắng": [
    "vạn thắng",
    "vajn thawsng"
  ],
  "Vạn Trạch": [
    "vạn trạch",
    "vajn trajch"
  ],
  "Vạn Điểm": [
    "vạn điểm",
    "vajn ddieerm"
  ],
  "Vọng Đông": [
    "vọng đông",
    "vojng ddoong"
  ],
  "Xuân Dương": [
    "xuân dương",
    "xuaan duwowng"
  ],
  "Xuân Hương": [
    "xuân hương",
    "xuaan huwowng"
  ],
  "Xuân Lương": [
    "xuân lương",
    "xuaan luwowng"
  ],
  "Xuân Quang 1": [
    "xuân quang 1",
    "xuaan quang 1"
  ],
  "Xuân Quang 2": [
    "xuân quang 2",
    "xuaan quang 2"
  ],
  "Xuân Quang 3": [
    "xuân quang 3",
    "xuaan quang 3"
  ],
  "Xuân Thiện": [
    "xuân thiện",
    "xuaan thieejn"
  ],
  "Xuân Thắng": [
    "xuân thắng",
    "xuaan thawsng"
  ],
  "Xuân Thịnh": [
    "xuân thịnh",
    "xuaan thijnh"
  ],
  "Xuân Thọ 1": [
    "xuân thọ 1",
    "xuaan thoj 1"
  ],
  "Xuân Thọ 2": [
    "xuân thọ 2",
    "xuaan thoj 2"
  ],
  "Xuân Trạch": [
    "xuân trạch",
    "xuaan trajch"
  ],
  "Xuân Đỉnh": [
    "xuân đỉnh",
    "xuaan ddirnh"
  ],
  "Xuân Định": [
    "xuân định",
    "xuaan ddijnh"
  ],
  "Xương Giang": [
    "xương giang",
    "xuwowng giang"
  ],
  "Xương Huân": [
    "xương huân",
    "xuwowng huaan"
  ],
  "Ya Tờ Mốt": [
    "ya tờ mốt",
    "ya towf moost"
  ],
  "Yên Cường": [
    "yên cường",
    "yeen cuwowfng"
  ],
  "Yên Dưỡng": [
    "yên dưỡng",
    "yeen duwowxng"
  ],
  "Yên Khương": [
    "yên khương",
    "yeen khuwowng"
  ],
  "Yên Nghiệp": [
    "yên nghiệp",
    "yeen nghieejp"
  ],
  "Yên Phương": [
    "yên phương",
    "yeen phuwowng"
  ],
  "Yên Vượng": [
    "yên vượng",
    "yeen vuwowjng"
  ],
  "Yến Dương": [
    "yến dương",
    "yeesn duwowng"
  ],
  "Ái Thượng": [
    "ái thượng",
    "asi thuwowjng"
  ],
  "Điềm Mặc": [
    "điềm mặc",
    "ddieefm mawjc"
  ],
  "Điền Hải": [
    "điền hải",
    "ddieefn hari"
  ],
  "Điền Lộc": [
    "điền lộc",
    "ddieefn loojc"
  ],
  "Điền Quang": [
    "điền quang",
    "ddieefn quang"
  ],
  "Điền Trung": [
    "điền trung",
    "ddieefn trung"
  ],
  "Điện Biên": [
    "điện biên",
    "ddieejn bieen"
  ],
  "Điện Phong": [
    "điện phong",
    "ddieejn phong"
  ],
  "Điện Quang": [
    "điện quang",
    "ddieejn quang"
  ],
  "Điện Thọ": [
    "điện thọ",
    "ddieejn thoj"
  ],
  "Điện Trung": [
    "điện trung",
    "ddieejn trung"
  ],
  "Điệp Nông": [
    "điệp nông",
    "ddieejp noong"
  ],
  "Đoọc Mạy": [
    "đoọc mạy",
    "ddoojc majy"
  ],
  "Đào Dương": [
    "đào dương",
    "ddafo duwowng"
  ],
  "Đào Thịnh": [
    "đào thịnh",
    "ddafo thijnh"
  ],
  "Đình Bảng": [
    "đình bảng",
    "ddifnh barng"
  ],
  "Đình Phùng": [
    "đình phùng",
    "ddifnh phufng"
  ],
  "Đình Xuyên": [
    "đình xuyên",
    "ddifnh xuyeen"
  ],
  "Đôn Thuận": [
    "đôn thuận",
    "ddoon thuaajn"
  ],
  "Đông Cuông": [
    "đông cuông",
    "ddoong cuoong"
  ],
  "Đông Hiếu": [
    "đông hiếu",
    "ddoong hieesu"
  ],
  "Đông Hiệp": [
    "đông hiệp",
    "ddoong hieejp"
  ],
  "Đông Hoàng": [
    "đông hoàng",
    "ddoong hoafng"
  ],
  "Đông Ngạc": [
    "đông ngạc",
    "ddoong ngajc"
  ],
  "Đông Thành": [
    "đông thành",
    "ddoong thafnh"
  ],
  "Đông Thới": [
    "đông thới",
    "ddoong thowsi"
  ],
  "Đông Tiến": [
    "đông tiến",
    "ddoong tieesn"
  ],
  "Đông Xuyên": [
    "đông xuyên",
    "ddoong xuyeen"
  ],
  "Đăk Djrăng": [
    "đăk djrăng",
    "ddawk djrawng"
  ],
  "Đăk Pơ Pho": [
    "đăk pơ pho",
    "ddawk pow pho"
  ],
  "Đăk Tơ Ver": [
    "đăk tơ ver",
    "ddawk tow ver"
  ],
  "Đơn Dương": [
    "đơn dương",
    "ddown duwowng"
  ],
  "Đường Hoa": [
    "đường hoa",
    "dduwowfng hoa"
  ],
  "Đường Âm": [
    "đường âm",
    "dduwowfng aam"
  ],
  "Đạ M' Rong": [
    "đạ m' rong",
    "ddaj m' rong"
  ],
  "Đại Chánh": [
    "đại chánh",
    "ddaji chasnh"
  ],
  "Đại Hiệp": [
    "đại hiệp",
    "ddaji hieejp"
  ],
  "Đại Hồng": [
    "đại hồng",
    "ddaji hoofng"
  ],
  "Đại Lịch": [
    "đại lịch",
    "ddaji lijch"
  ],
  "Đại Mạch": [
    "đại mạch",
    "ddaji majch"
  ],
  "Đại Nghĩa": [
    "đại nghĩa",
    "ddaji nghixa"
  ],
  "Đại Phạm": [
    "đại phạm",
    "ddaji phajm"
  ],
  "Đại Thành": [
    "đại thành",
    "ddaji thafnh"
  ],
  "Đại Tiến": [
    "đại tiến",
    "ddaji tieesn"
  ],
  "Đại Xuyên": [
    "đại xuyên",
    "ddaji xuyeen"
  ],
  "Đại Ân  2": [
    "đại ân  2",
    "ddaji aan  2"
  ],
  "Đại Đình": [
    "đại đình",
    "ddaji ddifnh"
  ],
  "Đại Đức": [
    "đại đức",
    "ddaji dduwsc"
  ],
  "Đạo Nghĩa": [
    "đạo nghĩa",
    "ddajo nghixa"
  ],
  "Đạo Viện": [
    "đạo viện",
    "ddajo vieejn"
  ],
  "Đạo Đức": [
    "đạo đức",
    "ddajo dduwsc"
  ],
  "Đạt Hiếu": [
    "đạt hiếu",
    "ddajt hieesu"
  ],
  "Đất Bằng": [
    "đất bằng",
    "ddaast bawfng"
  ],
  "Đất Cuốc": [
    "đất cuốc",
    "ddaast cuoosc"
  ],
  "Đắk Choong": [
    "đắk choong",
    "ddawsk choong"
  ],
  "Đắk DRông": [
    "đắk drông",
    "ddawsk droong"
  ],
  "Đắk KRoong": [
    "đắk kroong",
    "ddawsk kroong"
  ],
  "Đắk Liêng": [
    "đắk liêng",
    "ddawsk lieeng"
  ],
  "Đắk N'Dung": [
    "đắk n'dung",
    "ddawsk n'dung"
  ],
  "Đắk Nhoong": [
    "đắk nhoong",
    "ddawsk nhoong"
  ],
  "Đắk R'Tíh": [
    "đắk r'tíh",
    "ddawsk r'tish"
  ],
  "Đắk Rơ Wa": [
    "đắk rơ wa",
    "ddawsk row wa"
  ],
  "Đằng Giang": [
    "đằng giang",
    "ddawfng giang"
  ],
  "Đằng Hải": [
    "đằng hải",
    "ddawfng hari"
  ],
  "Địch Quả": [
    "địch quả",
    "ddijch quar"
  ],
  "Định Biên": [
    "định biên",
    "ddijnh bieen"
  ],
  "Định Bình": [
    "định bình",
    "ddijnh bifnh"
  ],
  "Định Công": [
    "định công",
    "ddijnh coong"
  ],
  "Định Hưng": [
    "định hưng",
    "ddijnh huwng"
  ],
  "Định Hải": [
    "định hải",
    "ddijnh hari"
  ],
  "Định Liên": [
    "định liên",
    "ddijnh lieen"
  ],
  "Định Quán": [
    "định quán",
    "ddijnh quasn"
  ],
  "Định Trung": [
    "định trung",
    "ddijnh trung"
  ],
  "Định Tăng": [
    "định tăng",
    "ddijnh tawng"
  ],
  "Đồn Đạc": [
    "đồn đạc",
    "ddoofn ddajc"
  ],
  "Đồng Bẩm": [
    "đồng bẩm",
    "ddoofng baarm"
  ],
  "Đồng Bục": [
    "đồng bục",
    "ddoofng bujc"
  ],
  "Đồng Cẩm": [
    "đồng cẩm",
    "ddoofng caarm"
  ],
  "Đồng Cốc": [
    "đồng cốc",
    "ddoofng coosc"
  ],
  "Đồng Giáp": [
    "đồng giáp",
    "ddoofng giasp"
  ],
  "Đồng Hải": [
    "đồng hải",
    "ddoofng hari"
  ],
  "Đồng Hới": [
    "đồng hới",
    "ddoofng howsi"
  ],
  "Đồng Hợp": [
    "đồng hợp",
    "ddoofng howjp"
  ],
  "Đồng Liên": [
    "đồng liên",
    "ddoofng lieen"
  ],
  "Đồng Lạc": [
    "đồng lạc",
    "ddoofng lajc"
  ],
  "Đồng Lộc": [
    "đồng lộc",
    "ddoofng loojc"
  ],
  "Đồng Lợi": [
    "đồng lợi",
    "ddoofng lowji"
  ],
  "Đồng Nhân": [
    "đồng nhân",
    "ddoofng nhaan"
  ],
  "Đồng Phong": [
    "đồng phong",
    "ddoofng phong"
  ],
  "Đồng Phúc": [
    "đồng phúc",
    "ddoofng phusc"
  ],
  "Đồng Quang": [
    "đồng quang",
    "ddoofng quang"
  ],
  "Đồng Quế": [
    "đồng quế",
    "ddoofng quees"
  ],
  "Đồng Thanh": [
    "đồng thanh",
    "ddoofng thanh"
  ],
  "Đồng Thái": [
    "đồng thái",
    "ddoofng thasi"
  ],
  "Đồng Tháp": [
    "đồng tháp",
    "ddoofng thasp"
  ],
  "Đồng Trung": [
    "đồng trung",
    "ddoofng trung"
  ],
  "Đồng Trúc": [
    "đồng trúc",
    "ddoofng trusc"
  ],
  "Đồng Tĩnh": [
    "đồng tĩnh",
    "ddoofng tixnh"
  ],
  "Đồng Xoài": [
    "đồng xoài",
    "ddoofng xoafi"
  ],
  "Đồng Xuân": [
    "đồng xuân",
    "ddoofng xuaan"
  ],
  "Đỗ Động": [
    "đỗ động",
    "ddoox ddoojng"
  ],
  "Đức Bồng": [
    "đức bồng",
    "dduwsc boofng"
  ],
  "Đức Chánh": [
    "đức chánh",
    "dduwsc chasnh"
  ],
  "Đức Chính": [
    "đức chính",
    "dduwsc chisnh"
  ],
  "Đức Hiệp": [
    "đức hiệp",
    "dduwsc hieejp"
  ],
  "Đức Hạnh": [
    "đức hạnh",
    "dduwsc hajnh"
  ],
  "Đức Hồng": [
    "đức hồng",
    "dduwsc hoofng"
  ],
  "Đức Liễu": [
    "đức liễu",
    "dduwsc lieexu"
  ],
  "Đức Lạng": [
    "đức lạng",
    "dduwsc lajng"
  ],
  "Đức Mạnh": [
    "đức mạnh",
    "dduwsc majnh"
  ],
  "Đức Nghĩa": [
    "đức nghĩa",
    "dduwsc nghixa"
  ],
  "Đức Thành": [
    "đức thành",
    "dduwsc thafnh"
  ],
  "Đức Thông": [
    "đức thông",
    "dduwsc thoong"
  ],
  "Đức Xuyên": [
    "đức xuyên",
    "dduwsc xuyeen"
  ],
  "An Hải Bắc": [
    "an hải bắc",
    "an hari bawsc"
  ],
  "An Lạc Thôn": [
    "an lạc thôn",
    "an lajc thoon"
  ],
  "An Ngãi Trung": [
    "an ngãi trung",
    "an ngaxi trung"
  ],
  "An Ninh Đông": [
    "an ninh đông",
    "an ninh ddoong"
  ],
  "An Phú Đông": [
    "an phú đông",
    "an phus ddoong"
  ],
  "An Thái Trung": [
    "an thái trung",
    "an thasi trung"
  ],
  "An Thạnh Nam": [
    "an thạnh nam",
    "an thajnh nam"
  ],
  "An Trường A": [
    "an trường a",
    "an truwowfng a"
  ],
  "An Vĩnh Ngãi": [
    "an vĩnh ngãi",
    "an vixnh ngaxi"
  ],
  "Ba Cụm Bắc": [
    "ba cụm bắc",
    "ba cujm bawsc"
  ],
  "Biển Động": [
    "biển động",
    "bieern ddoojng"
  ],
  "Bình Chương": [
    "bình chương",
    "bifnh chuwowng"
  ],
  "Bình Hòa Nam": [
    "bình hòa nam",
    "bifnh hofa nam"
  ],
  "Bình Khương": [
    "bình khương",
    "bifnh khuwowng"
  ],
  "Bình Phước": [
    "bình phước",
    "bifnh phuwowsc"
  ],
  "Bình Tường": [
    "bình tường",
    "bifnh tuwowfng"
  ],
  "Băng A Drênh": [
    "băng a drênh",
    "bawng a dreenh"
  ],
  "Bạch Đằng": [
    "bạch đằng",
    "bajch ddawfng"
  ],
  "Bảo Cường": [
    "bảo cường",
    "baro cuwowfng"
  ],
  "Bắc Cường": [
    "bắc cường",
    "bawsc cuwowfng"
  ],
  "Cam Hiệp Nam": [
    "cam hiệp nam",
    "cam hieejp nam"
  ],
  "Cam Hải Tây": [
    "cam hải tây",
    "cam hari taay"
  ],
  "Cam Thành Nam": [
    "cam thành nam",
    "cam thafnh nam"
  ],
  "Chiềng Chung": [
    "chiềng chung",
    "chieefng chung"
  ],
  "Chiềng Châu": [
    "chiềng châu",
    "chieefng chaau"
  ],
  "Chiềng Chăn": [
    "chiềng chăn",
    "chieefng chawn"
  ],
  "Chiềng Công": [
    "chiềng công",
    "chieefng coong"
  ],
  "Chiềng Hắc": [
    "chiềng hắc",
    "chieefng hawsc"
  ],
  "Chiềng Hặc": [
    "chiềng hặc",
    "chieefng hawjc"
  ],
  "Chiềng Muôn": [
    "chiềng muôn",
    "chieefng muoon"
  ],
  "Chiềng Ngàm": [
    "chiềng ngàm",
    "chieefng ngafm"
  ],
  "Chiềng Phung": [
    "chiềng phung",
    "chieefng phung"
  ],
  "Chiềng Pấc": [
    "chiềng pấc",
    "chieefng paasc"
  ],
  "Chiềng Pằn": [
    "chiềng pằn",
    "chieefng pawfn"
  ],
  "Chiềng Sàng": [
    "chiềng sàng",
    "chieefng safng"
  ],
  "Chiềng Sại": [
    "chiềng sại",
    "chieefng saji"
  ],
  "Chiềng Xuân": [
    "chiềng xuân",
    "chieefng xuaan"
  ],
  "Châu Cường": [
    "châu cường",
    "chaau cuwowfng"
  ],
  "Châu Thành A": [
    "châu thành a",
    "chaau thafnh a"
  ],
  "Chư Đăng Ya": [
    "chư đăng ya",
    "chuw ddawng ya"
  ],
  "Chấn Thịnh": [
    "chấn thịnh",
    "chaasn thijnh"
  ],
  "Cái Tàu Hạ": [
    "cái tàu hạ",
    "casi tafu haj"
  ],
  "Cán Chu Phìn": [
    "cán chu phìn",
    "casn chu phifn"
  ],
  "Cúc Đường": [
    "cúc đường",
    "cusc dduwowfng"
  ],
  "Cương Chính": [
    "cương chính",
    "cuwowng chisnh"
  ],
  "Cường Lợi": [
    "cường lợi",
    "cuwowfng lowji"
  ],
  "Cảnh Dương": [
    "cảnh dương",
    "carnh duwowng"
  ],
  "Cần Đước": [
    "cần đước",
    "caafn dduwowsc"
  ],
  "Diên Phước": [
    "diên phước",
    "dieen phuwowsc"
  ],
  "Diễn Nguyên": [
    "diễn nguyên",
    "dieexn nguyeen"
  ],
  "Diễn Quảng": [
    "diễn quảng",
    "dieexn quarng"
  ],
  "Diễn Thịnh": [
    "diễn thịnh",
    "dieexn thijnh"
  ],
  "Diễn Đồng": [
    "diễn đồng",
    "dieexn ddoofng"
  ],
  "Dương Liễu": [
    "dương liễu",
    "duwowng lieexu"
  ],
  "Dương Thành": [
    "dương thành",
    "duwowng thafnh"
  ],
  "Dương Thủy": [
    "dương thủy",
    "duwowng thury"
  ],
  "Dương Đông": [
    "dương đông",
    "duwowng ddoong"
  ],
  "Dương Đức": [
    "dương đức",
    "duwowng dduwsc"
  ],
  "Dế Su Phình": [
    "dế su phình",
    "dees su phifnh"
  ],
  "Gò Công Tây": [
    "gò công tây",
    "gof coong taay"
  ],
  "Hai Bà Trưng": [
    "hai bà trưng",
    "hai baf truwng"
  ],
  "Hiếu Phụng": [
    "hiếu phụng",
    "hieesu phujng"
  ],
  "Hiếu Thuận": [
    "hiếu thuận",
    "hieesu thuaajn"
  ],
  "Hiền Lương": [
    "hiền lương",
    "hieefn luwowng"
  ],
  "Hiệp Thuận": [
    "hiệp thuận",
    "hieejp thuaajn"
  ],
  "Hiệp Thạnh": [
    "hiệp thạnh",
    "hieejp thajnh"
  ],
  "Hiệp Xương": [
    "hiệp xương",
    "hieejp xuwowng"
  ],
  "Hoàng Cương": [
    "hoàng cương",
    "hoafng cuwowng"
  ],
  "Hoàng Lương": [
    "hoàng lương",
    "hoafng luwowng"
  ],
  "Hoàng Su Phì": [
    "hoàng su phì",
    "hoafng su phif"
  ],
  "Hoàng Đồng": [
    "hoàng đồng",
    "hoafng ddoofng"
  ],
  "Hoàng Động": [
    "hoàng động",
    "hoafng ddoojng"
  ],
  "Hoằng Ngọc": [
    "hoằng ngọc",
    "hoawfng ngojc"
  ],
  "Hoằng Thành": [
    "hoằng thành",
    "hoawfng thafnh"
  ],
  "Hoằng Tiến": [
    "hoằng tiến",
    "hoawfng tieesn"
  ],
  "Hoằng Xuyên": [
    "hoằng xuyên",
    "hoawfng xuyeen"
  ],
  "Hoằng Đông": [
    "hoằng đông",
    "hoawfng ddoong"
  ],
  "Hoằng Đại": [
    "hoằng đại",
    "hoawfng ddaji"
  ],
  "Hoằng Đạo": [
    "hoằng đạo",
    "hoawfng ddajo"
  ],
  "Hoằng Đạt": [
    "hoằng đạt",
    "hoawfng ddajt"
  ],
  "Hoằng Đức": [
    "hoằng đức",
    "hoawfng dduwsc"
  ],
  "Huyền Tụng": [
    "huyền tụng",
    "huyeefn tujng"
  ],
  "Hành Phước": [
    "hành phước",
    "hafnh phuwowsc"
  ],
  "Hòa Mỹ Tây": [
    "hòa mỹ tây",
    "hofa myx taay"
  ],
  "Hòa Quang Nam": [
    "hòa quang nam",
    "hofa quang nam"
  ],
  "Hòa Tân Tây": [
    "hòa tân tây",
    "hofa taan taay"
  ],
  "Hòa Xuân Nam": [
    "hòa xuân nam",
    "hofa xuaan nam"
  ],
  "Hóa Thượng": [
    "hóa thượng",
    "hosa thuwowjng"
  ],
  "Hùng Cường": [
    "hùng cường",
    "hufng cuwowfng"
  ],
  "Hưng Phước": [
    "hưng phước",
    "huwng phuwowsc"
  ],
  "Hương Ngải": [
    "hương ngải",
    "huwowng ngari"
  ],
  "Hương Thủy": [
    "hương thủy",
    "huwowng thury"
  ],
  "Hướng Lập": [
    "hướng lập",
    "huwowsng laajp"
  ],
  "Hướng Lộc": [
    "hướng lộc",
    "huwowsng loojc"
  ],
  "Hải Châu  I": [
    "hải châu  i",
    "hari chaau  i"
  ],
  "Hải Châu II": [
    "hải châu ii",
    "hari chaau ii"
  ],
  "Hải Cường": [
    "hải cường",
    "hari cuwowfng"
  ],
  "Hải Phương": [
    "hải phương",
    "hari phuwowng"
  ],
  "Hảo Đước": [
    "hảo đước",
    "haro dduwowsc"
  ],
  "Hồ Chí Minh": [
    "hồ chí minh",
    "hoof chis minh"
  ],
  "Hồng Dương": [
    "hồng dương",
    "hoofng duwowng"
  ],
  "Hồng Thuận": [
    "hồng thuận",
    "hoofng thuaajn"
  ],
  "Hội Thương": [
    "hội thương",
    "hooji thuwowng"
  ],
  "Khuyến Nông": [
    "khuyến nông",
    "khuyeesn noong"
  ],
  "Kháng Chiến": [
    "kháng chiến",
    "khasng chieesn"
  ],
  "Khánh Dương": [
    "khánh dương",
    "khasnh duwowng"
  ],
  "Khánh Thiện": [
    "khánh thiện",
    "khasnh thieejn"
  ],
  "Khánh Thuận": [
    "khánh thuận",
    "khasnh thuaajn"
  ],
  "Khánh Thịnh": [
    "khánh thịnh",
    "khasnh thijnh"
  ],
  "Khương Trung": [
    "khương trung",
    "khuwowng trung"
  ],
  "Kiến Thiết": [
    "kiến thiết",
    "kieesn thieest"
  ],
  "Kiến Xương": [
    "kiến xương",
    "kieesn xuwowng"
  ],
  "Kỳ Thượng": [
    "kỳ thượng",
    "kyf thuwowjng"
  ],
  "Lao Và Chải": [
    "lao và chải",
    "lao vaf chari"
  ],
  "Linh Trường": [
    "linh trường",
    "linh truwowfng"
  ],
  "Liên Phương": [
    "liên phương",
    "lieen phuwowng"
  ],
  "Liệp Tuyết": [
    "liệp tuyết",
    "lieejp tuyeest"
  ],
  "Long Thượng": [
    "long thượng",
    "long thuwowjng"
  ],
  "Long Trường": [
    "long trường",
    "long truwowfng"
  ],
  "Long Điền A": [
    "long điền a",
    "long ddieefn a"
  ],
  "Long Điền B": [
    "long điền b",
    "long ddieefn b"
  ],
  "Lâm Thượng": [
    "lâm thượng",
    "laam thuwowjng"
  ],
  "Lâu Thượng": [
    "lâu thượng",
    "laau thuwowjng"
  ],
  "Lê Minh Xuân": [
    "lê minh xuân",
    "lee minh xuaan"
  ],
  "Lý Thái Tổ": [
    "lý thái tổ",
    "lys thasi toor"
  ],
  "Lương Bằng": [
    "lương bằng",
    "luwowng bawfng"
  ],
  "Lương Hoà A": [
    "lương hoà a",
    "luwowng hoaf a"
  ],
  "Lương Nghĩa": [
    "lương nghĩa",
    "luwowng nghixa"
  ],
  "Lương Quới": [
    "lương quới",
    "luwowng quowsi"
  ],
  "Lương Thông": [
    "lương thông",
    "luwowng thoong"
  ],
  "Lộc Vượng": [
    "lộc vượng",
    "loojc vuwowjng"
  ],
  "Minh Phượng": [
    "minh phượng",
    "minh phuwowjng"
  ],
  "Mường Báng": [
    "mường báng",
    "muwowfng basng"
  ],
  "Mường Chanh": [
    "mường chanh",
    "muwowfng chanh"
  ],
  "Mường Chùm": [
    "mường chùm",
    "muwowfng chufm"
  ],
  "Mường Giôn": [
    "mường giôn",
    "muwowfng gioon"
  ],
  "Mường Hoong": [
    "mường hoong",
    "muwowfng hoong"
  ],
  "Mường Khong": [
    "mường khong",
    "muwowfng khong"
  ],
  "Mường Luân": [
    "mường luân",
    "muwowfng luaan"
  ],
  "Mường Lạn": [
    "mường lạn",
    "muwowfng lajn"
  ],
  "Mường Lầm": [
    "mường lầm",
    "muwowfng laafm"
  ],
  "Mường Lựm": [
    "mường lựm",
    "muwowfng luwjm"
  ],
  "Mường Nọc": [
    "mường nọc",
    "muwowfng nojc"
  ],
  "Mường Pồn": [
    "mường pồn",
    "muwowfng poofn"
  ],
  "Mường Sại": [
    "mường sại",
    "muwowfng saji"
  ],
  "Mường Thanh": [
    "mường thanh",
    "muwowfng thanh"
  ],
  "Mường Thín": [
    "mường thín",
    "muwowfng thisn"
  ],
  "Mường Toong": [
    "mường toong",
    "muwowfng toong"
  ],
  "Mường Tùng": [
    "mường tùng",
    "muwowfng tufng"
  ],
  "Mường Ảng": [
    "mường ảng",
    "muwowfng arng"
  ],
  "Mỹ Quý Tây": [
    "mỹ quý tây",
    "myx quys taay"
  ],
  "Mỹ Tịnh An": [
    "mỹ tịnh an",
    "myx tijnh an"
  ],
  "NT Mộc Châu": [
    "nt mộc châu",
    "nt moojc chaau"
  ],
  "NT Thái Bình": [
    "nt thái bình",
    "nt thasi bifnh"
  ],
  "NT Trần Phú": [
    "nt trần phú",
    "nt traafn phus"
  ],
  "Nam Cát Tiên": [
    "nam cát tiên",
    "nam cast tieen"
  ],
  "Nam Thái Sơn": [
    "nam thái sơn",
    "nam thasi sown"
  ],
  "Nam Từ Liêm": [
    "nam từ liêm",
    "nam tuwf lieem"
  ],
  "Nghi Công Nam": [
    "nghi công nam",
    "nghi coong nam"
  ],
  "Nghi Trường": [
    "nghi trường",
    "nghi truwowfng"
  ],
  "Nghiêm Xuyên": [
    "nghiêm xuyên",
    "nghieem xuyeen"
  ],
  "Nghĩa Hương": [
    "nghĩa hương",
    "nghixa huwowng"
  ],
  "Nghĩa Thuận": [
    "nghĩa thuận",
    "nghixa thuaajn"
  ],
  "Nghĩa Thắng": [
    "nghĩa thắng",
    "nghixa thawsng"
  ],
  "Nghĩa Thịnh": [
    "nghĩa thịnh",
    "nghixa thijnh"
  ],
  "Nghĩa Điền": [
    "nghĩa điền",
    "nghixa ddieefn"
  ],
  "Nghĩa Đồng": [
    "nghĩa đồng",
    "nghixa ddoofng"
  ],
  "Nguyễn Huân": [
    "nguyễn huân",
    "nguyeexn huaan"
  ],
  "Nguyễn Huệ": [
    "nguyễn huệ",
    "nguyeexn hueej"
  ],
  "Nguyễn Phúc": [
    "nguyễn phúc",
    "nguyeexn phusc"
  ],
  "Nguyễn Trãi": [
    "nguyễn trãi",
    "nguyeexn traxi"
  ],
  "Ngọc Chiến": [
    "ngọc chiến",
    "ngojc chieesn"
  ],
  "Ngọc Lương": [
    "ngọc lương",
    "ngojc luwowng"
  ],
  "Ngọc Phụng": [
    "ngọc phụng",
    "ngojc phujng"
  ],
  "Ngọc Thiện": [
    "ngọc thiện",
    "ngojc thieejn"
  ],
  "Ngọc Thuận": [
    "ngọc thuận",
    "ngojc thuaajn"
  ],
  "Ngọc Định": [
    "ngọc định",
    "ngojc ddijnh"
  ],
  "Ngọc Đồng": [
    "ngọc đồng",
    "ngojc ddoofng"
  ],
  "Ngọc Động": [
    "ngọc động",
    "ngojc ddoojng"
  ],
  "Nhuận Đức": [
    "nhuận đức",
    "nhuaajn dduwsc"
  ],
  "Nhuế Dương": [
    "nhuế dương",
    "nhuees duwowng"
  ],
  "Nhơn Nghĩa A": [
    "nhơn nghĩa a",
    "nhown nghixa a"
  ],
  "Ninh Thượng": [
    "ninh thượng",
    "ninh thuwowjng"
  ],
  "Phan Chu Trinh": [
    "phan chu trinh",
    "phan chu trinh"
  ],
  "Phan Rí Cửa": [
    "phan rí cửa",
    "phan ris cuwra"
  ],
  "Phiêng Khoài": [
    "phiêng khoài",
    "phieeng khoafi"
  ],
  "Phiêng Luông": [
    "phiêng luông",
    "phieeng luoong"
  ],
  "Phong Chương": [
    "phong chương",
    "phong chuwowng"
  ],
  "Phù Lưu Tế": [
    "phù lưu tế",
    "phuf luwu tees"
  ],
  "Phùng Nguyên": [
    "phùng nguyên",
    "phufng nguyeen"
  ],
  "Phú Thuận A": [
    "phú thuận a",
    "phus thuaajn a"
  ],
  "Phú Thuận B": [
    "phú thuận b",
    "phus thuaajn b"
  ],
  "Phú Thượng": [
    "phú thượng",
    "phus thuwowjng"
  ],
  "Phúc Thành A": [
    "phúc thành a",
    "phusc thafnh a"
  ],
  "Phăng Sô Lin": [
    "phăng sô lin",
    "phawng soo lin"
  ],
  "Phương Bình": [
    "phương bình",
    "phuwowng bifnh"
  ],
  "Phương Công": [
    "phương công",
    "phuwowng coong"
  ],
  "Phương Hải": [
    "phương hải",
    "phuwowng hari"
  ],
  "Phương Khoan": [
    "phương khoan",
    "phuwowng khoan"
  ],
  "Phương Liên": [
    "phương liên",
    "phuwowng lieen"
  ],
  "Phương Trung": [
    "phương trung",
    "phuwowng trung"
  ],
  "Phương Viên": [
    "phương viên",
    "phuwowng vieen"
  ],
  "Phương Độ": [
    "phương độ",
    "phuwowng ddooj"
  ],
  "Phước Bình": [
    "phước bình",
    "phuwowsc bifnh"
  ],
  "Phước Bửu": [
    "phước bửu",
    "phuwowsc buwru"
  ],
  "Phước Chỉ": [
    "phước chỉ",
    "phuwowsc chir"
  ],
  "Phước Cát ": [
    "phước cát ",
    "phuwowsc cast "
  ],
  "Phước Công": [
    "phước công",
    "phuwowsc coong"
  ],
  "Phước Diêm": [
    "phước diêm",
    "phuwowsc dieem"
  ],
  "Phước Hưng": [
    "phước hưng",
    "phuwowsc huwng"
  ],
  "Phước Hải": [
    "phước hải",
    "phuwowsc hari"
  ],
  "Phước Hảo": [
    "phước hảo",
    "phuwowsc haro"
  ],
  "Phước Hậu": [
    "phước hậu",
    "phuwowsc haaju"
  ],
  "Phước Hội": [
    "phước hội",
    "phuwowsc hooji"
  ],
  "Phước Hữu": [
    "phước hữu",
    "phuwowsc huwxu"
  ],
  "Phước Lại": [
    "phước lại",
    "phuwowsc laji"
  ],
  "Phước Lập": [
    "phước lập",
    "phuwowsc laajp"
  ],
  "Phước Lộc": [
    "phước lộc",
    "phuwowsc loojc"
  ],
  "Phước Lợi": [
    "phước lợi",
    "phuwowsc lowji"
  ],
  "Phước Ngãi": [
    "phước ngãi",
    "phuwowsc ngaxi"
  ],
  "Phước Năng": [
    "phước năng",
    "phuwowsc nawng"
  ],
  "Phước Quang": [
    "phước quang",
    "phuwowsc quang"
  ],
  "Phước Thái": [
    "phước thái",
    "phuwowsc thasi"
  ],
  "Phước Thể": [
    "phước thể",
    "phuwowsc theer"
  ],
  "Phước Trung": [
    "phước trung",
    "phuwowsc trung"
  ],
  "Phước Vĩnh": [
    "phước vĩnh",
    "phuwowsc vixnh"
  ],
  "Phước Xuân": [
    "phước xuân",
    "phuwowsc xuaan"
  ],
  "Phượng Kỳ": [
    "phượng kỳ",
    "phuwowjng kyf"
  ],
  "Phượng Lâu": [
    "phượng lâu",
    "phuwowjng laau"
  ],
  "Phượng Nghi": [
    "phượng nghi",
    "phuwowjng nghi"
  ],
  "Phượng Sơn": [
    "phượng sơn",
    "phuwowjng sown"
  ],
  "Phồn Xương": [
    "phồn xương",
    "phoofn xuwowng"
  ],
  "Phổ Cường": [
    "phổ cường",
    "phoor cuwowfng"
  ],
  "Phụng Hiệp": [
    "phụng hiệp",
    "phujng hieejp"
  ],
  "Pà Vầy Sủ": [
    "pà vầy sủ",
    "paf vaafy sur"
  ],
  "Quyết Tiến": [
    "quyết tiến",
    "quyeest tieesn"
  ],
  "Quảng Bạch": [
    "quảng bạch",
    "quarng bajch"
  ],
  "Quảng Chính": [
    "quảng chính",
    "quarng chisnh"
  ],
  "Quảng Hiệp": [
    "quảng hiệp",
    "quarng hieejp"
  ],
  "Quảng Nghĩa": [
    "quảng nghĩa",
    "quarng nghixa"
  ],
  "Quảng Ngạn": [
    "quảng ngạn",
    "quarng ngajn"
  ],
  "Quảng Ngần": [
    "quảng ngần",
    "quarng ngaafn"
  ],
  "Quảng Ngọc": [
    "quảng ngọc",
    "quarng ngojc"
  ],
  "Quảng Thành": [
    "quảng thành",
    "quarng thafnh"
  ],
  "Quảng Thủy": [
    "quảng thủy",
    "quarng thury"
  ],
  "Quảng Tiến": [
    "quảng tiến",
    "quarng tieesn"
  ],
  "Quảng Trực": [
    "quảng trực",
    "quarng truwjc"
  ],
  "Quảng Đông": [
    "quảng đông",
    "quarng ddoong"
  ],
  "Quảng Đại": [
    "quảng đại",
    "quarng ddaji"
  ],
  "Quảng Đức": [
    "quảng đức",
    "quarng dduwsc"
  ],
  "Quất Động": [
    "quất động",
    "quaast ddoojng"
  ],
  "Quới Thiện": [
    "quới thiện",
    "quowsi thieejn"
  ],
  "Quới Điền": [
    "quới điền",
    "quowsi ddieefn"
  ],
  "Quỳnh Bảng": [
    "quỳnh bảng",
    "quyfnh barng"
  ],
  "Quỳnh Diễn": [
    "quỳnh diễn",
    "quyfnh dieexn"
  ],
  "Quỳnh Hoàng": [
    "quỳnh hoàng",
    "quyfnh hoafng"
  ],
  "Quỳnh Hồng": [
    "quỳnh hồng",
    "quyfnh hoofng"
  ],
  "Quỳnh Nghĩa": [
    "quỳnh nghĩa",
    "quyfnh nghixa"
  ],
  "Quỳnh Ngọc": [
    "quỳnh ngọc",
    "quyfnh ngojc"
  ],
  "Song Phượng": [
    "song phượng",
    "song phuwowjng"
  ],
  "Song Tử Tây": [
    "song tử tây",
    "song tuwr taay"
  ],
  "Suối Quyền": [
    "suối quyền",
    "suoosi quyeefn"
  ],
  "Sà Dề Phìn": [
    "sà dề phìn",
    "saf deef phifn"
  ],
  "Sán Xả Hồ": [
    "sán xả hồ",
    "sasn xar hoof"
  ],
  "Sì Lở Lầu": [
    "sì lở lầu",
    "sif lowr laafu"
  ],
  "Sơn Thượng": [
    "sơn thượng",
    "sown thuwowjng"
  ],
  "Sơn Trường": [
    "sơn trường",
    "sown truwowfng"
  ],
  "Tam Giang Tây": [
    "tam giang tây",
    "tam giang taay"
  ],
  "Tam Quan Bắc": [
    "tam quan bắc",
    "tam quan bawsc"
  ],
  "Thanh Chương": [
    "thanh chương",
    "thanh chuwowng"
  ],
  "Thanh Cường": [
    "thanh cường",
    "thanh cuwowfng"
  ],
  "Thanh Khương": [
    "thanh khương",
    "thanh khuwowng"
  ],
  "Thanh Phước": [
    "thanh phước",
    "thanh phuwowsc"
  ],
  "Thiên Hương": [
    "thiên hương",
    "thieen huwowng"
  ],
  "Thiệu Chính": [
    "thiệu chính",
    "thieeju chisnh"
  ],
  "Thiệu Khánh": [
    "thiệu khánh",
    "thieeju khasnh"
  ],
  "Thiệu Ngọc": [
    "thiệu ngọc",
    "thieeju ngojc"
  ],
  "Thiệu Thành": [
    "thiệu thành",
    "thieeju thafnh"
  ],
  "Thiệu Tiến": [
    "thiệu tiến",
    "thieeju tieesn"
  ],
  "Thuần Thành": [
    "thuần thành",
    "thuaafn thafnh"
  ],
  "Thuận Hạnh": [
    "thuận hạnh",
    "thuaajn hajnh"
  ],
  "Thuận Thiên": [
    "thuận thiên",
    "thuaajn thieen"
  ],
  "Thuận Thành": [
    "thuận thành",
    "thuaajn thafnh"
  ],
  "Thuận Thới": [
    "thuận thới",
    "thuaajn thowsi"
  ],
  "Thuận Đức": [
    "thuận đức",
    "thuaajn dduwsc"
  ],
  "Thuỵ Hương": [
    "thuỵ hương",
    "thuyj huwowng"
  ],
  "Thuỷ Nguyên": [
    "thuỷ nguyên",
    "thuyr nguyeen"
  ],
  "Thuỷ Triều": [
    "thuỷ triều",
    "thuyr trieefu"
  ],
  "Thành Triệu": [
    "thành triệu",
    "thafnh trieeju"
  ],
  "Thái Cường": [
    "thái cường",
    "thasi cuwowfng"
  ],
  "Thái Phương": [
    "thái phương",
    "thasi phuwowng"
  ],
  "Thông Nguyên": [
    "thông nguyên",
    "thoong nguyeen"
  ],
  "Thường Tân": [
    "thường tân",
    "thuwowfng taan"
  ],
  "Thường Tín": [
    "thường tín",
    "thuwowfng tisn"
  ],
  "Thượng Cát": [
    "thượng cát",
    "thuwowjng cast"
  ],
  "Thượng Hòa": [
    "thượng hòa",
    "thuwowjng hofa"
  ],
  "Thượng Hóa": [
    "thượng hóa",
    "thuwowjng hosa"
  ],
  "Thượng Long": [
    "thượng long",
    "thuwowjng long"
  ],
  "Thượng Lâm": [
    "thượng lâm",
    "thuwowjng laam"
  ],
  "Thượng Lộ": [
    "thượng lộ",
    "thuwowjng looj"
  ],
  "Thượng Mỗ": [
    "thượng mỗ",
    "thuwowjng moox"
  ],
  "Thượng Ninh": [
    "thượng ninh",
    "thuwowjng ninh"
  ],
  "Thượng Nung": [
    "thượng nung",
    "thuwowjng nung"
  ],
  "Thượng Quan": [
    "thượng quan",
    "thuwowjng quan"
  ],
  "Thượng Sơn": [
    "thượng sơn",
    "thuwowjng sown"
  ],
  "Thượng Tân": [
    "thượng tân",
    "thuwowjng taan"
  ],
  "Thượng Ấm": [
    "thượng ấm",
    "thuwowjng aasm"
  ],
  "Thạch Khoán": [
    "thạch khoán",
    "thajch khoasn"
  ],
  "Thạch Kiệt": [
    "thạch kiệt",
    "thajch kieejt"
  ],
  "Thạch Ngọc": [
    "thạch ngọc",
    "thajch ngojc"
  ],
  "Thạch Thành": [
    "thạch thành",
    "thajch thafnh"
  ],
  "Thạch Thất": [
    "thạch thất",
    "thajch thaast"
  ],
  "Thạch Đạn": [
    "thạch đạn",
    "thajch ddajn"
  ],
  "Thạnh Nhựt": [
    "thạnh nhựt",
    "thajnh nhuwjt"
  ],
  "Thạnh Quới": [
    "thạnh quới",
    "thajnh quowsi"
  ],
  "Thạnh Tiến": [
    "thạnh tiến",
    "thajnh tieesn"
  ],
  "Thạnh Yên A": [
    "thạnh yên a",
    "thajnh yeen a"
  ],
  "Thạnh Đông": [
    "thạnh đông",
    "thajnh ddoong"
  ],
  "Thạnh Đức": [
    "thạnh đức",
    "thajnh dduwsc"
  ],
  "Thảo Điền": [
    "thảo điền",
    "tharo ddieefn"
  ],
  "Thẩm Dương": [
    "thẩm dương",
    "thaarm duwowng"
  ],
  "Thắng Nhất": [
    "thắng nhất",
    "thawsng nhaast"
  ],
  "Thắng Thuỷ": [
    "thắng thuỷ",
    "thawsng thuyr"
  ],
  "Thịnh Liệt": [
    "thịnh liệt",
    "thijnh lieejt"
  ],
  "Thịnh Thành": [
    "thịnh thành",
    "thijnh thafnh"
  ],
  "Thịnh Đức": [
    "thịnh đức",
    "thijnh dduwsc"
  ],
  "Thọ Cường": [
    "thọ cường",
    "thoj cuwowfng"
  ],
  "Thọ Nghiệp": [
    "thọ nghiệp",
    "thoj nghieejp"
  ],
  "Thống Nhất": [
    "thống nhất",
    "thoosng nhaast"
  ],
  "Thới Thuận": [
    "thới thuận",
    "thowsi thuaajn"
  ],
  "Thới Thạnh": [
    "thới thạnh",
    "thowsi thajnh"
  ],
  "Thục Luyện": [
    "thục luyện",
    "thujc luyeejn"
  ],
  "Thụy Hương": [
    "thụy hương",
    "thujy huwowng"
  ],
  "Thụy Quỳnh": [
    "thụy quỳnh",
    "thujy quyfnh"
  ],
  "Thủy Dương": [
    "thủy dương",
    "thury duwowng"
  ],
  "Thủy Lương": [
    "thủy lương",
    "thury luwowng"
  ],
  "Tiên Cường": [
    "tiên cường",
    "tieen cuwowfng"
  ],
  "Tiên Phương": [
    "tiên phương",
    "tieen phuwowng"
  ],
  "Tiên Phước": [
    "tiên phước",
    "tieen phuwowsc"
  ],
  "Tiến Thắng": [
    "tiến thắng",
    "tieesn thawsng"
  ],
  "Tiến Thịnh": [
    "tiến thịnh",
    "tieesn thijnh"
  ],
  "Triệu Thành": [
    "triệu thành",
    "trieeju thafnh"
  ],
  "Triệu Đại": [
    "triệu đại",
    "trieeju ddaji"
  ],
  "Tràng Lương": [
    "tràng lương",
    "trafng luwowng"
  ],
  "Tràng Định": [
    "tràng định",
    "trafng ddijnh"
  ],
  "Trưng Vương": [
    "trưng vương",
    "truwng vuwowng"
  ],
  "Trường Hòa": [
    "trường hòa",
    "truwowfng hofa"
  ],
  "Trường Long": [
    "trường long",
    "truwowfng long"
  ],
  "Trường Lâm": [
    "trường lâm",
    "truwowfng laam"
  ],
  "Trường Minh": [
    "trường minh",
    "truwowfng minh"
  ],
  "Trường Sinh": [
    "trường sinh",
    "truwowfng sinh"
  ],
  "Trường Sơn": [
    "trường sơn",
    "truwowfng sown"
  ],
  "Trường Tây": [
    "trường tây",
    "truwowfng taay"
  ],
  "Trường Yên": [
    "trường yên",
    "truwowfng yeen"
  ],
  "Trại Chuối": [
    "trại chuối",
    "traji chuoosi"
  ],
  "Trấn Dương": [
    "trấn dương",
    "traasn duwowng"
  ],
  "Trực Thuận": [
    "trực thuận",
    "truwjc thuaajn"
  ],
  "Trực Thắng": [
    "trực thắng",
    "truwjc thawsng"
  ],
  "Tuyên Thạnh": [
    "tuyên thạnh",
    "tuyeen thajnh"
  ],
  "Tuyết Nghĩa": [
    "tuyết nghĩa",
    "tuyeest nghixa"
  ],
  "Tân An Luông": [
    "tân an luông",
    "taan an luoong"
  ],
  "Tân Hòa Tây": [
    "tân hòa tây",
    "taan hofa taay"
  ],
  "Tân Phú Tây": [
    "tân phú tây",
    "taan phus taay"
  ],
  "Tân Phượng": [
    "tân phượng",
    "taan phuwowjng"
  ],
  "Tân Quý Tây": [
    "tân quý tây",
    "taan quys taay"
  ],
  "Tân Sơn Nhì": [
    "tân sơn nhì",
    "taan sown nhif"
  ],
  "Tân Thượng": [
    "tân thượng",
    "taan thuwowjng"
  ],
  "Tân Trường": [
    "tân trường",
    "taan truwowfng"
  ],
  "Tây Yên Tử": [
    "tây yên tử",
    "taay yeen tuwr"
  ],
  "Tông Qua Lìn": [
    "tông qua lìn",
    "toong qua lifn"
  ],
  "Tường Lộc": [
    "tường lộc",
    "tuwowfng loojc"
  ],
  "Tường Phong": [
    "tường phong",
    "tuwowfng phong"
  ],
  "Tượng Lĩnh": [
    "tượng lĩnh",
    "tuwowjng lixnh"
  ],
  "Tả Củ Tỷ": [
    "tả củ tỷ",
    "tar cur tyr"
  ],
  "Tả Gia Khâu": [
    "tả gia khâu",
    "tar gia khaau"
  ],
  "Tả Thanh Oai": [
    "tả thanh oai",
    "tar thanh oai"
  ],
  "Tằng Loỏng": [
    "tằng loỏng",
    "tawfng loorng"
  ],
  "Tịnh Thiện": [
    "tịnh thiện",
    "tijnh thieejn"
  ],
  "Việt Thuận": [
    "việt thuận",
    "vieejt thuaajn"
  ],
  "Việt Thắng": [
    "việt thắng",
    "vieejt thawsng"
  ],
  "Việt Thống": [
    "việt thống",
    "vieejt thoosng"
  ],
  "Vân Trường": [
    "vân trường",
    "vaan truwowfng"
  ],
  "Vĩnh Phương": [
    "vĩnh phương",
    "vixnh phuwowng"
  ],
  "Vĩnh Phước": [
    "vĩnh phước",
    "vixnh phuwowsc"
  ],
  "Vĩnh Tường": [
    "vĩnh tường",
    "vixnh tuwowfng"
  ],
  "Vĩnh Viễn A": [
    "vĩnh viễn a",
    "vixnh vieexn a"
  ],
  "Vượng Lộc": [
    "vượng lộc",
    "vuwowjng loojc"
  ],
  "Vạn Phước": [
    "vạn phước",
    "vajn phuwowsc"
  ],
  "Xuân Phương": [
    "xuân phương",
    "xuaan phuwowng"
  ],
  "Xuân Phước": [
    "xuân phước",
    "xuaan phuwowsc"
  ],
  "Xuân Sơn Nam": [
    "xuân sơn nam",
    "xuaan sown nam"
  ],
  "Xuân Tường": [
    "xuân tường",
    "xuaan tuwowfng"
  ],
  "Yên Thường": [
    "yên thường",
    "yeen thuwowfng"
  ],
  "Yên Thượng": [
    "yên thượng",
    "yeen thuwowjng"
  ],
  "Yên Trường": [
    "yên trường",
    "yeen truwowfng"
  ],
  "Ân Hảo Tây": [
    "ân hảo tây",
    "aan haro taay"
  ],
  "Ô Chợ Dừa": [
    "ô chợ dừa",
    "oo chowj duwfa"
  ],
  "Đan Phượng": [
    "đan phượng",
    "ddan phuwowjng"
  ],
  "Đan Thượng": [
    "đan thượng",
    "ddan thuwowjng"
  ],
  "Đan Trường": [
    "đan trường",
    "ddan truwowfng"
  ],
  "Điêu Lương": [
    "điêu lương",
    "ddieeu luwowng"
  ],
  "Điềm Thụy": [
    "điềm thụy",
    "ddieefm thujy"
  ],
  "Điện Hồng": [
    "điện hồng",
    "ddieejn hoofng"
  ],
  "Điện Ngọc": [
    "điện ngọc",
    "ddieejn ngojc"
  ],
  "Điện Tiến": [
    "điện tiến",
    "ddieejn tieesn"
  ],
  "Đoài Dương": [
    "đoài dương",
    "ddoafi duwowng"
  ],
  "Đông Cương": [
    "đông cương",
    "ddoong cuwowng"
  ],
  "Đông Dương": [
    "đông dương",
    "ddoong duwowng"
  ],
  "Đông Hưng A": [
    "đông hưng a",
    "ddoong huwng a"
  ],
  "Đông Hưng B": [
    "đông hưng b",
    "ddoong huwng b"
  ],
  "Đông Hương": [
    "đông hương",
    "ddoong huwowng"
  ],
  "Đông Hải 1": [
    "đông hải 1",
    "ddoong hari 1"
  ],
  "Đông Hải 2": [
    "đông hải 2",
    "ddoong hari 2"
  ],
  "Đông Lương": [
    "đông lương",
    "ddoong luwowng"
  ],
  "Đông Thuận": [
    "đông thuận",
    "ddoong thuaajn"
  ],
  "Đông Thạnh": [
    "đông thạnh",
    "ddoong thajnh"
  ],
  "Đông Thắng": [
    "đông thắng",
    "ddoong thawsng"
  ],
  "Đông Thịnh": [
    "đông thịnh",
    "ddoong thijnh"
  ],
  "Đông Triều": [
    "đông triều",
    "ddoong trieefu"
  ],
  "Đông Động": [
    "đông động",
    "ddoong ddoojng"
  ],
  "Đăk Tơ Pang": [
    "đăk tơ pang",
    "ddawk tow pang"
  ],
  "Đường Lâm": [
    "đường lâm",
    "dduwowfng laam"
  ],
  "Đạ K' Nàng": [
    "đạ k' nàng",
    "ddaj k' nafng"
  ],
  "Đại Cương": [
    "đại cương",
    "ddaji cuwowng"
  ],
  "Đại Thạnh": [
    "đại thạnh",
    "ddaji thajnh"
  ],
  "Đại Thắng": [
    "đại thắng",
    "ddaji thawsng"
  ],
  "Đại Thịnh": [
    "đại thịnh",
    "ddaji thijnh"
  ],
  "Đại Trạch": [
    "đại trạch",
    "ddaji trajch"
  ],
  "Đại Điền": [
    "đại điền",
    "ddaji ddieefn"
  ],
  "Đại Đồng": [
    "đại đồng",
    "ddaji ddoofng"
  ],
  "Đạo Thạnh": [
    "đạo thạnh",
    "ddajo thajnh"
  ],
  "Đắk Búk So": [
    "đắk búk so",
    "ddawsk busk so"
  ],
  "Đắk N'Drót": [
    "đắk n'drót",
    "ddawsk n'drost"
  ],
  "Đắk R'Lấp": [
    "đắk r'lấp",
    "ddawsk r'laasp"
  ],
  "Đắk R'Măng": [
    "đắk r'măng",
    "ddawsk r'mawng"
  ],
  "Đắk Ruồng": [
    "đắk ruồng",
    "ddawsk ruoofng"
  ],
  "Đắk Rơ Nga": [
    "đắk rơ nga",
    "ddawsk row nga"
  ],
  "Đắk Tờ Re": [
    "đắk tờ re",
    "ddawsk towf re"
  ],
  "Định Hiệp": [
    "định hiệp",
    "ddijnh hieejp"
  ],
  "Định Thành": [
    "định thành",
    "ddijnh thafnh"
  ],
  "Định Thủy": [
    "định thủy",
    "ddijnh thury"
  ],
  "Định Tiến": [
    "định tiến",
    "ddijnh tieesn"
  ],
  "Đồng Khởi": [
    "đồng khởi",
    "ddoofng khowri"
  ],
  "Đồng Thành": [
    "đồng thành",
    "ddoofng thafnh"
  ],
  "Đồng Tiến": [
    "đồng tiến",
    "ddoofng tieesn"
  ],
  "Đồng Việt": [
    "đồng việt",
    "ddoofng vieejt"
  ],
  "Đồng Đăng": [
    "đồng đăng",
    "ddoofng ddawng"
  ],
  "Động Đạt": [
    "động đạt",
    "ddoojng ddajt"
  ],
  "Đức Hương": [
    "đức hương",
    "dduwsc huwowng"
  ],
  "Đức Lương": [
    "đức lương",
    "dduwsc luwowng"
  ],
  "Đức Nhuận": [
    "đức nhuận",
    "dduwsc nhuaajn"
  ],
  "Đức Thuận": [
    "đức thuận",
    "dduwsc thuaajn"
  ],
  "Đức Thạnh": [
    "đức thạnh",
    "dduwsc thajnh"
  ],
  "Đức Thắng": [
    "đức thắng",
    "dduwsc thawsng"
  ],
  "Đức Trạch": [
    "đức trạch",
    "dduwsc trajch"
  ],
  "Đức Trọng": [
    "đức trọng",
    "dduwsc trojng"
  ],
  "Đức Xương": [
    "đức xương",
    "dduwsc xuwowng"
  ],
  "Đức Đồng": [
    "đức đồng",
    "dduwsc ddoofng"
  ],
  "An Hòa Thịnh": [
    "an hòa thịnh",
    "an hofa thijnh"
  ],
  "An Hải Đông": [
    "an hải đông",
    "an hari ddoong"
  ],
  "An Lợi Đông": [
    "an lợi đông",
    "an lowji ddoong"
  ],
  "An Phú Thuận": [
    "an phú thuận",
    "an phus thuaajn"
  ],
  "An Thái Đông": [
    "an thái đông",
    "an thasi ddoong"
  ],
  "An Thạnh Tây": [
    "an thạnh tây",
    "an thajnh taay"
  ],
  "Ba Hàng Đồi": [
    "ba hàng đồi",
    "ba hafng ddoofi"
  ],
  "Bình Hòa Tây": [
    "bình hòa tây",
    "bifnh hofa taay"
  ],
  "Bình Tân Phú": [
    "bình tân phú",
    "bifnh taan phus"
  ],
  "Bạch Long Vĩ": [
    "bạch long vĩ",
    "bajch long vix"
  ],
  "Bế Văn Đàn": [
    "bế văn đàn",
    "bees vawn ddafn"
  ],
  "Cam Phúc Bắc": [
    "cam phúc bắc",
    "cam phusc bawsc"
  ],
  "Chi Lăng Bắc": [
    "chi lăng bắc",
    "chi lawng bawsc"
  ],
  "Chiến Thắng": [
    "chiến thắng",
    "chieesn thawsng"
  ],
  "Chiềng Bằng": [
    "chiềng bằng",
    "chieefng bawfng"
  ],
  "Chiềng Khoang": [
    "chiềng khoang",
    "chieefng khoang"
  ],
  "Chiềng Khoong": [
    "chiềng khoong",
    "chieefng khoong"
  ],
  "Chiềng Khừa": [
    "chiềng khừa",
    "chieefng khuwfa"
  ],
  "Chiềng Ngần": [
    "chiềng ngần",
    "chieefng ngaafn"
  ],
  "Chiềng Đông": [
    "chiềng đông",
    "chieefng ddoong"
  ],
  "Chuyên Ngoại": [
    "chuyên ngoại",
    "chuyeen ngoaji"
  ],
  "Cái Đôi Vàm": [
    "cái đôi vàm",
    "casi ddooi vafm"
  ],
  "Cẩm Nhượng": [
    "cẩm nhượng",
    "caarm nhuwowjng"
  ],
  "Cẩm Thượng": [
    "cẩm thượng",
    "caarm thuwowjng"
  ],
  "Cẩm Đường": [
    "cẩm đường",
    "caarm dduwowfng"
  ],
  "Dư Hàng Kênh": [
    "dư hàng kênh",
    "duw hafng keenh"
  ],
  "Giang Sơn Tây": [
    "giang sơn tây",
    "giang sown taay"
  ],
  "Giồng Riềng": [
    "giồng riềng",
    "gioofng rieefng"
  ],
  "Giục Tượng": [
    "giục tượng",
    "giujc tuwowjng"
  ],
  "Hiệp Cường": [
    "hiệp cường",
    "hieejp cuwowfng"
  ],
  "Hiệp Phước": [
    "hiệp phước",
    "hieejp phuwowsc"
  ],
  "Hoài Thượng": [
    "hoài thượng",
    "hoafi thuwowjng"
  ],
  "Hoằng Thắng": [
    "hoằng thắng",
    "hoawfng thawsng"
  ],
  "Hoằng Thịnh": [
    "hoằng thịnh",
    "hoawfng thijnh"
  ],
  "Hoằng Trạch": [
    "hoằng trạch",
    "hoawfng trajch"
  ],
  "Hoằng Đồng": [
    "hoằng đồng",
    "hoawfng ddoofng"
  ],
  "Hành Tín Tây": [
    "hành tín tây",
    "hafnh tisn taay"
  ],
  "Hòa Hiệp Nam": [
    "hòa hiệp nam",
    "hofa hieejp nam"
  ],
  "Hòa Khánh Nam": [
    "hòa khánh nam",
    "hofa khasnh nam"
  ],
  "Hòa Thọ Tây": [
    "hòa thọ tây",
    "hofa thoj taay"
  ],
  "Hòa Xuân Tây": [
    "hòa xuân tây",
    "hofa xuaan taay"
  ],
  "Hưng Nhượng": [
    "hưng nhượng",
    "huwng nhuwowjng"
  ],
  "Hưng Điền A": [
    "hưng điền a",
    "huwng ddieefn a"
  ],
  "Hưng Điền B": [
    "hưng điền b",
    "huwng ddieefn b"
  ],
  "Hương Nguyên": [
    "hương nguyên",
    "huwowng nguyeen"
  ],
  "Hương Trạch": [
    "hương trạch",
    "huwowng trajch"
  ],
  "Hướng Hiệp": [
    "hướng hiệp",
    "huwowsng hieejp"
  ],
  "Hướng Phùng": [
    "hướng phùng",
    "huwowsng phufng"
  ],
  "Hướng Việt": [
    "hướng việt",
    "huwowsng vieejt"
  ],
  "Hướng Đạo": [
    "hướng đạo",
    "huwowsng ddajo"
  ],
  "Hải Thượng": [
    "hải thượng",
    "hari thuwowjng"
  ],
  "Hải Trường": [
    "hải trường",
    "hari truwowfng"
  ],
  "Hải Đường": [
    "hải đường",
    "hari dduwowfng"
  ],
  "Hậu Mỹ Phú": [
    "hậu mỹ phú",
    "haaju myx phus"
  ],
  "Hồ Thị Kỷ": [
    "hồ thị kỷ",
    "hoof thij kyr"
  ],
  "Hồng Phương": [
    "hồng phương",
    "hoofng phuwowng"
  ],
  "Hội An Đông": [
    "hội an đông",
    "hooji an ddoong"
  ],
  "Khánh Cường": [
    "khánh cường",
    "khasnh cuwowfng"
  ],
  "Khương Đình": [
    "khương đình",
    "khuwowng ddifnh"
  ],
  "Kiến Tường": [
    "kiến tường",
    "kieesn tuwowfng"
  ],
  "Lao Xả Phình": [
    "lao xả phình",
    "lao xar phifnh"
  ],
  "Liên Trường": [
    "liên trường",
    "lieen truwowfng"
  ],
  "Long Bình Tân": [
    "long bình tân",
    "long bifnh taan"
  ],
  "Long Hựu Tây": [
    "long hựu tây",
    "long huwju taay"
  ],
  "Long Thành Nam": [
    "long thành nam",
    "long thafnh nam"
  ],
  "Láng Thượng": [
    "láng thượng",
    "lasng thuwowjng"
  ],
  "Lưu Vĩnh Sơn": [
    "lưu vĩnh sơn",
    "luwu vixnh sown"
  ],
  "Lương An Trà": [
    "lương an trà",
    "luwowng an traf"
  ],
  "Lương Ngoại": [
    "lương ngoại",
    "luwowng ngoaji"
  ],
  "Lương Thiện": [
    "lương thiện",
    "luwowng thieejn"
  ],
  "Lương Thịnh": [
    "lương thịnh",
    "luwowng thijnh"
  ],
  "Lương Điền": [
    "lương điền",
    "luwowng ddieefn"
  ],
  "Lại Thượng": [
    "lại thượng",
    "laji thuwowjng"
  ],
  "Mường Bằng": [
    "mường bằng",
    "muwowfng bawfng"
  ],
  "Mường Chiên": [
    "mường chiên",
    "muwowfng chieen"
  ],
  "Mường Giàng": [
    "mường giàng",
    "muwowfng giafng"
  ],
  "Mường Lống": [
    "mường lống",
    "muwowfng loosng"
  ],
  "Mường Mươn": [
    "mường mươn",
    "muwowfng muwown"
  ],
  "Mường Phăng": [
    "mường phăng",
    "muwowfng phawng"
  ],
  "Mường Thải": [
    "mường thải",
    "muwowfng thari"
  ],
  "Mường Đăng": [
    "mường đăng",
    "muwowfng ddawng"
  ],
  "Mỏ Cày Bắc": [
    "mỏ cày bắc",
    "mor cafy bawsc"
  ],
  "Mỹ An Hưng A": [
    "mỹ an hưng a",
    "myx an huwng a"
  ],
  "Mỹ An Hưng B": [
    "mỹ an hưng b",
    "myx an huwng b"
  ],
  "Mỹ Hoà Hưng": [
    "mỹ hoà hưng",
    "myx hoaf huwng"
  ],
  "Mỹ Hạnh Nam": [
    "mỹ hạnh nam",
    "myx hajnh nam"
  ],
  "Mỹ Long Bắc": [
    "mỹ long bắc",
    "myx long bawsc"
  ],
  "Mỹ Thành Nam": [
    "mỹ thành nam",
    "myx thafnh nam"
  ],
  "Mỹ Thạnh An": [
    "mỹ thạnh an",
    "myx thajnh an"
  ],
  "N.T Phong Hải": [
    "n.t phong hải",
    "n.t phong hari"
  ],
  "NT Việt Trung": [
    "nt việt trung",
    "nt vieejt trung"
  ],
  "Nghinh Tường": [
    "nghinh tường",
    "nghinh tuwowfng"
  ],
  "Nghĩa Phương": [
    "nghĩa phương",
    "nghixa phuwowng"
  ],
  "Nghĩa Thương": [
    "nghĩa thương",
    "nghixa thuwowng"
  ],
  "Nguyễn Phích": [
    "nguyễn phích",
    "nguyeexn phisch"
  ],
  "Nguyệt Đức": [
    "nguyệt đức",
    "nguyeejt dduwsc"
  ],
  "Ngũ Chỉ Sơn": [
    "ngũ chỉ sơn",
    "ngux chir sown"
  ],
  "Ngũ Hành Sơn": [
    "ngũ hành sơn",
    "ngux hafnh sown"
  ],
  "Nhuận Trạch": [
    "nhuận trạch",
    "nhuaajn trajch"
  ],
  "Nhị Long Phú": [
    "nhị long phú",
    "nhij long phus"
  ],
  "Nhị Trường": [
    "nhị trường",
    "nhij truwowfng"
  ],
  "Nông Thượng": [
    "nông thượng",
    "noong thuwowjng"
  ],
  "Nông Trường": [
    "nông trường",
    "noong truwowfng"
  ],
  "Phan Rí Thành": [
    "phan rí thành",
    "phan ris thafnh"
  ],
  "Phong Dụ Hạ": [
    "phong dụ hạ",
    "phong duj haj"
  ],
  "Phong Thạnh A": [
    "phong thạnh a",
    "phong thajnh a"
  ],
  "Phú Mỹ Hưng": [
    "phú mỹ hưng",
    "phus myx huwng"
  ],
  "Phú Thọ Hòa": [
    "phú thọ hòa",
    "phus thoj hofa"
  ],
  "Phương Liễu": [
    "phương liễu",
    "phuwowng lieexu"
  ],
  "Phương Liệt": [
    "phương liệt",
    "phuwowng lieejt"
  ],
  "Phương Tiến": [
    "phương tiến",
    "phuwowng tieesn"
  ],
  "Phương Đình": [
    "phương đình",
    "phuwowng ddifnh"
  ],
  "Phương Đông": [
    "phương đông",
    "phuwowng ddoong"
  ],
  "Phước Chánh": [
    "phước chánh",
    "phuwowsc chasnh"
  ],
  "Phước Chính": [
    "phước chính",
    "phuwowsc chisnh"
  ],
  "Phước Cát 2": [
    "phước cát 2",
    "phuwowsc cast 2"
  ],
  "Phước Hiệp": [
    "phước hiệp",
    "phuwowsc hieejp"
  ],
  "Phước Kháng": [
    "phước kháng",
    "phuwowsc khasng"
  ],
  "Phước Khánh": [
    "phước khánh",
    "phuwowsc khasnh"
  ],
  "Phước Kiển": [
    "phước kiển",
    "phuwowsc kieern"
  ],
  "Phước Long A": [
    "phước long a",
    "phuwowsc long a"
  ],
  "Phước Long B": [
    "phước long b",
    "phuwowsc long b"
  ],
  "Phước Nghĩa": [
    "phước nghĩa",
    "phuwowsc nghixa"
  ],
  "Phước Thành": [
    "phước thành",
    "phuwowsc thafnh"
  ],
  "Phước Thới": [
    "phước thới",
    "phuwowsc thowsi"
  ],
  "Phước Tiến": [
    "phước tiến",
    "phuwowsc tieesn"
  ],
  "Phước Tỉnh": [
    "phước tỉnh",
    "phuwowsc tirnh"
  ],
  "Phước Đông": [
    "phước đông",
    "phuwowsc ddoong"
  ],
  "Phước Đại": [
    "phước đại",
    "phuwowsc ddaji"
  ],
  "Phước Đức": [
    "phước đức",
    "phuwowsc dduwsc"
  ],
  "Phường Đúc": [
    "phường đúc",
    "phuwowfng ddusc"
  ],
  "Phượng Cách": [
    "phượng cách",
    "phuwowjng casch"
  ],
  "Phượng Dực": [
    "phượng dực",
    "phuwowjng duwjc"
  ],
  "Phạm Văn Hai": [
    "phạm văn hai",
    "phajm vawn hai"
  ],
  "Quyết Chiến": [
    "quyết chiến",
    "quyeest chieesn"
  ],
  "Quyết Thắng": [
    "quyết thắng",
    "quyeest thawsng"
  ],
  "Quảng Nguyên": [
    "quảng nguyên",
    "quarng nguyeen"
  ],
  "Quảng Thuận": [
    "quảng thuận",
    "quarng thuaajn"
  ],
  "Quảng Thạch": [
    "quảng thạch",
    "quarng thajch"
  ],
  "Quảng Thắng": [
    "quảng thắng",
    "quarng thawsng"
  ],
  "Quảng Thịnh": [
    "quảng thịnh",
    "quarng thijnh"
  ],
  "Quảng Trạch": [
    "quảng trạch",
    "quarng trajch"
  ],
  "Quảng Xương": [
    "quảng xương",
    "quarng xuwowng"
  ],
  "Quảng Điền": [
    "quảng điền",
    "quarng ddieefn"
  ],
  "Quảng Định": [
    "quảng định",
    "quarng ddijnh"
  ],
  "Quỳnh Lương": [
    "quỳnh lương",
    "quyfnh luwowng"
  ],
  "Quỳnh Nguyên": [
    "quỳnh nguyên",
    "quyfnh nguyeen"
  ],
  "Quỳnh Thiện": [
    "quỳnh thiện",
    "quyfnh thieejn"
  ],
  "Quỳnh Thuận": [
    "quỳnh thuận",
    "quyfnh thuaajn"
  ],
  "Quỳnh Thạch": [
    "quỳnh thạch",
    "quyfnh thajch"
  ],
  "Quỳnh Thắng": [
    "quỳnh thắng",
    "quyfnh thawsng"
  ],
  "Sin Suối Hồ": [
    "sin suối hồ",
    "sin suoosi hoof"
  ],
  "Tam Mỹ Đông": [
    "tam mỹ đông",
    "tam myx ddoong"
  ],
  "Thanh Khê Tây": [
    "thanh khê tây",
    "thanh khee taay"
  ],
  "Thanh Phú Long": [
    "thanh phú long",
    "thanh phus long"
  ],
  "Thanh Trường": [
    "thanh trường",
    "thanh truwowfng"
  ],
  "Thanh Xuân Nam": [
    "thanh xuân nam",
    "thanh xuaan nam"
  ],
  "Thiện Phiến": [
    "thiện phiến",
    "thieejn phieesn"
  ],
  "Thiện Thuật": [
    "thiện thuật",
    "thieejn thuaajt"
  ],
  "Thiệu Dương": [
    "thiệu dương",
    "thieeju duwowng"
  ],
  "Thiệu Nguyên": [
    "thiệu nguyên",
    "thieeju nguyeen"
  ],
  "Thiệu Thịnh": [
    "thiệu thịnh",
    "thieeju thijnh"
  ],
  "Thuần Thiện": [
    "thuần thiện",
    "thuaafn thieejn"
  ],
  "Thuận Điền": [
    "thuận điền",
    "thuaajn ddieefn"
  ],
  "Thành Phước": [
    "thành phước",
    "thafnh phuwowsc"
  ],
  "Thành Thới A": [
    "thành thới a",
    "thafnh thowsi a"
  ],
  "Thành Thới B": [
    "thành thới b",
    "thafnh thowsi b"
  ],
  "Thái Thượng": [
    "thái thượng",
    "thasi thuwowjng"
  ],
  "Thèn Chu Phìn": [
    "thèn chu phìn",
    "thefn chu phifn"
  ],
  "Thăng Phước": [
    "thăng phước",
    "thawng phuwowsc"
  ],
  "Thường Lạc": [
    "thường lạc",
    "thuwowfng lajc"
  ],
  "Thường Xuân": [
    "thường xuân",
    "thuwowfng xuaan"
  ],
  "Thượng Bình": [
    "thượng bình",
    "thuwowjng bifnh"
  ],
  "Thượng Cốc": [
    "thượng cốc",
    "thuwowjng coosc"
  ],
  "Thượng Cửu": [
    "thượng cửu",
    "thuwowjng cuwru"
  ],
  "Thượng Giáo": [
    "thượng giáo",
    "thuwowjng giaso"
  ],
  "Thượng Giáp": [
    "thượng giáp",
    "thuwowjng giasp"
  ],
  "Thượng Lộc": [
    "thượng lộc",
    "thuwowjng loojc"
  ],
  "Thượng Nông": [
    "thượng nông",
    "thuwowjng noong"
  ],
  "Thượng Thanh": [
    "thượng thanh",
    "thuwowjng thanh"
  ],
  "Thượng Thôn": [
    "thượng thôn",
    "thuwowjng thoon"
  ],
  "Thượng Vực": [
    "thượng vực",
    "thuwowjng vuwjc"
  ],
  "Thạch Lương": [
    "thạch lương",
    "thajch luwowng"
  ],
  "Thạch Quảng": [
    "thạch quảng",
    "thajch quarng"
  ],
  "Thạch Thắng": [
    "thạch thắng",
    "thajch thawsng"
  ],
  "Thạch Định": [
    "thạch định",
    "thajch ddijnh"
  ],
  "Thạch Đồng": [
    "thạch đồng",
    "thajch ddoofng"
  ],
  "Thạnh Qưới": [
    "thạnh qưới",
    "thajnh quwowsi"
  ],
  "Thạnh Thắng": [
    "thạnh thắng",
    "thajnh thawsng"
  ],
  "Thới An Hội": [
    "thới an hội",
    "thowsi an hooji"
  ],
  "Thụy Phương": [
    "thụy phương",
    "thujy phuwowng"
  ],
  "Thủy Phương": [
    "thủy phương",
    "thury phuwowng"
  ],
  "Triệu Nguyên": [
    "triệu nguyên",
    "trieeju nguyeen"
  ],
  "Triệu Thuận": [
    "triệu thuận",
    "trieeju thuaajn"
  ],
  "Triệu Trạch": [
    "triệu trạch",
    "trieeju trajch"
  ],
  "Trung Mỹ Tây": [
    "trung mỹ tây",
    "trung myx taay"
  ],
  "Trung Thượng": [
    "trung thượng",
    "trung thuwowjng"
  ],
  "Trường Chinh": [
    "trường chinh",
    "truwowfng chinh"
  ],
  "Trường Giang": [
    "trường giang",
    "truwowfng giang"
  ],
  "Trường Lạc": [
    "trường lạc",
    "truwowfng lajc"
  ],
  "Trường Thọ": [
    "trường thọ",
    "truwowfng thoj"
  ],
  "Trường Trung": [
    "trường trung",
    "truwowfng trung"
  ],
  "Trường Xuân": [
    "trường xuân",
    "truwowfng xuaan"
  ],
  "Trực Cường": [
    "trực cường",
    "truwjc cuwowfng"
  ],
  "Tân An Thạnh": [
    "tân an thạnh",
    "taan an thajnh"
  ],
  "Tân Công Chí": [
    "tân công chí",
    "taan coong chis"
  ],
  "Tân Hưng Tây": [
    "tân hưng tây",
    "taan huwng taay"
  ],
  "Tân Long Hội": [
    "tân long hội",
    "taan long hooji"
  ],
  "Tân Lý Đông": [
    "tân lý đông",
    "taan lys ddoong"
  ],
  "Tân Phú Trung": [
    "tân phú trung",
    "taan phus trung"
  ],
  "Tân Quy Đông": [
    "tân quy đông",
    "taan quy ddoong"
  ],
  "Tân Thanh Tây": [
    "tân thanh tây",
    "taan thanh taay"
  ],
  "Tương Dương": [
    "tương dương",
    "tuwowng duwowng"
  ],
  "Tường Tiến": [
    "tường tiến",
    "tuwowfng tieesn"
  ],
  "Viên An Đông": [
    "viên an đông",
    "vieen an ddoong"
  ],
  "Việt Cường": [
    "việt cường",
    "vieejt cuwowfng"
  ],
  "Vàng Ma Chải": [
    "vàng ma chải",
    "vafng ma chari"
  ],
  "Vĩnh Bình Nam": [
    "vĩnh bình nam",
    "vixnh bifnh nam"
  ],
  "Vĩnh Hoà Phú": [
    "vĩnh hoà phú",
    "vixnh hoaf phus"
  ],
  "Vĩnh Phú Tây": [
    "vĩnh phú tây",
    "vixnh phus taay"
  ],
  "Vĩnh Trường": [
    "vĩnh trường",
    "vixnh truwowfng"
  ],
  "Xuân Thượng": [
    "xuân thượng",
    "xuaan thuwowjng"
  ],
  "Xuân Trường": [
    "xuân trường",
    "xuaan truwowfng"
  ],
  "Xuân Đường": [
    "xuân đường",
    "xuaan dduwowfng"
  ],
  "Xương Thịnh": [
    "xương thịnh",
    "xuwowng thijnh"
  ],
  "Điền Hương": [
    "điền hương",
    "ddieefn huwowng"
  ],
  "Điện Dương": [
    "điện dương",
    "ddieejn duwowng"
  ],
  "Đông Cường": [
    "đông cường",
    "ddoong cuwowfng"
  ],
  "Đông Phương": [
    "đông phương",
    "ddoong phuwowng"
  ],
  "Đông Phước": [
    "đông phước",
    "ddoong phuwowsc"
  ],
  "Đại Cường": [
    "đại cường",
    "ddaji cuwowfng"
  ],
  "Đại Phước": [
    "đại phước",
    "ddaji phuwowsc"
  ],
  "Đắk Kơ Ning": [
    "đắk kơ ning",
    "ddawsk kow ning"
  ],
  "Đắk Rơ Ông": [
    "đắk rơ ông",
    "ddawsk row oong"
  ],
  "Đắk Tơ Lung": [
    "đắk tơ lung",
    "ddawsk tow lung"
  ],
  "Đắk Tờ Kan": [
    "đắk tờ kan",
    "ddawsk towf kan"
  ],
  "Đặng Cương": [
    "đặng cương",
    "ddawjng cuwowng"
  ],
  "Đồng Cương": [
    "đồng cương",
    "ddoofng cuwowng"
  ],
  "Đồng Lương": [
    "đồng lương",
    "ddoofng luwowng"
  ],
  "Đồng Nguyên": [
    "đồng nguyên",
    "ddoofng nguyeen"
  ],
  "Đồng Ruộng": [
    "đồng ruộng",
    "ddoofng ruoojng"
  ],
  "Đồng Thạnh": [
    "đồng thạnh",
    "ddoofng thajnh"
  ],
  "Đồng Thắng": [
    "đồng thắng",
    "ddoofng thawsng"
  ],
  "Đồng Thịnh": [
    "đồng thịnh",
    "ddoofng thijnh"
  ],
  "Đồng Trạch": [
    "đồng trạch",
    "ddoofng trajch"
  ],
  "Đồng Tuyển": [
    "đồng tuyển",
    "ddoofng tuyeern"
  ],
  "Đồng Vương": [
    "đồng vương",
    "ddoofng vuwowng"
  ],
  "An Quảng Hữu": [
    "an quảng hữu",
    "an quarng huwxu"
  ],
  "An Thạnh Trung": [
    "an thạnh trung",
    "an thajnh trung"
  ],
  "An Thới Đông": [
    "an thới đông",
    "an thowsi ddoong"
  ],
  "Buôn Ma Thuột": [
    "buôn ma thuột",
    "buoon ma thuoojt"
  ],
  "Bát Đại Sơn": [
    "bát đại sơn",
    "bast ddaji sown"
  ],
  "Bình Hàng Tây": [
    "bình hàng tây",
    "bifnh hafng taay"
  ],
  "Bình Hòa Bắc": [
    "bình hòa bắc",
    "bifnh hofa bawsc"
  ],
  "Bình Hòa Hưng": [
    "bình hòa hưng",
    "bifnh hofa huwng"
  ],
  "Bình Hòa Trung": [
    "bình hòa trung",
    "bifnh hofa trung"
  ],
  "Bình Hưng Hòa": [
    "bình hưng hòa",
    "bifnh huwng hofa"
  ],
  "Bùi Thị Xuân": [
    "bùi thị xuân",
    "bufi thij xuaan"
  ],
  "Bạch Thượng": [
    "bạch thượng",
    "bajch thuwowjng"
  ],
  "Bần Yên Nhân": [
    "bần yên nhân",
    "baafn yeen nhaan"
  ],
  "Bắc Tân Uyên": [
    "bắc tân uyên",
    "bawsc taan uyeen"
  ],
  "Bắc Từ Liêm": [
    "bắc từ liêm",
    "bawsc tuwf lieem"
  ],
  "Cam Hiệp Bắc": [
    "cam hiệp bắc",
    "cam hieejp bawsc"
  ],
  "Cam Hải Đông": [
    "cam hải đông",
    "cam hari ddoong"
  ],
  "Cam Thành Bắc": [
    "cam thành bắc",
    "cam thafnh bawsc"
  ],
  "Cam Thịnh Tây": [
    "cam thịnh tây",
    "cam thijnh taay"
  ],
  "Chiềng Lương": [
    "chiềng lương",
    "chieefng luwowng"
  ],
  "Chiềng Tương": [
    "chiềng tương",
    "chieefng tuwowng"
  ],
  "Chánh Phú Hòa": [
    "chánh phú hòa",
    "chasnh phus hofa"
  ],
  "Châu Quế Hạ": [
    "châu quế hạ",
    "chaau quees haj"
  ],
  "Châu Văn Liêm": [
    "châu văn liêm",
    "chaau vawn lieem"
  ],
  "Chương Dương": [
    "chương dương",
    "chuwowng duwowng"
  ],
  "Cường Thịnh": [
    "cường thịnh",
    "cuwowfng thijnh"
  ],
  "Cầu Ông Lãnh": [
    "cầu ông lãnh",
    "caafu oong laxnh"
  ],
  "Diễn Trường": [
    "diễn trường",
    "dieexn truwowfng"
  ],
  "Dưỡng Điềm": [
    "dưỡng điềm",
    "duwowxng ddieefm"
  ],
  "Giàng Chu Phìn": [
    "giàng chu phìn",
    "giafng chu phifn"
  ],
  "Gò Công Đông": [
    "gò công đông",
    "gof coong ddoong"
  ],
  "Hiệp Mỹ Tây": [
    "hiệp mỹ tây",
    "hieejp myx taay"
  ],
  "Hoài Thanh Tây": [
    "hoài thanh tây",
    "hoafi thanh taay"
  ],
  "Hoàng Hoa Thám": [
    "hoàng hoa thám",
    "hoafng hoa thasm"
  ],
  "Hoàng Thu Phố": [
    "hoàng thu phố",
    "hoafng thu phoos"
  ],
  "Hàm Thuận Nam": [
    "hàm thuận nam",
    "hafm thuaajn nam"
  ],
  "Hòa Khánh Tây": [
    "hòa khánh tây",
    "hofa khasnh taay"
  ],
  "Hòa Mỹ Đông": [
    "hòa mỹ đông",
    "hofa myx ddoong"
  ],
  "Hòa Quang Bắc": [
    "hòa quang bắc",
    "hofa quang bawsc"
  ],
  "Hòa Tân Đông": [
    "hòa tân đông",
    "hofa taan ddoong"
  ],
  "Hưng Yên Bắc": [
    "hưng yên bắc",
    "huwng yeen bawsc"
  ],
  "Hậu Mỹ Trinh": [
    "hậu mỹ trinh",
    "haaju myx trinh"
  ],
  "Hồ Tùng Mậu": [
    "hồ tùng mậu",
    "hoof tufng maaju"
  ],
  "Hồng Thượng": [
    "hồng thượng",
    "hoofng thuwowjng"
  ],
  "Khánh Thượng": [
    "khánh thượng",
    "khasnh thuwowjng"
  ],
  "Khánh Yên Hạ": [
    "khánh yên hạ",
    "khasnh yeen haj"
  ],
  "Kiểng Phước": [
    "kiểng phước",
    "kieerng phuwowsc"
  ],
  "Lê Hồng Phong": [
    "lê hồng phong",
    "lee hoofng phong"
  ],
  "Lê Thanh Nghị": [
    "lê thanh nghị",
    "lee thanh nghij"
  ],
  "Lê Đại Hành": [
    "lê đại hành",
    "lee ddaji hafnh"
  ],
  "Lả Nhì Thàng": [
    "lả nhì thàng",
    "lar nhif thafng"
  ],
  "Mù Căng Chải": [
    "mù căng chải",
    "muf cawng chari"
  ],
  "Mường Khiêng": [
    "mường khiêng",
    "muwowfng khieeng"
  ],
  "Mỹ Chánh Tây": [
    "mỹ chánh tây",
    "myx chasnh taay"
  ],
  "Mỹ Hiệp Sơn": [
    "mỹ hiệp sơn",
    "myx hieejp sown"
  ],
  "Mỹ Phú Đông": [
    "mỹ phú đông",
    "myx phus ddoong"
  ],
  "Mỹ Quý Đông": [
    "mỹ quý đông",
    "myx quys ddoong"
  ],
  "Mỹ Đức Tây": [
    "mỹ đức tây",
    "myx dduwsc taay"
  ],
  "Nam Phúc Thăng": [
    "nam phúc thăng",
    "nam phusc thawng"
  ],
  "Nghi Công Bắc": [
    "nghi công bắc",
    "nghi coong bawsc"
  ],
  "Nguyễn An Ninh": [
    "nguyễn an ninh",
    "nguyeexn an ninh"
  ],
  "Nguyễn Nghiêm": [
    "nguyễn nghiêm",
    "nguyeexn nghieem"
  ],
  "Ngọc Đường": [
    "ngọc đường",
    "ngojc dduwowfng"
  ],
  "Nhơn Hòa Lập": [
    "nhơn hòa lập",
    "nhown hofa laajp"
  ],
  "Phan Bội Châu": [
    "phan bội châu",
    "phan booji chaau"
  ],
  "Phú Hòa Đông": [
    "phú hòa đông",
    "phus hofa ddoong"
  ],
  "Phú Ngãi Trị": [
    "phú ngãi trị",
    "phus ngaxi trij"
  ],
  "Phương Chiểu": [
    "phương chiểu",
    "phuwowng chieeru"
  ],
  "Phương Thiện": [
    "phương thiện",
    "phuwowng thieejn"
  ],
  "Phương Thạnh": [
    "phương thạnh",
    "phuwowng thajnh"
  ],
  "Phương Thịnh": [
    "phương thịnh",
    "phuwowng thijnh"
  ],
  "Phương Định": [
    "phương định",
    "phuwowng ddijnh"
  ],
  "Phước Chiến": [
    "phước chiến",
    "phuwowsc chieesn"
  ],
  "Phước Nguyên": [
    "phước nguyên",
    "phuwowsc nguyeen"
  ],
  "Phước Thiền": [
    "phước thiền",
    "phuwowsc thieefn"
  ],
  "Phước Thiện": [
    "phước thiện",
    "phuwowsc thieejn"
  ],
  "Phước Thuận": [
    "phước thuận",
    "phuwowsc thuaajn"
  ],
  "Phước Thạnh": [
    "phước thạnh",
    "phuwowsc thajnh"
  ],
  "Phước Thắng": [
    "phước thắng",
    "phuwowsc thawsng"
  ],
  "Phước Trạch": [
    "phước trạch",
    "phuwowsc trajch"
  ],
  "Phước Đồng": [
    "phước đồng",
    "phuwowsc ddoofng"
  ],
  "Phượng Tiến": [
    "phượng tiến",
    "phuwowjng tieesn"
  ],
  "Phạm Ngũ Lão": [
    "phạm ngũ lão",
    "phajm ngux laxo"
  ],
  "Pá Ma Pha Khinh": [
    "pá ma pha khinh",
    "pas ma pha khinh"
  ],
  "Quan Hồ Thẩn": [
    "quan hồ thẩn",
    "quan hoof thaarn"
  ],
  "Quảng Nghiệp": [
    "quảng nghiệp",
    "quarng nghieejp"
  ],
  "Quảng Phương": [
    "quảng phương",
    "quarng phuwowng"
  ],
  "Quảng Phước": [
    "quảng phước",
    "quarng phuwowsc"
  ],
  "Quỳnh Phương": [
    "quỳnh phương",
    "quyfnh phuwowng"
  ],
  "Sơn Thành Tây": [
    "sơn thành tây",
    "sown thafnh taay"
  ],
  "Tam Giang Đông": [
    "tam giang đông",
    "tam giang ddoong"
  ],
  "Tam Thôn Hiệp": [
    "tam thôn hiệp",
    "tam thoon hieejp"
  ],
  "Thiện Nghiệp": [
    "thiện nghiệp",
    "thieejn nghieejp"
  ],
  "Thuận Phước": [
    "thuận phước",
    "thuaajn phuwowsc"
  ],
  "Thuỷ Đường": [
    "thuỷ đường",
    "thuyr dduwowfng"
  ],
  "Thào Chư Phìn": [
    "thào chư phìn",
    "thafo chuw phifn"
  ],
  "Thượng Hiền": [
    "thượng hiền",
    "thuwowjng hieefn"
  ],
  "Thượng Kiệm": [
    "thượng kiệm",
    "thuwowjng kieejm"
  ],
  "Thượng Nhật": [
    "thượng nhật",
    "thuwowjng nhaajt"
  ],
  "Thượng Phùng": [
    "thượng phùng",
    "thuwowjng phufng"
  ],
  "Thượng Quận": [
    "thượng quận",
    "thuwowjng quaajn"
  ],
  "Thượng Trưng": [
    "thượng trưng",
    "thuwowjng truwng"
  ],
  "Thượng Đình": [
    "thượng đình",
    "thuwowjng ddifnh"
  ],
  "Thạch Tượng": [
    "thạch tượng",
    "thajch tuwowjng"
  ],
  "Thạnh Phước": [
    "thạnh phước",
    "thajnh phuwowsc"
  ],
  "Thạnh Đông A": [
    "thạnh đông a",
    "thajnh ddoong a"
  ],
  "Thạnh Đông B": [
    "thạnh đông b",
    "thajnh ddoong b"
  ],
  "Thịnh Vượng": [
    "thịnh vượng",
    "thijnh vuwowjng"
  ],
  "Thới An Đông": [
    "thới an đông",
    "thowsi an ddoong"
  ],
  "Thới Tam Thôn": [
    "thới tam thôn",
    "thowsi tam thoon"
  ],
  "Thụy Trường": [
    "thụy trường",
    "thujy truwowfng"
  ],
  "Triệu Phước": [
    "triệu phước",
    "trieeju phuwowsc"
  ],
  "Trung Lèng Hồ": [
    "trung lèng hồ",
    "trung lefng hoof"
  ],
  "Trung Lập Hạ": [
    "trung lập hạ",
    "trung laajp haj"
  ],
  "Trương Lương": [
    "trương lương",
    "truwowng luwowng"
  ],
  "Trương Định": [
    "trương định",
    "truwowng ddijnh"
  ],
  "Trường Khánh": [
    "trường khánh",
    "truwowfng khasnh"
  ],
  "Trường Long A": [
    "trường long a",
    "truwowfng long a"
  ],
  "Trường Thành": [
    "trường thành",
    "truwowfng thafnh"
  ],
  "Trường Thủy": [
    "trường thủy",
    "truwowfng thury"
  ],
  "Trường Đông": [
    "trường đông",
    "truwowfng ddoong"
  ],
  "Trịnh Tường": [
    "trịnh tường",
    "trijnh tuwowfng"
  ],
  "Trừ Văn Thố": [
    "trừ văn thố",
    "truwf vawn thoos"
  ],
  "Tung Chung Phố": [
    "tung chung phố",
    "tung chung phoos"
  ],
  "Tân Công Sính": [
    "tân công sính",
    "taan coong sisnh"
  ],
  "Tân Hòa Thành": [
    "tân hòa thành",
    "taan hofa thafnh"
  ],
  "Tân Hòa Đông": [
    "tân hòa đông",
    "taan hofa ddoong"
  ],
  "Tân Hội Trung": [
    "tân hội trung",
    "taan hooji trung"
  ],
  "Tân Khánh Hòa": [
    "tân khánh hòa",
    "taan khasnh hofa"
  ],
  "Tân Lộc Bắc": [
    "tân lộc bắc",
    "taan loojc bawsc"
  ],
  "Tân Mỹ Chánh": [
    "tân mỹ chánh",
    "taan myx chasnh"
  ],
  "Tân Phú Đông": [
    "tân phú đông",
    "taan phus ddoong"
  ],
  "Tân Thới Hòa": [
    "tân thới hòa",
    "taan thowsi hofa"
  ],
  "Tân Thới Nhì": [
    "tân thới nhì",
    "taan thowsi nhif"
  ],
  "Tăng Bạt Hổ": [
    "tăng bạt hổ",
    "tawng bajt hoor"
  ],
  "Tạ An Khương": [
    "tạ an khương",
    "taj an khuwowng"
  ],
  "Tả Sìn Thàng": [
    "tả sìn thàng",
    "tar sifn thafng"
  ],
  "Tịnh Ấn Tây": [
    "tịnh ấn tây",
    "tijnh aasn taay"
  ],
  "U Minh Thượng": [
    "u minh thượng",
    "u minh thuwowjng"
  ],
  "Vang Quới Tây": [
    "vang quới tây",
    "vang quowsi taay"
  ],
  "Vân Khánh Tây": [
    "vân khánh tây",
    "vaan khasnh taay"
  ],
  "Vĩnh Phước A": [
    "vĩnh phước a",
    "vixnh phuwowsc a"
  ],
  "Vĩnh Phước B": [
    "vĩnh phước b",
    "vixnh phuwowsc b"
  ],
  "Vĩnh Thanh Vân": [
    "vĩnh thanh vân",
    "vixnh thanh vaan"
  ],
  "Xuân Sơn Bắc": [
    "xuân sơn bắc",
    "xuaan sown bawsc"
  ],
  "Ân Hảo Đông": [
    "ân hảo đông",
    "aan haro ddoong"
  ],
  "Đinh Trang Hòa": [
    "đinh trang hòa",
    "ddinh trang hofa"
  ],
  "Điện Phương": [
    "điện phương",
    "ddieejn phuwowng"
  ],
  "Điện Phước": [
    "điện phước",
    "ddieejn phuwowsc"
  ],
  "Đoàn Thượng": [
    "đoàn thượng",
    "ddoafn thuwowjng"
  ],
  "Đường Hồng": [
    "đường hồng",
    "dduwowfng hoofng"
  ],
  "Định Thành A": [
    "định thành a",
    "ddijnh thafnh a"
  ],
  "Đồng Hướng": [
    "đồng hướng",
    "ddoofng huwowsng"
  ],
  "Đức Hòa Hạ": [
    "đức hòa hạ",
    "dduwsc hofa haj"
  ],
  "Đức Thượng": [
    "đức thượng",
    "dduwsc thuwowjng"
  ],
  "An Thạnh Thủy": [
    "an thạnh thủy",
    "an thajnh thury"
  ],
  "An Thạnh Đông": [
    "an thạnh đông",
    "an thajnh ddoong"
  ],
  "Bàn Tân Định": [
    "bàn tân định",
    "bafn taan ddijnh"
  ],
  "Bình Hàng Trung": [
    "bình hàng trung",
    "bifnh hafng trung"
  ],
  "Bình Hòa Đông": [
    "bình hòa đông",
    "bifnh hofa ddoong"
  ],
  "Bình Trưng Tây": [
    "bình trưng tây",
    "bifnh truwng taay"
  ],
  "Bình Định Nam": [
    "bình định nam",
    "bifnh ddijnh nam"
  ],
  "Bùi Hữu Nghĩa": [
    "bùi hữu nghĩa",
    "bufi huwxu nghixa"
  ],
  "Cam Phước Tây": [
    "cam phước tây",
    "cam phuwowsc taay"
  ],
  "Chiềng Khương": [
    "chiềng khương",
    "chieefng khuwowng"
  ],
  "Cây Trường II": [
    "cây trường ii",
    "caay truwowfng ii"
  ],
  "Cư Dliê M'nông": [
    "cư dliê m'nông",
    "cuw dliee m'noong"
  ],
  "Giang Sơn Đông": [
    "giang sơn đông",
    "giang sown ddoong"
  ],
  "Hoà Hiệp Trung": [
    "hoà hiệp trung",
    "hoaf hieejp trung"
  ],
  "Hoài Châu Bắc": [
    "hoài châu bắc",
    "hoafi chaau bawsc"
  ],
  "Hoàng Văn Thụ": [
    "hoàng văn thụ",
    "hoafng vawn thuj"
  ],
  "Hoằng Phượng": [
    "hoằng phượng",
    "hoawfng phuwowjng"
  ],
  "Hoằng Trường": [
    "hoằng trường",
    "hoawfng truwowfng"
  ],
  "Huống Thượng": [
    "huống thượng",
    "huoosng thuwowjng"
  ],
  "Hòa Cường Nam": [
    "hòa cường nam",
    "hofa cuwowfng nam"
  ],
  "Hòa Hiệp Bắc": [
    "hòa hiệp bắc",
    "hofa hieejp bawsc"
  ],
  "Hòa Khánh Bắc": [
    "hòa khánh bắc",
    "hofa khasnh bawsc"
  ],
  "Hòa Thuận Tây": [
    "hòa thuận tây",
    "hofa thuaajn taay"
  ],
  "Hòa Thọ Đông": [
    "hòa thọ đông",
    "hofa thoj ddoong"
  ],
  "Hòa Xuân Đông": [
    "hòa xuân đông",
    "hofa xuaan ddoong"
  ],
  "Hòa Định Tây": [
    "hòa định tây",
    "hofa ddijnh taay"
  ],
  "Hương Nhượng": [
    "hương nhượng",
    "huwowng nhuwowjng"
  ],
  "Hố Quáng Phìn": [
    "hố quáng phìn",
    "hoos quasng phifn"
  ],
  "Hồng Thái Tây": [
    "hồng thái tây",
    "hoofng thasi taay"
  ],
  "Khánh Bình Tây": [
    "khánh bình tây",
    "khasnh bifnh taay"
  ],
  "Khánh Vĩnh Yên": [
    "khánh vĩnh yên",
    "khasnh vixnh yeen"
  ],
  "Khánh Yên Trung": [
    "khánh yên trung",
    "khasnh yeen trung"
  ],
  "Long Hựu Đông": [
    "long hựu đông",
    "long huwju ddoong"
  ],
  "Long Thành Bắc": [
    "long thành bắc",
    "long thafnh bawsc"
  ],
  "Long Thành Trung": [
    "long thành trung",
    "long thafnh trung"
  ],
  "Long Thạnh Mỹ": [
    "long thạnh mỹ",
    "long thajnh myx"
  ],
  "Long Điền Tây": [
    "long điền tây",
    "long ddieefn taay"
  ],
  "Lâm Trung Thủy": [
    "lâm trung thủy",
    "laam trung thury"
  ],
  "Lùng Khấu Nhin": [
    "lùng khấu nhin",
    "lufng khaasu nhin"
  ],
  "Lưu Nghiệp Anh": [
    "lưu nghiệp anh",
    "luwu nghieejp anh"
  ],
  "Lương Thượng": [
    "lương thượng",
    "luwowng thuwowjng"
  ],
  "Lưỡng Vượng": [
    "lưỡng vượng",
    "luwowxng vuwowjng"
  ],
  "Lợi Bình Nhơn": [
    "lợi bình nhơn",
    "lowji bifnh nhown"
  ],
  "Lục Sỹ Thành": [
    "lục sỹ thành",
    "lujc syx thafnh"
  ],
  "Mường Chiềng": [
    "mường chiềng",
    "muwowfng chieefng"
  ],
  "Mường Khương": [
    "mường khương",
    "muwowfng khuwowng"
  ],
  "Mỹ Hạnh Bắc": [
    "mỹ hạnh bắc",
    "myx hajnh bawsc"
  ],
  "Mỹ Hạnh Trung": [
    "mỹ hạnh trung",
    "myx hajnh trung"
  ],
  "Mỹ Hội Đông": [
    "mỹ hội đông",
    "myx hooji ddoong"
  ],
  "Mỹ Thành Bắc": [
    "mỹ thành bắc",
    "myx thafnh bawsc"
  ],
  "Mỹ Thạnh Tây": [
    "mỹ thạnh tây",
    "myx thajnh taay"
  ],
  "Ngàm Đăng Vài": [
    "ngàm đăng vài",
    "ngafm ddawng vafi"
  ],
  "Ngư Thủy Bắc": [
    "ngư thủy bắc",
    "nguw thury bawsc"
  ],
  "Nhuận Phú Tân": [
    "nhuận phú tân",
    "nhuaajn phus taan"
  ],
  "Phùng Chí Kiên": [
    "phùng chí kiên",
    "phufng chis kieen"
  ],
  "Phước Vĩnh An": [
    "phước vĩnh an",
    "phuwowsc vixnh an"
  ],
  "Phạm Văn Cội": [
    "phạm văn cội",
    "phajm vawn cooji"
  ],
  "Phụng Thượng": [
    "phụng thượng",
    "phujng thuwowjng"
  ],
  "Quê Mỹ Thạnh": [
    "quê mỹ thạnh",
    "quee myx thajnh"
  ],
  "Quảng Trường": [
    "quảng trường",
    "quarng truwowfng"
  ],
  "Quốc Tử Giám": [
    "quốc tử giám",
    "quoosc tuwr giasm"
  ],
  "Thanh Khê Đông": [
    "thanh khê đông",
    "thanh khee ddoong"
  ],
  "Thanh Xuân Bắc": [
    "thanh xuân bắc",
    "thanh xuaan bawsc"
  ],
  "Thanh Xuân Trung": [
    "thanh xuân trung",
    "thanh xuaan trung"
  ],
  "Thái Bình Trung": [
    "thái bình trung",
    "thasi bifnh trung"
  ],
  "Thường Thạnh": [
    "thường thạnh",
    "thuwowfng thajnh"
  ],
  "Thường Thắng": [
    "thường thắng",
    "thuwowfng thawsng"
  ],
  "Thượng Quảng": [
    "thượng quảng",
    "thuwowjng quarng"
  ],
  "Thượng Trạch": [
    "thượng trạch",
    "thuwowjng trajch"
  ],
  "Thạnh Hòa Sơn": [
    "thạnh hòa sơn",
    "thajnh hofa sown"
  ],
  "Thạnh Mỹ Tây": [
    "thạnh mỹ tây",
    "thajnh myx taay"
  ],
  "Thạnh Thới An": [
    "thạnh thới an",
    "thajnh thowsi an"
  ],
  "Thủ Dầu Một": [
    "thủ dầu một",
    "thur daafu moojt"
  ],
  "Triệu Thượng": [
    "triệu thượng",
    "trieeju thuwowjng"
  ],
  "Trung Sơn Trầm": [
    "trung sơn trầm",
    "trung sown traafm"
  ],
  "Trung Thành Tây": [
    "trung thành tây",
    "trung thafnh taay"
  ],
  "Trường Thạnh": [
    "trường thạnh",
    "truwowfng thajnh"
  ],
  "Trường Thắng": [
    "trường thắng",
    "truwowfng thawsng"
  ],
  "Trường Thịnh": [
    "trường thịnh",
    "truwowfng thijnh"
  ],
  "Trường Xuân A": [
    "trường xuân a",
    "truwowfng xuaan a"
  ],
  "Trường Xuân B": [
    "trường xuân b",
    "truwowfng xuaan b"
  ],
  "Tuyên Bình Tây": [
    "tuyên bình tây",
    "tuyeen bifnh taay"
  ],
  "Tân Hưng Đông": [
    "tân hưng đông",
    "taan huwng ddoong"
  ],
  "Tân Hội Đông": [
    "tân hội đông",
    "taan hooji ddoong"
  ],
  "Tân Lâm Hương": [
    "tân lâm hương",
    "taan laam huwowng"
  ],
  "Tân Lộc Đông": [
    "tân lộc đông",
    "taan loojc ddoong"
  ],
  "Tân Phú Thạnh": [
    "tân phú thạnh",
    "taan phus thajnh"
  ],
  "Tân Quới Trung": [
    "tân quới trung",
    "taan quowsi trung"
  ],
  "Tân Thuận Tây": [
    "tân thuận tây",
    "taan thuaajn taay"
  ],
  "Tân Thành Bình": [
    "tân thành bình",
    "taan thafnh bifnh"
  ],
  "Tân Thông Hội": [
    "tân thông hội",
    "taan thoong hooji"
  ],
  "Tân Thạnh Tây": [
    "tân thạnh tây",
    "taan thajnh taay"
  ],
  "Tân Vĩnh Hiệp": [
    "tân vĩnh hiệp",
    "taan vixnh hieejp"
  ],
  "Tả Ngải Chồ": [
    "tả ngải chồ",
    "tar ngari choof"
  ],
  "Tả Sử Choóng": [
    "tả sử choóng",
    "tar suwr choosng"
  ],
  "Tủa Sín Chải": [
    "tủa sín chải",
    "tura sisn chari"
  ],
  "Vĩnh Bình Bắc": [
    "vĩnh bình bắc",
    "vixnh bifnh bawsc"
  ],
  "Vĩnh Hòa Hiệp": [
    "vĩnh hòa hiệp",
    "vixnh hofa hieejp"
  ],
  "Vĩnh Phú Đông": [
    "vĩnh phú đông",
    "vixnh phus ddoong"
  ],
  "Xuân Thới Sơn": [
    "xuân thới sơn",
    "xuaan thowsi sown"
  ],
  "Ân Tường Tây": [
    "ân tường tây",
    "aan tuwowfng taay"
  ],
  "Điền Thượng": [
    "điền thượng",
    "ddieefn thuwowjng"
  ],
  "Điện Nam Bắc": [
    "điện nam bắc",
    "ddieejn nam bawsc"
  ],
  "Điện Nam Trung": [
    "điện nam trung",
    "ddieejn nam trung"
  ],
  "Đông Phước A": [
    "đông phước a",
    "ddoong phuwowsc a"
  ],
  "Đại Hòa Lộc": [
    "đại hòa lộc",
    "ddaji hofa loojc"
  ],
  "Đức Bình Tây": [
    "đức bình tây",
    "dduwsc bifnh taay"
  ],
  "Đức Lập Hạ": [
    "đức lập hạ",
    "dduwsc laajp haj"
  ],
  " Hoàng Văn Thụ": [
    " hoàng văn thụ",
    " hoafng vawn thuj"
  ],
  "Bình Hưng Hoà A": [
    "bình hưng hoà a",
    "bifnh huwng hoaf a"
  ],
  "Bình Hưng Hoà B": [
    "bình hưng hoà b",
    "bifnh huwng hoaf b"
  ],
  "Bình Trinh Đông": [
    "bình trinh đông",
    "bifnh trinh ddoong"
  ],
  "Bình Trị Đông": [
    "bình trị đông",
    "bifnh trij ddoong"
  ],
  "Cam Thịnh Đông": [
    "cam thịnh đông",
    "cam thijnh ddoong"
  ],
  "Dương Minh Châu": [
    "dương minh châu",
    "duwowng minh chaau"
  ],
  "Hiệp Mỹ Đông": [
    "hiệp mỹ đông",
    "hieejp myx ddoong"
  ],
  "Hàm Thuận Bắc": [
    "hàm thuận bắc",
    "hafm thuaajn bawsc"
  ],
  "Hành Tín  Đông": [
    "hành tín  đông",
    "hafnh tisn  ddoong"
  ],
  "Hòa Bình Thạnh": [
    "hòa bình thạnh",
    "hofa bifnh thajnh"
  ],
  "Hòa Khánh Đông": [
    "hòa khánh đông",
    "hofa khasnh ddoong"
  ],
  "Hậu Mỹ Bắc A": [
    "hậu mỹ bắc a",
    "haaju myx bawsc a"
  ],
  "Hậu Mỹ Bắc B": [
    "hậu mỹ bắc b",
    "haaju myx bawsc b"
  ],
  "Hậu Thạnh Tây": [
    "hậu thạnh tây",
    "haaju thajnh taay"
  ],
  "Hồ Đắc Kiện": [
    "hồ đắc kiện",
    "hoof ddawsc kieejn"
  ],
  "Khương Thượng": [
    "khương thượng",
    "khuwowng thuwowjng"
  ],
  "Kim Song Trường": [
    "kim song trường",
    "kim song truwowfng"
  ],
  "Kông Lơng Khơng": [
    "kông lơng khơng",
    "koong lowng khowng"
  ],
  "Long Bình Điền": [
    "long bình điền",
    "long bifnh ddieefn"
  ],
  "Lương Hòa Lạc": [
    "lương hòa lạc",
    "luwowng hofa lajc"
  ],
  "Mỹ Hạnh Đông": [
    "mỹ hạnh đông",
    "myx hajnh ddoong"
  ],
  "Mỹ Phước Tây": [
    "mỹ phước tây",
    "myx phuwowsc taay"
  ],
  "Mỹ Thạnh Bắc": [
    "mỹ thạnh bắc",
    "myx thajnh bawsc"
  ],
  "Mỹ Thạnh Trung": [
    "mỹ thạnh trung",
    "myx thajnh trung"
  ],
  "Mỹ Đức Đông": [
    "mỹ đức đông",
    "myx dduwsc ddoong"
  ],
  "Nguyễn Cư Trinh": [
    "nguyễn cư trinh",
    "nguyeexn cuw trinh"
  ],
  "Nguyễn Văn Cừ": [
    "nguyễn văn cừ",
    "nguyeexn vawn cuwf"
  ],
  "Ninh Thạnh Lợi": [
    "ninh thạnh lợi",
    "ninh thajnh lowji"
  ],
  "Nại Hiên Đông": [
    "nại hiên đông",
    "naji hieen ddoong"
  ],
  "Phan Đình Phùng": [
    "phan đình phùng",
    "phan ddifnh phufng"
  ],
  "Phong Thạnh Tây": [
    "phong thạnh tây",
    "phong thajnh taay"
  ],
  "Phạm Đình Hổ": [
    "phạm đình hổ",
    "phajm ddifnh hoor"
  ],
  "Quảng Phú Cầu": [
    "quảng phú cầu",
    "quarng phus caafu"
  ],
  "Sơn Thành Đông": [
    "sơn thành đông",
    "sown thafnh ddoong"
  ],
  "Thanh Vĩnh Đông": [
    "thanh vĩnh đông",
    "thanh vixnh ddoong"
  ],
  "Thài Phìn Tủng": [
    "thài phìn tủng",
    "thafi phifn turng"
  ],
  "Thân Cửu Nghĩa": [
    "thân cửu nghĩa",
    "thaan cuwru nghixa"
  ],
  "Thượng Cường": [
    "thượng cường",
    "thuwowjng cuwowfng"
  ],
  "Thạnh Mỹ Lợi": [
    "thạnh mỹ lợi",
    "thajnh myx lowji"
  ],
  "Thủy Xuân Tiên": [
    "thủy xuân tiên",
    "thury xuaan tieen"
  ],
  "Trạch Mỹ Lộc": [
    "trạch mỹ lộc",
    "trajch myx loojc"
  ],
  "Trần Văn Thời": [
    "trần văn thời",
    "traafn vawn thowfi"
  ],
  "Trần Đăng Ninh": [
    "trần đăng ninh",
    "traafn ddawng ninh"
  ],
  "Tân  Khánh Trung": [
    "tân  khánh trung",
    "taan  khasnh trung"
  ],
  "Tân Bình Thạnh": [
    "tân bình thạnh",
    "taan bifnh thajnh"
  ],
  "Tân Chánh Hiệp": [
    "tân chánh hiệp",
    "taan chasnh hieejp"
  ],
  "Tân Hưng Thuận": [
    "tân hưng thuận",
    "taan huwng thuaajn"
  ],
  "Tân Khánh Đông": [
    "tân khánh đông",
    "taan khasnh ddoong"
  ],
  "Tân Lợi Thạnh": [
    "tân lợi thạnh",
    "taan lowji thajnh"
  ],
  "Tân Phước Tây": [
    "tân phước tây",
    "taan phuwowsc taay"
  ],
  "Tân Thuận Bình": [
    "tân thuận bình",
    "taan thuaajn bifnh"
  ],
  "Tân Thới Hiệp": [
    "tân thới hiệp",
    "taan thowsi hieejp"
  ],
  "Tân Thới Nhất": [
    "tân thới nhất",
    "taan thowsi nhaast"
  ],
  "Tân Đông Hiệp": [
    "tân đông hiệp",
    "taan ddoong hieejp"
  ],
  "Tăng Nhơn Phú A": [
    "tăng nhơn phú a",
    "tawng nhown phus a"
  ],
  "Tăng Nhơn Phú B": [
    "tăng nhơn phú b",
    "tawng nhown phus b"
  ],
  "Tường Thượng": [
    "tường thượng",
    "tuwowfng thuwowjng"
  ],
  "Tảo Dương Văn": [
    "tảo dương văn",
    "taro duwowng vawn"
  ],
  "Tịnh Ấn Đông": [
    "tịnh ấn đông",
    "tijnh aasn ddoong"
  ],
  "Vang Quới Đông": [
    "vang quới đông",
    "vang quowsi ddoong"
  ],
  "Vân Khánh Đông": [
    "vân khánh đông",
    "vaan khasnh ddoong"
  ],
  "Vĩnh Hội Đông": [
    "vĩnh hội đông",
    "vixnh hooji ddoong"
  ],
  "Vĩnh Thuận Tây": [
    "vĩnh thuận tây",
    "vixnh thuaajn taay"
  ],
  "Đa Phước Hội": [
    "đa phước hội",
    "dda phuwowsc hooji"
  ],
  "Điện Nam Đông": [
    "điện nam đông",
    "ddieejn nam ddoong"
  ],
  "Đào Hữu Cảnh": [
    "đào hữu cảnh",
    "ddafo huwxu carnh"
  ],
  "Đông Hòa Hiệp": [
    "đông hòa hiệp",
    "ddoong hofa hieejp"
  ],
  "Đốc Binh Kiều": [
    "đốc binh kiều",
    "ddoosc binh kieefu"
  ],
  "Đức Hòa Đông": [
    "đức hòa đông",
    "dduwsc hofa ddoong"
  ],
  "Đức Ninh Đông": [
    "đức ninh đông",
    "dduwsc ninh ddoong"
  ],
  "Bình Hòa Phước": [
    "bình hòa phước",
    "bifnh hofa phuwowsc"
  ],
  "Bình Phong Thạnh": [
    "bình phong thạnh",
    "bifnh phong thajnh"
  ],
  "Bình Phục Nhứt": [
    "bình phục nhứt",
    "bifnh phujc nhuwst"
  ],
  "Bình Thạnh Trung": [
    "bình thạnh trung",
    "bifnh thajnh trung"
  ],
  "Bình Trưng Đông": [
    "bình trưng đông",
    "bifnh truwng ddoong"
  ],
  "Bình Định Bắc": [
    "bình định bắc",
    "bifnh ddijnh bawsc"
  ],
  "Cam Phước Đông": [
    "cam phước đông",
    "cam phuwowsc ddoong"
  ],
  "Dương Xuân Hội": [
    "dương xuân hội",
    "duwowng xuaan hooji"
  ],
  "Dịch Vọng Hậu": [
    "dịch vọng hậu",
    "dijch vojng haaju"
  ],
  "Hiệp Bình Chánh": [
    "hiệp bình chánh",
    "hieejp bifnh chasnh"
  ],
  "Hòa Cường Bắc": [
    "hòa cường bắc",
    "hofa cuwowfng bawsc"
  ],
  "Hòa Thuận Đông": [
    "hòa thuận đông",
    "hofa thuaajn ddoong"
  ],
  "Hòa Định Đông": [
    "hòa định đông",
    "hofa ddijnh ddoong"
  ],
  "Hướng Thọ Phú": [
    "hướng thọ phú",
    "huwowsng thoj phus"
  ],
  "Hồng Thái Đông": [
    "hồng thái đông",
    "hoofng thasi ddoong"
  ],
  "Khánh Bình Đông": [
    "khánh bình đông",
    "khasnh bifnh ddoong"
  ],
  "Khánh Thạnh Tân": [
    "khánh thạnh tân",
    "khasnh thajnh taan"
  ],
  "Long Điền Đông": [
    "long điền đông",
    "long ddieefn ddoong"
  ],
  "Lương Thế Trân": [
    "lương thế trân",
    "luwowng thees traan"
  ],
  "Mỹ Thạnh Đông": [
    "mỹ thạnh đông",
    "myx thajnh ddoong"
  ],
  "Nam Phương Tiến": [
    "nam phương tiến",
    "nam phuwowng tieesn"
  ],
  "Nhơn Thạnh Trung": [
    "nhơn thạnh trung",
    "nhown thajnh trung"
  ],
  "Phước Long Thọ": [
    "phước long thọ",
    "phuwowsc long thoj"
  ],
  "Phước Mỹ Trung": [
    "phước mỹ trung",
    "phuwowsc myx trung"
  ],
  "Phước Tân Hưng": [
    "phước tân hưng",
    "phuwowsc taan huwng"
  ],
  "Phước Vĩnh Tây": [
    "phước vĩnh tây",
    "phuwowsc vixnh taay"
  ],
  "Quách Phẩm Bắc": [
    "quách phẩm bắc",
    "quasch phaarm bawsc"
  ],
  "Thanh Bình Thịnh": [
    "thanh bình thịnh",
    "thanh bifnh thijnh"
  ],
  "Thuận Nghĩa Hòa": [
    "thuận nghĩa hòa",
    "thuaajn nghixa hofa"
  ],
  "Thượng Bằng La": [
    "thượng bằng la",
    "thuwowjng bawfng la"
  ],
  "Thạnh Phú Đông": [
    "thạnh phú đông",
    "thajnh phus ddoong"
  ],
  "Thải Giàng Phố": [
    "thải giàng phố",
    "thari giafng phoos"
  ],
  "Thứ Mười Một": [
    "thứ mười một",
    "thuws muwowfi moojt"
  ],
  "Thừa Thiên Huế": [
    "thừa thiên huế",
    "thuwfa thieen huees"
  ],
  "Trung Thành Đông": [
    "trung thành đông",
    "trung thafnh ddoong"
  ],
  "Trường Long Hòa": [
    "trường long hòa",
    "truwowfng long hofa"
  ],
  "Trường Long Tây": [
    "trường long tây",
    "truwowfng long taay"
  ],
  "Trần Hưng Đạo": [
    "trần hưng đạo",
    "traafn huwng ddajo"
  ],
  "Trần Nguyên Hãn": [
    "trần nguyên hãn",
    "traafn nguyeen haxn"
  ],
  "Trần Quang Diệu": [
    "trần quang diệu",
    "traafn quang dieeju"
  ],
  "Trần Quang Khải": [
    "trần quang khải",
    "traafn quang khari"
  ],
  "Trần Thành Ngọ": [
    "trần thành ngọ",
    "traafn thafnh ngoj"
  ],
  "Trần Tế Xương": [
    "trần tế xương",
    "traafn tees xuwowng"
  ],
  "Tân Nhuận Đông": [
    "tân nhuận đông",
    "taan nhuaajn ddoong"
  ],
  "Tân Phước Hưng": [
    "tân phước hưng",
    "taan phuwowsc huwng"
  ],
  "Tân Thuận Đông": [
    "tân thuận đông",
    "taan thuaajn ddoong"
  ],
  "Tân Thạnh Đông": [
    "tân thạnh đông",
    "taan thajnh ddoong"
  ],
  "Vĩnh Thạnh Trung": [
    "vĩnh thạnh trung",
    "vixnh thajnh trung"
  ],
  "Xuân Thới Đông": [
    "xuân thới đông",
    "xuaan thowsi ddoong"
  ],
  "Ân Tường Đông": [
    "ân tường đông",
    "aan tuwowfng ddoong"
  ],
  "Điện Biên Phủ": [
    "điện biên phủ",
    "ddieejn bieen phur"
  ],
  "Điện Thắng Nam": [
    "điện thắng nam",
    "ddieejn thawsng nam"
  ],
  "Đường Thượng": [
    "đường thượng",
    "dduwowfng thuwowjng"
  ],
  "Đức Bình Đông": [
    "đức bình đông",
    "dduwsc bifnh ddoong"
  ],
  "Biển Bạch Đông": [
    "biển bạch đông",
    "bieern bajch ddoong"
  ],
  "Bình Phước Xuân": [
    "bình phước xuân",
    "bifnh phuwowsc xuaan"
  ],
  "Bình Thạnh Đông": [
    "bình thạnh đông",
    "bifnh thajnh ddoong"
  ],
  "Bình Trị Đông A": [
    "bình trị đông a",
    "bifnh trij ddoong a"
  ],
  "Bình Trị Đông B": [
    "bình trị đông b",
    "bifnh trij ddoong b"
  ],
  "Huỳnh Hữu Nghĩa": [
    "huỳnh hữu nghĩa",
    "huyfnh huwxu nghixa"
  ],
  "Hưng Khánh Trung A": [
    "hưng khánh trung a",
    "huwng khasnh trung a"
  ],
  "Hưng Khánh Trung B": [
    "hưng khánh trung b",
    "huwng khasnh trung b"
  ],
  "Hậu Thạnh Đông": [
    "hậu thạnh đông",
    "haaju thajnh ddoong"
  ],
  "Khuê Ngọc Điền": [
    "khuê ngọc điền",
    "khuee ngojc ddieefn"
  ],
  "Lý Thường Kiệt": [
    "lý thường kiệt",
    "lys thuwowfng kieejt"
  ],
  "Nguyễn Thái Bình": [
    "nguyễn thái bình",
    "nguyeexn thasi bifnh"
  ],
  "Nguyễn Thái Học": [
    "nguyễn thái học",
    "nguyeexn thasi hojc"
  ],
  "Ninh Thạnh Lợi A": [
    "ninh thạnh lợi a",
    "ninh thajnh lowji a"
  ],
  "Phong Dụ Thượng": [
    "phong dụ thượng",
    "phong duj thuwowjng"
  ],
  "Phong Thạnh Tây A": [
    "phong thạnh tây a",
    "phong thajnh taay a"
  ],
  "Phong Thạnh Tây B": [
    "phong thạnh tây b",
    "phong thajnh taay b"
  ],
  "Phong Thạnh Đông": [
    "phong thạnh đông",
    "phong thajnh ddoong"
  ],
  "Thường Phước 1": [
    "thường phước 1",
    "thuwowfng phuwowsc 1"
  ],
  "Thường Phước 2": [
    "thường phước 2",
    "thuwowfng phuwowsc 2"
  ],
  "Thượng Tân Lộc": [
    "thượng tân lộc",
    "thuwowjng taan loojc"
  ],
  "Thượng Yên Công": [
    "thượng yên công",
    "thuwowjng yeen coong"
  ],
  "Trung Phúc Cường": [
    "trung phúc cường",
    "trung phusc cuwowfng"
  ],
  "Tân Phước Khánh": [
    "tân phước khánh",
    "taan phuwowsc khasnh"
  ],
  "Tương Bình Hiệp": [
    "tương bình hiệp",
    "tuwowng bifnh hieejp"
  ],
  "Vĩnh Hòa Hưng Nam": [
    "vĩnh hòa hưng nam",
    "vixnh hofa huwng nam"
  ],
  "Vĩnh Thuận Đông": [
    "vĩnh thuận đông",
    "vixnh thuaajn ddoong"
  ],
  "Vĩnh Trạch Đông": [
    "vĩnh trạch đông",
    "vixnh trajch ddoong"
  ],
  "Điện Biên Đông": [
    "điện biên đông",
    "ddieejn bieen ddoong"
  ],
  "Đông Hưng Thuận": [
    "đông hưng thuận",
    "ddoong huwng thuaajn"
  ],
  "Đông Phương Yên": [
    "đông phương yên",
    "ddoong phuwowng yeen"
  ],
  "Đổng Quốc Bình": [
    "đổng quốc bình",
    "ddoorng quoosc bifnh"
  ],
  "Châu Quế Thượng": [
    "châu quế thượng",
    "chaau quees thuwowjng"
  ],
  "Hiệp Bình Phước": [
    "hiệp bình phước",
    "hieejp bifnh phuwowsc"
  ],
  "Khánh Yên Thượng": [
    "khánh yên thượng",
    "khasnh yeen thuwowjng"
  ],
  "Long Điền Đông A": [
    "long điền đông a",
    "long ddieefn ddoong a"
  ],
  "Nguyễn Trung Trực": [
    "nguyễn trung trực",
    "nguyeexn trung truwjc"
  ],
  "Nguyễn Việt Khái": [
    "nguyễn việt khái",
    "nguyeexn vieejt khasi"
  ],
  "Nguyễn Văn Thảnh": [
    "nguyễn văn thảnh",
    "nguyeexn vawn tharnh"
  ],
  "Phan Rang-Tháp Chàm": [
    "phan rang-tháp chàm",
    "phan rang-thasp chafm"
  ],
  "Phước Vĩnh Đông": [
    "phước vĩnh đông",
    "phuwowsc vixnh ddoong"
  ],
  "Trung Lập Thượng": [
    "trung lập thượng",
    "trung laajp thuwowjng"
  ],
  "Tạ An Khương  Nam": [
    "tạ an khương  nam",
    "taj an khuwowng  nam"
  ],
  "Đinh Trang Thượng": [
    "đinh trang thượng",
    "ddinh trang thuwowjng"
  ],
  "Điện Thắng Bắc": [
    "điện thắng bắc",
    "ddieejn thawsng bawsc"
  ],
  "Điện Thắng Trung": [
    "điện thắng trung",
    "ddieejn thawsng trung"
  ],
  "Đăng Hưng Phước": [
    "đăng hưng phước",
    "ddawng huwng phuwowsc"
  ],
  "Đại Đồng Thành": [
    "đại đồng thành",
    "ddaji ddoofng thafnh"
  ],
  "Đồng Nai Thượng": [
    "đồng nai thượng",
    "ddoofng nai thuwowjng"
  ],
  "Đức Hòa Thượng": [
    "đức hòa thượng",
    "dduwsc hofa thuwowjng"
  ],
  "Bà Rịa - Vũng Tàu": [
    "bà rịa - vũng tàu",
    "baf rija - vuxng tafu"
  ],
  "Dương Hồng  Thủy": [
    "dương hồng  thủy",
    "duwowng hoofng  thury"
  ],
  "Lương Khánh Thiện": [
    "lương khánh thiện",
    "luwowng khasnh thieejn"
  ],
  "Lịch Hội Thượng": [
    "lịch hội thượng",
    "lijch hooji thuwowjng"
  ],
  "Thạnh Thới Thuận": [
    "thạnh thới thuận",
    "thajnh thowsi thuaajn"
  ],
  "Trương Quang Trọng": [
    "trương quang trọng",
    "truwowng quang trojng"
  ],
  "Vĩnh Hòa Hưng Bắc": [
    "vĩnh hòa hưng bắc",
    "vixnh hofa huwng bawsc"
  ],
  "Xuân Thới Thượng": [
    "xuân thới thượng",
    "xuaan thowsi thuwowjng"
  ],
  "Đức Lập Thượng": [
    "đức lập thượng",
    "dduwsc laajp thuwowjng"
  ],
  "Khánh Bình Tây Bắc": [
    "khánh bình tây bắc",
    "khasnh bifnh taay bawsc"
  ],
  "Thường Thới Tiền": [
    "thường thới tiền",
    "thuwowfng thowsi tieefn"
  ],
  "Nguyễn Thị Minh Khai": [
    "nguyễn thị minh khai",
    "nguyeexn thij minh khai"
  ],
  "Thường Thới Hậu A": [
    "thường thới hậu a",
    "thuwowfng thowsi haaju a"
  ],
  "Tạ An Khương  Đông": [
    "tạ an khương  đông",
    "taj an khuwowng  ddoong"
  ],
  "Nông Trường Việt Lâm": [
    "nông trường việt lâm",
    "noong truwowfng vieejt laam"
  ]
}
