STANDARD_ADDRESSES = [
  "Phúc Xá, Ba Đình, Hà Nội",
  "Trúc Bạch, Ba Đình, Hà Nội",
  "Vĩnh Phúc, Ba Đình, Hà Nội",
  "Cống Vị, Ba Đình, Hà Nội",
  "Liễu Giai, Ba Đình, Hà Nội",
  "Nguyễn Trung Trực, Ba Đình, Hà Nội",
  "Quán Thánh, Ba Đình, Hà Nội",
  "Ngọc Hà, Ba Đình, Hà Nội",
  "Điện Biên, Ba Đình, Hà Nội",
  "Đội Cấn, Ba Đình, Hà Nội",
  "Ngọc Khánh, Ba Đình, Hà Nội",
  "Kim Mã, Ba Đình, Hà Nội",
  "Giảng Võ, Ba Đình, Hà Nội",
  "Thành Công, Ba Đình, Hà Nội",
  "Phúc Tân, Hoàn Kiếm, Hà Nội",
  "Đồng Xuân, Hoàn Kiếm, Hà Nội",
  "Hàng Mã, Hoàn Kiếm, Hà Nội",
  "Hàng Buồm, Hoàn Kiếm, Hà Nội",
  "Hàng Đào, Hoàn Kiếm, Hà Nội",
  "Hàng Bồ, Hoàn Kiếm, Hà Nội",
  "Cửa Đông, Hoàn Kiếm, Hà Nội",
  "Lý Thái Tổ, Hoàn Kiếm, Hà Nội",
  "Hàng Bạc, Hoàn Kiếm, Hà Nội",
  "Hàng Gai, Hoàn Kiếm, Hà Nội",
  "Chương Dương, Hoàn Kiếm, Hà Nội",
  "Hàng Trống, Hoàn Kiếm, Hà Nội",
  "Cửa Nam, Hoàn Kiếm, Hà Nội",
  "Hàng Bông, Hoàn Kiếm, Hà Nội",
  "Tràng Tiền, Hoàn Kiếm, Hà Nội",
  "Trần Hưng Đạo, Hoàn Kiếm, Hà Nội",
  "Phan Chu Trinh, Hoàn Kiếm, Hà Nội",
  "Hàng Bài, Hoàn Kiếm, Hà Nội",
  "Phú Thượng, Tây Hồ, Hà Nội",
  "Nhật Tân, Tây Hồ, Hà Nội",
  "Tứ Liên, Tây Hồ, Hà Nội",
  "Quảng An, Tây Hồ, Hà Nội",
  "Xuân La, Tây Hồ, Hà Nội",
  "Yên Phụ, Tây Hồ, Hà Nội",
  "Bưởi, Tây Hồ, Hà Nội",
  "Thụy Khuê, Tây Hồ, Hà Nội",
  "Thượng Thanh, Long Biên, Hà Nội",
  "Ngọc Thụy, Long Biên, Hà Nội",
  "Giang Biên, Long Biên, Hà Nội",
  "Đức Giang, Long Biên, Hà Nội",
  "Việt Hưng, Long Biên, Hà Nội",
  "Gia Thụy, Long Biên, Hà Nội",
  "Ngọc Lâm, Long Biên, Hà Nội",
  "Phúc Lợi, Long Biên, Hà Nội",
  "Bồ Đề, Long Biên, Hà Nội",
  "Sài Đồng, Long Biên, Hà Nội",
  "Long Biên, Long Biên, Hà Nội",
  "Thạch Bàn, Long Biên, Hà Nội",
  "Phúc Đồng, Long Biên, Hà Nội",
  "Cự Khối, Long Biên, Hà Nội",
  "Nghĩa Đô, Cầu Giấy, Hà Nội",
  "Nghĩa Tân, Cầu Giấy, Hà Nội",
  "Mai Dịch, Cầu Giấy, Hà Nội",
  "Dịch Vọng, Cầu Giấy, Hà Nội",
  "Dịch Vọng Hậu, Cầu Giấy, Hà Nội",
  "Quan Hoa, Cầu Giấy, Hà Nội",
  "Yên Hoà, Cầu Giấy, Hà Nội",
  "Trung Hoà, Cầu Giấy, Hà Nội",
  "Cát Linh, Đống Đa, Hà Nội",
  "Văn Miếu, Đống Đa, Hà Nội",
  "Quốc Tử Giám, Đống Đa, Hà Nội",
  "Láng Thượng, Đống Đa, Hà Nội",
  "Ô Chợ Dừa, Đống Đa, Hà Nội",
  "Văn Chương, Đống Đa, Hà Nội",
  "Hàng Bột, Đống Đa, Hà Nội",
  "Láng Hạ, Đống Đa, Hà Nội",
  "Khâm Thiên, Đống Đa, Hà Nội",
  "Thổ Quan, Đống Đa, Hà Nội",
  "Nam Đồng, Đống Đa, Hà Nội",
  "Trung Phụng, Đống Đa, Hà Nội",
  "Quang Trung, Đống Đa, Hà Nội",
  "Trung Liệt, Đống Đa, Hà Nội",
  "Phương Liên, Đống Đa, Hà Nội",
  "Thịnh Quang, Đống Đa, Hà Nội",
  "Trung Tự, Đống Đa, Hà Nội",
  "Kim Liên, Đống Đa, Hà Nội",
  "Phương Mai, Đống Đa, Hà Nội",
  "Ngã Tư Sở, Đống Đa, Hà Nội",
  "Khương Thượng, Đống Đa, Hà Nội",
  "Nguyễn Du, Hai Bà Trưng, Hà Nội",
  "Bạch Đằng, Hai Bà Trưng, Hà Nội",
  "Phạm Đình Hổ, Hai Bà Trưng, Hà Nội",
  "Lê Đại Hành, Hai Bà Trưng, Hà Nội",
  "Đồng Nhân, Hai Bà Trưng, Hà Nội",
  "Phố Huế, Hai Bà Trưng, Hà Nội",
  "Đống Mác, Hai Bà Trưng, Hà Nội",
  "Thanh Lương, Hai Bà Trưng, Hà Nội",
  "Thanh Nhàn, Hai Bà Trưng, Hà Nội",
  "Cầu Dền, Hai Bà Trưng, Hà Nội",
  "Bách Khoa, Hai Bà Trưng, Hà Nội",
  "Đồng Tâm, Hai Bà Trưng, Hà Nội",
  "Vĩnh Tuy, Hai Bà Trưng, Hà Nội",
  "Bạch Mai, Hai Bà Trưng, Hà Nội",
  "Quỳnh Mai, Hai Bà Trưng, Hà Nội",
  "Quỳnh Lôi, Hai Bà Trưng, Hà Nội",
  "Minh Khai, Hai Bà Trưng, Hà Nội",
  "Trương Định, Hai Bà Trưng, Hà Nội",
  "Thanh Trì, Hoàng Mai, Hà Nội",
  "Vĩnh Hưng, Hoàng Mai, Hà Nội",
  "Định Công, Hoàng Mai, Hà Nội",
  "Mai Động, Hoàng Mai, Hà Nội",
  "Tương Mai, Hoàng Mai, Hà Nội",
  "Đại Kim, Hoàng Mai, Hà Nội",
  "Tân Mai, Hoàng Mai, Hà Nội",
  "Hoàng Văn Thụ, Hoàng Mai, Hà Nội",
  "Giáp Bát, Hoàng Mai, Hà Nội",
  "Lĩnh Nam, Hoàng Mai, Hà Nội",
  "Thịnh Liệt, Hoàng Mai, Hà Nội",
  "Trần Phú, Hoàng Mai, Hà Nội",
  "Hoàng Liệt, Hoàng Mai, Hà Nội",
  "Yên Sở, Hoàng Mai, Hà Nội",
  "Nhân Chính, Thanh Xuân, Hà Nội",
  "Thượng Đình, Thanh Xuân, Hà Nội",
  "Khương Trung, Thanh Xuân, Hà Nội",
  "Khương Mai, Thanh Xuân, Hà Nội",
  "Thanh Xuân Trung, Thanh Xuân, Hà Nội",
  "Phương Liệt, Thanh Xuân, Hà Nội",
  "Hạ Đình, Thanh Xuân, Hà Nội",
  "Khương Đình, Thanh Xuân, Hà Nội",
  "Thanh Xuân Bắc, Thanh Xuân, Hà Nội",
  "Thanh Xuân Nam, Thanh Xuân, Hà Nội",
  "Kim Giang, Thanh Xuân, Hà Nội",
  "Sóc Sơn, Sóc Sơn, Hà Nội",
  "Bắc Sơn, Sóc Sơn, Hà Nội",
  "Minh Trí, Sóc Sơn, Hà Nội",
  "Hồng Kỳ, Sóc Sơn, Hà Nội",
  "Nam Sơn, Sóc Sơn, Hà Nội",
  "Trung Giã, Sóc Sơn, Hà Nội",
  "Tân Hưng, Sóc Sơn, Hà Nội",
  "Minh Phú, Sóc Sơn, Hà Nội",
  "Phù Linh, Sóc Sơn, Hà Nội",
  "Bắc Phú, Sóc Sơn, Hà Nội",
  "Tân Minh, Sóc Sơn, Hà Nội",
  "Quang Tiến, Sóc Sơn, Hà Nội",
  "Hiền Ninh, Sóc Sơn, Hà Nội",
  "Tân Dân, Sóc Sơn, Hà Nội",
  "Tiên Dược, Sóc Sơn, Hà Nội",
  "Việt Long, Sóc Sơn, Hà Nội",
  "Xuân Giang, Sóc Sơn, Hà Nội",
  "Mai Đình, Sóc Sơn, Hà Nội",
  "Đức Hoà, Sóc Sơn, Hà Nội",
  "Thanh Xuân, Sóc Sơn, Hà Nội",
  "Đông Xuân, Sóc Sơn, Hà Nội",
  "Kim Lũ, Sóc Sơn, Hà Nội",
  "Phú Cường, Sóc Sơn, Hà Nội",
  "Phú Minh, Sóc Sơn, Hà Nội",
  "Phù Lỗ, Sóc Sơn, Hà Nội",
  "Xuân Thu, Sóc Sơn, Hà Nội",
  "Đông Anh, Đông Anh, Hà Nội",
  "Xuân Nộn, Đông Anh, Hà Nội",
  "Thuỵ Lâm, Đông Anh, Hà Nội",
  "Bắc Hồng, Đông Anh, Hà Nội",
  "Nguyên Khê, Đông Anh, Hà Nội",
  "Nam Hồng, Đông Anh, Hà Nội",
  "Tiên Dương, Đông Anh, Hà Nội",
  "Vân Hà, Đông Anh, Hà Nội",
  "Uy Nỗ, Đông Anh, Hà Nội",
  "Vân Nội, Đông Anh, Hà Nội",
  "Liên Hà, Đông Anh, Hà Nội",
  "Việt Hùng, Đông Anh, Hà Nội",
  "Kim Nỗ, Đông Anh, Hà Nội",
  "Kim Chung, Đông Anh, Hà Nội",
  "Dục Tú, Đông Anh, Hà Nội",
  "Đại Mạch, Đông Anh, Hà Nội",
  "Vĩnh Ngọc, Đông Anh, Hà Nội",
  "Cổ Loa, Đông Anh, Hà Nội",
  "Hải Bối, Đông Anh, Hà Nội",
  "Xuân Canh, Đông Anh, Hà Nội",
  "Võng La, Đông Anh, Hà Nội",
  "Tàm Xá, Đông Anh, Hà Nội",
  "Mai Lâm, Đông Anh, Hà Nội",
  "Đông Hội, Đông Anh, Hà Nội",
  "Yên Viên, Gia Lâm, Hà Nội",
  "Yên Thường, Gia Lâm, Hà Nội",
  "Yên Viên, Gia Lâm, Hà Nội",
  "Ninh Hiệp, Gia Lâm, Hà Nội",
  "Đình Xuyên, Gia Lâm, Hà Nội",
  "Dương Hà, Gia Lâm, Hà Nội",
  "Phù Đổng, Gia Lâm, Hà Nội",
  "Trung Mầu, Gia Lâm, Hà Nội",
  "Lệ Chi, Gia Lâm, Hà Nội",
  "Cổ Bi, Gia Lâm, Hà Nội",
  "Đặng Xá, Gia Lâm, Hà Nội",
  "Phú Thị, Gia Lâm, Hà Nội",
  "Kim Sơn, Gia Lâm, Hà Nội",
  "Trâu Quỳ, Gia Lâm, Hà Nội",
  "Dương Quang, Gia Lâm, Hà Nội",
  "Dương Xá, Gia Lâm, Hà Nội",
  "Đông Dư, Gia Lâm, Hà Nội",
  "Đa Tốn, Gia Lâm, Hà Nội",
  "Kiêu Kỵ, Gia Lâm, Hà Nội",
  "Bát Tràng, Gia Lâm, Hà Nội",
  "Kim Lan, Gia Lâm, Hà Nội",
  "Văn Đức, Gia Lâm, Hà Nội",
  "Cầu Diễn, Nam Từ Liêm, Hà Nội",
  "Xuân Phương, Nam Từ Liêm, Hà Nội",
  "Phương Canh, Nam Từ Liêm, Hà Nội",
  "Mỹ Đình 1, Nam Từ Liêm, Hà Nội",
  "Mỹ Đình 2, Nam Từ Liêm, Hà Nội",
  "Tây Mỗ, Nam Từ Liêm, Hà Nội",
  "Mễ Trì, Nam Từ Liêm, Hà Nội",
  "Phú Đô, Nam Từ Liêm, Hà Nội",
  "Đại Mỗ, Nam Từ Liêm, Hà Nội",
  "Trung Văn, Nam Từ Liêm, Hà Nội",
  "Văn Điển, Thanh Trì, Hà Nội",
  "Tân Triều, Thanh Trì, Hà Nội",
  "Thanh Liệt, Thanh Trì, Hà Nội",
  "Tả Thanh Oai, Thanh Trì, Hà Nội",
  "Hữu Hoà, Thanh Trì, Hà Nội",
  "Tam Hiệp, Thanh Trì, Hà Nội",
  "Tứ Hiệp, Thanh Trì, Hà Nội",
  "Yên Mỹ, Thanh Trì, Hà Nội",
  "Vĩnh Quỳnh, Thanh Trì, Hà Nội",
  "Ngũ Hiệp, Thanh Trì, Hà Nội",
  "Duyên Hà, Thanh Trì, Hà Nội",
  "Ngọc Hồi, Thanh Trì, Hà Nội",
  "Vạn Phúc, Thanh Trì, Hà Nội",
  "Đại áng, Thanh Trì, Hà Nội",
  "Liên Ninh, Thanh Trì, Hà Nội",
  "Đông Mỹ, Thanh Trì, Hà Nội",
  "Thượng Cát, Bắc Từ Liêm, Hà Nội",
  "Liên Mạc, Bắc Từ Liêm, Hà Nội",
  "Đông Ngạc, Bắc Từ Liêm, Hà Nội",
  "Đức Thắng, Bắc Từ Liêm, Hà Nội",
  "Thụy Phương, Bắc Từ Liêm, Hà Nội",
  "Tây Tựu, Bắc Từ Liêm, Hà Nội",
  "Xuân Đỉnh, Bắc Từ Liêm, Hà Nội",
  "Xuân Tảo, Bắc Từ Liêm, Hà Nội",
  "Minh Khai, Bắc Từ Liêm, Hà Nội",
  "Cổ Nhuế 1, Bắc Từ Liêm, Hà Nội",
  "Cổ Nhuế 2, Bắc Từ Liêm, Hà Nội",
  "Phú Diễn, Bắc Từ Liêm, Hà Nội",
  "Phúc Diễn, Bắc Từ Liêm, Hà Nội",
  "Chi Đông, Mê Linh, Hà Nội",
  "Đại Thịnh, Mê Linh, Hà Nội",
  "Kim Hoa, Mê Linh, Hà Nội",
  "Thạch Đà, Mê Linh, Hà Nội",
  "Tiến Thắng, Mê Linh, Hà Nội",
  "Tự Lập, Mê Linh, Hà Nội",
  "Quang Minh, Mê Linh, Hà Nội",
  "Thanh Lâm, Mê Linh, Hà Nội",
  "Tam Đồng, Mê Linh, Hà Nội",
  "Liên Mạc, Mê Linh, Hà Nội",
  "Vạn Yên, Mê Linh, Hà Nội",
  "Chu Phan, Mê Linh, Hà Nội",
  "Tiến Thịnh, Mê Linh, Hà Nội",
  "Mê Linh, Mê Linh, Hà Nội",
  "Văn Khê, Mê Linh, Hà Nội",
  "Hoàng Kim, Mê Linh, Hà Nội",
  "Tiền Phong, Mê Linh, Hà Nội",
  "Tráng Việt, Mê Linh, Hà Nội",
  "Nguyễn Trãi, Hà Đông, Hà Nội",
  "Mộ Lao, Hà Đông, Hà Nội",
  "Văn Quán, Hà Đông, Hà Nội",
  "Vạn Phúc, Hà Đông, Hà Nội",
  "Yết Kiêu, Hà Đông, Hà Nội",
  "Quang Trung, Hà Đông, Hà Nội",
  "La Khê, Hà Đông, Hà Nội",
  "Phú La, Hà Đông, Hà Nội",
  "Phúc La, Hà Đông, Hà Nội",
  "Hà Cầu, Hà Đông, Hà Nội",
  "Yên Nghĩa, Hà Đông, Hà Nội",
  "Kiến Hưng, Hà Đông, Hà Nội",
  "Phú Lãm, Hà Đông, Hà Nội",
  "Phú Lương, Hà Đông, Hà Nội",
  "Dương Nội, Hà Đông, Hà Nội",
  "Đồng Mai, Hà Đông, Hà Nội",
  "Biên Giang, Hà Đông, Hà Nội",
  "Lê Lợi, Sơn Tây, Hà Nội",
  "Phú Thịnh, Sơn Tây, Hà Nội",
  "Ngô Quyền, Sơn Tây, Hà Nội",
  "Quang Trung, Sơn Tây, Hà Nội",
  "Sơn Lộc, Sơn Tây, Hà Nội",
  "Xuân Khanh, Sơn Tây, Hà Nội",
  "Đường Lâm, Sơn Tây, Hà Nội",
  "Viên Sơn, Sơn Tây, Hà Nội",
  "Xuân Sơn, Sơn Tây, Hà Nội",
  "Trung Hưng, Sơn Tây, Hà Nội",
  "Thanh Mỹ, Sơn Tây, Hà Nội",
  "Trung Sơn Trầm, Sơn Tây, Hà Nội",
  "Kim Sơn, Sơn Tây, Hà Nội",
  "Sơn Đông, Sơn Tây, Hà Nội",
  "Cổ Đông, Sơn Tây, Hà Nội",
  "Tây Đằng, Ba Vì, Hà Nội",
  "Phú Cường, Ba Vì, Hà Nội",
  "Cổ Đô, Ba Vì, Hà Nội",
  "Tản Hồng, Ba Vì, Hà Nội",
  "Vạn Thắng, Ba Vì, Hà Nội",
  "Châu Sơn, Ba Vì, Hà Nội",
  "Phong Vân, Ba Vì, Hà Nội",
  "Phú Đông, Ba Vì, Hà Nội",
  "Phú Phương, Ba Vì, Hà Nội",
  "Phú Châu, Ba Vì, Hà Nội",
  "Thái Hòa, Ba Vì, Hà Nội",
  "Đồng Thái, Ba Vì, Hà Nội",
  "Phú Sơn, Ba Vì, Hà Nội",
  "Minh Châu, Ba Vì, Hà Nội",
  "Vật Lại, Ba Vì, Hà Nội",
  "Chu Minh, Ba Vì, Hà Nội",
  "Tòng Bạt, Ba Vì, Hà Nội",
  "Cẩm Lĩnh, Ba Vì, Hà Nội",
  "Sơn Đà, Ba Vì, Hà Nội",
  "Đông Quang, Ba Vì, Hà Nội",
  "Tiên Phong, Ba Vì, Hà Nội",
  "Thụy An, Ba Vì, Hà Nội",
  "Cam Thượng, Ba Vì, Hà Nội",
  "Thuần Mỹ, Ba Vì, Hà Nội",
  "Tản Lĩnh, Ba Vì, Hà Nội",
  "Ba Trại, Ba Vì, Hà Nội",
  "Minh Quang, Ba Vì, Hà Nội",
  "Ba Vì, Ba Vì, Hà Nội",
  "Vân Hòa, Ba Vì, Hà Nội",
  "Yên Bài, Ba Vì, Hà Nội",
  "Khánh Thượng, Ba Vì, Hà Nội",
  "Phúc Thọ, Phúc Thọ, Hà Nội",
  "Vân Hà, Phúc Thọ, Hà Nội",
  "Vân Phúc, Phúc Thọ, Hà Nội",
  "Vân Nam, Phúc Thọ, Hà Nội",
  "Xuân Đình, Phúc Thọ, Hà Nội",
  "Sen Phương, Phúc Thọ, Hà Nội",
  "Võng Xuyên, Phúc Thọ, Hà Nội",
  "Thọ Lộc, Phúc Thọ, Hà Nội",
  "Long Xuyên, Phúc Thọ, Hà Nội",
  "Thượng Cốc, Phúc Thọ, Hà Nội",
  "Hát Môn, Phúc Thọ, Hà Nội",
  "Tích Giang, Phúc Thọ, Hà Nội",
  "Thanh Đa, Phúc Thọ, Hà Nội",
  "Trạch Mỹ Lộc, Phúc Thọ, Hà Nội",
  "Phúc Hòa, Phúc Thọ, Hà Nội",
  "Ngọc Tảo, Phúc Thọ, Hà Nội",
  "Phụng Thượng, Phúc Thọ, Hà Nội",
  "Tam Thuấn, Phúc Thọ, Hà Nội",
  "Tam Hiệp, Phúc Thọ, Hà Nội",
  "Hiệp Thuận, Phúc Thọ, Hà Nội",
  "Liên Hiệp, Phúc Thọ, Hà Nội",
  "Phùng, Đan Phượng, Hà Nội",
  "Trung Châu, Đan Phượng, Hà Nội",
  "Thọ An, Đan Phượng, Hà Nội",
  "Thọ Xuân, Đan Phượng, Hà Nội",
  "Hồng Hà, Đan Phượng, Hà Nội",
  "Liên Hồng, Đan Phượng, Hà Nội",
  "Liên Hà, Đan Phượng, Hà Nội",
  "Hạ Mỗ, Đan Phượng, Hà Nội",
  "Liên Trung, Đan Phượng, Hà Nội",
  "Phương Đình, Đan Phượng, Hà Nội",
  "Thượng Mỗ, Đan Phượng, Hà Nội",
  "Tân Hội, Đan Phượng, Hà Nội",
  "Tân Lập, Đan Phượng, Hà Nội",
  "Đan Phượng, Đan Phượng, Hà Nội",
  "Đồng Tháp, Đan Phượng, Hà Nội",
  "Song Phượng, Đan Phượng, Hà Nội",
  "Trạm Trôi, Hoài Đức, Hà Nội",
  "Đức Thượng, Hoài Đức, Hà Nội",
  "Minh Khai, Hoài Đức, Hà Nội",
  "Dương Liễu, Hoài Đức, Hà Nội",
  "Di Trạch, Hoài Đức, Hà Nội",
  "Đức Giang, Hoài Đức, Hà Nội",
  "Cát Quế, Hoài Đức, Hà Nội",
  "Kim Chung, Hoài Đức, Hà Nội",
  "Yên Sở, Hoài Đức, Hà Nội",
  "Sơn Đồng, Hoài Đức, Hà Nội",
  "Vân Canh, Hoài Đức, Hà Nội",
  "Đắc Sở, Hoài Đức, Hà Nội",
  "Lại Yên, Hoài Đức, Hà Nội",
  "Tiền Yên, Hoài Đức, Hà Nội",
  "Song Phương, Hoài Đức, Hà Nội",
  "An Khánh, Hoài Đức, Hà Nội",
  "An Thượng, Hoài Đức, Hà Nội",
  "Vân Côn, Hoài Đức, Hà Nội",
  "La Phù, Hoài Đức, Hà Nội",
  "Đông La, Hoài Đức, Hà Nội",
  "Đông Xuân, Quốc Oai, Hà Nội",
  "Quốc Oai, Quốc Oai, Hà Nội",
  "Sài Sơn, Quốc Oai, Hà Nội",
  "Phượng Cách, Quốc Oai, Hà Nội",
  "Yên Sơn, Quốc Oai, Hà Nội",
  "Ngọc Liệp, Quốc Oai, Hà Nội",
  "Ngọc Mỹ, Quốc Oai, Hà Nội",
  "Liệp Tuyết, Quốc Oai, Hà Nội",
  "Thạch Thán, Quốc Oai, Hà Nội",
  "Đồng Quang, Quốc Oai, Hà Nội",
  "Phú Cát, Quốc Oai, Hà Nội",
  "Tuyết Nghĩa, Quốc Oai, Hà Nội",
  "Nghĩa Hương, Quốc Oai, Hà Nội",
  "Cộng Hòa, Quốc Oai, Hà Nội",
  "Tân Phú, Quốc Oai, Hà Nội",
  "Đại Thành, Quốc Oai, Hà Nội",
  "Phú Mãn, Quốc Oai, Hà Nội",
  "Cấn Hữu, Quốc Oai, Hà Nội",
  "Tân Hòa, Quốc Oai, Hà Nội",
  "Hòa Thạch, Quốc Oai, Hà Nội",
  "Đông Yên, Quốc Oai, Hà Nội",
  "Yên Trung, Thạch Thất, Hà Nội",
  "Yên Bình, Thạch Thất, Hà Nội",
  "Tiến Xuân, Thạch Thất, Hà Nội",
  "Liên Quan, Thạch Thất, Hà Nội",
  "Đại Đồng, Thạch Thất, Hà Nội",
  "Cẩm Yên, Thạch Thất, Hà Nội",
  "Lại Thượng, Thạch Thất, Hà Nội",
  "Phú Kim, Thạch Thất, Hà Nội",
  "Hương Ngải, Thạch Thất, Hà Nội",
  "Canh Nậu, Thạch Thất, Hà Nội",
  "Kim Quan, Thạch Thất, Hà Nội",
  "Dị Nậu, Thạch Thất, Hà Nội",
  "Bình Yên, Thạch Thất, Hà Nội",
  "Chàng Sơn, Thạch Thất, Hà Nội",
  "Thạch Hoà, Thạch Thất, Hà Nội",
  "Cần Kiệm, Thạch Thất, Hà Nội",
  "Hữu Bằng, Thạch Thất, Hà Nội",
  "Phùng Xá, Thạch Thất, Hà Nội",
  "Tân Xã, Thạch Thất, Hà Nội",
  "Thạch Xá, Thạch Thất, Hà Nội",
  "Bình Phú, Thạch Thất, Hà Nội",
  "Hạ Bằng, Thạch Thất, Hà Nội",
  "Đồng Trúc, Thạch Thất, Hà Nội",
  "Chúc Sơn, Chương Mỹ, Hà Nội",
  "Xuân Mai, Chương Mỹ, Hà Nội",
  "Phụng Châu, Chương Mỹ, Hà Nội",
  "Tiên Phương, Chương Mỹ, Hà Nội",
  "Đông Sơn, Chương Mỹ, Hà Nội",
  "Đông Phương Yên, Chương Mỹ, Hà Nội",
  "Phú Nghĩa, Chương Mỹ, Hà Nội",
  "Trường Yên, Chương Mỹ, Hà Nội",
  "Ngọc Hòa, Chương Mỹ, Hà Nội",
  "Thủy Xuân Tiên, Chương Mỹ, Hà Nội",
  "Thanh Bình, Chương Mỹ, Hà Nội",
  "Trung Hòa, Chương Mỹ, Hà Nội",
  "Đại Yên, Chương Mỹ, Hà Nội",
  "Thụy Hương, Chương Mỹ, Hà Nội",
  "Tốt Động, Chương Mỹ, Hà Nội",
  "Lam Điền, Chương Mỹ, Hà Nội",
  "Tân Tiến, Chương Mỹ, Hà Nội",
  "Nam Phương Tiến, Chương Mỹ, Hà Nội",
  "Hợp Đồng, Chương Mỹ, Hà Nội",
  "Hoàng Văn Thụ, Chương Mỹ, Hà Nội",
  "Hoàng Diệu, Chương Mỹ, Hà Nội",
  "Hữu Văn, Chương Mỹ, Hà Nội",
  "Quảng Bị, Chương Mỹ, Hà Nội",
  "Mỹ Lương, Chương Mỹ, Hà Nội",
  "Thượng Vực, Chương Mỹ, Hà Nội",
  "Hồng Phong, Chương Mỹ, Hà Nội",
  "Đồng Phú, Chương Mỹ, Hà Nội",
  "Trần Phú, Chương Mỹ, Hà Nội",
  "Văn Võ, Chương Mỹ, Hà Nội",
  "Đồng Lạc, Chương Mỹ, Hà Nội",
  "Hòa Chính, Chương Mỹ, Hà Nội",
  "Phú Nam An, Chương Mỹ, Hà Nội",
  "Kim Bài, Thanh Oai, Hà Nội",
  "Cự Khê, Thanh Oai, Hà Nội",
  "Bích Hòa, Thanh Oai, Hà Nội",
  "Mỹ Hưng, Thanh Oai, Hà Nội",
  "Cao Viên, Thanh Oai, Hà Nội",
  "Bình Minh, Thanh Oai, Hà Nội",
  "Tam Hưng, Thanh Oai, Hà Nội",
  "Thanh Cao, Thanh Oai, Hà Nội",
  "Thanh Thùy, Thanh Oai, Hà Nội",
  "Thanh Mai, Thanh Oai, Hà Nội",
  "Thanh Văn, Thanh Oai, Hà Nội",
  "Đỗ Động, Thanh Oai, Hà Nội",
  "Kim An, Thanh Oai, Hà Nội",
  "Kim Thư, Thanh Oai, Hà Nội",
  "Phương Trung, Thanh Oai, Hà Nội",
  "Tân Ước, Thanh Oai, Hà Nội",
  "Dân Hòa, Thanh Oai, Hà Nội",
  "Liên Châu, Thanh Oai, Hà Nội",
  "Cao Dương, Thanh Oai, Hà Nội",
  "Xuân Dương, Thanh Oai, Hà Nội",
  "Hồng Dương, Thanh Oai, Hà Nội",
  "Thường Tín, Thường Tín, Hà Nội",
  "Ninh Sở, Thường Tín, Hà Nội",
  "Nhị Khê, Thường Tín, Hà Nội",
  "Duyên Thái, Thường Tín, Hà Nội",
  "Khánh Hà, Thường Tín, Hà Nội",
  "Hòa Bình, Thường Tín, Hà Nội",
  "Văn Bình, Thường Tín, Hà Nội",
  "Hiền Giang, Thường Tín, Hà Nội",
  "Hồng Vân, Thường Tín, Hà Nội",
  "Vân Tảo, Thường Tín, Hà Nội",
  "Liên Phương, Thường Tín, Hà Nội",
  "Văn Phú, Thường Tín, Hà Nội",
  "Tự Nhiên, Thường Tín, Hà Nội",
  "Tiền Phong, Thường Tín, Hà Nội",
  "Hà Hồi, Thường Tín, Hà Nội",
  "Thư Phú, Thường Tín, Hà Nội",
  "Nguyễn Trãi, Thường Tín, Hà Nội",
  "Quất Động, Thường Tín, Hà Nội",
  "Chương Dương, Thường Tín, Hà Nội",
  "Tân Minh, Thường Tín, Hà Nội",
  "Lê Lợi, Thường Tín, Hà Nội",
  "Thắng Lợi, Thường Tín, Hà Nội",
  "Dũng Tiến, Thường Tín, Hà Nội",
  "Thống Nhất, Thường Tín, Hà Nội",
  "Nghiêm Xuyên, Thường Tín, Hà Nội",
  "Tô Hiệu, Thường Tín, Hà Nội",
  "Văn Tự, Thường Tín, Hà Nội",
  "Vạn Điểm, Thường Tín, Hà Nội",
  "Minh Cường, Thường Tín, Hà Nội",
  "Phú Minh, Phú Xuyên, Hà Nội",
  "Phú Xuyên, Phú Xuyên, Hà Nội",
  "Hồng Minh, Phú Xuyên, Hà Nội",
  "Phượng Dực, Phú Xuyên, Hà Nội",
  "Nam Tiến, Phú Xuyên, Hà Nội",
  "Tri Trung, Phú Xuyên, Hà Nội",
  "Đại Thắng, Phú Xuyên, Hà Nội",
  "Phú Túc, Phú Xuyên, Hà Nội",
  "Văn Hoàng, Phú Xuyên, Hà Nội",
  "Hồng Thái, Phú Xuyên, Hà Nội",
  "Hoàng Long, Phú Xuyên, Hà Nội",
  "Quang Trung, Phú Xuyên, Hà Nội",
  "Nam Phong, Phú Xuyên, Hà Nội",
  "Nam Triều, Phú Xuyên, Hà Nội",
  "Tân Dân, Phú Xuyên, Hà Nội",
  "Sơn Hà, Phú Xuyên, Hà Nội",
  "Chuyên Mỹ, Phú Xuyên, Hà Nội",
  "Khai Thái, Phú Xuyên, Hà Nội",
  "Phúc Tiến, Phú Xuyên, Hà Nội",
  "Vân Từ, Phú Xuyên, Hà Nội",
  "Tri Thủy, Phú Xuyên, Hà Nội",
  "Đại Xuyên, Phú Xuyên, Hà Nội",
  "Phú Yên, Phú Xuyên, Hà Nội",
  "Bạch Hạ, Phú Xuyên, Hà Nội",
  "Quang Lãng, Phú Xuyên, Hà Nội",
  "Châu Can, Phú Xuyên, Hà Nội",
  "Minh Tân, Phú Xuyên, Hà Nội",
  "Vân Đình, Ứng Hòa, Hà Nội",
  "Viên An, Ứng Hòa, Hà Nội",
  "Viên Nội, Ứng Hòa, Hà Nội",
  "Hoa Sơn, Ứng Hòa, Hà Nội",
  "Quảng Phú Cầu, Ứng Hòa, Hà Nội",
  "Trường Thịnh, Ứng Hòa, Hà Nội",
  "Cao Thành, Ứng Hòa, Hà Nội",
  "Liên Bạt, Ứng Hòa, Hà Nội",
  "Sơn Công, Ứng Hòa, Hà Nội",
  "Đồng Tiến, Ứng Hòa, Hà Nội",
  "Phương Tú, Ứng Hòa, Hà Nội",
  "Trung Tú, Ứng Hòa, Hà Nội",
  "Đồng Tân, Ứng Hòa, Hà Nội",
  "Tảo Dương Văn, Ứng Hòa, Hà Nội",
  "Vạn Thái, Ứng Hòa, Hà Nội",
  "Minh Đức, Ứng Hòa, Hà Nội",
  "Hòa Lâm, Ứng Hòa, Hà Nội",
  "Hòa Xá, Ứng Hòa, Hà Nội",
  "Trầm Lộng, Ứng Hòa, Hà Nội",
  "Kim Đường, Ứng Hòa, Hà Nội",
  "Hòa Nam, Ứng Hòa, Hà Nội",
  "Hòa Phú, Ứng Hòa, Hà Nội",
  "Đội Bình, Ứng Hòa, Hà Nội",
  "Đại Hùng, Ứng Hòa, Hà Nội",
  "Đông Lỗ, Ứng Hòa, Hà Nội",
  "Phù Lưu, Ứng Hòa, Hà Nội",
  "Đại Cường, Ứng Hòa, Hà Nội",
  "Lưu Hoàng, Ứng Hòa, Hà Nội",
  "Hồng Quang, Ứng Hòa, Hà Nội",
  "Đại Nghĩa, Mỹ Đức, Hà Nội",
  "Đồng Tâm, Mỹ Đức, Hà Nội",
  "Thượng Lâm, Mỹ Đức, Hà Nội",
  "Tuy Lai, Mỹ Đức, Hà Nội",
  "Phúc Lâm, Mỹ Đức, Hà Nội",
  "Mỹ Thành, Mỹ Đức, Hà Nội",
  "Bột Xuyên, Mỹ Đức, Hà Nội",
  "An Mỹ, Mỹ Đức, Hà Nội",
  "Hồng Sơn, Mỹ Đức, Hà Nội",
  "Lê Thanh, Mỹ Đức, Hà Nội",
  "Xuy Xá, Mỹ Đức, Hà Nội",
  "Phùng Xá, Mỹ Đức, Hà Nội",
  "Phù Lưu Tế, Mỹ Đức, Hà Nội",
  "Đại Hưng, Mỹ Đức, Hà Nội",
  "Vạn Kim, Mỹ Đức, Hà Nội",
  "Đốc Tín, Mỹ Đức, Hà Nội",
  "Hương Sơn, Mỹ Đức, Hà Nội",
  "Hùng Tiến, Mỹ Đức, Hà Nội",
  "An Tiến, Mỹ Đức, Hà Nội",
  "Hợp Tiến, Mỹ Đức, Hà Nội",
  "Hợp Thanh, Mỹ Đức, Hà Nội",
  "An Phú, Mỹ Đức, Hà Nội",
  "Quang Trung, Hà Giang, Hà Giang",
  "Trần Phú, Hà Giang, Hà Giang",
  "Ngọc Hà, Hà Giang, Hà Giang",
  "Nguyễn Trãi, Hà Giang, Hà Giang",
  "Minh Khai, Hà Giang, Hà Giang",
  "Ngọc Đường, Hà Giang, Hà Giang",
  "Phương Độ, Hà Giang, Hà Giang",
  "Phương Thiện, Hà Giang, Hà Giang",
  "Phó Bảng, Đồng Văn, Hà Giang",
  "Lũng Cú, Đồng Văn, Hà Giang",
  "Má Lé, Đồng Văn, Hà Giang",
  "Đồng Văn, Đồng Văn, Hà Giang",
  "Lũng Táo, Đồng Văn, Hà Giang",
  "Phố Là, Đồng Văn, Hà Giang",
  "Thài Phìn Tủng, Đồng Văn, Hà Giang",
  "Sủng Là, Đồng Văn, Hà Giang",
  "Xà Phìn, Đồng Văn, Hà Giang",
  "Tả Phìn, Đồng Văn, Hà Giang",
  "Tả Lủng, Đồng Văn, Hà Giang",
  "Phố Cáo, Đồng Văn, Hà Giang",
  "Sính Lủng, Đồng Văn, Hà Giang",
  "Sảng Tủng, Đồng Văn, Hà Giang",
  "Lũng Thầu, Đồng Văn, Hà Giang",
  "Hố Quáng Phìn, Đồng Văn, Hà Giang",
  "Vần Chải, Đồng Văn, Hà Giang",
  "Lũng Phìn, Đồng Văn, Hà Giang",
  "Sủng Trái, Đồng Văn, Hà Giang",
  "Mèo Vạc, Mèo Vạc, Hà Giang",
  "Thượng Phùng, Mèo Vạc, Hà Giang",
  "Pải Lủng, Mèo Vạc, Hà Giang",
  "Xín Cái, Mèo Vạc, Hà Giang",
  "Pả Vi, Mèo Vạc, Hà Giang",
  "Giàng Chu Phìn, Mèo Vạc, Hà Giang",
  "Sủng Trà, Mèo Vạc, Hà Giang",
  "Sủng Máng, Mèo Vạc, Hà Giang",
  "Sơn Vĩ, Mèo Vạc, Hà Giang",
  "Tả Lủng, Mèo Vạc, Hà Giang",
  "Cán Chu Phìn, Mèo Vạc, Hà Giang",
  "Lũng Pù, Mèo Vạc, Hà Giang",
  "Lũng Chinh, Mèo Vạc, Hà Giang",
  "Tát Ngà, Mèo Vạc, Hà Giang",
  "Nậm Ban, Mèo Vạc, Hà Giang",
  "Khâu Vai, Mèo Vạc, Hà Giang",
  "Niêm Tòng, Mèo Vạc, Hà Giang",
  "Niêm Sơn, Mèo Vạc, Hà Giang",
  "Yên Minh, Yên Minh, Hà Giang",
  "Thắng Mố, Yên Minh, Hà Giang",
  "Phú Lũng, Yên Minh, Hà Giang",
  "Sủng Tráng, Yên Minh, Hà Giang",
  "Bạch Đích, Yên Minh, Hà Giang",
  "Na Khê, Yên Minh, Hà Giang",
  "Sủng Thài, Yên Minh, Hà Giang",
  "Hữu Vinh, Yên Minh, Hà Giang",
  "Lao Và Chải, Yên Minh, Hà Giang",
  "Mậu Duệ, Yên Minh, Hà Giang",
  "Đông Minh, Yên Minh, Hà Giang",
  "Mậu Long, Yên Minh, Hà Giang",
  "Ngam La, Yên Minh, Hà Giang",
  "Ngọc Long, Yên Minh, Hà Giang",
  "Đường Thượng, Yên Minh, Hà Giang",
  "Lũng Hồ, Yên Minh, Hà Giang",
  "Du Tiến, Yên Minh, Hà Giang",
  "Du Già, Yên Minh, Hà Giang",
  "Tam Sơn, Quản Bạ, Hà Giang",
  "Bát Đại Sơn, Quản Bạ, Hà Giang",
  "Nghĩa Thuận, Quản Bạ, Hà Giang",
  "Cán Tỷ, Quản Bạ, Hà Giang",
  "Cao Mã Pờ, Quản Bạ, Hà Giang",
  "Thanh Vân, Quản Bạ, Hà Giang",
  "Tùng Vài, Quản Bạ, Hà Giang",
  "Đông Hà, Quản Bạ, Hà Giang",
  "Quản Bạ, Quản Bạ, Hà Giang",
  "Lùng Tám, Quản Bạ, Hà Giang",
  "Quyết Tiến, Quản Bạ, Hà Giang",
  "Tả Ván, Quản Bạ, Hà Giang",
  "Thái An, Quản Bạ, Hà Giang",
  "Kim Thạch, Vị Xuyên, Hà Giang",
  "Phú Linh, Vị Xuyên, Hà Giang",
  "Kim Linh, Vị Xuyên, Hà Giang",
  "Vị Xuyên, Vị Xuyên, Hà Giang",
  "Nông Trường Việt Lâm, Vị Xuyên, Hà Giang",
  "Minh Tân, Vị Xuyên, Hà Giang",
  "Thuận Hoà, Vị Xuyên, Hà Giang",
  "Tùng Bá, Vị Xuyên, Hà Giang",
  "Thanh Thủy, Vị Xuyên, Hà Giang",
  "Thanh Đức, Vị Xuyên, Hà Giang",
  "Phong Quang, Vị Xuyên, Hà Giang",
  "Xín Chải, Vị Xuyên, Hà Giang",
  "Phương Tiến, Vị Xuyên, Hà Giang",
  "Lao Chải, Vị Xuyên, Hà Giang",
  "Cao Bồ, Vị Xuyên, Hà Giang",
  "Đạo Đức, Vị Xuyên, Hà Giang",
  "Thượng Sơn, Vị Xuyên, Hà Giang",
  "Linh Hồ, Vị Xuyên, Hà Giang",
  "Quảng Ngần, Vị Xuyên, Hà Giang",
  "Việt Lâm, Vị Xuyên, Hà Giang",
  "Ngọc Linh, Vị Xuyên, Hà Giang",
  "Ngọc Minh, Vị Xuyên, Hà Giang",
  "Bạch Ngọc, Vị Xuyên, Hà Giang",
  "Trung Thành, Vị Xuyên, Hà Giang",
  "Minh Sơn, Bắc Mê, Hà Giang",
  "Giáp Trung, Bắc Mê, Hà Giang",
  "Yên Định, Bắc Mê, Hà Giang",
  "Yên Phú, Bắc Mê, Hà Giang",
  "Minh Ngọc, Bắc Mê, Hà Giang",
  "Yên Phong, Bắc Mê, Hà Giang",
  "Lạc Nông, Bắc Mê, Hà Giang",
  "Phú Nam, Bắc Mê, Hà Giang",
  "Yên Cường, Bắc Mê, Hà Giang",
  "Thượng Tân, Bắc Mê, Hà Giang",
  "Đường Âm, Bắc Mê, Hà Giang",
  "Đường Hồng, Bắc Mê, Hà Giang",
  "Phiêng Luông, Bắc Mê, Hà Giang",
  "Vinh Quang, Hoàng Su Phì, Hà Giang",
  "Bản Máy, Hoàng Su Phì, Hà Giang",
  "Thàng Tín, Hoàng Su Phì, Hà Giang",
  "Thèn Chu Phìn, Hoàng Su Phì, Hà Giang",
  "Pố Lồ, Hoàng Su Phì, Hà Giang",
  "Bản Phùng, Hoàng Su Phì, Hà Giang",
  "Túng Sán, Hoàng Su Phì, Hà Giang",
  "Chiến Phố, Hoàng Su Phì, Hà Giang",
  "Đản Ván, Hoàng Su Phì, Hà Giang",
  "Tụ Nhân, Hoàng Su Phì, Hà Giang",
  "Tân Tiến, Hoàng Su Phì, Hà Giang",
  "Nàng Đôn, Hoàng Su Phì, Hà Giang",
  "Pờ Ly Ngài, Hoàng Su Phì, Hà Giang",
  "Sán Xả Hồ, Hoàng Su Phì, Hà Giang",
  "Bản Luốc, Hoàng Su Phì, Hà Giang",
  "Ngàm Đăng Vài, Hoàng Su Phì, Hà Giang",
  "Bản Nhùng, Hoàng Su Phì, Hà Giang",
  "Tả Sử Choóng, Hoàng Su Phì, Hà Giang",
  "Nậm Dịch, Hoàng Su Phì, Hà Giang",
  "Hồ Thầu, Hoàng Su Phì, Hà Giang",
  "Nam Sơn, Hoàng Su Phì, Hà Giang",
  "Nậm Tỵ, Hoàng Su Phì, Hà Giang",
  "Thông Nguyên, Hoàng Su Phì, Hà Giang",
  "Nậm Khòa, Hoàng Su Phì, Hà Giang",
  "Cốc Pài, Xín Mần, Hà Giang",
  "Nàn Xỉn, Xín Mần, Hà Giang",
  "Bản Díu, Xín Mần, Hà Giang",
  "Chí Cà, Xín Mần, Hà Giang",
  "Xín Mần, Xín Mần, Hà Giang",
  "Thèn Phàng, Xín Mần, Hà Giang",
  "Trung Thịnh, Xín Mần, Hà Giang",
  "Pà Vầy Sủ, Xín Mần, Hà Giang",
  "Cốc Rế, Xín Mần, Hà Giang",
  "Thu Tà, Xín Mần, Hà Giang",
  "Nàn Ma, Xín Mần, Hà Giang",
  "Tả Nhìu, Xín Mần, Hà Giang",
  "Bản Ngò, Xín Mần, Hà Giang",
  "Chế Là, Xín Mần, Hà Giang",
  "Nấm Dẩn, Xín Mần, Hà Giang",
  "Quảng Nguyên, Xín Mần, Hà Giang",
  "Nà Chì, Xín Mần, Hà Giang",
  "Khuôn Lùng, Xín Mần, Hà Giang",
  "Việt Quang, Bắc Quang, Hà Giang",
  "Vĩnh Tuy, Bắc Quang, Hà Giang",
  "Tân Lập, Bắc Quang, Hà Giang",
  "Tân Thành, Bắc Quang, Hà Giang",
  "Đồng Tiến, Bắc Quang, Hà Giang",
  "Đồng Tâm, Bắc Quang, Hà Giang",
  "Tân Quang, Bắc Quang, Hà Giang",
  "Thượng Bình, Bắc Quang, Hà Giang",
  "Hữu Sản, Bắc Quang, Hà Giang",
  "Kim Ngọc, Bắc Quang, Hà Giang",
  "Việt Vinh, Bắc Quang, Hà Giang",
  "Bằng Hành, Bắc Quang, Hà Giang",
  "Quang Minh, Bắc Quang, Hà Giang",
  "Liên Hiệp, Bắc Quang, Hà Giang",
  "Vô Điếm, Bắc Quang, Hà Giang",
  "Việt Hồng, Bắc Quang, Hà Giang",
  "Hùng An, Bắc Quang, Hà Giang",
  "Đức Xuân, Bắc Quang, Hà Giang",
  "Tiên Kiều, Bắc Quang, Hà Giang",
  "Vĩnh Hảo, Bắc Quang, Hà Giang",
  "Vĩnh Phúc, Bắc Quang, Hà Giang",
  "Đồng Yên, Bắc Quang, Hà Giang",
  "Đông Thành, Bắc Quang, Hà Giang",
  "Xuân Minh, Quang Bình, Hà Giang",
  "Tiên Nguyên, Quang Bình, Hà Giang",
  "Tân Nam, Quang Bình, Hà Giang",
  "Bản Rịa, Quang Bình, Hà Giang",
  "Yên Thành, Quang Bình, Hà Giang",
  "Yên Bình, Quang Bình, Hà Giang",
  "Tân Trịnh, Quang Bình, Hà Giang",
  "Tân Bắc, Quang Bình, Hà Giang",
  "Bằng Lang, Quang Bình, Hà Giang",
  "Yên Hà, Quang Bình, Hà Giang",
  "Hương Sơn, Quang Bình, Hà Giang",
  "Xuân Giang, Quang Bình, Hà Giang",
  "Nà Khương, Quang Bình, Hà Giang",
  "Tiên Yên, Quang Bình, Hà Giang",
  "Vĩ Thượng, Quang Bình, Hà Giang",
  "Sông Hiến, Cao Bằng, Cao Bằng",
  "Sông Bằng, Cao Bằng, Cao Bằng",
  "Hợp Giang, Cao Bằng, Cao Bằng",
  "Tân Giang, Cao Bằng, Cao Bằng",
  "Ngọc Xuân, Cao Bằng, Cao Bằng",
  "Đề Thám, Cao Bằng, Cao Bằng",
  "Hoà Chung, Cao Bằng, Cao Bằng",
  "Duyệt Trung, Cao Bằng, Cao Bằng",
  "Vĩnh Quang, Cao Bằng, Cao Bằng",
  "Hưng Đạo, Cao Bằng, Cao Bằng",
  "Chu Trinh, Cao Bằng, Cao Bằng",
  "Pác Miầu, Bảo Lâm, Cao Bằng",
  "Đức Hạnh, Bảo Lâm, Cao Bằng",
  "Lý Bôn, Bảo Lâm, Cao Bằng",
  "Nam Cao, Bảo Lâm, Cao Bằng",
  "Nam Quang, Bảo Lâm, Cao Bằng",
  "Vĩnh Quang, Bảo Lâm, Cao Bằng",
  "Quảng Lâm, Bảo Lâm, Cao Bằng",
  "Thạch Lâm, Bảo Lâm, Cao Bằng",
  "Vĩnh Phong, Bảo Lâm, Cao Bằng",
  "Mông Ân, Bảo Lâm, Cao Bằng",
  "Thái Học, Bảo Lâm, Cao Bằng",
  "Thái Sơn, Bảo Lâm, Cao Bằng",
  "Yên Thổ, Bảo Lâm, Cao Bằng",
  "Bảo Lạc, Bảo Lạc, Cao Bằng",
  "Cốc Pàng, Bảo Lạc, Cao Bằng",
  "Thượng Hà, Bảo Lạc, Cao Bằng",
  "Cô Ba, Bảo Lạc, Cao Bằng",
  "Bảo Toàn, Bảo Lạc, Cao Bằng",
  "Khánh Xuân, Bảo Lạc, Cao Bằng",
  "Xuân Trường, Bảo Lạc, Cao Bằng",
  "Hồng Trị, Bảo Lạc, Cao Bằng",
  "Kim Cúc, Bảo Lạc, Cao Bằng",
  "Phan Thanh, Bảo Lạc, Cao Bằng",
  "Hồng An, Bảo Lạc, Cao Bằng",
  "Hưng Đạo, Bảo Lạc, Cao Bằng",
  "Hưng Thịnh, Bảo Lạc, Cao Bằng",
  "Huy Giáp, Bảo Lạc, Cao Bằng",
  "Đình Phùng, Bảo Lạc, Cao Bằng",
  "Sơn Lập, Bảo Lạc, Cao Bằng",
  "Sơn Lộ, Bảo Lạc, Cao Bằng",
  "Thông Nông, Hà Quảng, Cao Bằng",
  "Cần Yên, Hà Quảng, Cao Bằng",
  "Cần Nông, Hà Quảng, Cao Bằng",
  "Lương Thông, Hà Quảng, Cao Bằng",
  "Đa Thông, Hà Quảng, Cao Bằng",
  "Ngọc Động, Hà Quảng, Cao Bằng",
  "Yên Sơn, Hà Quảng, Cao Bằng",
  "Lương Can, Hà Quảng, Cao Bằng",
  "Thanh Long, Hà Quảng, Cao Bằng",
  "Xuân Hòa, Hà Quảng, Cao Bằng",
  "Lũng Nặm, Hà Quảng, Cao Bằng",
  "Trường Hà, Hà Quảng, Cao Bằng",
  "Cải Viên, Hà Quảng, Cao Bằng",
  "Nội Thôn, Hà Quảng, Cao Bằng",
  "Tổng Cọt, Hà Quảng, Cao Bằng",
  "Sóc Hà, Hà Quảng, Cao Bằng",
  "Thượng Thôn, Hà Quảng, Cao Bằng",
  "Hồng Sỹ, Hà Quảng, Cao Bằng",
  "Quý Quân, Hà Quảng, Cao Bằng",
  "Mã Ba, Hà Quảng, Cao Bằng",
  "Ngọc Đào, Hà Quảng, Cao Bằng",
  "Trà Lĩnh, Trùng Khánh, Cao Bằng",
  "Tri Phương, Trùng Khánh, Cao Bằng",
  "Quang Hán, Trùng Khánh, Cao Bằng",
  "Xuân Nội, Trùng Khánh, Cao Bằng",
  "Quang Trung, Trùng Khánh, Cao Bằng",
  "Quang Vinh, Trùng Khánh, Cao Bằng",
  "Cao Chương, Trùng Khánh, Cao Bằng",
  "Trùng Khánh, Trùng Khánh, Cao Bằng",
  "Ngọc Khê, Trùng Khánh, Cao Bằng",
  "Ngọc Côn, Trùng Khánh, Cao Bằng",
  "Phong Nậm, Trùng Khánh, Cao Bằng",
  "Đình Phong, Trùng Khánh, Cao Bằng",
  "Đàm Thuỷ, Trùng Khánh, Cao Bằng",
  "Khâm Thành, Trùng Khánh, Cao Bằng",
  "Chí Viễn, Trùng Khánh, Cao Bằng",
  "Lăng Hiếu, Trùng Khánh, Cao Bằng",
  "Phong Châu, Trùng Khánh, Cao Bằng",
  "Trung Phúc, Trùng Khánh, Cao Bằng",
  "Cao Thăng, Trùng Khánh, Cao Bằng",
  "Đức Hồng, Trùng Khánh, Cao Bằng",
  "Đoài Dương, Trùng Khánh, Cao Bằng",
  "Minh Long, Hạ Lang, Cao Bằng",
  "Lý Quốc, Hạ Lang, Cao Bằng",
  "Thắng Lợi, Hạ Lang, Cao Bằng",
  "Đồng Loan, Hạ Lang, Cao Bằng",
  "Đức Quang, Hạ Lang, Cao Bằng",
  "Kim Loan, Hạ Lang, Cao Bằng",
  "Quang Long, Hạ Lang, Cao Bằng",
  "An Lạc, Hạ Lang, Cao Bằng",
  "Thanh Nhật, Hạ Lang, Cao Bằng",
  "Vinh Quý, Hạ Lang, Cao Bằng",
  "Thống Nhất, Hạ Lang, Cao Bằng",
  "Cô Ngân, Hạ Lang, Cao Bằng",
  "Thị Hoa, Hạ Lang, Cao Bằng",
  "Quốc Toản, Quảng Hòa, Cao Bằng",
  "Quảng Uyên, Quảng Hòa, Cao Bằng",
  "Phi Hải, Quảng Hòa, Cao Bằng",
  "Quảng Hưng, Quảng Hòa, Cao Bằng",
  "Độc Lập, Quảng Hòa, Cao Bằng",
  "Cai Bộ, Quảng Hòa, Cao Bằng",
  "Phúc Sen, Quảng Hòa, Cao Bằng",
  "Chí Thảo, Quảng Hòa, Cao Bằng",
  "Tự Do, Quảng Hòa, Cao Bằng",
  "Hồng Quang, Quảng Hòa, Cao Bằng",
  "Ngọc Động, Quảng Hòa, Cao Bằng",
  "Hạnh Phúc, Quảng Hòa, Cao Bằng",
  "Tà Lùng, Quảng Hòa, Cao Bằng",
  "Bế Văn Đàn, Quảng Hòa, Cao Bằng",
  "Cách Linh, Quảng Hòa, Cao Bằng",
  "Đại Sơn, Quảng Hòa, Cao Bằng",
  "Tiên Thành, Quảng Hòa, Cao Bằng",
  "Hoà Thuận, Quảng Hòa, Cao Bằng",
  "Mỹ Hưng, Quảng Hòa, Cao Bằng",
  "Nước Hai, Hoà An, Cao Bằng",
  "Dân Chủ, Hoà An, Cao Bằng",
  "Nam Tuấn, Hoà An, Cao Bằng",
  "Đại Tiến, Hoà An, Cao Bằng",
  "Đức Long, Hoà An, Cao Bằng",
  "Ngũ Lão, Hoà An, Cao Bằng",
  "Trương Lương, Hoà An, Cao Bằng",
  "Hồng Việt, Hoà An, Cao Bằng",
  "Hoàng Tung, Hoà An, Cao Bằng",
  "Nguyễn Huệ, Hoà An, Cao Bằng",
  "Quang Trung, Hoà An, Cao Bằng",
  "Bạch Đằng, Hoà An, Cao Bằng",
  "Bình Dương, Hoà An, Cao Bằng",
  "Lê Chung, Hoà An, Cao Bằng",
  "Hồng Nam, Hoà An, Cao Bằng",
  "Nguyên Bình, Nguyên Bình, Cao Bằng",
  "Tĩnh Túc, Nguyên Bình, Cao Bằng",
  "Yên Lạc, Nguyên Bình, Cao Bằng",
  "Triệu Nguyên, Nguyên Bình, Cao Bằng",
  "Ca Thành, Nguyên Bình, Cao Bằng",
  "Vũ Nông, Nguyên Bình, Cao Bằng",
  "Minh Tâm, Nguyên Bình, Cao Bằng",
  "Thể Dục, Nguyên Bình, Cao Bằng",
  "Mai Long, Nguyên Bình, Cao Bằng",
  "Vũ Minh, Nguyên Bình, Cao Bằng",
  "Hoa Thám, Nguyên Bình, Cao Bằng",
  "Phan Thanh, Nguyên Bình, Cao Bằng",
  "Quang Thành, Nguyên Bình, Cao Bằng",
  "Tam Kim, Nguyên Bình, Cao Bằng",
  "Thành Công, Nguyên Bình, Cao Bằng",
  "Thịnh Vượng, Nguyên Bình, Cao Bằng",
  "Hưng Đạo, Nguyên Bình, Cao Bằng",
  "Đông Khê, Thạch An, Cao Bằng",
  "Canh Tân, Thạch An, Cao Bằng",
  "Kim Đồng, Thạch An, Cao Bằng",
  "Minh Khai, Thạch An, Cao Bằng",
  "Đức Thông, Thạch An, Cao Bằng",
  "Thái Cường, Thạch An, Cao Bằng",
  "Vân Trình, Thạch An, Cao Bằng",
  "Thụy Hùng, Thạch An, Cao Bằng",
  "Quang Trọng, Thạch An, Cao Bằng",
  "Trọng Con, Thạch An, Cao Bằng",
  "Lê Lai, Thạch An, Cao Bằng",
  "Đức Long, Thạch An, Cao Bằng",
  "Lê Lợi, Thạch An, Cao Bằng",
  "Đức Xuân, Thạch An, Cao Bằng",
  "Nguyễn Thị Minh Khai, Bắc Kạn, Bắc Kạn",
  "Sông Cầu, Bắc Kạn, Bắc Kạn",
  "Đức Xuân, Bắc Kạn, Bắc Kạn",
  "Phùng Chí Kiên, Bắc Kạn, Bắc Kạn",
  "Huyền Tụng, Bắc Kạn, Bắc Kạn",
  "Dương Quang, Bắc Kạn, Bắc Kạn",
  "Nông Thượng, Bắc Kạn, Bắc Kạn",
  "Xuất Hóa, Bắc Kạn, Bắc Kạn",
  "Bằng Thành, Pác Nặm, Bắc Kạn",
  "Nhạn Môn, Pác Nặm, Bắc Kạn",
  "Bộc Bố, Pác Nặm, Bắc Kạn",
  "Công Bằng, Pác Nặm, Bắc Kạn",
  "Giáo Hiệu, Pác Nặm, Bắc Kạn",
  "Xuân La, Pác Nặm, Bắc Kạn",
  "An Thắng, Pác Nặm, Bắc Kạn",
  "Cổ Linh, Pác Nặm, Bắc Kạn",
  "Nghiên Loan, Pác Nặm, Bắc Kạn",
  "Cao Tân, Pác Nặm, Bắc Kạn",
  "Chợ Rã, Ba Bể, Bắc Kạn",
  "Bành Trạch, Ba Bể, Bắc Kạn",
  "Phúc Lộc, Ba Bể, Bắc Kạn",
  "Hà Hiệu, Ba Bể, Bắc Kạn",
  "Cao Thượng, Ba Bể, Bắc Kạn",
  "Khang Ninh, Ba Bể, Bắc Kạn",
  "Nam Mẫu, Ba Bể, Bắc Kạn",
  "Thượng Giáo, Ba Bể, Bắc Kạn",
  "Địa Linh, Ba Bể, Bắc Kạn",
  "Yến Dương, Ba Bể, Bắc Kạn",
  "Chu Hương, Ba Bể, Bắc Kạn",
  "Quảng Khê, Ba Bể, Bắc Kạn",
  "Mỹ Phương, Ba Bể, Bắc Kạn",
  "Hoàng Trĩ, Ba Bể, Bắc Kạn",
  "Đồng Phúc, Ba Bể, Bắc Kạn",
  "Nà Phặc, Ngân Sơn, Bắc Kạn",
  "Thượng Ân, Ngân Sơn, Bắc Kạn",
  "Bằng Vân, Ngân Sơn, Bắc Kạn",
  "Cốc Đán, Ngân Sơn, Bắc Kạn",
  "Trung Hoà, Ngân Sơn, Bắc Kạn",
  "Đức Vân, Ngân Sơn, Bắc Kạn",
  "Vân Tùng, Ngân Sơn, Bắc Kạn",
  "Thượng Quan, Ngân Sơn, Bắc Kạn",
  "Hiệp Lực, Ngân Sơn, Bắc Kạn",
  "Thuần Mang, Ngân Sơn, Bắc Kạn",
  "Phủ Thông, Bạch Thông, Bắc Kạn",
  "Vi Hương, Bạch Thông, Bắc Kạn",
  "Sĩ Bình, Bạch Thông, Bắc Kạn",
  "Vũ Muộn, Bạch Thông, Bắc Kạn",
  "Đôn Phong, Bạch Thông, Bắc Kạn",
  "Lục Bình, Bạch Thông, Bắc Kạn",
  "Tân Tú, Bạch Thông, Bắc Kạn",
  "Nguyên Phúc, Bạch Thông, Bắc Kạn",
  "Cao Sơn, Bạch Thông, Bắc Kạn",
  "Quân Hà, Bạch Thông, Bắc Kạn",
  "Cẩm Giàng, Bạch Thông, Bắc Kạn",
  "Mỹ Thanh, Bạch Thông, Bắc Kạn",
  "Dương Phong, Bạch Thông, Bắc Kạn",
  "Quang Thuận, Bạch Thông, Bắc Kạn",
  "Bằng Lũng, Chợ Đồn, Bắc Kạn",
  "Xuân Lạc, Chợ Đồn, Bắc Kạn",
  "Nam Cường, Chợ Đồn, Bắc Kạn",
  "Đồng Lạc, Chợ Đồn, Bắc Kạn",
  "Tân Lập, Chợ Đồn, Bắc Kạn",
  "Bản Thi, Chợ Đồn, Bắc Kạn",
  "Quảng Bạch, Chợ Đồn, Bắc Kạn",
  "Bằng Phúc, Chợ Đồn, Bắc Kạn",
  "Yên Thịnh, Chợ Đồn, Bắc Kạn",
  "Yên Thượng, Chợ Đồn, Bắc Kạn",
  "Phương Viên, Chợ Đồn, Bắc Kạn",
  "Ngọc Phái, Chợ Đồn, Bắc Kạn",
  "Đồng Thắng, Chợ Đồn, Bắc Kạn",
  "Lương Bằng, Chợ Đồn, Bắc Kạn",
  "Bằng Lãng, Chợ Đồn, Bắc Kạn",
  "Đại Sảo, Chợ Đồn, Bắc Kạn",
  "Nghĩa Tá, Chợ Đồn, Bắc Kạn",
  "Yên Mỹ, Chợ Đồn, Bắc Kạn",
  "Bình Trung, Chợ Đồn, Bắc Kạn",
  "Yên Phong, Chợ Đồn, Bắc Kạn",
  "Đồng Tâm, Chợ Mới, Bắc Kạn",
  "Tân Sơn, Chợ Mới, Bắc Kạn",
  "Thanh Vận, Chợ Mới, Bắc Kạn",
  "Mai Lạp, Chợ Mới, Bắc Kạn",
  "Hoà Mục, Chợ Mới, Bắc Kạn",
  "Thanh Mai, Chợ Mới, Bắc Kạn",
  "Cao Kỳ, Chợ Mới, Bắc Kạn",
  "Nông Hạ, Chợ Mới, Bắc Kạn",
  "Yên Cư, Chợ Mới, Bắc Kạn",
  "Thanh Thịnh, Chợ Mới, Bắc Kạn",
  "Yên Hân, Chợ Mới, Bắc Kạn",
  "Như Cố, Chợ Mới, Bắc Kạn",
  "Bình Văn, Chợ Mới, Bắc Kạn",
  "Quảng Chu, Chợ Mới, Bắc Kạn",
  "Văn Vũ, Na Rì, Bắc Kạn",
  "Văn Lang, Na Rì, Bắc Kạn",
  "Lương Thượng, Na Rì, Bắc Kạn",
  "Kim Hỷ, Na Rì, Bắc Kạn",
  "Cường Lợi, Na Rì, Bắc Kạn",
  "Yến Lạc, Na Rì, Bắc Kạn",
  "Kim Lư, Na Rì, Bắc Kạn",
  "Sơn Thành, Na Rì, Bắc Kạn",
  "Văn Minh, Na Rì, Bắc Kạn",
  "Côn Minh, Na Rì, Bắc Kạn",
  "Cư Lễ, Na Rì, Bắc Kạn",
  "Trần Phú, Na Rì, Bắc Kạn",
  "Quang Phong, Na Rì, Bắc Kạn",
  "Dương Sơn, Na Rì, Bắc Kạn",
  "Xuân Dương, Na Rì, Bắc Kạn",
  "Đổng Xá, Na Rì, Bắc Kạn",
  "Liêm Thuỷ, Na Rì, Bắc Kạn",
  "Phan Thiết, Tuyên Quang, Tuyên Quang",
  "Minh Xuân, Tuyên Quang, Tuyên Quang",
  "Tân Quang, Tuyên Quang, Tuyên Quang",
  "Tràng Đà, Tuyên Quang, Tuyên Quang",
  "Nông Tiến, Tuyên Quang, Tuyên Quang",
  "Ỷ La, Tuyên Quang, Tuyên Quang",
  "Tân Hà, Tuyên Quang, Tuyên Quang",
  "Hưng Thành, Tuyên Quang, Tuyên Quang",
  "Kim Phú, Tuyên Quang, Tuyên Quang",
  "An Khang, Tuyên Quang, Tuyên Quang",
  "Mỹ Lâm, Tuyên Quang, Tuyên Quang",
  "An Tường, Tuyên Quang, Tuyên Quang",
  "Lưỡng Vượng, Tuyên Quang, Tuyên Quang",
  "Thái Long, Tuyên Quang, Tuyên Quang",
  "Đội Cấn, Tuyên Quang, Tuyên Quang",
  "Phúc Yên, Lâm Bình, Tuyên Quang",
  "Xuân Lập, Lâm Bình, Tuyên Quang",
  "Khuôn Hà, Lâm Bình, Tuyên Quang",
  "Lăng Can, Lâm Bình, Tuyên Quang",
  "Thượng Lâm, Lâm Bình, Tuyên Quang",
  "Bình An, Lâm Bình, Tuyên Quang",
  "Hồng Quang, Lâm Bình, Tuyên Quang",
  "Thổ Bình, Lâm Bình, Tuyên Quang",
  "Na Hang, Na Hang, Tuyên Quang",
  "Sinh Long, Na Hang, Tuyên Quang",
  "Thượng Giáp, Na Hang, Tuyên Quang",
  "Thượng Nông, Na Hang, Tuyên Quang",
  "Côn Lôn, Na Hang, Tuyên Quang",
  "Yên Hoa, Na Hang, Tuyên Quang",
  "Hồng Thái, Na Hang, Tuyên Quang",
  "Đà Vị, Na Hang, Tuyên Quang",
  "Khau Tinh, Na Hang, Tuyên Quang",
  "Sơn Phú, Na Hang, Tuyên Quang",
  "Năng Khả, Na Hang, Tuyên Quang",
  "Thanh Tương, Na Hang, Tuyên Quang",
  "Vĩnh Lộc, Chiêm Hóa, Tuyên Quang",
  "Phúc Sơn, Chiêm Hóa, Tuyên Quang",
  "Minh Quang, Chiêm Hóa, Tuyên Quang",
  "Trung Hà, Chiêm Hóa, Tuyên Quang",
  "Tân Mỹ, Chiêm Hóa, Tuyên Quang",
  "Hà Lang, Chiêm Hóa, Tuyên Quang",
  "Hùng Mỹ, Chiêm Hóa, Tuyên Quang",
  "Yên Lập, Chiêm Hóa, Tuyên Quang",
  "Tân An, Chiêm Hóa, Tuyên Quang",
  "Bình Phú, Chiêm Hóa, Tuyên Quang",
  "Xuân Quang, Chiêm Hóa, Tuyên Quang",
  "Ngọc Hội, Chiêm Hóa, Tuyên Quang",
  "Phú Bình, Chiêm Hóa, Tuyên Quang",
  "Hòa Phú, Chiêm Hóa, Tuyên Quang",
  "Phúc Thịnh, Chiêm Hóa, Tuyên Quang",
  "Kiên Đài, Chiêm Hóa, Tuyên Quang",
  "Tân Thịnh, Chiêm Hóa, Tuyên Quang",
  "Trung Hòa, Chiêm Hóa, Tuyên Quang",
  "Kim Bình, Chiêm Hóa, Tuyên Quang",
  "Hòa An, Chiêm Hóa, Tuyên Quang",
  "Vinh Quang, Chiêm Hóa, Tuyên Quang",
  "Tri Phú, Chiêm Hóa, Tuyên Quang",
  "Nhân Lý, Chiêm Hóa, Tuyên Quang",
  "Yên Nguyên, Chiêm Hóa, Tuyên Quang",
  "Linh Phú, Chiêm Hóa, Tuyên Quang",
  "Bình Nhân, Chiêm Hóa, Tuyên Quang",
  "Tân Yên, Hàm Yên, Tuyên Quang",
  "Yên Thuận, Hàm Yên, Tuyên Quang",
  "Bạch Xa, Hàm Yên, Tuyên Quang",
  "Minh Khương, Hàm Yên, Tuyên Quang",
  "Yên Lâm, Hàm Yên, Tuyên Quang",
  "Minh Dân, Hàm Yên, Tuyên Quang",
  "Phù Lưu, Hàm Yên, Tuyên Quang",
  "Minh Hương, Hàm Yên, Tuyên Quang",
  "Yên Phú, Hàm Yên, Tuyên Quang",
  "Tân Thành, Hàm Yên, Tuyên Quang",
  "Bình Xa, Hàm Yên, Tuyên Quang",
  "Thái Sơn, Hàm Yên, Tuyên Quang",
  "Nhân Mục, Hàm Yên, Tuyên Quang",
  "Thành Long, Hàm Yên, Tuyên Quang",
  "Bằng Cốc, Hàm Yên, Tuyên Quang",
  "Thái Hòa, Hàm Yên, Tuyên Quang",
  "Đức Ninh, Hàm Yên, Tuyên Quang",
  "Hùng Đức, Hàm Yên, Tuyên Quang",
  "Quí Quân, Yên Sơn, Tuyên Quang",
  "Lực Hành, Yên Sơn, Tuyên Quang",
  "Kiến Thiết, Yên Sơn, Tuyên Quang",
  "Trung Minh, Yên Sơn, Tuyên Quang",
  "Chiêu Yên, Yên Sơn, Tuyên Quang",
  "Trung Trực, Yên Sơn, Tuyên Quang",
  "Xuân Vân, Yên Sơn, Tuyên Quang",
  "Phúc Ninh, Yên Sơn, Tuyên Quang",
  "Hùng Lợi, Yên Sơn, Tuyên Quang",
  "Trung Sơn, Yên Sơn, Tuyên Quang",
  "Tân Tiến, Yên Sơn, Tuyên Quang",
  "Tứ Quận, Yên Sơn, Tuyên Quang",
  "Đạo Viện, Yên Sơn, Tuyên Quang",
  "Tân Long, Yên Sơn, Tuyên Quang",
  "Thắng Quân, Yên Sơn, Tuyên Quang",
  "Kim Quan, Yên Sơn, Tuyên Quang",
  "Lang Quán, Yên Sơn, Tuyên Quang",
  "Phú Thịnh, Yên Sơn, Tuyên Quang",
  "Công Đa, Yên Sơn, Tuyên Quang",
  "Trung Môn, Yên Sơn, Tuyên Quang",
  "Chân Sơn, Yên Sơn, Tuyên Quang",
  "Thái Bình, Yên Sơn, Tuyên Quang",
  "Tiến Bộ, Yên Sơn, Tuyên Quang",
  "Mỹ Bằng, Yên Sơn, Tuyên Quang",
  "Hoàng Khai, Yên Sơn, Tuyên Quang",
  "Nhữ Hán, Yên Sơn, Tuyên Quang",
  "Nhữ Khê, Yên Sơn, Tuyên Quang",
  "Đội Bình, Yên Sơn, Tuyên Quang",
  "Sơn Dương, Sơn Dương, Tuyên Quang",
  "Trung Yên, Sơn Dương, Tuyên Quang",
  "Minh Thanh, Sơn Dương, Tuyên Quang",
  "Tân Trào, Sơn Dương, Tuyên Quang",
  "Vĩnh Lợi, Sơn Dương, Tuyên Quang",
  "Thượng Ấm, Sơn Dương, Tuyên Quang",
  "Bình Yên, Sơn Dương, Tuyên Quang",
  "Lương Thiện, Sơn Dương, Tuyên Quang",
  "Tú Thịnh, Sơn Dương, Tuyên Quang",
  "Cấp Tiến, Sơn Dương, Tuyên Quang",
  "Hợp Thành, Sơn Dương, Tuyên Quang",
  "Phúc Ứng, Sơn Dương, Tuyên Quang",
  "Đông Thọ, Sơn Dương, Tuyên Quang",
  "Kháng Nhật, Sơn Dương, Tuyên Quang",
  "Hợp Hòa, Sơn Dương, Tuyên Quang",
  "Quyết Thắng, Sơn Dương, Tuyên Quang",
  "Đồng Quý, Sơn Dương, Tuyên Quang",
  "Tân Thanh, Sơn Dương, Tuyên Quang",
  "Vân Sơn, Sơn Dương, Tuyên Quang",
  "Văn Phú, Sơn Dương, Tuyên Quang",
  "Chi Thiết, Sơn Dương, Tuyên Quang",
  "Đông Lợi, Sơn Dương, Tuyên Quang",
  "Thiện Kế, Sơn Dương, Tuyên Quang",
  "Hồng Lạc, Sơn Dương, Tuyên Quang",
  "Phú Lương, Sơn Dương, Tuyên Quang",
  "Ninh Lai, Sơn Dương, Tuyên Quang",
  "Đại Phú, Sơn Dương, Tuyên Quang",
  "Sơn Nam, Sơn Dương, Tuyên Quang",
  "Hào Phú, Sơn Dương, Tuyên Quang",
  "Tam Đa, Sơn Dương, Tuyên Quang",
  "Trường Sinh, Sơn Dương, Tuyên Quang",
  "Duyên Hải, Lào Cai, Lào Cai",
  "Lào Cai, Lào Cai, Lào Cai",
  "Cốc Lếu, Lào Cai, Lào Cai",
  "Kim Tân, Lào Cai, Lào Cai",
  "Bắc Lệnh, Lào Cai, Lào Cai",
  "Pom Hán, Lào Cai, Lào Cai",
  "Xuân Tăng, Lào Cai, Lào Cai",
  "Bình Minh, Lào Cai, Lào Cai",
  "Thống Nhất, Lào Cai, Lào Cai",
  "Đồng Tuyển, Lào Cai, Lào Cai",
  "Vạn Hoà, Lào Cai, Lào Cai",
  "Bắc Cường, Lào Cai, Lào Cai",
  "Nam Cường, Lào Cai, Lào Cai",
  "Cam Đường, Lào Cai, Lào Cai",
  "Tả Phời, Lào Cai, Lào Cai",
  "Hợp Thành, Lào Cai, Lào Cai",
  "Cốc San, Lào Cai, Lào Cai",
  "Bát Xát, Bát Xát, Lào Cai",
  "A Mú Sung, Bát Xát, Lào Cai",
  "Nậm Chạc, Bát Xát, Lào Cai",
  "A Lù, Bát Xát, Lào Cai",
  "Trịnh Tường, Bát Xát, Lào Cai",
  "Y Tý, Bát Xát, Lào Cai",
  "Cốc Mỳ, Bát Xát, Lào Cai",
  "Dền Sáng, Bát Xát, Lào Cai",
  "Bản Vược, Bát Xát, Lào Cai",
  "Sàng Ma Sáo, Bát Xát, Lào Cai",
  "Bản Qua, Bát Xát, Lào Cai",
  "Mường Vi, Bát Xát, Lào Cai",
  "Dền Thàng, Bát Xát, Lào Cai",
  "Bản Xèo, Bát Xát, Lào Cai",
  "Mường Hum, Bát Xát, Lào Cai",
  "Trung Lèng Hồ, Bát Xát, Lào Cai",
  "Quang Kim, Bát Xát, Lào Cai",
  "Pa Cheo, Bát Xát, Lào Cai",
  "Nậm Pung, Bát Xát, Lào Cai",
  "Phìn Ngan, Bát Xát, Lào Cai",
  "Tòng Sành, Bát Xát, Lào Cai",
  "Pha Long, Mường Khương, Lào Cai",
  "Tả Ngải Chồ, Mường Khương, Lào Cai",
  "Tung Chung Phố, Mường Khương, Lào Cai",
  "Mường Khương, Mường Khương, Lào Cai",
  "Dìn Chin, Mường Khương, Lào Cai",
  "Tả Gia Khâu, Mường Khương, Lào Cai",
  "Nậm Chảy, Mường Khương, Lào Cai",
  "Nấm Lư, Mường Khương, Lào Cai",
  "Lùng Khấu Nhin, Mường Khương, Lào Cai",
  "Thanh Bình, Mường Khương, Lào Cai",
  "Cao Sơn, Mường Khương, Lào Cai",
  "Lùng Vai, Mường Khương, Lào Cai",
  "Bản Lầu, Mường Khương, Lào Cai",
  "La Pan Tẩn, Mường Khương, Lào Cai",
  "Tả Thàng, Mường Khương, Lào Cai",
  "Bản Sen, Mường Khương, Lào Cai",
  "Nàn Sán, Si Ma Cai, Lào Cai",
  "Thào Chư Phìn, Si Ma Cai, Lào Cai",
  "Bản Mế, Si Ma Cai, Lào Cai",
  "Si Ma Cai, Si Ma Cai, Lào Cai",
  "Sán Chải, Si Ma Cai, Lào Cai",
  "Lùng Thẩn, Si Ma Cai, Lào Cai",
  "Cán Cấu, Si Ma Cai, Lào Cai",
  "Sín Chéng, Si Ma Cai, Lào Cai",
  "Quan Hồ Thẩn, Si Ma Cai, Lào Cai",
  "Nàn Xín, Si Ma Cai, Lào Cai",
  "Bắc Hà, Bắc Hà, Lào Cai",
  "Lùng Cải, Bắc Hà, Lào Cai",
  "Lùng Phình, Bắc Hà, Lào Cai",
  "Tả Van Chư, Bắc Hà, Lào Cai",
  "Tả Củ Tỷ, Bắc Hà, Lào Cai",
  "Thải Giàng Phố, Bắc Hà, Lào Cai",
  "Hoàng Thu Phố, Bắc Hà, Lào Cai",
  "Bản Phố, Bắc Hà, Lào Cai",
  "Bản Liền, Bắc Hà, Lào Cai",
  "Tà Chải, Bắc Hà, Lào Cai",
  "Na Hối, Bắc Hà, Lào Cai",
  "Cốc Ly, Bắc Hà, Lào Cai",
  "Nậm Mòn, Bắc Hà, Lào Cai",
  "Nậm Đét, Bắc Hà, Lào Cai",
  "Nậm Khánh, Bắc Hà, Lào Cai",
  "Bảo Nhai, Bắc Hà, Lào Cai",
  "Nậm Lúc, Bắc Hà, Lào Cai",
  "Cốc Lầu, Bắc Hà, Lào Cai",
  "Bản Cái, Bắc Hà, Lào Cai",
  "N.T Phong Hải, Bảo Thắng, Lào Cai",
  "Phố Lu, Bảo Thắng, Lào Cai",
  "Tằng Loỏng, Bảo Thắng, Lào Cai",
  "Bản Phiệt, Bảo Thắng, Lào Cai",
  "Bản Cầm, Bảo Thắng, Lào Cai",
  "Thái Niên, Bảo Thắng, Lào Cai",
  "Phong Niên, Bảo Thắng, Lào Cai",
  "Gia Phú, Bảo Thắng, Lào Cai",
  "Xuân Quang, Bảo Thắng, Lào Cai",
  "Sơn Hải, Bảo Thắng, Lào Cai",
  "Xuân Giao, Bảo Thắng, Lào Cai",
  "Trì Quang, Bảo Thắng, Lào Cai",
  "Sơn Hà, Bảo Thắng, Lào Cai",
  "Phú Nhuận, Bảo Thắng, Lào Cai",
  "Phố Ràng, Bảo Yên, Lào Cai",
  "Tân Tiến, Bảo Yên, Lào Cai",
  "Nghĩa Đô, Bảo Yên, Lào Cai",
  "Vĩnh Yên, Bảo Yên, Lào Cai",
  "Điện Quan, Bảo Yên, Lào Cai",
  "Xuân Hoà, Bảo Yên, Lào Cai",
  "Tân Dương, Bảo Yên, Lào Cai",
  "Thượng Hà, Bảo Yên, Lào Cai",
  "Kim Sơn, Bảo Yên, Lào Cai",
  "Cam Cọn, Bảo Yên, Lào Cai",
  "Minh Tân, Bảo Yên, Lào Cai",
  "Xuân Thượng, Bảo Yên, Lào Cai",
  "Việt Tiến, Bảo Yên, Lào Cai",
  "Yên Sơn, Bảo Yên, Lào Cai",
  "Bảo Hà, Bảo Yên, Lào Cai",
  "Lương Sơn, Bảo Yên, Lào Cai",
  "Phúc Khánh, Bảo Yên, Lào Cai",
  "Sa Pa, Sa Pa, Lào Cai",
  "Sa Pả, Sa Pa, Lào Cai",
  "Ô Quý Hồ, Sa Pa, Lào Cai",
  "Ngũ Chỉ Sơn, Sa Pa, Lào Cai",
  "Phan Si Păng, Sa Pa, Lào Cai",
  "Trung Chải, Sa Pa, Lào Cai",
  "Tả Phìn, Sa Pa, Lào Cai",
  "Hàm Rồng, Sa Pa, Lào Cai",
  "Hoàng Liên, Sa Pa, Lào Cai",
  "Thanh Bình, Sa Pa, Lào Cai",
  "Cầu Mây, Sa Pa, Lào Cai",
  "Mường Hoa, Sa Pa, Lào Cai",
  "Tả Van, Sa Pa, Lào Cai",
  "Mường Bo, Sa Pa, Lào Cai",
  "Bản Hồ, Sa Pa, Lào Cai",
  "Liên Minh, Sa Pa, Lào Cai",
  "Khánh Yên, Văn Bàn, Lào Cai",
  "Võ Lao, Văn Bàn, Lào Cai",
  "Sơn Thuỷ, Văn Bàn, Lào Cai",
  "Nậm Mả, Văn Bàn, Lào Cai",
  "Tân Thượng, Văn Bàn, Lào Cai",
  "Nậm Rạng, Văn Bàn, Lào Cai",
  "Nậm Chầy, Văn Bàn, Lào Cai",
  "Tân An, Văn Bàn, Lào Cai",
  "Khánh Yên Thượng, Văn Bàn, Lào Cai",
  "Nậm Xé, Văn Bàn, Lào Cai",
  "Dần Thàng, Văn Bàn, Lào Cai",
  "Chiềng Ken, Văn Bàn, Lào Cai",
  "Làng Giàng, Văn Bàn, Lào Cai",
  "Hoà Mạc, Văn Bàn, Lào Cai",
  "Khánh Yên Trung, Văn Bàn, Lào Cai",
  "Khánh Yên Hạ, Văn Bàn, Lào Cai",
  "Dương Quỳ, Văn Bàn, Lào Cai",
  "Nậm Tha, Văn Bàn, Lào Cai",
  "Minh Lương, Văn Bàn, Lào Cai",
  "Thẩm Dương, Văn Bàn, Lào Cai",
  "Liêm Phú, Văn Bàn, Lào Cai",
  "Nậm Xây, Văn Bàn, Lào Cai",
  "Noong Bua, Điện Biên Phủ, Điện Biên",
  "Him Lam, Điện Biên Phủ, Điện Biên",
  "Thanh Bình, Điện Biên Phủ, Điện Biên",
  "Tân Thanh, Điện Biên Phủ, Điện Biên",
  "Mường Thanh, Điện Biên Phủ, Điện Biên",
  "Nam Thanh, Điện Biên Phủ, Điện Biên",
  "Thanh Trường, Điện Biên Phủ, Điện Biên",
  "Thanh Minh, Điện Biên Phủ, Điện Biên",
  "Nà Tấu, Điện Biên Phủ, Điện Biên",
  "Nà Nhạn, Điện Biên Phủ, Điện Biên",
  "Mường Phăng, Điện Biên Phủ, Điện Biên",
  "Pá Khoang, Điện Biên Phủ, Điện Biên",
  "Sông Đà, Mường Lay, Điện Biên",
  "Na Lay, Mường Lay, Điện Biên",
  "Lay Nưa, Mường Lay, Điện Biên",
  "Sín Thầu, Mường Nhé, Điện Biên",
  "Sen Thượng, Mường Nhé, Điện Biên",
  "Chung Chải, Mường Nhé, Điện Biên",
  "Leng Su Sìn, Mường Nhé, Điện Biên",
  "Pá Mỳ, Mường Nhé, Điện Biên",
  "Mường Nhé, Mường Nhé, Điện Biên",
  "Nậm Vì, Mường Nhé, Điện Biên",
  "Nậm Kè, Mường Nhé, Điện Biên",
  "Mường Toong, Mường Nhé, Điện Biên",
  "Quảng Lâm, Mường Nhé, Điện Biên",
  "Huổi Lếnh, Mường Nhé, Điện Biên",
  "Mường Chà, Mường Chà, Điện Biên",
  "Xá Tổng, Mường Chà, Điện Biên",
  "Mường Tùng, Mường Chà, Điện Biên",
  "Hừa Ngài, Mường Chà, Điện Biên",
  "Huổi Mí, Mường Chà, Điện Biên",
  "Pa Ham, Mường Chà, Điện Biên",
  "Nậm Nèn, Mường Chà, Điện Biên",
  "Huổi Lèng, Mường Chà, Điện Biên",
  "Sa Lông, Mường Chà, Điện Biên",
  "Ma Thì Hồ, Mường Chà, Điện Biên",
  "Na Sang, Mường Chà, Điện Biên",
  "Mường Mươn, Mường Chà, Điện Biên",
  "Tủa Chùa, Tủa Chùa, Điện Biên",
  "Huổi Só, Tủa Chùa, Điện Biên",
  "Xín Chải, Tủa Chùa, Điện Biên",
  "Tả Sìn Thàng, Tủa Chùa, Điện Biên",
  "Lao Xả Phình, Tủa Chùa, Điện Biên",
  "Tả Phìn, Tủa Chùa, Điện Biên",
  "Tủa Thàng, Tủa Chùa, Điện Biên",
  "Trung Thu, Tủa Chùa, Điện Biên",
  "Sính Phình, Tủa Chùa, Điện Biên",
  "Sáng Nhè, Tủa Chùa, Điện Biên",
  "Mường Đun, Tủa Chùa, Điện Biên",
  "Mường Báng, Tủa Chùa, Điện Biên",
  "Tuần Giáo, Tuần Giáo, Điện Biên",
  "Phình Sáng, Tuần Giáo, Điện Biên",
  "Rạng Đông, Tuần Giáo, Điện Biên",
  "Mùn Chung, Tuần Giáo, Điện Biên",
  "Nà Tòng, Tuần Giáo, Điện Biên",
  "Ta Ma, Tuần Giáo, Điện Biên",
  "Mường Mùn, Tuần Giáo, Điện Biên",
  "Pú Xi, Tuần Giáo, Điện Biên",
  "Pú Nhung, Tuần Giáo, Điện Biên",
  "Quài Nưa, Tuần Giáo, Điện Biên",
  "Mường Thín, Tuần Giáo, Điện Biên",
  "Tỏa Tình, Tuần Giáo, Điện Biên",
  "Nà Sáy, Tuần Giáo, Điện Biên",
  "Mường Khong, Tuần Giáo, Điện Biên",
  "Quài Cang, Tuần Giáo, Điện Biên",
  "Quài Tở, Tuần Giáo, Điện Biên",
  "Chiềng Sinh, Tuần Giáo, Điện Biên",
  "Chiềng Đông, Tuần Giáo, Điện Biên",
  "Tênh Phông, Tuần Giáo, Điện Biên",
  "Mường Pồn, Điện Biên, Điện Biên",
  "Thanh Nưa, Điện Biên, Điện Biên",
  "Hua Thanh, Điện Biên, Điện Biên",
  "Thanh Luông, Điện Biên, Điện Biên",
  "Thanh Hưng, Điện Biên, Điện Biên",
  "Thanh Xương, Điện Biên, Điện Biên",
  "Thanh Chăn, Điện Biên, Điện Biên",
  "Pa Thơm, Điện Biên, Điện Biên",
  "Thanh An, Điện Biên, Điện Biên",
  "Thanh Yên, Điện Biên, Điện Biên",
  "Noong Luống, Điện Biên, Điện Biên",
  "Noọng Hẹt, Điện Biên, Điện Biên",
  "Sam Mứn, Điện Biên, Điện Biên",
  "Pom Lót, Điện Biên, Điện Biên",
  "Núa Ngam, Điện Biên, Điện Biên",
  "Hẹ Muông, Điện Biên, Điện Biên",
  "Na Ư, Điện Biên, Điện Biên",
  "Mường Nhà, Điện Biên, Điện Biên",
  "Na Tông, Điện Biên, Điện Biên",
  "Mường Lói, Điện Biên, Điện Biên",
  "Phu Luông, Điện Biên, Điện Biên",
  "Điện Biên Đông, Điện Biên Đông, Điện Biên",
  "Na Son, Điện Biên Đông, Điện Biên",
  "Phì Nhừ, Điện Biên Đông, Điện Biên",
  "Chiềng Sơ, Điện Biên Đông, Điện Biên",
  "Mường Luân, Điện Biên Đông, Điện Biên",
  "Pú Nhi, Điện Biên Đông, Điện Biên",
  "Nong U, Điện Biên Đông, Điện Biên",
  "Xa Dung, Điện Biên Đông, Điện Biên",
  "Keo Lôm, Điện Biên Đông, Điện Biên",
  "Luân Giới, Điện Biên Đông, Điện Biên",
  "Phình Giàng, Điện Biên Đông, Điện Biên",
  "Pú Hồng, Điện Biên Đông, Điện Biên",
  "Tìa Dình, Điện Biên Đông, Điện Biên",
  "Háng Lìa, Điện Biên Đông, Điện Biên",
  "Mường Ảng, Mường Ảng, Điện Biên",
  "Mường Đăng, Mường Ảng, Điện Biên",
  "Ngối Cáy, Mường Ảng, Điện Biên",
  "Ẳng Tở, Mường Ảng, Điện Biên",
  "Búng Lao, Mường Ảng, Điện Biên",
  "Xuân Lao, Mường Ảng, Điện Biên",
  "Ẳng Nưa, Mường Ảng, Điện Biên",
  "Ẳng Cang, Mường Ảng, Điện Biên",
  "Nặm Lịch, Mường Ảng, Điện Biên",
  "Mường Lạn, Mường Ảng, Điện Biên",
  "Nậm Tin, Nậm Pồ, Điện Biên",
  "Pa Tần, Nậm Pồ, Điện Biên",
  "Chà Cang, Nậm Pồ, Điện Biên",
  "Na Cô Sa, Nậm Pồ, Điện Biên",
  "Nà Khoa, Nậm Pồ, Điện Biên",
  "Nà Hỳ, Nậm Pồ, Điện Biên",
  "Nà Bủng, Nậm Pồ, Điện Biên",
  "Nậm Nhừ, Nậm Pồ, Điện Biên",
  "Nậm Chua, Nậm Pồ, Điện Biên",
  "Nậm Khăn, Nậm Pồ, Điện Biên",
  "Chà Tở, Nậm Pồ, Điện Biên",
  "Vàng Đán, Nậm Pồ, Điện Biên",
  "Chà Nưa, Nậm Pồ, Điện Biên",
  "Phìn Hồ, Nậm Pồ, Điện Biên",
  "Si Pa Phìn, Nậm Pồ, Điện Biên",
  "Quyết Thắng, Lai Châu, Lai Châu",
  "Tân Phong, Lai Châu, Lai Châu",
  "Quyết Tiến, Lai Châu, Lai Châu",
  "Đoàn Kết, Lai Châu, Lai Châu",
  "Sùng Phài, Lai Châu, Lai Châu",
  "Đông Phong, Lai Châu, Lai Châu",
  "San Thàng, Lai Châu, Lai Châu",
  "Tam Đường, Tam Đường, Lai Châu",
  "Thèn Sin, Tam Đường, Lai Châu",
  "Tả Lèng, Tam Đường, Lai Châu",
  "Giang Ma, Tam Đường, Lai Châu",
  "Hồ Thầu, Tam Đường, Lai Châu",
  "Bình Lư, Tam Đường, Lai Châu",
  "Sơn Bình, Tam Đường, Lai Châu",
  "Nùng Nàng, Tam Đường, Lai Châu",
  "Bản Giang, Tam Đường, Lai Châu",
  "Bản Hon, Tam Đường, Lai Châu",
  "Bản Bo, Tam Đường, Lai Châu",
  "Nà Tăm, Tam Đường, Lai Châu",
  "Khun Há, Tam Đường, Lai Châu",
  "Mường Tè, Mường Tè, Lai Châu",
  "Thu Lũm, Mường Tè, Lai Châu",
  "Ka Lăng, Mường Tè, Lai Châu",
  "Tá Bạ, Mường Tè, Lai Châu",
  "Pa ủ, Mường Tè, Lai Châu",
  "Mường Tè, Mường Tè, Lai Châu",
  "Pa Vệ Sử, Mường Tè, Lai Châu",
  "Mù Cả, Mường Tè, Lai Châu",
  "Bum Tở, Mường Tè, Lai Châu",
  "Nậm Khao, Mường Tè, Lai Châu",
  "Tà Tổng, Mường Tè, Lai Châu",
  "Bum Nưa, Mường Tè, Lai Châu",
  "Vàng San, Mường Tè, Lai Châu",
  "Kan Hồ, Mường Tè, Lai Châu",
  "Sìn Hồ, Sìn Hồ, Lai Châu",
  "Chăn Nưa, Sìn Hồ, Lai Châu",
  "Pa Tần, Sìn Hồ, Lai Châu",
  "Phìn Hồ, Sìn Hồ, Lai Châu",
  "Hồng Thu, Sìn Hồ, Lai Châu",
  "Phăng Sô Lin, Sìn Hồ, Lai Châu",
  "Ma Quai, Sìn Hồ, Lai Châu",
  "Lùng Thàng, Sìn Hồ, Lai Châu",
  "Tả Phìn, Sìn Hồ, Lai Châu",
  "Sà Dề Phìn, Sìn Hồ, Lai Châu",
  "Nậm Tăm, Sìn Hồ, Lai Châu",
  "Tả Ngảo, Sìn Hồ, Lai Châu",
  "Pu Sam Cáp, Sìn Hồ, Lai Châu",
  "Nậm Cha, Sìn Hồ, Lai Châu",
  "Pa Khoá, Sìn Hồ, Lai Châu",
  "Làng Mô, Sìn Hồ, Lai Châu",
  "Noong Hẻo, Sìn Hồ, Lai Châu",
  "Nậm Mạ, Sìn Hồ, Lai Châu",
  "Căn Co, Sìn Hồ, Lai Châu",
  "Tủa Sín Chải, Sìn Hồ, Lai Châu",
  "Nậm Cuổi, Sìn Hồ, Lai Châu",
  "Nậm Hăn, Sìn Hồ, Lai Châu",
  "Lả Nhì Thàng, Phong Thổ, Lai Châu",
  "Huổi Luông, Phong Thổ, Lai Châu",
  "Phong Thổ, Phong Thổ, Lai Châu",
  "Sì Lở Lầu, Phong Thổ, Lai Châu",
  "Mồ Sì San, Phong Thổ, Lai Châu",
  "Pa Vây Sử, Phong Thổ, Lai Châu",
  "Vàng Ma Chải, Phong Thổ, Lai Châu",
  "Tông Qua Lìn, Phong Thổ, Lai Châu",
  "Mù Sang, Phong Thổ, Lai Châu",
  "Dào San, Phong Thổ, Lai Châu",
  "Ma Ly Pho, Phong Thổ, Lai Châu",
  "Bản Lang, Phong Thổ, Lai Châu",
  "Hoang Thèn, Phong Thổ, Lai Châu",
  "Khổng Lào, Phong Thổ, Lai Châu",
  "Nậm Xe, Phong Thổ, Lai Châu",
  "Mường So, Phong Thổ, Lai Châu",
  "Sin Suối Hồ, Phong Thổ, Lai Châu",
  "Than Uyên, Than Uyên, Lai Châu",
  "Phúc Than, Than Uyên, Lai Châu",
  "Mường Than, Than Uyên, Lai Châu",
  "Mường Mít, Than Uyên, Lai Châu",
  "Pha Mu, Than Uyên, Lai Châu",
  "Mường Cang, Than Uyên, Lai Châu",
  "Hua Nà, Than Uyên, Lai Châu",
  "Tà Hừa, Than Uyên, Lai Châu",
  "Mường Kim, Than Uyên, Lai Châu",
  "Tà Mung, Than Uyên, Lai Châu",
  "Tà Gia, Than Uyên, Lai Châu",
  "Khoen On, Than Uyên, Lai Châu",
  "Tân Uyên, Tân Uyên, Lai Châu",
  "Mường Khoa, Tân Uyên, Lai Châu",
  "Phúc Khoa, Tân Uyên, Lai Châu",
  "Thân Thuộc, Tân Uyên, Lai Châu",
  "Trung Đồng, Tân Uyên, Lai Châu",
  "Hố Mít, Tân Uyên, Lai Châu",
  "Nậm Cần, Tân Uyên, Lai Châu",
  "Nậm Sỏ, Tân Uyên, Lai Châu",
  "Pắc Ta, Tân Uyên, Lai Châu",
  "Tà Mít, Tân Uyên, Lai Châu",
  "Nậm Nhùn, Nậm Nhùn, Lai Châu",
  "Hua Bun, Nậm Nhùn, Lai Châu",
  "Mường Mô, Nậm Nhùn, Lai Châu",
  "Nậm Chà, Nậm Nhùn, Lai Châu",
  "Nậm Manh, Nậm Nhùn, Lai Châu",
  "Nậm Hàng, Nậm Nhùn, Lai Châu",
  "Lê Lợi, Nậm Nhùn, Lai Châu",
  "Pú Đao, Nậm Nhùn, Lai Châu",
  "Nậm Pì, Nậm Nhùn, Lai Châu",
  "Nậm Ban, Nậm Nhùn, Lai Châu",
  "Trung Chải, Nậm Nhùn, Lai Châu",
  "Chiềng Lề, Sơn La, Sơn La",
  "Tô Hiệu, Sơn La, Sơn La",
  "Quyết Thắng, Sơn La, Sơn La",
  "Quyết Tâm, Sơn La, Sơn La",
  "Chiềng Cọ, Sơn La, Sơn La",
  "Chiềng Đen, Sơn La, Sơn La",
  "Chiềng Xôm, Sơn La, Sơn La",
  "Chiềng An, Sơn La, Sơn La",
  "Chiềng Cơi, Sơn La, Sơn La",
  "Chiềng Ngần, Sơn La, Sơn La",
  "Hua La, Sơn La, Sơn La",
  "Chiềng Sinh, Sơn La, Sơn La",
  "Mường Chiên, Quỳnh Nhai, Sơn La",
  "Cà Nàng, Quỳnh Nhai, Sơn La",
  "Chiềng Khay, Quỳnh Nhai, Sơn La",
  "Mường Giôn, Quỳnh Nhai, Sơn La",
  "Pá Ma Pha Khinh, Quỳnh Nhai, Sơn La",
  "Chiềng Ơn, Quỳnh Nhai, Sơn La",
  "Mường Giàng, Quỳnh Nhai, Sơn La",
  "Chiềng Bằng, Quỳnh Nhai, Sơn La",
  "Mường Sại, Quỳnh Nhai, Sơn La",
  "Nậm ét, Quỳnh Nhai, Sơn La",
  "Chiềng Khoang, Quỳnh Nhai, Sơn La",
  "Thuận Châu, Thuận Châu, Sơn La",
  "Phổng Lái, Thuận Châu, Sơn La",
  "Mường é, Thuận Châu, Sơn La",
  "Chiềng Pha, Thuận Châu, Sơn La",
  "Chiềng La, Thuận Châu, Sơn La",
  "Chiềng Ngàm, Thuận Châu, Sơn La",
  "Liệp Tè, Thuận Châu, Sơn La",
  "é Tòng, Thuận Châu, Sơn La",
  "Phổng Lập, Thuận Châu, Sơn La",
  "Phổng Lăng, Thuận Châu, Sơn La",
  "Chiềng Ly, Thuận Châu, Sơn La",
  "Noong Lay, Thuận Châu, Sơn La",
  "Mường Khiêng, Thuận Châu, Sơn La",
  "Mường Bám, Thuận Châu, Sơn La",
  "Long Hẹ, Thuận Châu, Sơn La",
  "Chiềng Bôm, Thuận Châu, Sơn La",
  "Thôm Mòn, Thuận Châu, Sơn La",
  "Tông Lạnh, Thuận Châu, Sơn La",
  "Tông Cọ, Thuận Châu, Sơn La",
  "Bó Mười, Thuận Châu, Sơn La",
  "Co Mạ, Thuận Châu, Sơn La",
  "Púng Tra, Thuận Châu, Sơn La",
  "Chiềng Pấc, Thuận Châu, Sơn La",
  "Nậm Lầu, Thuận Châu, Sơn La",
  "Bon Phặng, Thuận Châu, Sơn La",
  "Co Tòng, Thuận Châu, Sơn La",
  "Muổi Nọi, Thuận Châu, Sơn La",
  "Pá Lông, Thuận Châu, Sơn La",
  "Bản Lầm, Thuận Châu, Sơn La",
  "Ít Ong, Mường La, Sơn La",
  "Nậm Giôn, Mường La, Sơn La",
  "Chiềng Lao, Mường La, Sơn La",
  "Hua Trai, Mường La, Sơn La",
  "Ngọc Chiến, Mường La, Sơn La",
  "Mường Trai, Mường La, Sơn La",
  "Nậm Păm, Mường La, Sơn La",
  "Chiềng Muôn, Mường La, Sơn La",
  "Chiềng Ân, Mường La, Sơn La",
  "Pi Toong, Mường La, Sơn La",
  "Chiềng Công, Mường La, Sơn La",
  "Tạ Bú, Mường La, Sơn La",
  "Chiềng San, Mường La, Sơn La",
  "Mường Bú, Mường La, Sơn La",
  "Chiềng Hoa, Mường La, Sơn La",
  "Mường Chùm, Mường La, Sơn La",
  "Bắc Yên, Bắc Yên, Sơn La",
  "Phiêng Ban, Bắc Yên, Sơn La",
  "Hang Chú, Bắc Yên, Sơn La",
  "Xím Vàng, Bắc Yên, Sơn La",
  "Tà Xùa, Bắc Yên, Sơn La",
  "Háng Đồng, Bắc Yên, Sơn La",
  "Pắc Ngà, Bắc Yên, Sơn La",
  "Làng Chếu, Bắc Yên, Sơn La",
  "Chim Vàn, Bắc Yên, Sơn La",
  "Mường Khoa, Bắc Yên, Sơn La",
  "Song Pe, Bắc Yên, Sơn La",
  "Hồng Ngài, Bắc Yên, Sơn La",
  "Tạ Khoa, Bắc Yên, Sơn La",
  "Hua Nhàn, Bắc Yên, Sơn La",
  "Phiêng Côn, Bắc Yên, Sơn La",
  "Chiềng Sại, Bắc Yên, Sơn La",
  "Phù Yên, Phù Yên, Sơn La",
  "Suối Tọ, Phù Yên, Sơn La",
  "Mường Thải, Phù Yên, Sơn La",
  "Mường Cơi, Phù Yên, Sơn La",
  "Quang Huy, Phù Yên, Sơn La",
  "Huy Bắc, Phù Yên, Sơn La",
  "Huy Thượng, Phù Yên, Sơn La",
  "Tân Lang, Phù Yên, Sơn La",
  "Gia Phù, Phù Yên, Sơn La",
  "Tường Phù, Phù Yên, Sơn La",
  "Huy Hạ, Phù Yên, Sơn La",
  "Huy Tân, Phù Yên, Sơn La",
  "Mường Lang, Phù Yên, Sơn La",
  "Suối Bau, Phù Yên, Sơn La",
  "Huy Tường, Phù Yên, Sơn La",
  "Mường Do, Phù Yên, Sơn La",
  "Sập Xa, Phù Yên, Sơn La",
  "Tường Thượng, Phù Yên, Sơn La",
  "Tường Tiến, Phù Yên, Sơn La",
  "Tường Phong, Phù Yên, Sơn La",
  "Tường Hạ, Phù Yên, Sơn La",
  "Kim Bon, Phù Yên, Sơn La",
  "Mường Bang, Phù Yên, Sơn La",
  "Đá Đỏ, Phù Yên, Sơn La",
  "Tân Phong, Phù Yên, Sơn La",
  "Nam Phong, Phù Yên, Sơn La",
  "Bắc Phong, Phù Yên, Sơn La",
  "Mộc Châu, Mộc Châu, Sơn La",
  "NT Mộc Châu, Mộc Châu, Sơn La",
  "Chiềng Sơn, Mộc Châu, Sơn La",
  "Tân Hợp, Mộc Châu, Sơn La",
  "Qui Hướng, Mộc Châu, Sơn La",
  "Tân Lập, Mộc Châu, Sơn La",
  "Nà Mường, Mộc Châu, Sơn La",
  "Tà Lai, Mộc Châu, Sơn La",
  "Chiềng Hắc, Mộc Châu, Sơn La",
  "Hua Păng, Mộc Châu, Sơn La",
  "Chiềng Khừa, Mộc Châu, Sơn La",
  "Mường Sang, Mộc Châu, Sơn La",
  "Đông Sang, Mộc Châu, Sơn La",
  "Phiêng Luông, Mộc Châu, Sơn La",
  "Lóng Sập, Mộc Châu, Sơn La",
  "Yên Châu, Yên Châu, Sơn La",
  "Chiềng Đông, Yên Châu, Sơn La",
  "Sập Vạt, Yên Châu, Sơn La",
  "Chiềng Sàng, Yên Châu, Sơn La",
  "Chiềng Pằn, Yên Châu, Sơn La",
  "Viêng Lán, Yên Châu, Sơn La",
  "Chiềng Hặc, Yên Châu, Sơn La",
  "Mường Lựm, Yên Châu, Sơn La",
  "Chiềng On, Yên Châu, Sơn La",
  "Yên Sơn, Yên Châu, Sơn La",
  "Chiềng Khoi, Yên Châu, Sơn La",
  "Tú Nang, Yên Châu, Sơn La",
  "Lóng Phiêng, Yên Châu, Sơn La",
  "Phiêng Khoài, Yên Châu, Sơn La",
  "Chiềng Tương, Yên Châu, Sơn La",
  "Hát Lót, Mai Sơn, Sơn La",
  "Chiềng Sung, Mai Sơn, Sơn La",
  "Mường Bằng, Mai Sơn, Sơn La",
  "Chiềng Chăn, Mai Sơn, Sơn La",
  "Mương Chanh, Mai Sơn, Sơn La",
  "Chiềng Ban, Mai Sơn, Sơn La",
  "Chiềng Mung, Mai Sơn, Sơn La",
  "Mường Bon, Mai Sơn, Sơn La",
  "Chiềng Chung, Mai Sơn, Sơn La",
  "Chiềng Mai, Mai Sơn, Sơn La",
  "Hát Lót, Mai Sơn, Sơn La",
  "Nà Pó, Mai Sơn, Sơn La",
  "Cò  Nòi, Mai Sơn, Sơn La",
  "Chiềng Nơi, Mai Sơn, Sơn La",
  "Phiêng Cằm, Mai Sơn, Sơn La",
  "Chiềng Dong, Mai Sơn, Sơn La",
  "Chiềng Kheo, Mai Sơn, Sơn La",
  "Chiềng Ve, Mai Sơn, Sơn La",
  "Chiềng Lương, Mai Sơn, Sơn La",
  "Phiêng Pằn, Mai Sơn, Sơn La",
  "Nà Ơt, Mai Sơn, Sơn La",
  "Tà Hộc, Mai Sơn, Sơn La",
  "Sông Mã, Sông Mã, Sơn La",
  "Bó Sinh, Sông Mã, Sơn La",
  "Pú Pẩu, Sông Mã, Sơn La",
  "Chiềng Phung, Sông Mã, Sơn La",
  "Chiềng En, Sông Mã, Sơn La",
  "Mường Lầm, Sông Mã, Sơn La",
  "Nậm Ty, Sông Mã, Sơn La",
  "Đứa Mòn, Sông Mã, Sơn La",
  "Yên Hưng, Sông Mã, Sơn La",
  "Chiềng Sơ, Sông Mã, Sơn La",
  "Nà Nghịu, Sông Mã, Sơn La",
  "Nậm Mằn, Sông Mã, Sơn La",
  "Chiềng Khoong, Sông Mã, Sơn La",
  "Chiềng Cang, Sông Mã, Sơn La",
  "Huổi Một, Sông Mã, Sơn La",
  "Mường Sai, Sông Mã, Sơn La",
  "Mường Cai, Sông Mã, Sơn La",
  "Mường Hung, Sông Mã, Sơn La",
  "Chiềng Khương, Sông Mã, Sơn La",
  "Sam Kha, Sốp Cộp, Sơn La",
  "Púng Bánh, Sốp Cộp, Sơn La",
  "Sốp Cộp, Sốp Cộp, Sơn La",
  "Dồm Cang, Sốp Cộp, Sơn La",
  "Nậm Lạnh, Sốp Cộp, Sơn La",
  "Mường Lèo, Sốp Cộp, Sơn La",
  "Mường Và, Sốp Cộp, Sơn La",
  "Mường Lạn, Sốp Cộp, Sơn La",
  "Suối Bàng, Vân Hồ, Sơn La",
  "Song Khủa, Vân Hồ, Sơn La",
  "Liên Hoà, Vân Hồ, Sơn La",
  "Tô Múa, Vân Hồ, Sơn La",
  "Mường Tè, Vân Hồ, Sơn La",
  "Chiềng Khoa, Vân Hồ, Sơn La",
  "Mường Men, Vân Hồ, Sơn La",
  "Quang Minh, Vân Hồ, Sơn La",
  "Vân Hồ, Vân Hồ, Sơn La",
  "Lóng Luông, Vân Hồ, Sơn La",
  "Chiềng Yên, Vân Hồ, Sơn La",
  "Chiềng Xuân, Vân Hồ, Sơn La",
  "Xuân Nha, Vân Hồ, Sơn La",
  "Tân Xuân, Vân Hồ, Sơn La",
  "Yên Thịnh, Yên Bái, Yên Bái",
  "Yên Ninh, Yên Bái, Yên Bái",
  "Minh Tân, Yên Bái, Yên Bái",
  "Nguyễn Thái Học, Yên Bái, Yên Bái",
  "Đồng Tâm, Yên Bái, Yên Bái",
  "Nguyễn Phúc, Yên Bái, Yên Bái",
  "Hồng Hà, Yên Bái, Yên Bái",
  "Minh Bảo, Yên Bái, Yên Bái",
  "Nam Cường, Yên Bái, Yên Bái",
  "Tuy Lộc, Yên Bái, Yên Bái",
  "Tân Thịnh, Yên Bái, Yên Bái",
  "Âu Lâu, Yên Bái, Yên Bái",
  "Giới Phiên, Yên Bái, Yên Bái",
  "Hợp Minh, Yên Bái, Yên Bái",
  "Văn Phú, Yên Bái, Yên Bái",
  "Pú Trạng, Nghĩa Lộ, Yên Bái",
  "Trung Tâm, Nghĩa Lộ, Yên Bái",
  "Tân An, Nghĩa Lộ, Yên Bái",
  "Cầu Thia, Nghĩa Lộ, Yên Bái",
  "Nghĩa Lợi, Nghĩa Lộ, Yên Bái",
  "Nghĩa Phúc, Nghĩa Lộ, Yên Bái",
  "Nghĩa An, Nghĩa Lộ, Yên Bái",
  "Nghĩa Lộ, Nghĩa Lộ, Yên Bái",
  "Sơn A, Nghĩa Lộ, Yên Bái",
  "Phù Nham, Nghĩa Lộ, Yên Bái",
  "Thanh Lương, Nghĩa Lộ, Yên Bái",
  "Hạnh Sơn, Nghĩa Lộ, Yên Bái",
  "Phúc Sơn, Nghĩa Lộ, Yên Bái",
  "Thạch Lương, Nghĩa Lộ, Yên Bái",
  "Yên Thế, Lục Yên, Yên Bái",
  "Tân Phượng, Lục Yên, Yên Bái",
  "Lâm Thượng, Lục Yên, Yên Bái",
  "Khánh Thiện, Lục Yên, Yên Bái",
  "Minh Chuẩn, Lục Yên, Yên Bái",
  "Mai Sơn, Lục Yên, Yên Bái",
  "Khai Trung, Lục Yên, Yên Bái",
  "Mường Lai, Lục Yên, Yên Bái",
  "An Lạc, Lục Yên, Yên Bái",
  "Minh Xuân, Lục Yên, Yên Bái",
  "Tô Mậu, Lục Yên, Yên Bái",
  "Tân Lĩnh, Lục Yên, Yên Bái",
  "Yên Thắng, Lục Yên, Yên Bái",
  "Khánh Hoà, Lục Yên, Yên Bái",
  "Vĩnh Lạc, Lục Yên, Yên Bái",
  "Liễu Đô, Lục Yên, Yên Bái",
  "Động Quan, Lục Yên, Yên Bái",
  "Tân Lập, Lục Yên, Yên Bái",
  "Minh Tiến, Lục Yên, Yên Bái",
  "Trúc Lâu, Lục Yên, Yên Bái",
  "Phúc Lợi, Lục Yên, Yên Bái",
  "Phan Thanh, Lục Yên, Yên Bái",
  "An Phú, Lục Yên, Yên Bái",
  "Trung Tâm, Lục Yên, Yên Bái",
  "Mậu A, Văn Yên, Yên Bái",
  "Lang Thíp, Văn Yên, Yên Bái",
  "Lâm Giang, Văn Yên, Yên Bái",
  "Châu Quế Thượng, Văn Yên, Yên Bái",
  "Châu Quế Hạ, Văn Yên, Yên Bái",
  "An Bình, Văn Yên, Yên Bái",
  "Quang Minh, Văn Yên, Yên Bái",
  "Đông An, Văn Yên, Yên Bái",
  "Đông Cuông, Văn Yên, Yên Bái",
  "Phong Dụ Hạ, Văn Yên, Yên Bái",
  "Mậu Đông, Văn Yên, Yên Bái",
  "Ngòi A, Văn Yên, Yên Bái",
  "Xuân Tầm, Văn Yên, Yên Bái",
  "Tân Hợp, Văn Yên, Yên Bái",
  "An Thịnh, Văn Yên, Yên Bái",
  "Yên Thái, Văn Yên, Yên Bái",
  "Phong Dụ Thượng, Văn Yên, Yên Bái",
  "Yên Hợp, Văn Yên, Yên Bái",
  "Đại Sơn, Văn Yên, Yên Bái",
  "Đại Phác, Văn Yên, Yên Bái",
  "Yên Phú, Văn Yên, Yên Bái",
  "Xuân Ái, Văn Yên, Yên Bái",
  "Viễn Sơn, Văn Yên, Yên Bái",
  "Mỏ Vàng, Văn Yên, Yên Bái",
  "Nà Hẩu, Văn Yên, Yên Bái",
  "Mù Căng Chải, Mù Căng Chải, Yên Bái",
  "Hồ Bốn, Mù Căng Chải, Yên Bái",
  "Nậm Có, Mù Căng Chải, Yên Bái",
  "Khao Mang, Mù Căng Chải, Yên Bái",
  "Mồ Dề, Mù Căng Chải, Yên Bái",
  "Chế Cu Nha, Mù Căng Chải, Yên Bái",
  "Lao Chải, Mù Căng Chải, Yên Bái",
  "Kim Nọi, Mù Căng Chải, Yên Bái",
  "Cao Phạ, Mù Căng Chải, Yên Bái",
  "La Pán Tẩn, Mù Căng Chải, Yên Bái",
  "Dế Su Phình, Mù Căng Chải, Yên Bái",
  "Chế Tạo, Mù Căng Chải, Yên Bái",
  "Púng Luông, Mù Căng Chải, Yên Bái",
  "Nậm Khắt, Mù Căng Chải, Yên Bái",
  "Cổ Phúc, Trấn Yên, Yên Bái",
  "Tân Đồng, Trấn Yên, Yên Bái",
  "Báo Đáp, Trấn Yên, Yên Bái",
  "Đào Thịnh, Trấn Yên, Yên Bái",
  "Việt Thành, Trấn Yên, Yên Bái",
  "Hòa Cuông, Trấn Yên, Yên Bái",
  "Minh Quán, Trấn Yên, Yên Bái",
  "Quy Mông, Trấn Yên, Yên Bái",
  "Cường Thịnh, Trấn Yên, Yên Bái",
  "Kiên Thành, Trấn Yên, Yên Bái",
  "Nga Quán, Trấn Yên, Yên Bái",
  "Y Can, Trấn Yên, Yên Bái",
  "Lương Thịnh, Trấn Yên, Yên Bái",
  "Bảo Hưng, Trấn Yên, Yên Bái",
  "Việt Cường, Trấn Yên, Yên Bái",
  "Minh Quân, Trấn Yên, Yên Bái",
  "Hồng Ca, Trấn Yên, Yên Bái",
  "Hưng Thịnh, Trấn Yên, Yên Bái",
  "Hưng Khánh, Trấn Yên, Yên Bái",
  "Việt Hồng, Trấn Yên, Yên Bái",
  "Vân Hội, Trấn Yên, Yên Bái",
  "Trạm Tấu, Trạm Tấu, Yên Bái",
  "Túc Đán, Trạm Tấu, Yên Bái",
  "Pá Lau, Trạm Tấu, Yên Bái",
  "Xà Hồ, Trạm Tấu, Yên Bái",
  "Phình Hồ, Trạm Tấu, Yên Bái",
  "Trạm Tấu, Trạm Tấu, Yên Bái",
  "Tà Si Láng, Trạm Tấu, Yên Bái",
  "Pá Hu, Trạm Tấu, Yên Bái",
  "Làng Nhì, Trạm Tấu, Yên Bái",
  "Bản Công, Trạm Tấu, Yên Bái",
  "Bản Mù, Trạm Tấu, Yên Bái",
  "Hát Lìu, Trạm Tấu, Yên Bái",
  "NT Liên Sơn, Văn Chấn, Yên Bái",
  "NT Trần Phú, Văn Chấn, Yên Bái",
  "Tú Lệ, Văn Chấn, Yên Bái",
  "Nậm Búng, Văn Chấn, Yên Bái",
  "Gia Hội, Văn Chấn, Yên Bái",
  "Sùng Đô, Văn Chấn, Yên Bái",
  "Nậm Mười, Văn Chấn, Yên Bái",
  "An Lương, Văn Chấn, Yên Bái",
  "Nậm Lành, Văn Chấn, Yên Bái",
  "Sơn Lương, Văn Chấn, Yên Bái",
  "Suối Quyền, Văn Chấn, Yên Bái",
  "Suối Giàng, Văn Chấn, Yên Bái",
  "Nghĩa Sơn, Văn Chấn, Yên Bái",
  "Suối Bu, Văn Chấn, Yên Bái",
  "Sơn Thịnh, Văn Chấn, Yên Bái",
  "Đại Lịch, Văn Chấn, Yên Bái",
  "Đồng Khê, Văn Chấn, Yên Bái",
  "Cát Thịnh, Văn Chấn, Yên Bái",
  "Tân Thịnh, Văn Chấn, Yên Bái",
  "Chấn Thịnh, Văn Chấn, Yên Bái",
  "Bình Thuận, Văn Chấn, Yên Bái",
  "Thượng Bằng La, Văn Chấn, Yên Bái",
  "Minh An, Văn Chấn, Yên Bái",
  "Nghĩa Tâm, Văn Chấn, Yên Bái",
  "Yên Bình, Yên Bình, Yên Bái",
  "Thác Bà, Yên Bình, Yên Bái",
  "Xuân Long, Yên Bình, Yên Bái",
  "Cảm Nhân, Yên Bình, Yên Bái",
  "Ngọc Chấn, Yên Bình, Yên Bái",
  "Tân Nguyên, Yên Bình, Yên Bái",
  "Phúc Ninh, Yên Bình, Yên Bái",
  "Bảo Ái, Yên Bình, Yên Bái",
  "Mỹ Gia, Yên Bình, Yên Bái",
  "Xuân Lai, Yên Bình, Yên Bái",
  "Mông Sơn, Yên Bình, Yên Bái",
  "Cảm Ân, Yên Bình, Yên Bái",
  "Yên Thành, Yên Bình, Yên Bái",
  "Tân Hương, Yên Bình, Yên Bái",
  "Phúc An, Yên Bình, Yên Bái",
  "Bạch Hà, Yên Bình, Yên Bái",
  "Vũ Linh, Yên Bình, Yên Bái",
  "Đại Đồng, Yên Bình, Yên Bái",
  "Vĩnh Kiên, Yên Bình, Yên Bái",
  "Yên Bình, Yên Bình, Yên Bái",
  "Thịnh Hưng, Yên Bình, Yên Bái",
  "Hán Đà, Yên Bình, Yên Bái",
  "Phú Thịnh, Yên Bình, Yên Bái",
  "Đại Minh, Yên Bình, Yên Bái",
  "Thái Bình, Hòa Bình, Hoà Bình",
  "Tân Hòa, Hòa Bình, Hoà Bình",
  "Thịnh Lang, Hòa Bình, Hoà Bình",
  "Hữu Nghị, Hòa Bình, Hoà Bình",
  "Tân Thịnh, Hòa Bình, Hoà Bình",
  "Đồng Tiến, Hòa Bình, Hoà Bình",
  "Phương Lâm, Hòa Bình, Hoà Bình",
  "Yên Mông, Hòa Bình, Hoà Bình",
  "Sủ Ngòi, Hòa Bình, Hoà Bình",
  "Dân Chủ, Hòa Bình, Hoà Bình",
  "Hòa Bình, Hòa Bình, Hoà Bình",
  "Thống Nhất, Hòa Bình, Hoà Bình",
  "Kỳ Sơn, Hòa Bình, Hoà Bình",
  "Thịnh Minh, Hòa Bình, Hoà Bình",
  "Hợp Thành, Hòa Bình, Hoà Bình",
  "Quang Tiến, Hòa Bình, Hoà Bình",
  "Mông Hóa, Hòa Bình, Hoà Bình",
  "Trung Minh, Hòa Bình, Hoà Bình",
  "Độc Lập, Hòa Bình, Hoà Bình",
  "Đà Bắc, Đà Bắc, Hoà Bình",
  "Nánh Nghê, Đà Bắc, Hoà Bình",
  "Giáp Đắt, Đà Bắc, Hoà Bình",
  "Mường Chiềng, Đà Bắc, Hoà Bình",
  "Tân Pheo, Đà Bắc, Hoà Bình",
  "Đồng Chum, Đà Bắc, Hoà Bình",
  "Tân Minh, Đà Bắc, Hoà Bình",
  "Đoàn Kết, Đà Bắc, Hoà Bình",
  "Đồng Ruộng, Đà Bắc, Hoà Bình",
  "Tú Lý, Đà Bắc, Hoà Bình",
  "Trung Thành, Đà Bắc, Hoà Bình",
  "Yên Hòa, Đà Bắc, Hoà Bình",
  "Cao Sơn, Đà Bắc, Hoà Bình",
  "Toàn Sơn, Đà Bắc, Hoà Bình",
  "Hiền Lương, Đà Bắc, Hoà Bình",
  "Tiền Phong, Đà Bắc, Hoà Bình",
  "Vầy Nưa, Đà Bắc, Hoà Bình",
  "Lương Sơn, Lương Sơn, Hoà Bình",
  "Lâm Sơn, Lương Sơn, Hoà Bình",
  "Hòa Sơn, Lương Sơn, Hoà Bình",
  "Tân Vinh, Lương Sơn, Hoà Bình",
  "Nhuận Trạch, Lương Sơn, Hoà Bình",
  "Cao Sơn, Lương Sơn, Hoà Bình",
  "Cư Yên, Lương Sơn, Hoà Bình",
  "Liên Sơn, Lương Sơn, Hoà Bình",
  "Cao Dương, Lương Sơn, Hoà Bình",
  "Thanh Sơn, Lương Sơn, Hoà Bình",
  "Thanh Cao, Lương Sơn, Hoà Bình",
  "Bo, Kim Bôi, Hoà Bình",
  "Đú Sáng, Kim Bôi, Hoà Bình",
  "Hùng Sơn, Kim Bôi, Hoà Bình",
  "Bình Sơn, Kim Bôi, Hoà Bình",
  "Tú Sơn, Kim Bôi, Hoà Bình",
  "Vĩnh Tiến, Kim Bôi, Hoà Bình",
  "Đông Bắc, Kim Bôi, Hoà Bình",
  "Xuân Thủy, Kim Bôi, Hoà Bình",
  "Vĩnh Đồng, Kim Bôi, Hoà Bình",
  "Kim Lập, Kim Bôi, Hoà Bình",
  "Hợp Tiến, Kim Bôi, Hoà Bình",
  "Kim Bôi, Kim Bôi, Hoà Bình",
  "Nam Thượng, Kim Bôi, Hoà Bình",
  "Cuối Hạ, Kim Bôi, Hoà Bình",
  "Sào Báy, Kim Bôi, Hoà Bình",
  "Mi Hòa, Kim Bôi, Hoà Bình",
  "Nuông Dăm, Kim Bôi, Hoà Bình",
  "Cao Phong, Cao Phong, Hoà Bình",
  "Bình Thanh, Cao Phong, Hoà Bình",
  "Thung Nai, Cao Phong, Hoà Bình",
  "Bắc Phong, Cao Phong, Hoà Bình",
  "Thu Phong, Cao Phong, Hoà Bình",
  "Hợp Phong, Cao Phong, Hoà Bình",
  "Tây Phong, Cao Phong, Hoà Bình",
  "Dũng Phong, Cao Phong, Hoà Bình",
  "Nam Phong, Cao Phong, Hoà Bình",
  "Thạch Yên, Cao Phong, Hoà Bình",
  "Mãn Đức, Tân Lạc, Hoà Bình",
  "Suối Hoa, Tân Lạc, Hoà Bình",
  "Phú Vinh, Tân Lạc, Hoà Bình",
  "Phú Cường, Tân Lạc, Hoà Bình",
  "Mỹ Hòa, Tân Lạc, Hoà Bình",
  "Quyết Chiến, Tân Lạc, Hoà Bình",
  "Phong Phú, Tân Lạc, Hoà Bình",
  "Tử Nê, Tân Lạc, Hoà Bình",
  "Thanh Hối, Tân Lạc, Hoà Bình",
  "Ngọc Mỹ, Tân Lạc, Hoà Bình",
  "Đông Lai, Tân Lạc, Hoà Bình",
  "Vân Sơn, Tân Lạc, Hoà Bình",
  "Nhân Mỹ, Tân Lạc, Hoà Bình",
  "Lỗ Sơn, Tân Lạc, Hoà Bình",
  "Ngổ Luông, Tân Lạc, Hoà Bình",
  "Gia Mô, Tân Lạc, Hoà Bình",
  "Tân Thành, Mai Châu, Hoà Bình",
  "Mai Châu, Mai Châu, Hoà Bình",
  "Sơn Thủy, Mai Châu, Hoà Bình",
  "Pà Cò, Mai Châu, Hoà Bình",
  "Hang Kia, Mai Châu, Hoà Bình",
  "Đồng Tân, Mai Châu, Hoà Bình",
  "Cun Pheo, Mai Châu, Hoà Bình",
  "Bao La, Mai Châu, Hoà Bình",
  "Tòng Đậu, Mai Châu, Hoà Bình",
  "Nà Phòn, Mai Châu, Hoà Bình",
  "Săm Khóe, Mai Châu, Hoà Bình",
  "Chiềng Châu, Mai Châu, Hoà Bình",
  "Mai Hạ, Mai Châu, Hoà Bình",
  "Thành Sơn, Mai Châu, Hoà Bình",
  "Mai Hịch, Mai Châu, Hoà Bình",
  "Vạn Mai, Mai Châu, Hoà Bình",
  "Vụ Bản, Lạc Sơn, Hoà Bình",
  "Quý Hòa, Lạc Sơn, Hoà Bình",
  "Miền Đồi, Lạc Sơn, Hoà Bình",
  "Mỹ Thành, Lạc Sơn, Hoà Bình",
  "Tuân Đạo, Lạc Sơn, Hoà Bình",
  "Văn Nghĩa, Lạc Sơn, Hoà Bình",
  "Văn Sơn, Lạc Sơn, Hoà Bình",
  "Tân Lập, Lạc Sơn, Hoà Bình",
  "Nhân Nghĩa, Lạc Sơn, Hoà Bình",
  "Thượng Cốc, Lạc Sơn, Hoà Bình",
  "Quyết Thắng, Lạc Sơn, Hoà Bình",
  "Xuất Hóa, Lạc Sơn, Hoà Bình",
  "Yên Phú, Lạc Sơn, Hoà Bình",
  "Bình Hẻm, Lạc Sơn, Hoà Bình",
  "Định Cư, Lạc Sơn, Hoà Bình",
  "Chí Đạo, Lạc Sơn, Hoà Bình",
  "Ngọc Sơn, Lạc Sơn, Hoà Bình",
  "Hương Nhượng, Lạc Sơn, Hoà Bình",
  "Vũ Bình, Lạc Sơn, Hoà Bình",
  "Tự Do, Lạc Sơn, Hoà Bình",
  "Yên Nghiệp, Lạc Sơn, Hoà Bình",
  "Tân Mỹ, Lạc Sơn, Hoà Bình",
  "Ân Nghĩa, Lạc Sơn, Hoà Bình",
  "Ngọc Lâu, Lạc Sơn, Hoà Bình",
  "Hàng Trạm, Yên Thủy, Hoà Bình",
  "Lạc Sỹ, Yên Thủy, Hoà Bình",
  "Lạc Lương, Yên Thủy, Hoà Bình",
  "Bảo Hiệu, Yên Thủy, Hoà Bình",
  "Đa Phúc, Yên Thủy, Hoà Bình",
  "Hữu Lợi, Yên Thủy, Hoà Bình",
  "Lạc Thịnh, Yên Thủy, Hoà Bình",
  "Đoàn Kết, Yên Thủy, Hoà Bình",
  "Phú Lai, Yên Thủy, Hoà Bình",
  "Yên Trị, Yên Thủy, Hoà Bình",
  "Ngọc Lương, Yên Thủy, Hoà Bình",
  "Ba Hàng Đồi, Lạc Thủy, Hoà Bình",
  "Chi Nê, Lạc Thủy, Hoà Bình",
  "Phú Nghĩa, Lạc Thủy, Hoà Bình",
  "Phú Thành, Lạc Thủy, Hoà Bình",
  "Hưng Thi, Lạc Thủy, Hoà Bình",
  "Khoan Dụ, Lạc Thủy, Hoà Bình",
  "Đồng Tâm, Lạc Thủy, Hoà Bình",
  "Yên Bồng, Lạc Thủy, Hoà Bình",
  "Thống Nhất, Lạc Thủy, Hoà Bình",
  "An Bình, Lạc Thủy, Hoà Bình",
  "Quán Triều, Thái Nguyên, Thái Nguyên",
  "Quang Vinh, Thái Nguyên, Thái Nguyên",
  "Túc Duyên, Thái Nguyên, Thái Nguyên",
  "Hoàng Văn Thụ, Thái Nguyên, Thái Nguyên",
  "Trưng Vương, Thái Nguyên, Thái Nguyên",
  "Quang Trung, Thái Nguyên, Thái Nguyên",
  "Phan Đình Phùng, Thái Nguyên, Thái Nguyên",
  "Tân Thịnh, Thái Nguyên, Thái Nguyên",
  "Thịnh Đán, Thái Nguyên, Thái Nguyên",
  "Đồng Quang, Thái Nguyên, Thái Nguyên",
  "Gia Sàng, Thái Nguyên, Thái Nguyên",
  "Tân Lập, Thái Nguyên, Thái Nguyên",
  "Cam Giá, Thái Nguyên, Thái Nguyên",
  "Phú Xá, Thái Nguyên, Thái Nguyên",
  "Hương Sơn, Thái Nguyên, Thái Nguyên",
  "Trung Thành, Thái Nguyên, Thái Nguyên",
  "Tân Thành, Thái Nguyên, Thái Nguyên",
  "Tân Long, Thái Nguyên, Thái Nguyên",
  "Phúc Hà, Thái Nguyên, Thái Nguyên",
  "Phúc Xuân, Thái Nguyên, Thái Nguyên",
  "Quyết Thắng, Thái Nguyên, Thái Nguyên",
  "Phúc Trìu, Thái Nguyên, Thái Nguyên",
  "Thịnh Đức, Thái Nguyên, Thái Nguyên",
  "Tích Lương, Thái Nguyên, Thái Nguyên",
  "Tân Cương, Thái Nguyên, Thái Nguyên",
  "Sơn Cẩm, Thái Nguyên, Thái Nguyên",
  "Chùa Hang, Thái Nguyên, Thái Nguyên",
  "Cao Ngạn, Thái Nguyên, Thái Nguyên",
  "Linh Sơn, Thái Nguyên, Thái Nguyên",
  "Đồng Bẩm, Thái Nguyên, Thái Nguyên",
  "Huống Thượng, Thái Nguyên, Thái Nguyên",
  "Đồng Liên, Thái Nguyên, Thái Nguyên",
  "Lương Sơn, Sông Công, Thái Nguyên",
  "Châu Sơn, Sông Công, Thái Nguyên",
  "Mỏ Chè, Sông Công, Thái Nguyên",
  "Cải Đan, Sông Công, Thái Nguyên",
  "Thắng Lợi, Sông Công, Thái Nguyên",
  "Phố Cò, Sông Công, Thái Nguyên",
  "Tân Quang, Sông Công, Thái Nguyên",
  "Bách Quang, Sông Công, Thái Nguyên",
  "Bình Sơn, Sông Công, Thái Nguyên",
  "Bá Xuyên, Sông Công, Thái Nguyên",
  "Chợ Chu, Định Hóa, Thái Nguyên",
  "Linh Thông, Định Hóa, Thái Nguyên",
  "Lam Vỹ, Định Hóa, Thái Nguyên",
  "Quy Kỳ, Định Hóa, Thái Nguyên",
  "Tân Thịnh, Định Hóa, Thái Nguyên",
  "Kim Phượng, Định Hóa, Thái Nguyên",
  "Bảo Linh, Định Hóa, Thái Nguyên",
  "Phúc Chu, Định Hóa, Thái Nguyên",
  "Tân Dương, Định Hóa, Thái Nguyên",
  "Phượng Tiến, Định Hóa, Thái Nguyên",
  "Bảo Cường, Định Hóa, Thái Nguyên",
  "Đồng Thịnh, Định Hóa, Thái Nguyên",
  "Định Biên, Định Hóa, Thái Nguyên",
  "Thanh Định, Định Hóa, Thái Nguyên",
  "Trung Hội, Định Hóa, Thái Nguyên",
  "Trung Lương, Định Hóa, Thái Nguyên",
  "Bình Yên, Định Hóa, Thái Nguyên",
  "Điềm Mặc, Định Hóa, Thái Nguyên",
  "Phú Tiến, Định Hóa, Thái Nguyên",
  "Bộc Nhiêu, Định Hóa, Thái Nguyên",
  "Sơn Phú, Định Hóa, Thái Nguyên",
  "Phú Đình, Định Hóa, Thái Nguyên",
  "Bình Thành, Định Hóa, Thái Nguyên",
  "Giang Tiên, Phú Lương, Thái Nguyên",
  "Đu, Phú Lương, Thái Nguyên",
  "Yên Ninh, Phú Lương, Thái Nguyên",
  "Yên Trạch, Phú Lương, Thái Nguyên",
  "Yên Đổ, Phú Lương, Thái Nguyên",
  "Yên Lạc, Phú Lương, Thái Nguyên",
  "Ôn Lương, Phú Lương, Thái Nguyên",
  "Động Đạt, Phú Lương, Thái Nguyên",
  "Phủ Lý, Phú Lương, Thái Nguyên",
  "Phú Đô, Phú Lương, Thái Nguyên",
  "Hợp Thành, Phú Lương, Thái Nguyên",
  "Tức Tranh, Phú Lương, Thái Nguyên",
  "Phấn Mễ, Phú Lương, Thái Nguyên",
  "Vô Tranh, Phú Lương, Thái Nguyên",
  "Cổ Lũng, Phú Lương, Thái Nguyên",
  "Sông Cầu, Đồng Hỷ, Thái Nguyên",
  "Trại Cau, Đồng Hỷ, Thái Nguyên",
  "Văn Lăng, Đồng Hỷ, Thái Nguyên",
  "Tân Long, Đồng Hỷ, Thái Nguyên",
  "Hòa Bình, Đồng Hỷ, Thái Nguyên",
  "Quang Sơn, Đồng Hỷ, Thái Nguyên",
  "Minh Lập, Đồng Hỷ, Thái Nguyên",
  "Văn Hán, Đồng Hỷ, Thái Nguyên",
  "Hóa Trung, Đồng Hỷ, Thái Nguyên",
  "Khe Mo, Đồng Hỷ, Thái Nguyên",
  "Cây Thị, Đồng Hỷ, Thái Nguyên",
  "Hóa Thượng, Đồng Hỷ, Thái Nguyên",
  "Hợp Tiến, Đồng Hỷ, Thái Nguyên",
  "Tân Lợi, Đồng Hỷ, Thái Nguyên",
  "Nam Hòa, Đồng Hỷ, Thái Nguyên",
  "Đình Cả, Võ Nhai, Thái Nguyên",
  "Sảng Mộc, Võ Nhai, Thái Nguyên",
  "Nghinh Tường, Võ Nhai, Thái Nguyên",
  "Thần Xa, Võ Nhai, Thái Nguyên",
  "Vũ Chấn, Võ Nhai, Thái Nguyên",
  "Thượng Nung, Võ Nhai, Thái Nguyên",
  "Phú Thượng, Võ Nhai, Thái Nguyên",
  "Cúc Đường, Võ Nhai, Thái Nguyên",
  "La Hiên, Võ Nhai, Thái Nguyên",
  "Lâu Thượng, Võ Nhai, Thái Nguyên",
  "Tràng Xá, Võ Nhai, Thái Nguyên",
  "Phương Giao, Võ Nhai, Thái Nguyên",
  "Liên Minh, Võ Nhai, Thái Nguyên",
  "Dân Tiến, Võ Nhai, Thái Nguyên",
  "Bình Long, Võ Nhai, Thái Nguyên",
  "Hùng Sơn, Đại Từ, Thái Nguyên",
  "Quân Chu, Đại Từ, Thái Nguyên",
  "Phúc Lương, Đại Từ, Thái Nguyên",
  "Minh Tiến, Đại Từ, Thái Nguyên",
  "Yên Lãng, Đại Từ, Thái Nguyên",
  "Đức Lương, Đại Từ, Thái Nguyên",
  "Phú Cường, Đại Từ, Thái Nguyên",
  "Na Mao, Đại Từ, Thái Nguyên",
  "Phú Lạc, Đại Từ, Thái Nguyên",
  "Tân Linh, Đại Từ, Thái Nguyên",
  "Phú Thịnh, Đại Từ, Thái Nguyên",
  "Phục Linh, Đại Từ, Thái Nguyên",
  "Phú Xuyên, Đại Từ, Thái Nguyên",
  "Bản Ngoại, Đại Từ, Thái Nguyên",
  "Tiên Hội, Đại Từ, Thái Nguyên",
  "Cù Vân, Đại Từ, Thái Nguyên",
  "Hà Thượng, Đại Từ, Thái Nguyên",
  "La Bằng, Đại Từ, Thái Nguyên",
  "Hoàng Nông, Đại Từ, Thái Nguyên",
  "Khôi Kỳ, Đại Từ, Thái Nguyên",
  "An Khánh, Đại Từ, Thái Nguyên",
  "Tân Thái, Đại Từ, Thái Nguyên",
  "Bình Thuận, Đại Từ, Thái Nguyên",
  "Lục Ba, Đại Từ, Thái Nguyên",
  "Mỹ Yên, Đại Từ, Thái Nguyên",
  "Vạn Thọ, Đại Từ, Thái Nguyên",
  "Văn Yên, Đại Từ, Thái Nguyên",
  "Ký Phú, Đại Từ, Thái Nguyên",
  "Cát Nê, Đại Từ, Thái Nguyên",
  "Quân Chu, Đại Từ, Thái Nguyên",
  "Bãi Bông, Phổ Yên, Thái Nguyên",
  "Bắc Sơn, Phổ Yên, Thái Nguyên",
  "Ba Hàng, Phổ Yên, Thái Nguyên",
  "Phúc Tân, Phổ Yên, Thái Nguyên",
  "Phúc Thuận, Phổ Yên, Thái Nguyên",
  "Hồng Tiến, Phổ Yên, Thái Nguyên",
  "Minh Đức, Phổ Yên, Thái Nguyên",
  "Đắc Sơn, Phổ Yên, Thái Nguyên",
  "Đồng Tiến, Phổ Yên, Thái Nguyên",
  "Thành Công, Phổ Yên, Thái Nguyên",
  "Tiên Phong, Phổ Yên, Thái Nguyên",
  "Vạn Phái, Phổ Yên, Thái Nguyên",
  "Nam Tiến, Phổ Yên, Thái Nguyên",
  "Tân Hương, Phổ Yên, Thái Nguyên",
  "Đông Cao, Phổ Yên, Thái Nguyên",
  "Trung Thành, Phổ Yên, Thái Nguyên",
  "Tân Phú, Phổ Yên, Thái Nguyên",
  "Thuận Thành, Phổ Yên, Thái Nguyên",
  "Hương Sơn, Phú Bình, Thái Nguyên",
  "Bàn Đạt, Phú Bình, Thái Nguyên",
  "Tân Khánh, Phú Bình, Thái Nguyên",
  "Tân Kim, Phú Bình, Thái Nguyên",
  "Tân Thành, Phú Bình, Thái Nguyên",
  "Đào Xá, Phú Bình, Thái Nguyên",
  "Bảo Lý, Phú Bình, Thái Nguyên",
  "Thượng Đình, Phú Bình, Thái Nguyên",
  "Tân Hòa, Phú Bình, Thái Nguyên",
  "Nhã Lộng, Phú Bình, Thái Nguyên",
  "Điềm Thụy, Phú Bình, Thái Nguyên",
  "Xuân Phương, Phú Bình, Thái Nguyên",
  "Tân Đức, Phú Bình, Thái Nguyên",
  "Úc Kỳ, Phú Bình, Thái Nguyên",
  "Lương Phú, Phú Bình, Thái Nguyên",
  "Nga My, Phú Bình, Thái Nguyên",
  "Kha Sơn, Phú Bình, Thái Nguyên",
  "Thanh Ninh, Phú Bình, Thái Nguyên",
  "Dương Thành, Phú Bình, Thái Nguyên",
  "Hà Châu, Phú Bình, Thái Nguyên",
  "Hoàng Văn Thụ, Lạng Sơn, Lạng Sơn",
  "Tam Thanh, Lạng Sơn, Lạng Sơn",
  "Vĩnh Trại, Lạng Sơn, Lạng Sơn",
  "Đông Kinh, Lạng Sơn, Lạng Sơn",
  "Chi Lăng, Lạng Sơn, Lạng Sơn",
  "Hoàng Đồng, Lạng Sơn, Lạng Sơn",
  "Quảng Lạc, Lạng Sơn, Lạng Sơn",
  "Mai Pha, Lạng Sơn, Lạng Sơn",
  "Thất Khê, Tràng Định, Lạng Sơn",
  "Khánh Long, Tràng Định, Lạng Sơn",
  "Đoàn Kết, Tràng Định, Lạng Sơn",
  "Quốc Khánh, Tràng Định, Lạng Sơn",
  "Vĩnh Tiến, Tràng Định, Lạng Sơn",
  "Cao Minh, Tràng Định, Lạng Sơn",
  "Chí Minh, Tràng Định, Lạng Sơn",
  "Tri Phương, Tràng Định, Lạng Sơn",
  "Tân Tiến, Tràng Định, Lạng Sơn",
  "Tân Yên, Tràng Định, Lạng Sơn",
  "Đội Cấn, Tràng Định, Lạng Sơn",
  "Tân Minh, Tràng Định, Lạng Sơn",
  "Kim Đồng, Tràng Định, Lạng Sơn",
  "Chi Lăng, Tràng Định, Lạng Sơn",
  "Trung Thành, Tràng Định, Lạng Sơn",
  "Đại Đồng, Tràng Định, Lạng Sơn",
  "Đào Viên, Tràng Định, Lạng Sơn",
  "Đề Thám, Tràng Định, Lạng Sơn",
  "Kháng Chiến, Tràng Định, Lạng Sơn",
  "Hùng Sơn, Tràng Định, Lạng Sơn",
  "Quốc Việt, Tràng Định, Lạng Sơn",
  "Hùng Việt, Tràng Định, Lạng Sơn",
  "Hưng Đạo, Bình Gia, Lạng Sơn",
  "Vĩnh Yên, Bình Gia, Lạng Sơn",
  "Hoa Thám, Bình Gia, Lạng Sơn",
  "Quý Hòa, Bình Gia, Lạng Sơn",
  "Hồng Phong, Bình Gia, Lạng Sơn",
  "Yên Lỗ, Bình Gia, Lạng Sơn",
  "Thiện Hòa, Bình Gia, Lạng Sơn",
  "Quang Trung, Bình Gia, Lạng Sơn",
  "Thiện Thuật, Bình Gia, Lạng Sơn",
  "Minh Khai, Bình Gia, Lạng Sơn",
  "Thiện Long, Bình Gia, Lạng Sơn",
  "Hoàng Văn Thụ, Bình Gia, Lạng Sơn",
  "Hòa Bình, Bình Gia, Lạng Sơn",
  "Mông Ân, Bình Gia, Lạng Sơn",
  "Tân Hòa, Bình Gia, Lạng Sơn",
  "Bình Gia, Bình Gia, Lạng Sơn",
  "Hồng Thái, Bình Gia, Lạng Sơn",
  "Bình La, Bình Gia, Lạng Sơn",
  "Tân Văn, Bình Gia, Lạng Sơn",
  "Na Sầm, Văn Lãng, Lạng Sơn",
  "Trùng Khánh, Văn Lãng, Lạng Sơn",
  "Bắc La, Văn Lãng, Lạng Sơn",
  "Thụy Hùng, Văn Lãng, Lạng Sơn",
  "Bắc Hùng, Văn Lãng, Lạng Sơn",
  "Tân Tác, Văn Lãng, Lạng Sơn",
  "Thanh Long, Văn Lãng, Lạng Sơn",
  "Hội Hoan, Văn Lãng, Lạng Sơn",
  "Bắc Việt, Văn Lãng, Lạng Sơn",
  "Hoàng Việt, Văn Lãng, Lạng Sơn",
  "Gia Miễn, Văn Lãng, Lạng Sơn",
  "Thành Hòa, Văn Lãng, Lạng Sơn",
  "Tân Thanh, Văn Lãng, Lạng Sơn",
  "Tân Mỹ, Văn Lãng, Lạng Sơn",
  "Hồng Thái, Văn Lãng, Lạng Sơn",
  " Hoàng Văn Thụ, Văn Lãng, Lạng Sơn",
  "Nhạc Kỳ, Văn Lãng, Lạng Sơn",
  "Đồng Đăng, Cao Lộc, Lạng Sơn",
  "Cao Lộc, Cao Lộc, Lạng Sơn",
  "Bảo Lâm, Cao Lộc, Lạng Sơn",
  "Thanh Lòa, Cao Lộc, Lạng Sơn",
  "Cao Lâu, Cao Lộc, Lạng Sơn",
  "Thạch Đạn, Cao Lộc, Lạng Sơn",
  "Xuất Lễ, Cao Lộc, Lạng Sơn",
  "Hồng Phong, Cao Lộc, Lạng Sơn",
  "Thụy Hùng, Cao Lộc, Lạng Sơn",
  "Lộc Yên, Cao Lộc, Lạng Sơn",
  "Phú Xá, Cao Lộc, Lạng Sơn",
  "Bình Trung, Cao Lộc, Lạng Sơn",
  "Hải Yến, Cao Lộc, Lạng Sơn",
  "Hòa Cư, Cao Lộc, Lạng Sơn",
  "Hợp Thành, Cao Lộc, Lạng Sơn",
  "Công Sơn, Cao Lộc, Lạng Sơn",
  "Gia Cát, Cao Lộc, Lạng Sơn",
  "Mẫu Sơn, Cao Lộc, Lạng Sơn",
  "Xuân Long, Cao Lộc, Lạng Sơn",
  "Tân Liên, Cao Lộc, Lạng Sơn",
  "Yên Trạch, Cao Lộc, Lạng Sơn",
  "Tân Thành, Cao Lộc, Lạng Sơn",
  "Văn Quan, Văn Quan, Lạng Sơn",
  "Trấn Ninh, Văn Quan, Lạng Sơn",
  "Liên Hội, Văn Quan, Lạng Sơn",
  "Hòa Bình, Văn Quan, Lạng Sơn",
  "Tú Xuyên, Văn Quan, Lạng Sơn",
  "Điềm He, Văn Quan, Lạng Sơn",
  "An Sơn, Văn Quan, Lạng Sơn",
  "Khánh Khê, Văn Quan, Lạng Sơn",
  "Lương Năng, Văn Quan, Lạng Sơn",
  "Đồng Giáp, Văn Quan, Lạng Sơn",
  "Bình Phúc, Văn Quan, Lạng Sơn",
  "Tràng Các, Văn Quan, Lạng Sơn",
  "Tân Đoàn, Văn Quan, Lạng Sơn",
  "Tri Lễ, Văn Quan, Lạng Sơn",
  "Tràng Phái, Văn Quan, Lạng Sơn",
  "Yên Phúc, Văn Quan, Lạng Sơn",
  "Hữu Lễ, Văn Quan, Lạng Sơn",
  "Bắc Sơn, Bắc Sơn, Lạng Sơn",
  "Long Đống, Bắc Sơn, Lạng Sơn",
  "Vạn Thủy, Bắc Sơn, Lạng Sơn",
  "Đồng ý, Bắc Sơn, Lạng Sơn",
  "Tân Tri, Bắc Sơn, Lạng Sơn",
  "Bắc Quỳnh, Bắc Sơn, Lạng Sơn",
  "Hưng Vũ, Bắc Sơn, Lạng Sơn",
  "Tân Lập, Bắc Sơn, Lạng Sơn",
  "Vũ Sơn, Bắc Sơn, Lạng Sơn",
  "Chiêu Vũ, Bắc Sơn, Lạng Sơn",
  "Tân Hương, Bắc Sơn, Lạng Sơn",
  "Chiến Thắng, Bắc Sơn, Lạng Sơn",
  "Vũ Lăng, Bắc Sơn, Lạng Sơn",
  "Trấn Yên, Bắc Sơn, Lạng Sơn",
  "Vũ Lễ, Bắc Sơn, Lạng Sơn",
  "Nhất Hòa, Bắc Sơn, Lạng Sơn",
  "Tân Thành, Bắc Sơn, Lạng Sơn",
  "Nhất Tiến, Bắc Sơn, Lạng Sơn",
  "Hữu Lũng, Hữu Lũng, Lạng Sơn",
  "Hữu Liên, Hữu Lũng, Lạng Sơn",
  "Yên Bình, Hữu Lũng, Lạng Sơn",
  "Quyết Thắng, Hữu Lũng, Lạng Sơn",
  "Hòa Bình, Hữu Lũng, Lạng Sơn",
  "Yên Thịnh, Hữu Lũng, Lạng Sơn",
  "Yên Sơn, Hữu Lũng, Lạng Sơn",
  "Thiện Tân, Hữu Lũng, Lạng Sơn",
  "Yên Vượng, Hữu Lũng, Lạng Sơn",
  "Minh Tiến, Hữu Lũng, Lạng Sơn",
  "Nhật Tiến, Hữu Lũng, Lạng Sơn",
  "Thanh Sơn, Hữu Lũng, Lạng Sơn",
  "Đồng Tân, Hữu Lũng, Lạng Sơn",
  "Cai Kinh, Hữu Lũng, Lạng Sơn",
  "Hòa Lạc, Hữu Lũng, Lạng Sơn",
  "Vân Nham, Hữu Lũng, Lạng Sơn",
  "Đồng Tiến, Hữu Lũng, Lạng Sơn",
  "Tân Thành, Hữu Lũng, Lạng Sơn",
  "Hòa Sơn, Hữu Lũng, Lạng Sơn",
  "Minh Sơn, Hữu Lũng, Lạng Sơn",
  "Hồ Sơn, Hữu Lũng, Lạng Sơn",
  "Sơn Hà, Hữu Lũng, Lạng Sơn",
  "Minh Hòa, Hữu Lũng, Lạng Sơn",
  "Hòa Thắng, Hữu Lũng, Lạng Sơn",
  "Đồng Mỏ, Chi Lăng, Lạng Sơn",
  "Chi Lăng, Chi Lăng, Lạng Sơn",
  "Vân An, Chi Lăng, Lạng Sơn",
  "Vân Thủy, Chi Lăng, Lạng Sơn",
  "Gia Lộc, Chi Lăng, Lạng Sơn",
  "Bắc Thủy, Chi Lăng, Lạng Sơn",
  "Chiến Thắng, Chi Lăng, Lạng Sơn",
  "Mai Sao, Chi Lăng, Lạng Sơn",
  "Bằng Hữu, Chi Lăng, Lạng Sơn",
  "Thượng Cường, Chi Lăng, Lạng Sơn",
  "Bằng Mạc, Chi Lăng, Lạng Sơn",
  "Nhân Lý, Chi Lăng, Lạng Sơn",
  "Lâm Sơn, Chi Lăng, Lạng Sơn",
  "Liên Sơn, Chi Lăng, Lạng Sơn",
  "Vạn Linh, Chi Lăng, Lạng Sơn",
  "Hòa Bình, Chi Lăng, Lạng Sơn",
  "Hữu Kiên, Chi Lăng, Lạng Sơn",
  "Quan Sơn, Chi Lăng, Lạng Sơn",
  "Y Tịch, Chi Lăng, Lạng Sơn",
  "Chi Lăng, Chi Lăng, Lạng Sơn",
  "Na Dương, Lộc Bình, Lạng Sơn",
  "Lộc Bình, Lộc Bình, Lạng Sơn",
  "Mẫu Sơn, Lộc Bình, Lạng Sơn",
  "Yên Khoái, Lộc Bình, Lạng Sơn",
  "Khánh Xuân, Lộc Bình, Lạng Sơn",
  "Tú Mịch, Lộc Bình, Lạng Sơn",
  "Hữu Khánh, Lộc Bình, Lạng Sơn",
  "Đồng Bục, Lộc Bình, Lạng Sơn",
  "Tam Gia, Lộc Bình, Lạng Sơn",
  "Tú Đoạn, Lộc Bình, Lạng Sơn",
  "Khuất Xá, Lộc Bình, Lạng Sơn",
  "Tĩnh Bắc, Lộc Bình, Lạng Sơn",
  "Thống Nhất, Lộc Bình, Lạng Sơn",
  "Sàn Viên, Lộc Bình, Lạng Sơn",
  "Đông Quan, Lộc Bình, Lạng Sơn",
  "Minh Hiệp, Lộc Bình, Lạng Sơn",
  "Hữu Lân, Lộc Bình, Lạng Sơn",
  "Lợi Bác, Lộc Bình, Lạng Sơn",
  "Nam Quan, Lộc Bình, Lạng Sơn",
  "Xuân Dương, Lộc Bình, Lạng Sơn",
  "Ái Quốc, Lộc Bình, Lạng Sơn",
  "Đình Lập, Đình Lập, Lạng Sơn",
  "NT Thái Bình, Đình Lập, Lạng Sơn",
  "Bắc Xa, Đình Lập, Lạng Sơn",
  "Bính Xá, Đình Lập, Lạng Sơn",
  "Kiên Mộc, Đình Lập, Lạng Sơn",
  "Đình Lập, Đình Lập, Lạng Sơn",
  "Thái Bình, Đình Lập, Lạng Sơn",
  "Cường Lợi, Đình Lập, Lạng Sơn",
  "Châu Sơn, Đình Lập, Lạng Sơn",
  "Lâm Ca, Đình Lập, Lạng Sơn",
  "Đồng Thắng, Đình Lập, Lạng Sơn",
  "Bắc Lãng, Đình Lập, Lạng Sơn",
  "Hà Khánh, Hạ Long, Quảng Ninh",
  "Hà Phong, Hạ Long, Quảng Ninh",
  "Hà Khẩu, Hạ Long, Quảng Ninh",
  "Cao Xanh, Hạ Long, Quảng Ninh",
  "Giếng Đáy, Hạ Long, Quảng Ninh",
  "Hà Tu, Hạ Long, Quảng Ninh",
  "Hà Trung, Hạ Long, Quảng Ninh",
  "Hà Lầm, Hạ Long, Quảng Ninh",
  "Bãi Cháy, Hạ Long, Quảng Ninh",
  "Cao Thắng, Hạ Long, Quảng Ninh",
  "Hùng Thắng, Hạ Long, Quảng Ninh",
  "Yết Kiêu, Hạ Long, Quảng Ninh",
  "Trần Hưng Đạo, Hạ Long, Quảng Ninh",
  "Hồng Hải, Hạ Long, Quảng Ninh",
  "Hồng Gai, Hạ Long, Quảng Ninh",
  "Bạch Đằng, Hạ Long, Quảng Ninh",
  "Hồng Hà, Hạ Long, Quảng Ninh",
  "Tuần Châu, Hạ Long, Quảng Ninh",
  "Việt Hưng, Hạ Long, Quảng Ninh",
  "Đại Yên, Hạ Long, Quảng Ninh",
  "Hoành Bồ, Hạ Long, Quảng Ninh",
  "Kỳ Thượng, Hạ Long, Quảng Ninh",
  "Đồng Sơn, Hạ Long, Quảng Ninh",
  "Tân Dân, Hạ Long, Quảng Ninh",
  "Đồng Lâm, Hạ Long, Quảng Ninh",
  "Hòa Bình, Hạ Long, Quảng Ninh",
  "Vũ Oai, Hạ Long, Quảng Ninh",
  "Dân Chủ, Hạ Long, Quảng Ninh",
  "Quảng La, Hạ Long, Quảng Ninh",
  "Bằng Cả, Hạ Long, Quảng Ninh",
  "Thống Nhất, Hạ Long, Quảng Ninh",
  "Sơn Dương, Hạ Long, Quảng Ninh",
  "Lê Lợi, Hạ Long, Quảng Ninh",
  "Ka Long, Móng Cái, Quảng Ninh",
  "Trần Phú, Móng Cái, Quảng Ninh",
  "Ninh Dương, Móng Cái, Quảng Ninh",
  "Hoà Lạc, Móng Cái, Quảng Ninh",
  "Trà Cổ, Móng Cái, Quảng Ninh",
  "Hải Sơn, Móng Cái, Quảng Ninh",
  "Bắc Sơn, Móng Cái, Quảng Ninh",
  "Hải Đông, Móng Cái, Quảng Ninh",
  "Hải Tiến, Móng Cái, Quảng Ninh",
  "Hải Yên, Móng Cái, Quảng Ninh",
  "Quảng Nghĩa, Móng Cái, Quảng Ninh",
  "Hải Hoà, Móng Cái, Quảng Ninh",
  "Hải Xuân, Móng Cái, Quảng Ninh",
  "Vạn Ninh, Móng Cái, Quảng Ninh",
  "Bình Ngọc, Móng Cái, Quảng Ninh",
  "Vĩnh Trung, Móng Cái, Quảng Ninh",
  "Vĩnh Thực, Móng Cái, Quảng Ninh",
  "Mông Dương, Cẩm Phả, Quảng Ninh",
  "Cửa Ông, Cẩm Phả, Quảng Ninh",
  "Cẩm Sơn, Cẩm Phả, Quảng Ninh",
  "Cẩm Đông, Cẩm Phả, Quảng Ninh",
  "Cẩm Phú, Cẩm Phả, Quảng Ninh",
  "Cẩm Tây, Cẩm Phả, Quảng Ninh",
  "Quang Hanh, Cẩm Phả, Quảng Ninh",
  "Cẩm Thịnh, Cẩm Phả, Quảng Ninh",
  "Cẩm Thủy, Cẩm Phả, Quảng Ninh",
  "Cẩm Thạch, Cẩm Phả, Quảng Ninh",
  "Cẩm Thành, Cẩm Phả, Quảng Ninh",
  "Cẩm Trung, Cẩm Phả, Quảng Ninh",
  "Cẩm Bình, Cẩm Phả, Quảng Ninh",
  "Cộng Hòa, Cẩm Phả, Quảng Ninh",
  "Cẩm Hải, Cẩm Phả, Quảng Ninh",
  "Dương Huy, Cẩm Phả, Quảng Ninh",
  "Vàng Danh, Uông Bí, Quảng Ninh",
  "Thanh Sơn, Uông Bí, Quảng Ninh",
  "Bắc Sơn, Uông Bí, Quảng Ninh",
  "Quang Trung, Uông Bí, Quảng Ninh",
  "Trưng Vương, Uông Bí, Quảng Ninh",
  "Nam Khê, Uông Bí, Quảng Ninh",
  "Yên Thanh, Uông Bí, Quảng Ninh",
  "Thượng Yên Công, Uông Bí, Quảng Ninh",
  "Phương Đông, Uông Bí, Quảng Ninh",
  "Phương Nam, Uông Bí, Quảng Ninh",
  "Bình Liêu, Bình Liêu, Quảng Ninh",
  "Hoành Mô, Bình Liêu, Quảng Ninh",
  "Đồng Tâm, Bình Liêu, Quảng Ninh",
  "Đồng Văn, Bình Liêu, Quảng Ninh",
  "Vô Ngại, Bình Liêu, Quảng Ninh",
  "Lục Hồn, Bình Liêu, Quảng Ninh",
  "Húc Động, Bình Liêu, Quảng Ninh",
  "Tiên Yên, Tiên Yên, Quảng Ninh",
  "Hà Lâu, Tiên Yên, Quảng Ninh",
  "Đại Dực, Tiên Yên, Quảng Ninh",
  "Phong Dụ, Tiên Yên, Quảng Ninh",
  "Điền Xá, Tiên Yên, Quảng Ninh",
  "Đông Ngũ, Tiên Yên, Quảng Ninh",
  "Yên Than, Tiên Yên, Quảng Ninh",
  "Đông Hải, Tiên Yên, Quảng Ninh",
  "Hải Lạng, Tiên Yên, Quảng Ninh",
  "Tiên Lãng, Tiên Yên, Quảng Ninh",
  "Đồng Rui, Tiên Yên, Quảng Ninh",
  "Đầm Hà, Đầm Hà, Quảng Ninh",
  "Quảng Lâm, Đầm Hà, Quảng Ninh",
  "Quảng An, Đầm Hà, Quảng Ninh",
  "Tân Bình, Đầm Hà, Quảng Ninh",
  "Dực Yên, Đầm Hà, Quảng Ninh",
  "Quảng Tân, Đầm Hà, Quảng Ninh",
  "Đầm Hà, Đầm Hà, Quảng Ninh",
  "Tân Lập, Đầm Hà, Quảng Ninh",
  "Đại Bình, Đầm Hà, Quảng Ninh",
  "Quảng Hà, Hải Hà, Quảng Ninh",
  "Quảng Đức, Hải Hà, Quảng Ninh",
  "Quảng Sơn, Hải Hà, Quảng Ninh",
  "Quảng Thành, Hải Hà, Quảng Ninh",
  "Quảng Thịnh, Hải Hà, Quảng Ninh",
  "Quảng Minh, Hải Hà, Quảng Ninh",
  "Quảng Chính, Hải Hà, Quảng Ninh",
  "Quảng Long, Hải Hà, Quảng Ninh",
  "Đường Hoa, Hải Hà, Quảng Ninh",
  "Quảng Phong, Hải Hà, Quảng Ninh",
  "Cái Chiên, Hải Hà, Quảng Ninh",
  "Ba Chẽ, Ba Chẽ, Quảng Ninh",
  "Thanh Sơn, Ba Chẽ, Quảng Ninh",
  "Thanh Lâm, Ba Chẽ, Quảng Ninh",
  "Đạp Thanh, Ba Chẽ, Quảng Ninh",
  "Nam Sơn, Ba Chẽ, Quảng Ninh",
  "Lương Mông, Ba Chẽ, Quảng Ninh",
  "Đồn Đạc, Ba Chẽ, Quảng Ninh",
  "Minh Cầm, Ba Chẽ, Quảng Ninh",
  "Cái Rồng, Vân Đồn, Quảng Ninh",
  "Đài Xuyên, Vân Đồn, Quảng Ninh",
  "Bình Dân, Vân Đồn, Quảng Ninh",
  "Vạn Yên, Vân Đồn, Quảng Ninh",
  "Minh Châu, Vân Đồn, Quảng Ninh",
  "Đoàn Kết, Vân Đồn, Quảng Ninh",
  "Hạ Long, Vân Đồn, Quảng Ninh",
  "Đông Xá, Vân Đồn, Quảng Ninh",
  "Bản Sen, Vân Đồn, Quảng Ninh",
  "Thắng Lợi, Vân Đồn, Quảng Ninh",
  "Quan Lạn, Vân Đồn, Quảng Ninh",
  "Ngọc Vừng, Vân Đồn, Quảng Ninh",
  "Mạo Khê, Đông Triều, Quảng Ninh",
  "Đông Triều, Đông Triều, Quảng Ninh",
  "An Sinh, Đông Triều, Quảng Ninh",
  "Tràng Lương, Đông Triều, Quảng Ninh",
  "Bình Khê, Đông Triều, Quảng Ninh",
  "Việt Dân, Đông Triều, Quảng Ninh",
  "Tân Việt, Đông Triều, Quảng Ninh",
  "Bình Dương, Đông Triều, Quảng Ninh",
  "Đức Chính, Đông Triều, Quảng Ninh",
  "Tràng An, Đông Triều, Quảng Ninh",
  "Nguyễn Huệ, Đông Triều, Quảng Ninh",
  "Thủy An, Đông Triều, Quảng Ninh",
  "Xuân Sơn, Đông Triều, Quảng Ninh",
  "Hồng Thái Tây, Đông Triều, Quảng Ninh",
  "Hồng Thái Đông, Đông Triều, Quảng Ninh",
  "Hoàng Quế, Đông Triều, Quảng Ninh",
  "Yên Thọ, Đông Triều, Quảng Ninh",
  "Hồng Phong, Đông Triều, Quảng Ninh",
  "Kim Sơn, Đông Triều, Quảng Ninh",
  "Hưng Đạo, Đông Triều, Quảng Ninh",
  "Yên Đức, Đông Triều, Quảng Ninh",
  "Quảng Yên, Quảng Yên, Quảng Ninh",
  "Đông Mai, Quảng Yên, Quảng Ninh",
  "Minh Thành, Quảng Yên, Quảng Ninh",
  "Sông Khoai, Quảng Yên, Quảng Ninh",
  "Hiệp Hòa, Quảng Yên, Quảng Ninh",
  "Cộng Hòa, Quảng Yên, Quảng Ninh",
  "Tiền An, Quảng Yên, Quảng Ninh",
  "Hoàng Tân, Quảng Yên, Quảng Ninh",
  "Tân An, Quảng Yên, Quảng Ninh",
  "Yên Giang, Quảng Yên, Quảng Ninh",
  "Nam Hoà, Quảng Yên, Quảng Ninh",
  "Hà An, Quảng Yên, Quảng Ninh",
  "Cẩm La, Quảng Yên, Quảng Ninh",
  "Phong Hải, Quảng Yên, Quảng Ninh",
  "Yên Hải, Quảng Yên, Quảng Ninh",
  "Liên Hòa, Quảng Yên, Quảng Ninh",
  "Phong Cốc, Quảng Yên, Quảng Ninh",
  "Liên Vị, Quảng Yên, Quảng Ninh",
  "Tiền Phong, Quảng Yên, Quảng Ninh",
  "Cô Tô, Cô Tô, Quảng Ninh",
  "Đồng Tiến, Cô Tô, Quảng Ninh",
  "Thanh Lân, Cô Tô, Quảng Ninh",
  "Thọ Xương, Bắc Giang, Bắc Giang",
  "Trần Nguyên Hãn, Bắc Giang, Bắc Giang",
  "Ngô Quyền, Bắc Giang, Bắc Giang",
  "Hoàng Văn Thụ, Bắc Giang, Bắc Giang",
  "Trần Phú, Bắc Giang, Bắc Giang",
  "Mỹ Độ, Bắc Giang, Bắc Giang",
  "Lê Lợi, Bắc Giang, Bắc Giang",
  "Song Mai, Bắc Giang, Bắc Giang",
  "Xương Giang, Bắc Giang, Bắc Giang",
  "Đa Mai, Bắc Giang, Bắc Giang",
  "Dĩnh Kế, Bắc Giang, Bắc Giang",
  "Dĩnh Trì, Bắc Giang, Bắc Giang",
  "Tân Mỹ, Bắc Giang, Bắc Giang",
  "Đồng Sơn, Bắc Giang, Bắc Giang",
  "Tân Tiến, Bắc Giang, Bắc Giang",
  "Song Khê, Bắc Giang, Bắc Giang",
  "Đồng Tiến, Yên Thế, Bắc Giang",
  "Canh Nậu, Yên Thế, Bắc Giang",
  "Xuân Lương, Yên Thế, Bắc Giang",
  "Tam Tiến, Yên Thế, Bắc Giang",
  "Đồng Vương, Yên Thế, Bắc Giang",
  "Đồng Hưu, Yên Thế, Bắc Giang",
  "Đồng Tâm, Yên Thế, Bắc Giang",
  "Tam Hiệp, Yên Thế, Bắc Giang",
  "Tiến Thắng, Yên Thế, Bắc Giang",
  "Hồng Kỳ, Yên Thế, Bắc Giang",
  "Đồng Lạc, Yên Thế, Bắc Giang",
  "Đông Sơn, Yên Thế, Bắc Giang",
  "Tân Hiệp, Yên Thế, Bắc Giang",
  "Hương Vĩ, Yên Thế, Bắc Giang",
  "Đồng Kỳ, Yên Thế, Bắc Giang",
  "An Thượng, Yên Thế, Bắc Giang",
  "Phồn Xương, Yên Thế, Bắc Giang",
  "Tân Sỏi, Yên Thế, Bắc Giang",
  "Bố Hạ, Yên Thế, Bắc Giang",
  "Lan Giới, Tân Yên, Bắc Giang",
  "Nhã Nam, Tân Yên, Bắc Giang",
  "Tân Trung, Tân Yên, Bắc Giang",
  "Đại Hóa, Tân Yên, Bắc Giang",
  "Quang Tiến, Tân Yên, Bắc Giang",
  "Phúc Sơn, Tân Yên, Bắc Giang",
  "An Dương, Tân Yên, Bắc Giang",
  "Phúc Hòa, Tân Yên, Bắc Giang",
  "Liên Sơn, Tân Yên, Bắc Giang",
  "Hợp Đức, Tân Yên, Bắc Giang",
  "Lam Cốt, Tân Yên, Bắc Giang",
  "Cao Xá, Tân Yên, Bắc Giang",
  "Cao Thượng, Tân Yên, Bắc Giang",
  "Việt Ngọc, Tân Yên, Bắc Giang",
  "Song Vân, Tân Yên, Bắc Giang",
  "Ngọc Châu, Tân Yên, Bắc Giang",
  "Ngọc Vân, Tân Yên, Bắc Giang",
  "Việt Lập, Tân Yên, Bắc Giang",
  "Liên Chung, Tân Yên, Bắc Giang",
  "Ngọc Thiện, Tân Yên, Bắc Giang",
  "Ngọc Lý, Tân Yên, Bắc Giang",
  "Quế Nham, Tân Yên, Bắc Giang",
  "Vôi, Lạng Giang, Bắc Giang",
  "Nghĩa Hòa, Lạng Giang, Bắc Giang",
  "Nghĩa Hưng, Lạng Giang, Bắc Giang",
  "Quang Thịnh, Lạng Giang, Bắc Giang",
  "Hương Sơn, Lạng Giang, Bắc Giang",
  "Đào Mỹ, Lạng Giang, Bắc Giang",
  "Tiên Lục, Lạng Giang, Bắc Giang",
  "An Hà, Lạng Giang, Bắc Giang",
  "Kép, Lạng Giang, Bắc Giang",
  "Mỹ Hà, Lạng Giang, Bắc Giang",
  "Hương Lạc, Lạng Giang, Bắc Giang",
  "Dương Đức, Lạng Giang, Bắc Giang",
  "Tân Thanh, Lạng Giang, Bắc Giang",
  "Yên Mỹ, Lạng Giang, Bắc Giang",
  "Tân Hưng, Lạng Giang, Bắc Giang",
  "Mỹ Thái, Lạng Giang, Bắc Giang",
  "Xương Lâm, Lạng Giang, Bắc Giang",
  "Xuân Hương, Lạng Giang, Bắc Giang",
  "Tân Dĩnh, Lạng Giang, Bắc Giang",
  "Đại Lâm, Lạng Giang, Bắc Giang",
  "Thái Đào, Lạng Giang, Bắc Giang",
  "Đồi Ngô, Lục Nam, Bắc Giang",
  "Đông Hưng, Lục Nam, Bắc Giang",
  "Đông Phú, Lục Nam, Bắc Giang",
  "Tam Dị, Lục Nam, Bắc Giang",
  "Bảo Sơn, Lục Nam, Bắc Giang",
  "Bảo Đài, Lục Nam, Bắc Giang",
  "Thanh Lâm, Lục Nam, Bắc Giang",
  "Tiên Nha, Lục Nam, Bắc Giang",
  "Trường Giang, Lục Nam, Bắc Giang",
  "Phương Sơn, Lục Nam, Bắc Giang",
  "Chu Điện, Lục Nam, Bắc Giang",
  "Cương Sơn, Lục Nam, Bắc Giang",
  "Nghĩa Phương, Lục Nam, Bắc Giang",
  "Vô Tranh, Lục Nam, Bắc Giang",
  "Bình Sơn, Lục Nam, Bắc Giang",
  "Lan Mẫu, Lục Nam, Bắc Giang",
  "Yên Sơn, Lục Nam, Bắc Giang",
  "Khám Lạng, Lục Nam, Bắc Giang",
  "Huyền Sơn, Lục Nam, Bắc Giang",
  "Trường Sơn, Lục Nam, Bắc Giang",
  "Lục Sơn, Lục Nam, Bắc Giang",
  "Bắc Lũng, Lục Nam, Bắc Giang",
  "Vũ Xá, Lục Nam, Bắc Giang",
  "Cẩm Lý, Lục Nam, Bắc Giang",
  "Đan Hội, Lục Nam, Bắc Giang",
  "Chũ, Lục Ngạn, Bắc Giang",
  "Cấm Sơn, Lục Ngạn, Bắc Giang",
  "Tân Sơn, Lục Ngạn, Bắc Giang",
  "Phong Minh, Lục Ngạn, Bắc Giang",
  "Phong Vân, Lục Ngạn, Bắc Giang",
  "Xa Lý, Lục Ngạn, Bắc Giang",
  "Hộ Đáp, Lục Ngạn, Bắc Giang",
  "Sơn Hải, Lục Ngạn, Bắc Giang",
  "Thanh Hải, Lục Ngạn, Bắc Giang",
  "Kiên Lao, Lục Ngạn, Bắc Giang",
  "Biên Sơn, Lục Ngạn, Bắc Giang",
  "Kiên Thành, Lục Ngạn, Bắc Giang",
  "Hồng Giang, Lục Ngạn, Bắc Giang",
  "Kim Sơn, Lục Ngạn, Bắc Giang",
  "Tân Hoa, Lục Ngạn, Bắc Giang",
  "Giáp Sơn, Lục Ngạn, Bắc Giang",
  "Biển Động, Lục Ngạn, Bắc Giang",
  "Quý Sơn, Lục Ngạn, Bắc Giang",
  "Trù Hựu, Lục Ngạn, Bắc Giang",
  "Phì Điền, Lục Ngạn, Bắc Giang",
  "Tân Quang, Lục Ngạn, Bắc Giang",
  "Đồng Cốc, Lục Ngạn, Bắc Giang",
  "Tân Lập, Lục Ngạn, Bắc Giang",
  "Phú Nhuận, Lục Ngạn, Bắc Giang",
  "Mỹ An, Lục Ngạn, Bắc Giang",
  "Nam Dương, Lục Ngạn, Bắc Giang",
  "Tân Mộc, Lục Ngạn, Bắc Giang",
  "Đèo Gia, Lục Ngạn, Bắc Giang",
  "Phượng Sơn, Lục Ngạn, Bắc Giang",
  "An Châu, Sơn Động, Bắc Giang",
  "Tây Yên Tử, Sơn Động, Bắc Giang",
  "Vân Sơn, Sơn Động, Bắc Giang",
  "Hữu Sản, Sơn Động, Bắc Giang",
  "Đại Sơn, Sơn Động, Bắc Giang",
  "Phúc Sơn, Sơn Động, Bắc Giang",
  "Giáo Liêm, Sơn Động, Bắc Giang",
  "Cẩm Đàn, Sơn Động, Bắc Giang",
  "An Lạc, Sơn Động, Bắc Giang",
  "Vĩnh An, Sơn Động, Bắc Giang",
  "Yên Định, Sơn Động, Bắc Giang",
  "Lệ Viễn, Sơn Động, Bắc Giang",
  "An Bá, Sơn Động, Bắc Giang",
  "Tuấn Đạo, Sơn Động, Bắc Giang",
  "Dương Hưu, Sơn Động, Bắc Giang",
  "Long Sơn, Sơn Động, Bắc Giang",
  "Thanh Luận, Sơn Động, Bắc Giang",
  "Nham Biền, Yên Dũng, Bắc Giang",
  "Tân An, Yên Dũng, Bắc Giang",
  "Lão Hộ, Yên Dũng, Bắc Giang",
  "Hương Gián, Yên Dũng, Bắc Giang",
  "Quỳnh Sơn, Yên Dũng, Bắc Giang",
  "Nội Hoàng, Yên Dũng, Bắc Giang",
  "Tiền Phong, Yên Dũng, Bắc Giang",
  "Xuân Phú, Yên Dũng, Bắc Giang",
  "Tân Liễu, Yên Dũng, Bắc Giang",
  "Trí Yên, Yên Dũng, Bắc Giang",
  "Lãng Sơn, Yên Dũng, Bắc Giang",
  "Yên Lư, Yên Dũng, Bắc Giang",
  "Tiến Dũng, Yên Dũng, Bắc Giang",
  "Đức Giang, Yên Dũng, Bắc Giang",
  "Cảnh Thụy, Yên Dũng, Bắc Giang",
  "Tư Mại, Yên Dũng, Bắc Giang",
  "Đồng Việt, Yên Dũng, Bắc Giang",
  "Đồng Phúc, Yên Dũng, Bắc Giang",
  "Thượng Lan, Việt Yên, Bắc Giang",
  "Việt Tiến, Việt Yên, Bắc Giang",
  "Nghĩa Trung, Việt Yên, Bắc Giang",
  "Minh Đức, Việt Yên, Bắc Giang",
  "Hương Mai, Việt Yên, Bắc Giang",
  "Tự Lạn, Việt Yên, Bắc Giang",
  "Bích Động, Việt Yên, Bắc Giang",
  "Trung Sơn, Việt Yên, Bắc Giang",
  "Hồng Thái, Việt Yên, Bắc Giang",
  "Tiên Sơn, Việt Yên, Bắc Giang",
  "Tăng Tiến, Việt Yên, Bắc Giang",
  "Quảng Minh, Việt Yên, Bắc Giang",
  "Nếnh, Việt Yên, Bắc Giang",
  "Ninh Sơn, Việt Yên, Bắc Giang",
  "Vân Trung, Việt Yên, Bắc Giang",
  "Vân Hà, Việt Yên, Bắc Giang",
  "Quang Châu, Việt Yên, Bắc Giang",
  "Đồng Tân, Hiệp Hòa, Bắc Giang",
  "Thanh Vân, Hiệp Hòa, Bắc Giang",
  "Hoàng Lương, Hiệp Hòa, Bắc Giang",
  "Hoàng Vân, Hiệp Hòa, Bắc Giang",
  "Hoàng Thanh, Hiệp Hòa, Bắc Giang",
  "Hoàng An, Hiệp Hòa, Bắc Giang",
  "Ngọc Sơn, Hiệp Hòa, Bắc Giang",
  "Thái Sơn, Hiệp Hòa, Bắc Giang",
  "Hòa Sơn, Hiệp Hòa, Bắc Giang",
  "Thắng, Hiệp Hòa, Bắc Giang",
  "Quang Minh, Hiệp Hòa, Bắc Giang",
  "Lương Phong, Hiệp Hòa, Bắc Giang",
  "Hùng Sơn, Hiệp Hòa, Bắc Giang",
  "Đại Thành, Hiệp Hòa, Bắc Giang",
  "Thường Thắng, Hiệp Hòa, Bắc Giang",
  "Hợp Thịnh, Hiệp Hòa, Bắc Giang",
  "Danh Thắng, Hiệp Hòa, Bắc Giang",
  "Mai Trung, Hiệp Hòa, Bắc Giang",
  "Đoan Bái, Hiệp Hòa, Bắc Giang",
  "Bắc Lý, Hiệp Hòa, Bắc Giang",
  "Xuân Cẩm, Hiệp Hòa, Bắc Giang",
  "Hương Lâm, Hiệp Hòa, Bắc Giang",
  "Đông Lỗ, Hiệp Hòa, Bắc Giang",
  "Châu Minh, Hiệp Hòa, Bắc Giang",
  "Mai Đình, Hiệp Hòa, Bắc Giang",
  "Dữu Lâu, Việt Trì, Phú Thọ",
  "Vân Cơ, Việt Trì, Phú Thọ",
  "Nông Trang, Việt Trì, Phú Thọ",
  "Tân Dân, Việt Trì, Phú Thọ",
  "Gia Cẩm, Việt Trì, Phú Thọ",
  "Tiên Cát, Việt Trì, Phú Thọ",
  "Thọ Sơn, Việt Trì, Phú Thọ",
  "Thanh Miếu, Việt Trì, Phú Thọ",
  "Bạch Hạc, Việt Trì, Phú Thọ",
  "Bến Gót, Việt Trì, Phú Thọ",
  "Vân Phú, Việt Trì, Phú Thọ",
  "Phượng Lâu, Việt Trì, Phú Thọ",
  "Thụy Vân, Việt Trì, Phú Thọ",
  "Minh Phương, Việt Trì, Phú Thọ",
  "Trưng Vương, Việt Trì, Phú Thọ",
  "Minh Nông, Việt Trì, Phú Thọ",
  "Sông Lô, Việt Trì, Phú Thọ",
  "Kim Đức, Việt Trì, Phú Thọ",
  "Hùng Lô, Việt Trì, Phú Thọ",
  "Hy Cương, Việt Trì, Phú Thọ",
  "Chu Hóa, Việt Trì, Phú Thọ",
  "Thanh Đình, Việt Trì, Phú Thọ",
  "Hùng Vương, Phú Thọ, Phú Thọ",
  "Phong Châu, Phú Thọ, Phú Thọ",
  "Âu Cơ, Phú Thọ, Phú Thọ",
  "Hà Lộc, Phú Thọ, Phú Thọ",
  "Phú Hộ, Phú Thọ, Phú Thọ",
  "Văn Lung, Phú Thọ, Phú Thọ",
  "Thanh Minh, Phú Thọ, Phú Thọ",
  "Hà Thạch, Phú Thọ, Phú Thọ",
  "Thanh Vinh, Phú Thọ, Phú Thọ",
  "Đoan Hùng, Đoan Hùng, Phú Thọ",
  "Hùng Xuyên, Đoan Hùng, Phú Thọ",
  "Bằng Luân, Đoan Hùng, Phú Thọ",
  "Vân Du, Đoan Hùng, Phú Thọ",
  "Phú Lâm, Đoan Hùng, Phú Thọ",
  "Minh Lương, Đoan Hùng, Phú Thọ",
  "Bằng Doãn, Đoan Hùng, Phú Thọ",
  "Chí Đám, Đoan Hùng, Phú Thọ",
  "Phúc Lai, Đoan Hùng, Phú Thọ",
  "Ngọc Quan, Đoan Hùng, Phú Thọ",
  "Hợp Nhất, Đoan Hùng, Phú Thọ",
  "Sóc Đăng, Đoan Hùng, Phú Thọ",
  "Tây Cốc, Đoan Hùng, Phú Thọ",
  "Yên Kiện, Đoan Hùng, Phú Thọ",
  "Hùng Long, Đoan Hùng, Phú Thọ",
  "Vụ Quang, Đoan Hùng, Phú Thọ",
  "Vân Đồn, Đoan Hùng, Phú Thọ",
  "Tiêu Sơn, Đoan Hùng, Phú Thọ",
  "Minh Tiến, Đoan Hùng, Phú Thọ",
  "Minh Phú, Đoan Hùng, Phú Thọ",
  "Chân Mộng, Đoan Hùng, Phú Thọ",
  "Ca Đình, Đoan Hùng, Phú Thọ",
  "Hạ Hoà, Hạ Hoà, Phú Thọ",
  "Đại Phạm, Hạ Hoà, Phú Thọ",
  "Đan Thượng, Hạ Hoà, Phú Thọ",
  "Hà Lương, Hạ Hoà, Phú Thọ",
  "Tứ Hiệp, Hạ Hoà, Phú Thọ",
  "Hiền Lương, Hạ Hoà, Phú Thọ",
  "Phương Viên, Hạ Hoà, Phú Thọ",
  "Gia Điền, Hạ Hoà, Phú Thọ",
  "Ấm Hạ, Hạ Hoà, Phú Thọ",
  "Hương Xạ, Hạ Hoà, Phú Thọ",
  "Xuân Áng, Hạ Hoà, Phú Thọ",
  "Yên Kỳ, Hạ Hoà, Phú Thọ",
  "Minh Hạc, Hạ Hoà, Phú Thọ",
  "Lang Sơn, Hạ Hoà, Phú Thọ",
  "Bằng Giã, Hạ Hoà, Phú Thọ",
  "Yên Luật, Hạ Hoà, Phú Thọ",
  "Vô Tranh, Hạ Hoà, Phú Thọ",
  "Văn Lang, Hạ Hoà, Phú Thọ",
  "Minh Côi, Hạ Hoà, Phú Thọ",
  "Vĩnh Chân, Hạ Hoà, Phú Thọ",
  "Thanh Ba, Thanh Ba, Phú Thọ",
  "Vân Lĩnh, Thanh Ba, Phú Thọ",
  "Đông Lĩnh, Thanh Ba, Phú Thọ",
  "Đại An, Thanh Ba, Phú Thọ",
  "Hanh Cù, Thanh Ba, Phú Thọ",
  "Đồng Xuân, Thanh Ba, Phú Thọ",
  "Quảng Yên, Thanh Ba, Phú Thọ",
  "Ninh Dân, Thanh Ba, Phú Thọ",
  "Võ Lao, Thanh Ba, Phú Thọ",
  "Khải Xuân, Thanh Ba, Phú Thọ",
  "Mạn Lạn, Thanh Ba, Phú Thọ",
  "Hoàng Cương, Thanh Ba, Phú Thọ",
  "Chí Tiên, Thanh Ba, Phú Thọ",
  "Đông Thành, Thanh Ba, Phú Thọ",
  "Sơn Cương, Thanh Ba, Phú Thọ",
  "Thanh Hà, Thanh Ba, Phú Thọ",
  "Đỗ Sơn, Thanh Ba, Phú Thọ",
  "Đỗ Xuyên, Thanh Ba, Phú Thọ",
  "Lương Lỗ, Thanh Ba, Phú Thọ",
  "Phong Châu, Phù Ninh, Phú Thọ",
  "Phú Mỹ, Phù Ninh, Phú Thọ",
  "Lệ Mỹ, Phù Ninh, Phú Thọ",
  "Liên Hoa, Phù Ninh, Phú Thọ",
  "Trạm Thản, Phù Ninh, Phú Thọ",
  "Trị Quận, Phù Ninh, Phú Thọ",
  "Trung Giáp, Phù Ninh, Phú Thọ",
  "Tiên Phú, Phù Ninh, Phú Thọ",
  "Hạ Giáp, Phù Ninh, Phú Thọ",
  "Bảo Thanh, Phù Ninh, Phú Thọ",
  "Phú Lộc, Phù Ninh, Phú Thọ",
  "Gia Thanh, Phù Ninh, Phú Thọ",
  "Tiên Du, Phù Ninh, Phú Thọ",
  "Phú Nham, Phù Ninh, Phú Thọ",
  "An Đạo, Phù Ninh, Phú Thọ",
  "Bình Phú, Phù Ninh, Phú Thọ",
  "Phù Ninh, Phù Ninh, Phú Thọ",
  "Yên Lập, Yên Lập, Phú Thọ",
  "Mỹ Lung, Yên Lập, Phú Thọ",
  "Mỹ Lương, Yên Lập, Phú Thọ",
  "Lương Sơn, Yên Lập, Phú Thọ",
  "Xuân An, Yên Lập, Phú Thọ",
  "Xuân Viên, Yên Lập, Phú Thọ",
  "Xuân Thủy, Yên Lập, Phú Thọ",
  "Trung Sơn, Yên Lập, Phú Thọ",
  "Hưng Long, Yên Lập, Phú Thọ",
  "Nga Hoàng, Yên Lập, Phú Thọ",
  "Đồng Lạc, Yên Lập, Phú Thọ",
  "Thượng Long, Yên Lập, Phú Thọ",
  "Đồng Thịnh, Yên Lập, Phú Thọ",
  "Phúc Khánh, Yên Lập, Phú Thọ",
  "Minh Hòa, Yên Lập, Phú Thọ",
  "Ngọc Lập, Yên Lập, Phú Thọ",
  "Ngọc Đồng, Yên Lập, Phú Thọ",
  "Cẩm Khê, Cẩm Khê, Phú Thọ",
  "Tiên Lương, Cẩm Khê, Phú Thọ",
  "Tuy Lộc, Cẩm Khê, Phú Thọ",
  "Ngô Xá, Cẩm Khê, Phú Thọ",
  "Minh Tân, Cẩm Khê, Phú Thọ",
  "Phượng Vĩ, Cẩm Khê, Phú Thọ",
  "Thụy Liễu, Cẩm Khê, Phú Thọ",
  "Tùng Khê, Cẩm Khê, Phú Thọ",
  "Tam Sơn, Cẩm Khê, Phú Thọ",
  "Văn Bán, Cẩm Khê, Phú Thọ",
  "Cấp Dẫn, Cẩm Khê, Phú Thọ",
  "Xương Thịnh, Cẩm Khê, Phú Thọ",
  "Phú Khê, Cẩm Khê, Phú Thọ",
  "Sơn Tình, Cẩm Khê, Phú Thọ",
  "Yên Tập, Cẩm Khê, Phú Thọ",
  "Hương Lung, Cẩm Khê, Phú Thọ",
  "Tạ Xá, Cẩm Khê, Phú Thọ",
  "Phú Lạc, Cẩm Khê, Phú Thọ",
  "Chương Xá, Cẩm Khê, Phú Thọ",
  "Hùng Việt, Cẩm Khê, Phú Thọ",
  "Văn Khúc, Cẩm Khê, Phú Thọ",
  "Yên Dưỡng, Cẩm Khê, Phú Thọ",
  "Điêu Lương, Cẩm Khê, Phú Thọ",
  "Đồng Lương, Cẩm Khê, Phú Thọ",
  "Hưng Hoá, Tam Nông, Phú Thọ",
  "Hiền Quan, Tam Nông, Phú Thọ",
  "Bắc Sơn, Tam Nông, Phú Thọ",
  "Thanh Uyên, Tam Nông, Phú Thọ",
  "Lam Sơn, Tam Nông, Phú Thọ",
  "Vạn Xuân, Tam Nông, Phú Thọ",
  "Quang Húc, Tam Nông, Phú Thọ",
  "Hương Nộn, Tam Nông, Phú Thọ",
  "Tề Lễ, Tam Nông, Phú Thọ",
  "Thọ Văn, Tam Nông, Phú Thọ",
  "Dị Nậu, Tam Nông, Phú Thọ",
  "Dân Quyền, Tam Nông, Phú Thọ",
  "Lâm Thao, Lâm Thao, Phú Thọ",
  "Tiên Kiên, Lâm Thao, Phú Thọ",
  "Hùng Sơn, Lâm Thao, Phú Thọ",
  "Xuân Lũng, Lâm Thao, Phú Thọ",
  "Xuân Huy, Lâm Thao, Phú Thọ",
  "Thạch Sơn, Lâm Thao, Phú Thọ",
  "Sơn Vi, Lâm Thao, Phú Thọ",
  "Phùng Nguyên, Lâm Thao, Phú Thọ",
  "Cao Xá, Lâm Thao, Phú Thọ",
  "Vĩnh Lại, Lâm Thao, Phú Thọ",
  "Tứ Xã, Lâm Thao, Phú Thọ",
  "Bản Nguyên, Lâm Thao, Phú Thọ",
  "Thanh Sơn, Thanh Sơn, Phú Thọ",
  "Sơn Hùng, Thanh Sơn, Phú Thọ",
  "Địch Quả, Thanh Sơn, Phú Thọ",
  "Giáp Lai, Thanh Sơn, Phú Thọ",
  "Thục Luyện, Thanh Sơn, Phú Thọ",
  "Võ Miếu, Thanh Sơn, Phú Thọ",
  "Thạch Khoán, Thanh Sơn, Phú Thọ",
  "Cự Thắng, Thanh Sơn, Phú Thọ",
  "Tất Thắng, Thanh Sơn, Phú Thọ",
  "Văn Miếu, Thanh Sơn, Phú Thọ",
  "Cự Đồng, Thanh Sơn, Phú Thọ",
  "Thắng Sơn, Thanh Sơn, Phú Thọ",
  "Tân Minh, Thanh Sơn, Phú Thọ",
  "Hương Cần, Thanh Sơn, Phú Thọ",
  "Khả Cửu, Thanh Sơn, Phú Thọ",
  "Đông Cửu, Thanh Sơn, Phú Thọ",
  "Tân Lập, Thanh Sơn, Phú Thọ",
  "Yên Lãng, Thanh Sơn, Phú Thọ",
  "Yên Lương, Thanh Sơn, Phú Thọ",
  "Thượng Cửu, Thanh Sơn, Phú Thọ",
  "Lương Nha, Thanh Sơn, Phú Thọ",
  "Yên Sơn, Thanh Sơn, Phú Thọ",
  "Tinh Nhuệ, Thanh Sơn, Phú Thọ",
  "Đào Xá, Thanh Thuỷ, Phú Thọ",
  "Thạch Đồng, Thanh Thuỷ, Phú Thọ",
  "Xuân Lộc, Thanh Thuỷ, Phú Thọ",
  "Tân Phương, Thanh Thuỷ, Phú Thọ",
  "Thanh Thủy, Thanh Thuỷ, Phú Thọ",
  "Sơn Thủy, Thanh Thuỷ, Phú Thọ",
  "Bảo Yên, Thanh Thuỷ, Phú Thọ",
  "Đoan Hạ, Thanh Thuỷ, Phú Thọ",
  "Đồng Trung, Thanh Thuỷ, Phú Thọ",
  "Hoàng Xá, Thanh Thuỷ, Phú Thọ",
  "Tu Vũ, Thanh Thuỷ, Phú Thọ",
  "Thu Cúc, Tân Sơn, Phú Thọ",
  "Thạch Kiệt, Tân Sơn, Phú Thọ",
  "Thu Ngạc, Tân Sơn, Phú Thọ",
  "Kiệt Sơn, Tân Sơn, Phú Thọ",
  "Đồng Sơn, Tân Sơn, Phú Thọ",
  "Lai Đồng, Tân Sơn, Phú Thọ",
  "Tân Phú, Tân Sơn, Phú Thọ",
  "Mỹ Thuận, Tân Sơn, Phú Thọ",
  "Tân Sơn, Tân Sơn, Phú Thọ",
  "Xuân Đài, Tân Sơn, Phú Thọ",
  "Minh Đài, Tân Sơn, Phú Thọ",
  "Văn Luông, Tân Sơn, Phú Thọ",
  "Xuân Sơn, Tân Sơn, Phú Thọ",
  "Long Cốc, Tân Sơn, Phú Thọ",
  "Kim Thượng, Tân Sơn, Phú Thọ",
  "Tam Thanh, Tân Sơn, Phú Thọ",
  "Vinh Tiền, Tân Sơn, Phú Thọ",
  "Tích Sơn, Vĩnh Yên, Vĩnh Phúc",
  "Liên Bảo, Vĩnh Yên, Vĩnh Phúc",
  "Hội Hợp, Vĩnh Yên, Vĩnh Phúc",
  "Đống Đa, Vĩnh Yên, Vĩnh Phúc",
  "Ngô Quyền, Vĩnh Yên, Vĩnh Phúc",
  "Đồng Tâm, Vĩnh Yên, Vĩnh Phúc",
  "Định Trung, Vĩnh Yên, Vĩnh Phúc",
  "Khai Quang, Vĩnh Yên, Vĩnh Phúc",
  "Thanh Trù, Vĩnh Yên, Vĩnh Phúc",
  "Trưng Trắc, Phúc Yên, Vĩnh Phúc",
  "Hùng Vương, Phúc Yên, Vĩnh Phúc",
  "Trưng Nhị, Phúc Yên, Vĩnh Phúc",
  "Phúc Thắng, Phúc Yên, Vĩnh Phúc",
  "Xuân Hoà, Phúc Yên, Vĩnh Phúc",
  "Đồng Xuân, Phúc Yên, Vĩnh Phúc",
  "Ngọc Thanh, Phúc Yên, Vĩnh Phúc",
  "Cao Minh, Phúc Yên, Vĩnh Phúc",
  "Nam Viêm, Phúc Yên, Vĩnh Phúc",
  "Tiền Châu, Phúc Yên, Vĩnh Phúc",
  "Lập Thạch, Lập Thạch, Vĩnh Phúc",
  "Quang Sơn, Lập Thạch, Vĩnh Phúc",
  "Ngọc Mỹ, Lập Thạch, Vĩnh Phúc",
  "Hợp Lý, Lập Thạch, Vĩnh Phúc",
  "Bắc Bình, Lập Thạch, Vĩnh Phúc",
  "Thái Hòa, Lập Thạch, Vĩnh Phúc",
  "Hoa Sơn, Lập Thạch, Vĩnh Phúc",
  "Liễn Sơn, Lập Thạch, Vĩnh Phúc",
  "Xuân Hòa, Lập Thạch, Vĩnh Phúc",
  "Vân Trục, Lập Thạch, Vĩnh Phúc",
  "Liên Hòa, Lập Thạch, Vĩnh Phúc",
  "Tử Du, Lập Thạch, Vĩnh Phúc",
  "Bàn Giản, Lập Thạch, Vĩnh Phúc",
  "Xuân Lôi, Lập Thạch, Vĩnh Phúc",
  "Đồng Ích, Lập Thạch, Vĩnh Phúc",
  "Tiên Lữ, Lập Thạch, Vĩnh Phúc",
  "Văn Quán, Lập Thạch, Vĩnh Phúc",
  "Đình Chu, Lập Thạch, Vĩnh Phúc",
  "Triệu Đề, Lập Thạch, Vĩnh Phúc",
  "Sơn Đông, Lập Thạch, Vĩnh Phúc",
  "Hợp Hòa, Tam Dương, Vĩnh Phúc",
  "Hoàng Hoa, Tam Dương, Vĩnh Phúc",
  "Đồng Tĩnh, Tam Dương, Vĩnh Phúc",
  "Kim Long, Tam Dương, Vĩnh Phúc",
  "Hướng Đạo, Tam Dương, Vĩnh Phúc",
  "Đạo Tú, Tam Dương, Vĩnh Phúc",
  "An Hòa, Tam Dương, Vĩnh Phúc",
  "Thanh Vân, Tam Dương, Vĩnh Phúc",
  "Duy Phiên, Tam Dương, Vĩnh Phúc",
  "Hoàng Đan, Tam Dương, Vĩnh Phúc",
  "Hoàng Lâu, Tam Dương, Vĩnh Phúc",
  "Vân Hội, Tam Dương, Vĩnh Phúc",
  "Hợp Thịnh, Tam Dương, Vĩnh Phúc",
  "Tam Đảo, Tam Đảo, Vĩnh Phúc",
  "Hợp Châu, Tam Đảo, Vĩnh Phúc",
  "Đạo Trù, Tam Đảo, Vĩnh Phúc",
  "Yên Dương, Tam Đảo, Vĩnh Phúc",
  "Bồ Lý, Tam Đảo, Vĩnh Phúc",
  "Đại Đình, Tam Đảo, Vĩnh Phúc",
  "Tam Quan, Tam Đảo, Vĩnh Phúc",
  "Hồ Sơn, Tam Đảo, Vĩnh Phúc",
  "Minh Quang, Tam Đảo, Vĩnh Phúc",
  "Hương Canh, Bình Xuyên, Vĩnh Phúc",
  "Gia Khánh, Bình Xuyên, Vĩnh Phúc",
  "Trung Mỹ, Bình Xuyên, Vĩnh Phúc",
  "Bá Hiến, Bình Xuyên, Vĩnh Phúc",
  "Thiện Kế, Bình Xuyên, Vĩnh Phúc",
  "Hương Sơn, Bình Xuyên, Vĩnh Phúc",
  "Tam Hợp, Bình Xuyên, Vĩnh Phúc",
  "Quất Lưu, Bình Xuyên, Vĩnh Phúc",
  "Sơn Lôi, Bình Xuyên, Vĩnh Phúc",
  "Đạo Đức, Bình Xuyên, Vĩnh Phúc",
  "Tân Phong, Bình Xuyên, Vĩnh Phúc",
  "Thanh Lãng, Bình Xuyên, Vĩnh Phúc",
  "Phú Xuân, Bình Xuyên, Vĩnh Phúc",
  "Yên Lạc, Yên Lạc, Vĩnh Phúc",
  "Đồng Cương, Yên Lạc, Vĩnh Phúc",
  "Đồng Văn, Yên Lạc, Vĩnh Phúc",
  "Bình Định, Yên Lạc, Vĩnh Phúc",
  "Trung Nguyên, Yên Lạc, Vĩnh Phúc",
  "Tề Lỗ, Yên Lạc, Vĩnh Phúc",
  "Tam Hồng, Yên Lạc, Vĩnh Phúc",
  "Yên Đồng, Yên Lạc, Vĩnh Phúc",
  "Văn Tiến, Yên Lạc, Vĩnh Phúc",
  "Nguyệt Đức, Yên Lạc, Vĩnh Phúc",
  "Yên Phương, Yên Lạc, Vĩnh Phúc",
  "Hồng Phương, Yên Lạc, Vĩnh Phúc",
  "Trung Kiên, Yên Lạc, Vĩnh Phúc",
  "Liên Châu, Yên Lạc, Vĩnh Phúc",
  "Đại Tự, Yên Lạc, Vĩnh Phúc",
  "Hồng Châu, Yên Lạc, Vĩnh Phúc",
  "Trung Hà, Yên Lạc, Vĩnh Phúc",
  "Vĩnh Tường, Vĩnh Tường, Vĩnh Phúc",
  "Kim Xá, Vĩnh Tường, Vĩnh Phúc",
  "Yên Bình, Vĩnh Tường, Vĩnh Phúc",
  "Chấn Hưng, Vĩnh Tường, Vĩnh Phúc",
  "Nghĩa Hưng, Vĩnh Tường, Vĩnh Phúc",
  "Yên Lập, Vĩnh Tường, Vĩnh Phúc",
  "Việt Xuân, Vĩnh Tường, Vĩnh Phúc",
  "Bồ Sao, Vĩnh Tường, Vĩnh Phúc",
  "Đại Đồng, Vĩnh Tường, Vĩnh Phúc",
  "Tân Tiến, Vĩnh Tường, Vĩnh Phúc",
  "Lũng Hoà, Vĩnh Tường, Vĩnh Phúc",
  "Cao Đại, Vĩnh Tường, Vĩnh Phúc",
  "Thổ Tang, Vĩnh Tường, Vĩnh Phúc",
  "Vĩnh Sơn, Vĩnh Tường, Vĩnh Phúc",
  "Bình Dương, Vĩnh Tường, Vĩnh Phúc",
  "Tân Phú, Vĩnh Tường, Vĩnh Phúc",
  "Thượng Trưng, Vĩnh Tường, Vĩnh Phúc",
  "Vũ Di, Vĩnh Tường, Vĩnh Phúc",
  "Lý Nhân, Vĩnh Tường, Vĩnh Phúc",
  "Tuân Chính, Vĩnh Tường, Vĩnh Phúc",
  "Vân Xuân, Vĩnh Tường, Vĩnh Phúc",
  "Tam Phúc, Vĩnh Tường, Vĩnh Phúc",
  "Tứ Trưng, Vĩnh Tường, Vĩnh Phúc",
  "Ngũ Kiên, Vĩnh Tường, Vĩnh Phúc",
  "An Tường, Vĩnh Tường, Vĩnh Phúc",
  "Vĩnh Thịnh, Vĩnh Tường, Vĩnh Phúc",
  "Phú Đa, Vĩnh Tường, Vĩnh Phúc",
  "Vĩnh Ninh, Vĩnh Tường, Vĩnh Phúc",
  "Lãng Công, Sông Lô, Vĩnh Phúc",
  "Quang Yên, Sông Lô, Vĩnh Phúc",
  "Bạch Lưu, Sông Lô, Vĩnh Phúc",
  "Hải Lựu, Sông Lô, Vĩnh Phúc",
  "Đồng Quế, Sông Lô, Vĩnh Phúc",
  "Nhân Đạo, Sông Lô, Vĩnh Phúc",
  "Đôn Nhân, Sông Lô, Vĩnh Phúc",
  "Phương Khoan, Sông Lô, Vĩnh Phúc",
  "Tân Lập, Sông Lô, Vĩnh Phúc",
  "Nhạo Sơn, Sông Lô, Vĩnh Phúc",
  "Tam Sơn, Sông Lô, Vĩnh Phúc",
  "Như Thụy, Sông Lô, Vĩnh Phúc",
  "Yên Thạch, Sông Lô, Vĩnh Phúc",
  "Đồng Thịnh, Sông Lô, Vĩnh Phúc",
  "Tứ Yên, Sông Lô, Vĩnh Phúc",
  "Đức Bác, Sông Lô, Vĩnh Phúc",
  "Cao Phong, Sông Lô, Vĩnh Phúc",
  "Vũ Ninh, Bắc Ninh, Bắc Ninh",
  "Đáp Cầu, Bắc Ninh, Bắc Ninh",
  "Thị Cầu, Bắc Ninh, Bắc Ninh",
  "Kinh Bắc, Bắc Ninh, Bắc Ninh",
  "Vệ An, Bắc Ninh, Bắc Ninh",
  "Tiền An, Bắc Ninh, Bắc Ninh",
  "Đại Phúc, Bắc Ninh, Bắc Ninh",
  "Ninh Xá, Bắc Ninh, Bắc Ninh",
  "Suối Hoa, Bắc Ninh, Bắc Ninh",
  "Võ Cường, Bắc Ninh, Bắc Ninh",
  "Hòa Long, Bắc Ninh, Bắc Ninh",
  "Vạn An, Bắc Ninh, Bắc Ninh",
  "Khúc Xuyên, Bắc Ninh, Bắc Ninh",
  "Phong Khê, Bắc Ninh, Bắc Ninh",
  "Kim Chân, Bắc Ninh, Bắc Ninh",
  "Vân Dương, Bắc Ninh, Bắc Ninh",
  "Nam Sơn, Bắc Ninh, Bắc Ninh",
  "Khắc Niệm, Bắc Ninh, Bắc Ninh",
  "Hạp Lĩnh, Bắc Ninh, Bắc Ninh",
  "Chờ, Yên Phong, Bắc Ninh",
  "Dũng Liệt, Yên Phong, Bắc Ninh",
  "Tam Đa, Yên Phong, Bắc Ninh",
  "Tam Giang, Yên Phong, Bắc Ninh",
  "Yên Trung, Yên Phong, Bắc Ninh",
  "Thụy Hòa, Yên Phong, Bắc Ninh",
  "Hòa Tiến, Yên Phong, Bắc Ninh",
  "Đông Tiến, Yên Phong, Bắc Ninh",
  "Yên Phụ, Yên Phong, Bắc Ninh",
  "Trung Nghĩa, Yên Phong, Bắc Ninh",
  "Đông Phong, Yên Phong, Bắc Ninh",
  "Long Châu, Yên Phong, Bắc Ninh",
  "Văn Môn, Yên Phong, Bắc Ninh",
  "Đông Thọ, Yên Phong, Bắc Ninh",
  "Phố Mới, Quế Võ, Bắc Ninh",
  "Việt Thống, Quế Võ, Bắc Ninh",
  "Đại Xuân, Quế Võ, Bắc Ninh",
  "Nhân Hòa, Quế Võ, Bắc Ninh",
  "Bằng An, Quế Võ, Bắc Ninh",
  "Phương Liễu, Quế Võ, Bắc Ninh",
  "Quế Tân, Quế Võ, Bắc Ninh",
  "Phù Lương, Quế Võ, Bắc Ninh",
  "Phù Lãng, Quế Võ, Bắc Ninh",
  "Phượng Mao, Quế Võ, Bắc Ninh",
  "Việt Hùng, Quế Võ, Bắc Ninh",
  "Ngọc Xá, Quế Võ, Bắc Ninh",
  "Châu Phong, Quế Võ, Bắc Ninh",
  "Bồng Lai, Quế Võ, Bắc Ninh",
  "Cách Bi, Quế Võ, Bắc Ninh",
  "Đào Viên, Quế Võ, Bắc Ninh",
  "Yên Giả, Quế Võ, Bắc Ninh",
  "Mộ Đạo, Quế Võ, Bắc Ninh",
  "Đức Long, Quế Võ, Bắc Ninh",
  "Chi Lăng, Quế Võ, Bắc Ninh",
  "Hán Quảng, Quế Võ, Bắc Ninh",
  "Lim, Tiên Du, Bắc Ninh",
  "Phú Lâm, Tiên Du, Bắc Ninh",
  "Nội Duệ, Tiên Du, Bắc Ninh",
  "Liên Bão, Tiên Du, Bắc Ninh",
  "Hiên Vân, Tiên Du, Bắc Ninh",
  "Hoàn Sơn, Tiên Du, Bắc Ninh",
  "Lạc Vệ, Tiên Du, Bắc Ninh",
  "Việt Đoàn, Tiên Du, Bắc Ninh",
  "Phật Tích, Tiên Du, Bắc Ninh",
  "Tân Chi, Tiên Du, Bắc Ninh",
  "Đại Đồng, Tiên Du, Bắc Ninh",
  "Tri Phương, Tiên Du, Bắc Ninh",
  "Minh Đạo, Tiên Du, Bắc Ninh",
  "Cảnh Hưng, Tiên Du, Bắc Ninh",
  "Đông Ngàn, Từ Sơn, Bắc Ninh",
  "Tam Sơn, Từ Sơn, Bắc Ninh",
  "Hương Mạc, Từ Sơn, Bắc Ninh",
  "Tương Giang, Từ Sơn, Bắc Ninh",
  "Phù Khê, Từ Sơn, Bắc Ninh",
  "Đồng Kỵ, Từ Sơn, Bắc Ninh",
  "Trang Hạ, Từ Sơn, Bắc Ninh",
  "Đồng Nguyên, Từ Sơn, Bắc Ninh",
  "Châu Khê, Từ Sơn, Bắc Ninh",
  "Tân Hồng, Từ Sơn, Bắc Ninh",
  "Đình Bảng, Từ Sơn, Bắc Ninh",
  "Phù Chẩn, Từ Sơn, Bắc Ninh",
  "Hồ, Thuận Thành, Bắc Ninh",
  "Hoài Thượng, Thuận Thành, Bắc Ninh",
  "Đại Đồng Thành, Thuận Thành, Bắc Ninh",
  "Mão Điền, Thuận Thành, Bắc Ninh",
  "Song Hồ, Thuận Thành, Bắc Ninh",
  "Đình Tổ, Thuận Thành, Bắc Ninh",
  "An Bình, Thuận Thành, Bắc Ninh",
  "Trí Quả, Thuận Thành, Bắc Ninh",
  "Gia Đông, Thuận Thành, Bắc Ninh",
  "Thanh Khương, Thuận Thành, Bắc Ninh",
  "Trạm Lộ, Thuận Thành, Bắc Ninh",
  "Xuân Lâm, Thuận Thành, Bắc Ninh",
  "Hà Mãn, Thuận Thành, Bắc Ninh",
  "Ngũ Thái, Thuận Thành, Bắc Ninh",
  "Nguyệt Đức, Thuận Thành, Bắc Ninh",
  "Ninh Xá, Thuận Thành, Bắc Ninh",
  "Nghĩa Đạo, Thuận Thành, Bắc Ninh",
  "Song Liễu, Thuận Thành, Bắc Ninh",
  "Gia Bình, Gia Bình, Bắc Ninh",
  "Vạn Ninh, Gia Bình, Bắc Ninh",
  "Thái Bảo, Gia Bình, Bắc Ninh",
  "Giang Sơn, Gia Bình, Bắc Ninh",
  "Cao Đức, Gia Bình, Bắc Ninh",
  "Đại Lai, Gia Bình, Bắc Ninh",
  "Song Giang, Gia Bình, Bắc Ninh",
  "Bình Dương, Gia Bình, Bắc Ninh",
  "Lãng Ngâm, Gia Bình, Bắc Ninh",
  "Nhân Thắng, Gia Bình, Bắc Ninh",
  "Xuân Lai, Gia Bình, Bắc Ninh",
  "Đông Cứu, Gia Bình, Bắc Ninh",
  "Đại Bái, Gia Bình, Bắc Ninh",
  "Quỳnh Phú, Gia Bình, Bắc Ninh",
  "Thứa, Lương Tài, Bắc Ninh",
  "An Thịnh, Lương Tài, Bắc Ninh",
  "Trung Kênh, Lương Tài, Bắc Ninh",
  "Phú Hòa, Lương Tài, Bắc Ninh",
  "Mỹ Hương, Lương Tài, Bắc Ninh",
  "Tân Lãng, Lương Tài, Bắc Ninh",
  "Quảng Phú, Lương Tài, Bắc Ninh",
  "Trừng Xá, Lương Tài, Bắc Ninh",
  "Lai Hạ, Lương Tài, Bắc Ninh",
  "Trung Chính, Lương Tài, Bắc Ninh",
  "Minh Tân, Lương Tài, Bắc Ninh",
  "Bình Định, Lương Tài, Bắc Ninh",
  "Phú Lương, Lương Tài, Bắc Ninh",
  "Lâm Thao, Lương Tài, Bắc Ninh",
  "Cẩm Thượng, Hải Dương, Hải Dương",
  "Bình Hàn, Hải Dương, Hải Dương",
  "Ngọc Châu, Hải Dương, Hải Dương",
  "Nhị Châu, Hải Dương, Hải Dương",
  "Quang Trung, Hải Dương, Hải Dương",
  "Nguyễn Trãi, Hải Dương, Hải Dương",
  "Phạm Ngũ Lão, Hải Dương, Hải Dương",
  "Trần Hưng Đạo, Hải Dương, Hải Dương",
  "Trần Phú, Hải Dương, Hải Dương",
  "Thanh Bình, Hải Dương, Hải Dương",
  "Tân Bình, Hải Dương, Hải Dương",
  "Lê Thanh Nghị, Hải Dương, Hải Dương",
  "Hải Tân, Hải Dương, Hải Dương",
  "Tứ Minh, Hải Dương, Hải Dương",
  "Việt Hoà, Hải Dương, Hải Dương",
  "Ái Quốc, Hải Dương, Hải Dương",
  "An Thượng, Hải Dương, Hải Dương",
  "Nam Đồng, Hải Dương, Hải Dương",
  "Quyết Thắng, Hải Dương, Hải Dương",
  "Tiền Tiến, Hải Dương, Hải Dương",
  "Thạch Khôi, Hải Dương, Hải Dương",
  "Liên Hồng, Hải Dương, Hải Dương",
  "Tân Hưng, Hải Dương, Hải Dương",
  "Gia Xuyên, Hải Dương, Hải Dương",
  "Ngọc Sơn, Hải Dương, Hải Dương",
  "Phả Lại, Chí Linh, Hải Dương",
  "Sao Đỏ, Chí Linh, Hải Dương",
  "Bến Tắm, Chí Linh, Hải Dương",
  "Hoàng Hoa Thám, Chí Linh, Hải Dương",
  "Bắc An, Chí Linh, Hải Dương",
  "Hưng Đạo, Chí Linh, Hải Dương",
  "Lê Lợi, Chí Linh, Hải Dương",
  "Hoàng Tiến, Chí Linh, Hải Dương",
  "Cộng Hoà, Chí Linh, Hải Dương",
  "Hoàng Tân, Chí Linh, Hải Dương",
  "Cổ Thành, Chí Linh, Hải Dương",
  "Văn An, Chí Linh, Hải Dương",
  "Chí Minh, Chí Linh, Hải Dương",
  "Văn Đức, Chí Linh, Hải Dương",
  "Thái Học, Chí Linh, Hải Dương",
  "Nhân Huệ, Chí Linh, Hải Dương",
  "An Lạc, Chí Linh, Hải Dương",
  "Đồng Lạc, Chí Linh, Hải Dương",
  "Tân Dân, Chí Linh, Hải Dương",
  "Nam Sách, Nam Sách, Hải Dương",
  "Nam Hưng, Nam Sách, Hải Dương",
  "Nam Tân, Nam Sách, Hải Dương",
  "Hợp Tiến, Nam Sách, Hải Dương",
  "Hiệp Cát, Nam Sách, Hải Dương",
  "Thanh Quang, Nam Sách, Hải Dương",
  "Quốc Tuấn, Nam Sách, Hải Dương",
  "Nam Chính, Nam Sách, Hải Dương",
  "An Bình, Nam Sách, Hải Dương",
  "Nam Trung, Nam Sách, Hải Dương",
  "An Sơn, Nam Sách, Hải Dương",
  "Cộng Hòa, Nam Sách, Hải Dương",
  "Thái Tân, Nam Sách, Hải Dương",
  "An Lâm, Nam Sách, Hải Dương",
  "Phú Điền, Nam Sách, Hải Dương",
  "Nam Hồng, Nam Sách, Hải Dương",
  "Hồng Phong, Nam Sách, Hải Dương",
  "Đồng Lạc, Nam Sách, Hải Dương",
  "Minh Tân, Nam Sách, Hải Dương",
  "An Lưu, Kinh Môn, Hải Dương",
  "Bạch Đằng, Kinh Môn, Hải Dương",
  "Thất Hùng, Kinh Môn, Hải Dương",
  "Lê Ninh, Kinh Môn, Hải Dương",
  "Hoành Sơn, Kinh Môn, Hải Dương",
  "Phạm Thái, Kinh Môn, Hải Dương",
  "Duy Tân, Kinh Môn, Hải Dương",
  "Tân Dân, Kinh Môn, Hải Dương",
  "Minh Tân, Kinh Môn, Hải Dương",
  "Quang Thành, Kinh Môn, Hải Dương",
  "Hiệp Hòa, Kinh Môn, Hải Dương",
  "Phú Thứ, Kinh Môn, Hải Dương",
  "Thăng Long, Kinh Môn, Hải Dương",
  "Lạc Long, Kinh Môn, Hải Dương",
  "An Sinh, Kinh Môn, Hải Dương",
  "Hiệp Sơn, Kinh Môn, Hải Dương",
  "Thượng Quận, Kinh Môn, Hải Dương",
  "An Phụ, Kinh Môn, Hải Dương",
  "Hiệp An, Kinh Môn, Hải Dương",
  "Long Xuyên, Kinh Môn, Hải Dương",
  "Thái Thịnh, Kinh Môn, Hải Dương",
  "Hiến Thành, Kinh Môn, Hải Dương",
  "Minh Hòa, Kinh Môn, Hải Dương",
  "Phú Thái, Kim Thành, Hải Dương",
  "Lai Vu, Kim Thành, Hải Dương",
  "Cộng Hòa, Kim Thành, Hải Dương",
  "Thượng Vũ, Kim Thành, Hải Dương",
  "Cổ Dũng, Kim Thành, Hải Dương",
  "Tuấn Việt, Kim Thành, Hải Dương",
  "Kim Xuyên, Kim Thành, Hải Dương",
  "Phúc Thành A, Kim Thành, Hải Dương",
  "Ngũ Phúc, Kim Thành, Hải Dương",
  "Kim Anh, Kim Thành, Hải Dương",
  "Kim Liên, Kim Thành, Hải Dương",
  "Kim Tân, Kim Thành, Hải Dương",
  "Kim Đính, Kim Thành, Hải Dương",
  "Bình Dân, Kim Thành, Hải Dương",
  "Tam Kỳ, Kim Thành, Hải Dương",
  "Đồng Cẩm, Kim Thành, Hải Dương",
  "Liên Hòa, Kim Thành, Hải Dương",
  "Đại Đức, Kim Thành, Hải Dương",
  "Thanh Hà, Thanh Hà, Hải Dương",
  "Hồng Lạc, Thanh Hà, Hải Dương",
  "Việt Hồng, Thanh Hà, Hải Dương",
  "Tân Việt, Thanh Hà, Hải Dương",
  "Cẩm Chế, Thanh Hà, Hải Dương",
  "Thanh An, Thanh Hà, Hải Dương",
  "Thanh Lang, Thanh Hà, Hải Dương",
  "Tân An, Thanh Hà, Hải Dương",
  "Liên Mạc, Thanh Hà, Hải Dương",
  "Thanh Hải, Thanh Hà, Hải Dương",
  "Thanh Khê, Thanh Hà, Hải Dương",
  "Thanh Xá, Thanh Hà, Hải Dương",
  "Thanh Xuân, Thanh Hà, Hải Dương",
  "Thanh Thủy, Thanh Hà, Hải Dương",
  "An Phượng, Thanh Hà, Hải Dương",
  "Thanh Sơn, Thanh Hà, Hải Dương",
  "Thanh Quang, Thanh Hà, Hải Dương",
  "Thanh Hồng, Thanh Hà, Hải Dương",
  "Thanh Cường, Thanh Hà, Hải Dương",
  "Vĩnh Lập, Thanh Hà, Hải Dương",
  "Cẩm Giang, Cẩm Giàng, Hải Dương",
  "Lai Cách, Cẩm Giàng, Hải Dương",
  "Cẩm Hưng, Cẩm Giàng, Hải Dương",
  "Cẩm Hoàng, Cẩm Giàng, Hải Dương",
  "Cẩm Văn, Cẩm Giàng, Hải Dương",
  "Ngọc Liên, Cẩm Giàng, Hải Dương",
  "Thạch Lỗi, Cẩm Giàng, Hải Dương",
  "Cẩm Vũ, Cẩm Giàng, Hải Dương",
  "Đức Chính, Cẩm Giàng, Hải Dương",
  "Định Sơn, Cẩm Giàng, Hải Dương",
  "Lương Điền, Cẩm Giàng, Hải Dương",
  "Cao An, Cẩm Giàng, Hải Dương",
  "Tân Trường, Cẩm Giàng, Hải Dương",
  "Cẩm Phúc, Cẩm Giàng, Hải Dương",
  "Cẩm Điền, Cẩm Giàng, Hải Dương",
  "Cẩm Đông, Cẩm Giàng, Hải Dương",
  "Cẩm Đoài, Cẩm Giàng, Hải Dương",
  "Kẻ Sặt, Bình Giang, Hải Dương",
  "Vĩnh Hưng, Bình Giang, Hải Dương",
  "Hùng Thắng, Bình Giang, Hải Dương",
  "Vĩnh Hồng, Bình Giang, Hải Dương",
  "Long Xuyên, Bình Giang, Hải Dương",
  "Tân Việt, Bình Giang, Hải Dương",
  "Thúc Kháng, Bình Giang, Hải Dương",
  "Tân Hồng, Bình Giang, Hải Dương",
  "Bình Minh, Bình Giang, Hải Dương",
  "Hồng Khê, Bình Giang, Hải Dương",
  "Thái Học, Bình Giang, Hải Dương",
  "Cổ Bì, Bình Giang, Hải Dương",
  "Nhân Quyền, Bình Giang, Hải Dương",
  "Thái Dương, Bình Giang, Hải Dương",
  "Thái Hòa, Bình Giang, Hải Dương",
  "Bình Xuyên, Bình Giang, Hải Dương",
  "Gia Lộc, Gia Lộc, Hải Dương",
  "Thống Nhất, Gia Lộc, Hải Dương",
  "Yết Kiêu, Gia Lộc, Hải Dương",
  "Gia Tân, Gia Lộc, Hải Dương",
  "Tân Tiến, Gia Lộc, Hải Dương",
  "Gia Khánh, Gia Lộc, Hải Dương",
  "Gia Lương, Gia Lộc, Hải Dương",
  "Lê Lợi, Gia Lộc, Hải Dương",
  "Toàn Thắng, Gia Lộc, Hải Dương",
  "Hoàng Diệu, Gia Lộc, Hải Dương",
  "Hồng Hưng, Gia Lộc, Hải Dương",
  "Phạm Trấn, Gia Lộc, Hải Dương",
  "Đoàn Thượng, Gia Lộc, Hải Dương",
  "Thống Kênh, Gia Lộc, Hải Dương",
  "Quang Minh, Gia Lộc, Hải Dương",
  "Đồng Quang, Gia Lộc, Hải Dương",
  "Nhật Tân, Gia Lộc, Hải Dương",
  "Đức Xương, Gia Lộc, Hải Dương",
  "Tứ Kỳ, Tứ Kỳ, Hải Dương",
  "Đại Sơn, Tứ Kỳ, Hải Dương",
  "Hưng Đạo, Tứ Kỳ, Hải Dương",
  "Ngọc Kỳ, Tứ Kỳ, Hải Dương",
  "Bình Lăng, Tứ Kỳ, Hải Dương",
  "Chí Minh, Tứ Kỳ, Hải Dương",
  "Tái Sơn, Tứ Kỳ, Hải Dương",
  "Quang Phục, Tứ Kỳ, Hải Dương",
  "Dân Chủ, Tứ Kỳ, Hải Dương",
  "Tân Kỳ, Tứ Kỳ, Hải Dương",
  "Quang Khải, Tứ Kỳ, Hải Dương",
  "Đại Hợp, Tứ Kỳ, Hải Dương",
  "Quảng Nghiệp, Tứ Kỳ, Hải Dương",
  "An Thanh, Tứ Kỳ, Hải Dương",
  "Minh Đức, Tứ Kỳ, Hải Dương",
  "Văn Tố, Tứ Kỳ, Hải Dương",
  "Quang Trung, Tứ Kỳ, Hải Dương",
  "Phượng Kỳ, Tứ Kỳ, Hải Dương",
  "Cộng Lạc, Tứ Kỳ, Hải Dương",
  "Tiên Động, Tứ Kỳ, Hải Dương",
  "Nguyên Giáp, Tứ Kỳ, Hải Dương",
  "Hà Kỳ, Tứ Kỳ, Hải Dương",
  "Hà Thanh, Tứ Kỳ, Hải Dương",
  "Ninh Giang, Ninh Giang, Hải Dương",
  "Ứng Hoè, Ninh Giang, Hải Dương",
  "Nghĩa An, Ninh Giang, Hải Dương",
  "Hồng Đức, Ninh Giang, Hải Dương",
  "An Đức, Ninh Giang, Hải Dương",
  "Vạn Phúc, Ninh Giang, Hải Dương",
  "Tân Hương, Ninh Giang, Hải Dương",
  "Vĩnh Hòa, Ninh Giang, Hải Dương",
  "Đông Xuyên, Ninh Giang, Hải Dương",
  "Tân Phong, Ninh Giang, Hải Dương",
  "Ninh Hải, Ninh Giang, Hải Dương",
  "Đồng Tâm, Ninh Giang, Hải Dương",
  "Tân Quang, Ninh Giang, Hải Dương",
  "Kiến Quốc, Ninh Giang, Hải Dương",
  "Hồng Dụ, Ninh Giang, Hải Dương",
  "Văn Hội, Ninh Giang, Hải Dương",
  "Hồng Phong, Ninh Giang, Hải Dương",
  "Hiệp Lực, Ninh Giang, Hải Dương",
  "Hồng Phúc, Ninh Giang, Hải Dương",
  "Hưng Long, Ninh Giang, Hải Dương",
  "Thanh Miện, Thanh Miện, Hải Dương",
  "Thanh Tùng, Thanh Miện, Hải Dương",
  "Phạm Kha, Thanh Miện, Hải Dương",
  "Ngô Quyền, Thanh Miện, Hải Dương",
  "Đoàn Tùng, Thanh Miện, Hải Dương",
  "Hồng Quang, Thanh Miện, Hải Dương",
  "Tân Trào, Thanh Miện, Hải Dương",
  "Lam Sơn, Thanh Miện, Hải Dương",
  "Đoàn Kết, Thanh Miện, Hải Dương",
  "Lê Hồng, Thanh Miện, Hải Dương",
  "Tứ Cường, Thanh Miện, Hải Dương",
  "Ngũ Hùng, Thanh Miện, Hải Dương",
  "Cao Thắng, Thanh Miện, Hải Dương",
  "Chi Lăng Bắc, Thanh Miện, Hải Dương",
  "Chi Lăng Nam, Thanh Miện, Hải Dương",
  "Thanh Giang, Thanh Miện, Hải Dương",
  "Hồng Phong, Thanh Miện, Hải Dương",
  "Quán Toan, Hồng Bàng, Hải Phòng",
  "Hùng Vương, Hồng Bàng, Hải Phòng",
  "Sở Dầu, Hồng Bàng, Hải Phòng",
  "Thượng Lý, Hồng Bàng, Hải Phòng",
  "Hạ Lý, Hồng Bàng, Hải Phòng",
  "Minh Khai, Hồng Bàng, Hải Phòng",
  "Trại Chuối, Hồng Bàng, Hải Phòng",
  "Hoàng Văn Thụ, Hồng Bàng, Hải Phòng",
  "Phan Bội Châu, Hồng Bàng, Hải Phòng",
  "Máy Chai, Ngô Quyền, Hải Phòng",
  "Máy Tơ, Ngô Quyền, Hải Phòng",
  "Vạn Mỹ, Ngô Quyền, Hải Phòng",
  "Cầu Tre, Ngô Quyền, Hải Phòng",
  "Lạc Viên, Ngô Quyền, Hải Phòng",
  "Gia Viên, Ngô Quyền, Hải Phòng",
  "Đông Khê, Ngô Quyền, Hải Phòng",
  "Cầu Đất, Ngô Quyền, Hải Phòng",
  "Lê Lợi, Ngô Quyền, Hải Phòng",
  "Đằng Giang, Ngô Quyền, Hải Phòng",
  "Lạch Tray, Ngô Quyền, Hải Phòng",
  "Đổng Quốc Bình, Ngô Quyền, Hải Phòng",
  "Cát Dài, Lê Chân, Hải Phòng",
  "An Biên, Lê Chân, Hải Phòng",
  "Lam Sơn, Lê Chân, Hải Phòng",
  "An Dương, Lê Chân, Hải Phòng",
  "Trần Nguyên Hãn, Lê Chân, Hải Phòng",
  "Hồ Nam, Lê Chân, Hải Phòng",
  "Trại Cau, Lê Chân, Hải Phòng",
  "Dư Hàng, Lê Chân, Hải Phòng",
  "Hàng Kênh, Lê Chân, Hải Phòng",
  "Đông Hải, Lê Chân, Hải Phòng",
  "Niệm Nghĩa, Lê Chân, Hải Phòng",
  "Nghĩa Xá, Lê Chân, Hải Phòng",
  "Dư Hàng Kênh, Lê Chân, Hải Phòng",
  "Kênh Dương, Lê Chân, Hải Phòng",
  "Vĩnh Niệm, Lê Chân, Hải Phòng",
  "Đông Hải 1, Hải An, Hải Phòng",
  "Đông Hải 2, Hải An, Hải Phòng",
  "Đằng Lâm, Hải An, Hải Phòng",
  "Thành Tô, Hải An, Hải Phòng",
  "Đằng Hải, Hải An, Hải Phòng",
  "Nam Hải, Hải An, Hải Phòng",
  "Cát Bi, Hải An, Hải Phòng",
  "Tràng Cát, Hải An, Hải Phòng",
  "Quán Trữ, Kiến An, Hải Phòng",
  "Lãm Hà, Kiến An, Hải Phòng",
  "Đồng Hoà, Kiến An, Hải Phòng",
  "Bắc Sơn, Kiến An, Hải Phòng",
  "Nam Sơn, Kiến An, Hải Phòng",
  "Ngọc Sơn, Kiến An, Hải Phòng",
  "Trần Thành Ngọ, Kiến An, Hải Phòng",
  "Văn Đẩu, Kiến An, Hải Phòng",
  "Phù Liễn, Kiến An, Hải Phòng",
  "Tràng Minh, Kiến An, Hải Phòng",
  "Ngọc Xuyên, Đồ Sơn, Hải Phòng",
  "Hải Sơn, Đồ Sơn, Hải Phòng",
  "Vạn Hương, Đồ Sơn, Hải Phòng",
  "Minh Đức, Đồ Sơn, Hải Phòng",
  "Bàng La, Đồ Sơn, Hải Phòng",
  "Hợp Đức, Đồ Sơn, Hải Phòng",
  "Đa Phúc, Dương Kinh, Hải Phòng",
  "Hưng Đạo, Dương Kinh, Hải Phòng",
  "Anh Dũng, Dương Kinh, Hải Phòng",
  "Hải Thành, Dương Kinh, Hải Phòng",
  "Hoà Nghĩa, Dương Kinh, Hải Phòng",
  "Tân Thành, Dương Kinh, Hải Phòng",
  "Núi Đèo, Thuỷ Nguyên, Hải Phòng",
  "Minh Đức, Thuỷ Nguyên, Hải Phòng",
  "Lại Xuân, Thuỷ Nguyên, Hải Phòng",
  "An Sơn, Thuỷ Nguyên, Hải Phòng",
  "Kỳ Sơn, Thuỷ Nguyên, Hải Phòng",
  "Liên Khê, Thuỷ Nguyên, Hải Phòng",
  "Lưu Kiếm, Thuỷ Nguyên, Hải Phòng",
  "Lưu Kỳ, Thuỷ Nguyên, Hải Phòng",
  "Gia Minh, Thuỷ Nguyên, Hải Phòng",
  "Gia Đức, Thuỷ Nguyên, Hải Phòng",
  "Minh Tân, Thuỷ Nguyên, Hải Phòng",
  "Phù Ninh, Thuỷ Nguyên, Hải Phòng",
  "Quảng Thanh, Thuỷ Nguyên, Hải Phòng",
  "Chính Mỹ, Thuỷ Nguyên, Hải Phòng",
  "Kênh Giang, Thuỷ Nguyên, Hải Phòng",
  "Hợp Thành, Thuỷ Nguyên, Hải Phòng",
  "Cao Nhân, Thuỷ Nguyên, Hải Phòng",
  "Mỹ Đồng, Thuỷ Nguyên, Hải Phòng",
  "Đông Sơn, Thuỷ Nguyên, Hải Phòng",
  "Hoà Bình, Thuỷ Nguyên, Hải Phòng",
  "Trung Hà, Thuỷ Nguyên, Hải Phòng",
  "An Lư, Thuỷ Nguyên, Hải Phòng",
  "Thuỷ Triều, Thuỷ Nguyên, Hải Phòng",
  "Ngũ Lão, Thuỷ Nguyên, Hải Phòng",
  "Phục Lễ, Thuỷ Nguyên, Hải Phòng",
  "Tam Hưng, Thuỷ Nguyên, Hải Phòng",
  "Phả Lễ, Thuỷ Nguyên, Hải Phòng",
  "Lập Lễ, Thuỷ Nguyên, Hải Phòng",
  "Kiền Bái, Thuỷ Nguyên, Hải Phòng",
  "Thiên Hương, Thuỷ Nguyên, Hải Phòng",
  "Thuỷ Sơn, Thuỷ Nguyên, Hải Phòng",
  "Thuỷ Đường, Thuỷ Nguyên, Hải Phòng",
  "Hoàng Động, Thuỷ Nguyên, Hải Phòng",
  "Lâm Động, Thuỷ Nguyên, Hải Phòng",
  "Hoa Động, Thuỷ Nguyên, Hải Phòng",
  "Tân Dương, Thuỷ Nguyên, Hải Phòng",
  "Dương Quan, Thuỷ Nguyên, Hải Phòng",
  "An Dương, An Dương, Hải Phòng",
  "Lê Thiện, An Dương, Hải Phòng",
  "Đại Bản, An Dương, Hải Phòng",
  "An Hoà, An Dương, Hải Phòng",
  "Hồng Phong, An Dương, Hải Phòng",
  "Tân Tiến, An Dương, Hải Phòng",
  "An Hưng, An Dương, Hải Phòng",
  "An Hồng, An Dương, Hải Phòng",
  "Bắc Sơn, An Dương, Hải Phòng",
  "Nam Sơn, An Dương, Hải Phòng",
  "Lê Lợi, An Dương, Hải Phòng",
  "Đặng Cương, An Dương, Hải Phòng",
  "Đồng Thái, An Dương, Hải Phòng",
  "Quốc Tuấn, An Dương, Hải Phòng",
  "An Đồng, An Dương, Hải Phòng",
  "Hồng Thái, An Dương, Hải Phòng",
  "An Lão, An Lão, Hải Phòng",
  "Bát Trang, An Lão, Hải Phòng",
  "Trường Thọ, An Lão, Hải Phòng",
  "Trường Thành, An Lão, Hải Phòng",
  "An Tiến, An Lão, Hải Phòng",
  "Quang Hưng, An Lão, Hải Phòng",
  "Quang Trung, An Lão, Hải Phòng",
  "Quốc Tuấn, An Lão, Hải Phòng",
  "An Thắng, An Lão, Hải Phòng",
  "Trường Sơn, An Lão, Hải Phòng",
  "Tân Dân, An Lão, Hải Phòng",
  "Thái Sơn, An Lão, Hải Phòng",
  "Tân Viên, An Lão, Hải Phòng",
  "Mỹ Đức, An Lão, Hải Phòng",
  "Chiến Thắng, An Lão, Hải Phòng",
  "An Thọ, An Lão, Hải Phòng",
  "An Thái, An Lão, Hải Phòng",
  "Núi Đối, Kiến Thuỵ, Hải Phòng",
  "Đông Phương, Kiến Thuỵ, Hải Phòng",
  "Thuận Thiên, Kiến Thuỵ, Hải Phòng",
  "Hữu Bằng, Kiến Thuỵ, Hải Phòng",
  "Đại Đồng, Kiến Thuỵ, Hải Phòng",
  "Ngũ Phúc, Kiến Thuỵ, Hải Phòng",
  "Kiến Quốc, Kiến Thuỵ, Hải Phòng",
  "Du Lễ, Kiến Thuỵ, Hải Phòng",
  "Thuỵ Hương, Kiến Thuỵ, Hải Phòng",
  "Thanh Sơn, Kiến Thuỵ, Hải Phòng",
  "Minh Tân, Kiến Thuỵ, Hải Phòng",
  "Đại Hà, Kiến Thuỵ, Hải Phòng",
  "Ngũ Đoan, Kiến Thuỵ, Hải Phòng",
  "Tân Phong, Kiến Thuỵ, Hải Phòng",
  "Tân Trào, Kiến Thuỵ, Hải Phòng",
  "Đoàn Xá, Kiến Thuỵ, Hải Phòng",
  "Tú Sơn, Kiến Thuỵ, Hải Phòng",
  "Đại Hợp, Kiến Thuỵ, Hải Phòng",
  "Tiên Lãng, Tiên Lãng, Hải Phòng",
  "Đại Thắng, Tiên Lãng, Hải Phòng",
  "Tiên Cường, Tiên Lãng, Hải Phòng",
  "Tự Cường, Tiên Lãng, Hải Phòng",
  "Quyết Tiến, Tiên Lãng, Hải Phòng",
  "Khởi Nghĩa, Tiên Lãng, Hải Phòng",
  "Tiên Thanh, Tiên Lãng, Hải Phòng",
  "Cấp Tiến, Tiên Lãng, Hải Phòng",
  "Kiến Thiết, Tiên Lãng, Hải Phòng",
  "Đoàn Lập, Tiên Lãng, Hải Phòng",
  "Bạch Đằng, Tiên Lãng, Hải Phòng",
  "Quang Phục, Tiên Lãng, Hải Phòng",
  "Toàn Thắng, Tiên Lãng, Hải Phòng",
  "Tiên Thắng, Tiên Lãng, Hải Phòng",
  "Tiên Minh, Tiên Lãng, Hải Phòng",
  "Bắc Hưng, Tiên Lãng, Hải Phòng",
  "Nam Hưng, Tiên Lãng, Hải Phòng",
  "Hùng Thắng, Tiên Lãng, Hải Phòng",
  "Tây Hưng, Tiên Lãng, Hải Phòng",
  "Đông Hưng, Tiên Lãng, Hải Phòng",
  "Vinh Quang, Tiên Lãng, Hải Phòng",
  "Vĩnh Bảo, Vĩnh Bảo, Hải Phòng",
  "Dũng Tiến, Vĩnh Bảo, Hải Phòng",
  "Giang Biên, Vĩnh Bảo, Hải Phòng",
  "Thắng Thuỷ, Vĩnh Bảo, Hải Phòng",
  "Trung Lập, Vĩnh Bảo, Hải Phòng",
  "Việt Tiến, Vĩnh Bảo, Hải Phòng",
  "Vĩnh An, Vĩnh Bảo, Hải Phòng",
  "Vĩnh Long, Vĩnh Bảo, Hải Phòng",
  "Hiệp Hoà, Vĩnh Bảo, Hải Phòng",
  "Hùng Tiến, Vĩnh Bảo, Hải Phòng",
  "An Hoà, Vĩnh Bảo, Hải Phòng",
  "Tân Hưng, Vĩnh Bảo, Hải Phòng",
  "Tân Liên, Vĩnh Bảo, Hải Phòng",
  "Nhân Hoà, Vĩnh Bảo, Hải Phòng",
  "Tam Đa, Vĩnh Bảo, Hải Phòng",
  "Hưng Nhân, Vĩnh Bảo, Hải Phòng",
  "Vinh Quang, Vĩnh Bảo, Hải Phòng",
  "Đồng Minh, Vĩnh Bảo, Hải Phòng",
  "Thanh Lương, Vĩnh Bảo, Hải Phòng",
  "Liên Am, Vĩnh Bảo, Hải Phòng",
  "Lý Học, Vĩnh Bảo, Hải Phòng",
  "Tam Cường, Vĩnh Bảo, Hải Phòng",
  "Hoà Bình, Vĩnh Bảo, Hải Phòng",
  "Tiền Phong, Vĩnh Bảo, Hải Phòng",
  "Vĩnh Phong, Vĩnh Bảo, Hải Phòng",
  "Cộng Hiền, Vĩnh Bảo, Hải Phòng",
  "Cao Minh, Vĩnh Bảo, Hải Phòng",
  "Cổ Am, Vĩnh Bảo, Hải Phòng",
  "Vĩnh Tiến, Vĩnh Bảo, Hải Phòng",
  "Trấn Dương, Vĩnh Bảo, Hải Phòng",
  "Cát Bà, Cát Hải, Hải Phòng",
  "Cát Hải, Cát Hải, Hải Phòng",
  "Nghĩa Lộ, Cát Hải, Hải Phòng",
  "Đồng Bài, Cát Hải, Hải Phòng",
  "Hoàng Châu, Cát Hải, Hải Phòng",
  "Văn Phong, Cát Hải, Hải Phòng",
  "Phù Long, Cát Hải, Hải Phòng",
  "Gia Luận, Cát Hải, Hải Phòng",
  "Hiền Hào, Cát Hải, Hải Phòng",
  "Trân Châu, Cát Hải, Hải Phòng",
  "Việt Hải, Cát Hải, Hải Phòng",
  "Xuân Đám, Cát Hải, Hải Phòng",
  ", Bạch Long Vĩ, Hải Phòng",
  "Lam Sơn, Hưng Yên, Hưng Yên",
  "Hiến Nam, Hưng Yên, Hưng Yên",
  "An Tảo, Hưng Yên, Hưng Yên",
  "Lê Lợi, Hưng Yên, Hưng Yên",
  "Minh Khai, Hưng Yên, Hưng Yên",
  "Quang Trung, Hưng Yên, Hưng Yên",
  "Hồng Châu, Hưng Yên, Hưng Yên",
  "Trung Nghĩa, Hưng Yên, Hưng Yên",
  "Liên Phương, Hưng Yên, Hưng Yên",
  "Hồng Nam, Hưng Yên, Hưng Yên",
  "Quảng Châu, Hưng Yên, Hưng Yên",
  "Bảo Khê, Hưng Yên, Hưng Yên",
  "Phú Cường, Hưng Yên, Hưng Yên",
  "Hùng Cường, Hưng Yên, Hưng Yên",
  "Phương Chiểu, Hưng Yên, Hưng Yên",
  "Tân Hưng, Hưng Yên, Hưng Yên",
  "Hoàng Hanh, Hưng Yên, Hưng Yên",
  "Như Quỳnh, Văn Lâm, Hưng Yên",
  "Lạc Đạo, Văn Lâm, Hưng Yên",
  "Chỉ Đạo, Văn Lâm, Hưng Yên",
  "Đại Đồng, Văn Lâm, Hưng Yên",
  "Việt Hưng, Văn Lâm, Hưng Yên",
  "Tân Quang, Văn Lâm, Hưng Yên",
  "Đình Dù, Văn Lâm, Hưng Yên",
  "Minh Hải, Văn Lâm, Hưng Yên",
  "Lương Tài, Văn Lâm, Hưng Yên",
  "Trưng Trắc, Văn Lâm, Hưng Yên",
  "Lạc Hồng, Văn Lâm, Hưng Yên",
  "Văn Giang, Văn Giang, Hưng Yên",
  "Xuân Quan, Văn Giang, Hưng Yên",
  "Cửu Cao, Văn Giang, Hưng Yên",
  "Phụng Công, Văn Giang, Hưng Yên",
  "Nghĩa Trụ, Văn Giang, Hưng Yên",
  "Long Hưng, Văn Giang, Hưng Yên",
  "Vĩnh Khúc, Văn Giang, Hưng Yên",
  "Liên Nghĩa, Văn Giang, Hưng Yên",
  "Tân Tiến, Văn Giang, Hưng Yên",
  "Thắng Lợi, Văn Giang, Hưng Yên",
  "Mễ Sở, Văn Giang, Hưng Yên",
  "Yên Mỹ, Yên Mỹ, Hưng Yên",
  "Giai Phạm, Yên Mỹ, Hưng Yên",
  "Nghĩa Hiệp, Yên Mỹ, Hưng Yên",
  "Đồng Than, Yên Mỹ, Hưng Yên",
  "Ngọc Long, Yên Mỹ, Hưng Yên",
  "Liêu Xá, Yên Mỹ, Hưng Yên",
  "Hoàn Long, Yên Mỹ, Hưng Yên",
  "Tân Lập, Yên Mỹ, Hưng Yên",
  "Thanh Long, Yên Mỹ, Hưng Yên",
  "Yên Phú, Yên Mỹ, Hưng Yên",
  "Việt Cường, Yên Mỹ, Hưng Yên",
  "Trung Hòa, Yên Mỹ, Hưng Yên",
  "Yên Hòa, Yên Mỹ, Hưng Yên",
  "Minh Châu, Yên Mỹ, Hưng Yên",
  "Trung Hưng, Yên Mỹ, Hưng Yên",
  "Lý Thường Kiệt, Yên Mỹ, Hưng Yên",
  "Tân Việt, Yên Mỹ, Hưng Yên",
  "Bần Yên Nhân, Mỹ Hào, Hưng Yên",
  "Phan Đình Phùng, Mỹ Hào, Hưng Yên",
  "Cẩm Xá, Mỹ Hào, Hưng Yên",
  "Dương Quang, Mỹ Hào, Hưng Yên",
  "Hòa Phong, Mỹ Hào, Hưng Yên",
  "Nhân Hòa, Mỹ Hào, Hưng Yên",
  "Dị Sử, Mỹ Hào, Hưng Yên",
  "Bạch Sam, Mỹ Hào, Hưng Yên",
  "Minh Đức, Mỹ Hào, Hưng Yên",
  "Phùng Chí Kiên, Mỹ Hào, Hưng Yên",
  "Xuân Dục, Mỹ Hào, Hưng Yên",
  "Ngọc Lâm, Mỹ Hào, Hưng Yên",
  "Hưng Long, Mỹ Hào, Hưng Yên",
  "Ân Thi, Ân Thi, Hưng Yên",
  "Phù Ủng, Ân Thi, Hưng Yên",
  "Bắc Sơn, Ân Thi, Hưng Yên",
  "Bãi Sậy, Ân Thi, Hưng Yên",
  "Đào Dương, Ân Thi, Hưng Yên",
  "Tân Phúc, Ân Thi, Hưng Yên",
  "Vân Du, Ân Thi, Hưng Yên",
  "Quang Vinh, Ân Thi, Hưng Yên",
  "Xuân Trúc, Ân Thi, Hưng Yên",
  "Hoàng Hoa Thám, Ân Thi, Hưng Yên",
  "Quảng Lãng, Ân Thi, Hưng Yên",
  "Văn Nhuệ, Ân Thi, Hưng Yên",
  "Đặng Lễ, Ân Thi, Hưng Yên",
  "Cẩm Ninh, Ân Thi, Hưng Yên",
  "Nguyễn Trãi, Ân Thi, Hưng Yên",
  "Đa Lộc, Ân Thi, Hưng Yên",
  "Hồ Tùng Mậu, Ân Thi, Hưng Yên",
  "Tiền Phong, Ân Thi, Hưng Yên",
  "Hồng Vân, Ân Thi, Hưng Yên",
  "Hồng Quang, Ân Thi, Hưng Yên",
  "Hạ Lễ, Ân Thi, Hưng Yên",
  "Khoái Châu, Khoái Châu, Hưng Yên",
  "Đông Tảo, Khoái Châu, Hưng Yên",
  "Bình Minh, Khoái Châu, Hưng Yên",
  "Dạ Trạch, Khoái Châu, Hưng Yên",
  "Hàm Tử, Khoái Châu, Hưng Yên",
  "Ông Đình, Khoái Châu, Hưng Yên",
  "Tân Dân, Khoái Châu, Hưng Yên",
  "Tứ Dân, Khoái Châu, Hưng Yên",
  "An Vĩ, Khoái Châu, Hưng Yên",
  "Đông Kết, Khoái Châu, Hưng Yên",
  "Bình Kiều, Khoái Châu, Hưng Yên",
  "Dân Tiến, Khoái Châu, Hưng Yên",
  "Đồng Tiến, Khoái Châu, Hưng Yên",
  "Hồng Tiến, Khoái Châu, Hưng Yên",
  "Tân Châu, Khoái Châu, Hưng Yên",
  "Liên Khê, Khoái Châu, Hưng Yên",
  "Phùng Hưng, Khoái Châu, Hưng Yên",
  "Việt Hòa, Khoái Châu, Hưng Yên",
  "Đông Ninh, Khoái Châu, Hưng Yên",
  "Đại Tập, Khoái Châu, Hưng Yên",
  "Chí Tân, Khoái Châu, Hưng Yên",
  "Đại Hưng, Khoái Châu, Hưng Yên",
  "Thuần Hưng, Khoái Châu, Hưng Yên",
  "Thành Công, Khoái Châu, Hưng Yên",
  "Nhuế Dương, Khoái Châu, Hưng Yên",
  "Lương Bằng, Kim Động, Hưng Yên",
  "Nghĩa Dân, Kim Động, Hưng Yên",
  "Toàn Thắng, Kim Động, Hưng Yên",
  "Vĩnh Xá, Kim Động, Hưng Yên",
  "Phạm Ngũ Lão, Kim Động, Hưng Yên",
  "Thọ Vinh, Kim Động, Hưng Yên",
  "Đồng Thanh, Kim Động, Hưng Yên",
  "Song Mai, Kim Động, Hưng Yên",
  "Chính Nghĩa, Kim Động, Hưng Yên",
  "Nhân La, Kim Động, Hưng Yên",
  "Phú Thịnh, Kim Động, Hưng Yên",
  "Mai Động, Kim Động, Hưng Yên",
  "Đức Hợp, Kim Động, Hưng Yên",
  "Hùng An, Kim Động, Hưng Yên",
  "Ngọc Thanh, Kim Động, Hưng Yên",
  "Vũ Xá, Kim Động, Hưng Yên",
  "Hiệp Cường, Kim Động, Hưng Yên",
  "Vương, Tiên Lữ, Hưng Yên",
  "Hưng Đạo, Tiên Lữ, Hưng Yên",
  "Ngô Quyền, Tiên Lữ, Hưng Yên",
  "Nhật Tân, Tiên Lữ, Hưng Yên",
  "Dị Chế, Tiên Lữ, Hưng Yên",
  "Lệ Xá, Tiên Lữ, Hưng Yên",
  "An Viên, Tiên Lữ, Hưng Yên",
  "Đức Thắng, Tiên Lữ, Hưng Yên",
  "Trung Dũng, Tiên Lữ, Hưng Yên",
  "Hải Triều, Tiên Lữ, Hưng Yên",
  "Thủ Sỹ, Tiên Lữ, Hưng Yên",
  "Thiện Phiến, Tiên Lữ, Hưng Yên",
  "Thụy Lôi, Tiên Lữ, Hưng Yên",
  "Cương Chính, Tiên Lữ, Hưng Yên",
  "Minh Phượng, Tiên Lữ, Hưng Yên",
  "Trần Cao, Phù Cừ, Hưng Yên",
  "Minh Tân, Phù Cừ, Hưng Yên",
  "Phan Sào Nam, Phù Cừ, Hưng Yên",
  "Quang Hưng, Phù Cừ, Hưng Yên",
  "Minh Hoàng, Phù Cừ, Hưng Yên",
  "Đoàn Đào, Phù Cừ, Hưng Yên",
  "Tống Phan, Phù Cừ, Hưng Yên",
  "Đình Cao, Phù Cừ, Hưng Yên",
  "Nhật Quang, Phù Cừ, Hưng Yên",
  "Tiền Tiến, Phù Cừ, Hưng Yên",
  "Tam Đa, Phù Cừ, Hưng Yên",
  "Minh Tiến, Phù Cừ, Hưng Yên",
  "Nguyên Hòa, Phù Cừ, Hưng Yên",
  "Tống Trân, Phù Cừ, Hưng Yên",
  "Lê Hồng Phong, Thái Bình, Thái Bình",
  "Bồ Xuyên, Thái Bình, Thái Bình",
  "Đề Thám, Thái Bình, Thái Bình",
  "Kỳ Bá, Thái Bình, Thái Bình",
  "Quang Trung, Thái Bình, Thái Bình",
  "Phú Khánh, Thái Bình, Thái Bình",
  "Tiền Phong, Thái Bình, Thái Bình",
  "Trần Hưng Đạo, Thái Bình, Thái Bình",
  "Trần Lãm, Thái Bình, Thái Bình",
  "Đông Hòa, Thái Bình, Thái Bình",
  "Hoàng Diệu, Thái Bình, Thái Bình",
  "Phú Xuân, Thái Bình, Thái Bình",
  "Vũ Phúc, Thái Bình, Thái Bình",
  "Vũ Chính, Thái Bình, Thái Bình",
  "Đông Mỹ, Thái Bình, Thái Bình",
  "Đông Thọ, Thái Bình, Thái Bình",
  "Vũ Đông, Thái Bình, Thái Bình",
  "Vũ Lạc, Thái Bình, Thái Bình",
  "Tân Bình, Thái Bình, Thái Bình",
  "Quỳnh Côi, Quỳnh Phụ, Thái Bình",
  "An Khê, Quỳnh Phụ, Thái Bình",
  "An Đồng, Quỳnh Phụ, Thái Bình",
  "Quỳnh Hoa, Quỳnh Phụ, Thái Bình",
  "Quỳnh Lâm, Quỳnh Phụ, Thái Bình",
  "Quỳnh Thọ, Quỳnh Phụ, Thái Bình",
  "An Hiệp, Quỳnh Phụ, Thái Bình",
  "Quỳnh Hoàng, Quỳnh Phụ, Thái Bình",
  "Quỳnh Giao, Quỳnh Phụ, Thái Bình",
  "An Thái, Quỳnh Phụ, Thái Bình",
  "An Cầu, Quỳnh Phụ, Thái Bình",
  "Quỳnh Hồng, Quỳnh Phụ, Thái Bình",
  "Quỳnh Khê, Quỳnh Phụ, Thái Bình",
  "Quỳnh Minh, Quỳnh Phụ, Thái Bình",
  "An Ninh, Quỳnh Phụ, Thái Bình",
  "Quỳnh Ngọc, Quỳnh Phụ, Thái Bình",
  "Quỳnh Hải, Quỳnh Phụ, Thái Bình",
  "An Bài, Quỳnh Phụ, Thái Bình",
  "An Ấp, Quỳnh Phụ, Thái Bình",
  "Quỳnh Hội, Quỳnh Phụ, Thái Bình",
  "Châu Sơn, Quỳnh Phụ, Thái Bình",
  "Quỳnh Mỹ, Quỳnh Phụ, Thái Bình",
  "An Quí, Quỳnh Phụ, Thái Bình",
  "An Thanh, Quỳnh Phụ, Thái Bình",
  "An Vũ, Quỳnh Phụ, Thái Bình",
  "An Lễ, Quỳnh Phụ, Thái Bình",
  "Quỳnh Hưng, Quỳnh Phụ, Thái Bình",
  "Quỳnh Bảo, Quỳnh Phụ, Thái Bình",
  "An Mỹ, Quỳnh Phụ, Thái Bình",
  "Quỳnh Nguyên, Quỳnh Phụ, Thái Bình",
  "An Vinh, Quỳnh Phụ, Thái Bình",
  "Quỳnh Xá, Quỳnh Phụ, Thái Bình",
  "An Dục, Quỳnh Phụ, Thái Bình",
  "Đông Hải, Quỳnh Phụ, Thái Bình",
  "Quỳnh Trang, Quỳnh Phụ, Thái Bình",
  "An Tràng, Quỳnh Phụ, Thái Bình",
  "Đồng Tiến, Quỳnh Phụ, Thái Bình",
  "Hưng Hà, Hưng Hà, Thái Bình",
  "Điệp Nông, Hưng Hà, Thái Bình",
  "Tân Lễ, Hưng Hà, Thái Bình",
  "Cộng Hòa, Hưng Hà, Thái Bình",
  "Dân Chủ, Hưng Hà, Thái Bình",
  "Canh Tân, Hưng Hà, Thái Bình",
  "Hòa Tiến, Hưng Hà, Thái Bình",
  "Hùng Dũng, Hưng Hà, Thái Bình",
  "Tân Tiến, Hưng Hà, Thái Bình",
  "Hưng Nhân, Hưng Hà, Thái Bình",
  "Đoan Hùng, Hưng Hà, Thái Bình",
  "Duyên Hải, Hưng Hà, Thái Bình",
  "Tân Hòa, Hưng Hà, Thái Bình",
  "Văn Cẩm, Hưng Hà, Thái Bình",
  "Bắc Sơn, Hưng Hà, Thái Bình",
  "Đông Đô, Hưng Hà, Thái Bình",
  "Phúc Khánh, Hưng Hà, Thái Bình",
  "Liên Hiệp, Hưng Hà, Thái Bình",
  "Tây Đô, Hưng Hà, Thái Bình",
  "Thống Nhất, Hưng Hà, Thái Bình",
  "Tiến Đức, Hưng Hà, Thái Bình",
  "Thái Hưng, Hưng Hà, Thái Bình",
  "Thái Phương, Hưng Hà, Thái Bình",
  "Hòa Bình, Hưng Hà, Thái Bình",
  "Chi Lăng, Hưng Hà, Thái Bình",
  "Minh Khai, Hưng Hà, Thái Bình",
  "Hồng An, Hưng Hà, Thái Bình",
  "Kim Chung, Hưng Hà, Thái Bình",
  "Hồng Lĩnh, Hưng Hà, Thái Bình",
  "Minh Tân, Hưng Hà, Thái Bình",
  "Văn Lang, Hưng Hà, Thái Bình",
  "Độc Lập, Hưng Hà, Thái Bình",
  "Chí Hòa, Hưng Hà, Thái Bình",
  "Minh Hòa, Hưng Hà, Thái Bình",
  "Hồng Minh, Hưng Hà, Thái Bình",
  "Đông Hưng, Đông Hưng, Thái Bình",
  "Đô Lương, Đông Hưng, Thái Bình",
  "Đông Phương, Đông Hưng, Thái Bình",
  "Liên Giang, Đông Hưng, Thái Bình",
  "An Châu, Đông Hưng, Thái Bình",
  "Đông Sơn, Đông Hưng, Thái Bình",
  "Đông Cường, Đông Hưng, Thái Bình",
  "Phú Lương, Đông Hưng, Thái Bình",
  "Mê Linh, Đông Hưng, Thái Bình",
  "Lô Giang, Đông Hưng, Thái Bình",
  "Đông La, Đông Hưng, Thái Bình",
  "Minh Tân, Đông Hưng, Thái Bình",
  "Đông Xá, Đông Hưng, Thái Bình",
  "Chương Dương, Đông Hưng, Thái Bình",
  "Nguyên Xá, Đông Hưng, Thái Bình",
  "Phong Châu, Đông Hưng, Thái Bình",
  "Hợp Tiến, Đông Hưng, Thái Bình",
  "Hồng Việt, Đông Hưng, Thái Bình",
  "Hà Giang, Đông Hưng, Thái Bình",
  "Đông Kinh, Đông Hưng, Thái Bình",
  "Đông Hợp, Đông Hưng, Thái Bình",
  "Thăng Long, Đông Hưng, Thái Bình",
  "Đông Các, Đông Hưng, Thái Bình",
  "Phú Châu, Đông Hưng, Thái Bình",
  "Liên Hoa, Đông Hưng, Thái Bình",
  "Đông Tân, Đông Hưng, Thái Bình",
  "Đông Vinh, Đông Hưng, Thái Bình",
  "Đông Động, Đông Hưng, Thái Bình",
  "Hồng Bạch, Đông Hưng, Thái Bình",
  "Trọng Quan, Đông Hưng, Thái Bình",
  "Hồng Giang, Đông Hưng, Thái Bình",
  "Đông Quan, Đông Hưng, Thái Bình",
  "Đông Quang, Đông Hưng, Thái Bình",
  "Đông Xuân, Đông Hưng, Thái Bình",
  "Đông Á, Đông Hưng, Thái Bình",
  "Đông Hoàng, Đông Hưng, Thái Bình",
  "Đông Dương, Đông Hưng, Thái Bình",
  "Minh Phú, Đông Hưng, Thái Bình",
  "Diêm Điền, Thái Thụy, Thái Bình",
  "Thụy Trường, Thái Thụy, Thái Bình",
  "Hồng Dũng, Thái Thụy, Thái Bình",
  "Thụy Quỳnh, Thái Thụy, Thái Bình",
  "An Tân, Thái Thụy, Thái Bình",
  "Thụy Ninh, Thái Thụy, Thái Bình",
  "Thụy Hưng, Thái Thụy, Thái Bình",
  "Thụy Việt, Thái Thụy, Thái Bình",
  "Thụy Văn, Thái Thụy, Thái Bình",
  "Thụy Xuân, Thái Thụy, Thái Bình",
  "Dương Phúc, Thái Thụy, Thái Bình",
  "Thụy Trình, Thái Thụy, Thái Bình",
  "Thụy Bình, Thái Thụy, Thái Bình",
  "Thụy Chính, Thái Thụy, Thái Bình",
  "Thụy Dân, Thái Thụy, Thái Bình",
  "Thụy Hải, Thái Thụy, Thái Bình",
  "Thụy Liên, Thái Thụy, Thái Bình",
  "Thụy Duyên, Thái Thụy, Thái Bình",
  "Thụy Thanh, Thái Thụy, Thái Bình",
  "Thụy Sơn, Thái Thụy, Thái Bình",
  "Thụy Phong, Thái Thụy, Thái Bình",
  "Thái Thượng, Thái Thụy, Thái Bình",
  "Thái Nguyên, Thái Thụy, Thái Bình",
  "Dương Hồng  Thủy, Thái Thụy, Thái Bình",
  "Thái Giang, Thái Thụy, Thái Bình",
  "Hòa An, Thái Thụy, Thái Bình",
  "Sơn Hà, Thái Thụy, Thái Bình",
  "Thái Phúc, Thái Thụy, Thái Bình",
  "Thái Hưng, Thái Thụy, Thái Bình",
  "Thái Đô, Thái Thụy, Thái Bình",
  "Thái Xuyên, Thái Thụy, Thái Bình",
  " Mỹ Lộc, Thái Thụy, Thái Bình",
  "Tân Học, Thái Thụy, Thái Bình",
  "Thái Thịnh, Thái Thụy, Thái Bình",
  "Thuần Thành, Thái Thụy, Thái Bình",
  "Thái Thọ, Thái Thụy, Thái Bình",
  "Tiền Hải, Tiền Hải, Thái Bình",
  "Đông Trà, Tiền Hải, Thái Bình",
  "Đông Long, Tiền Hải, Thái Bình",
  "Đông Quí, Tiền Hải, Thái Bình",
  "Vũ Lăng, Tiền Hải, Thái Bình",
  "Đông Xuyên, Tiền Hải, Thái Bình",
  "Tây Lương, Tiền Hải, Thái Bình",
  "Tây Ninh, Tiền Hải, Thái Bình",
  "Đông Trung, Tiền Hải, Thái Bình",
  "Đông Hoàng, Tiền Hải, Thái Bình",
  "Đông Minh, Tiền Hải, Thái Bình",
  "Đông Phong, Tiền Hải, Thái Bình",
  "An Ninh, Tiền Hải, Thái Bình",
  "Đông Cơ, Tiền Hải, Thái Bình",
  "Tây Giang, Tiền Hải, Thái Bình",
  "Đông Lâm, Tiền Hải, Thái Bình",
  "Phương Công, Tiền Hải, Thái Bình",
  "Tây Phong, Tiền Hải, Thái Bình",
  "Tây Tiến, Tiền Hải, Thái Bình",
  "Nam Cường, Tiền Hải, Thái Bình",
  "Vân Trường, Tiền Hải, Thái Bình",
  "Nam Thắng, Tiền Hải, Thái Bình",
  "Nam Chính, Tiền Hải, Thái Bình",
  "Bắc Hải, Tiền Hải, Thái Bình",
  "Nam Thịnh, Tiền Hải, Thái Bình",
  "Nam Hà, Tiền Hải, Thái Bình",
  "Nam Thanh, Tiền Hải, Thái Bình",
  "Nam Trung, Tiền Hải, Thái Bình",
  "Nam Hồng, Tiền Hải, Thái Bình",
  "Nam Hưng, Tiền Hải, Thái Bình",
  "Nam Hải, Tiền Hải, Thái Bình",
  "Nam Phú, Tiền Hải, Thái Bình",
  "Kiến Xương, Kiến Xương, Thái Bình",
  "Trà Giang, Kiến Xương, Thái Bình",
  "Quốc Tuấn, Kiến Xương, Thái Bình",
  "An Bình, Kiến Xương, Thái Bình",
  "Tây Sơn, Kiến Xương, Thái Bình",
  "Hồng Thái, Kiến Xương, Thái Bình",
  "Bình Nguyên, Kiến Xương, Thái Bình",
  "Lê Lợi, Kiến Xương, Thái Bình",
  "Vũ Lễ, Kiến Xương, Thái Bình",
  "Thanh Tân, Kiến Xương, Thái Bình",
  "Thượng Hiền, Kiến Xương, Thái Bình",
  "Nam Cao, Kiến Xương, Thái Bình",
  "Đình Phùng, Kiến Xương, Thái Bình",
  "Vũ Ninh, Kiến Xương, Thái Bình",
  "Vũ An, Kiến Xương, Thái Bình",
  "Quang Lịch, Kiến Xương, Thái Bình",
  "Hòa Bình, Kiến Xương, Thái Bình",
  "Bình Minh, Kiến Xương, Thái Bình",
  "Vũ Quí, Kiến Xương, Thái Bình",
  "Quang Bình, Kiến Xương, Thái Bình",
  "Vũ Trung, Kiến Xương, Thái Bình",
  "Vũ Thắng, Kiến Xương, Thái Bình",
  "Vũ Công, Kiến Xương, Thái Bình",
  "Vũ Hòa, Kiến Xương, Thái Bình",
  "Quang Minh, Kiến Xương, Thái Bình",
  "Quang Trung, Kiến Xương, Thái Bình",
  "Minh Quang, Kiến Xương, Thái Bình",
  "Vũ Bình, Kiến Xương, Thái Bình",
  "Minh Tân, Kiến Xương, Thái Bình",
  "Nam Bình, Kiến Xương, Thái Bình",
  "Bình Thanh, Kiến Xương, Thái Bình",
  "Bình Định, Kiến Xương, Thái Bình",
  "Hồng Tiến, Kiến Xương, Thái Bình",
  "Vũ Thư, Vũ Thư, Thái Bình",
  "Hồng Lý, Vũ Thư, Thái Bình",
  "Đồng Thanh, Vũ Thư, Thái Bình",
  "Xuân Hòa, Vũ Thư, Thái Bình",
  "Hiệp Hòa, Vũ Thư, Thái Bình",
  "Phúc Thành, Vũ Thư, Thái Bình",
  "Tân Phong, Vũ Thư, Thái Bình",
  "Song Lãng, Vũ Thư, Thái Bình",
  "Tân Hòa, Vũ Thư, Thái Bình",
  "Việt Hùng, Vũ Thư, Thái Bình",
  "Minh Lãng, Vũ Thư, Thái Bình",
  "Minh Khai, Vũ Thư, Thái Bình",
  "Dũng Nghĩa, Vũ Thư, Thái Bình",
  "Minh Quang, Vũ Thư, Thái Bình",
  "Tam Quang, Vũ Thư, Thái Bình",
  "Tân Lập, Vũ Thư, Thái Bình",
  "Bách Thuận, Vũ Thư, Thái Bình",
  "Tự Tân, Vũ Thư, Thái Bình",
  "Song An, Vũ Thư, Thái Bình",
  "Trung An, Vũ Thư, Thái Bình",
  "Vũ Hội, Vũ Thư, Thái Bình",
  "Hòa Bình, Vũ Thư, Thái Bình",
  "Nguyên Xá, Vũ Thư, Thái Bình",
  "Việt Thuận, Vũ Thư, Thái Bình",
  "Vũ Vinh, Vũ Thư, Thái Bình",
  "Vũ Đoài, Vũ Thư, Thái Bình",
  "Vũ Tiến, Vũ Thư, Thái Bình",
  "Vũ Vân, Vũ Thư, Thái Bình",
  "Duy Nhất, Vũ Thư, Thái Bình",
  "Hồng Phong, Vũ Thư, Thái Bình",
  "Quang Trung, Phủ Lý, Hà Nam",
  "Lương Khánh Thiện, Phủ Lý, Hà Nam",
  "Lê Hồng Phong, Phủ Lý, Hà Nam",
  "Minh Khai, Phủ Lý, Hà Nam",
  "Hai Bà Trưng, Phủ Lý, Hà Nam",
  "Trần Hưng Đạo, Phủ Lý, Hà Nam",
  "Lam Hạ, Phủ Lý, Hà Nam",
  "Phù Vân, Phủ Lý, Hà Nam",
  "Liêm Chính, Phủ Lý, Hà Nam",
  "Liêm Chung, Phủ Lý, Hà Nam",
  "Thanh Châu, Phủ Lý, Hà Nam",
  "Châu Sơn, Phủ Lý, Hà Nam",
  "Tiên Tân, Phủ Lý, Hà Nam",
  "Tiên Hiệp, Phủ Lý, Hà Nam",
  "Tiên Hải, Phủ Lý, Hà Nam",
  "Kim Bình, Phủ Lý, Hà Nam",
  "Liêm Tuyền, Phủ Lý, Hà Nam",
  "Liêm Tiết, Phủ Lý, Hà Nam",
  "Thanh Tuyền, Phủ Lý, Hà Nam",
  "Đinh Xá, Phủ Lý, Hà Nam",
  "Trịnh Xá, Phủ Lý, Hà Nam",
  "Đồng Văn, Duy Tiên, Hà Nam",
  "Hòa Mạc, Duy Tiên, Hà Nam",
  "Mộc Bắc, Duy Tiên, Hà Nam",
  "Châu Giang, Duy Tiên, Hà Nam",
  "Bạch Thượng, Duy Tiên, Hà Nam",
  "Duy Minh, Duy Tiên, Hà Nam",
  "Mộc Nam, Duy Tiên, Hà Nam",
  "Duy Hải, Duy Tiên, Hà Nam",
  "Chuyên Ngoại, Duy Tiên, Hà Nam",
  "Yên Bắc, Duy Tiên, Hà Nam",
  "Trác Văn, Duy Tiên, Hà Nam",
  "Tiên Nội, Duy Tiên, Hà Nam",
  "Hoàng Đông, Duy Tiên, Hà Nam",
  "Yên Nam, Duy Tiên, Hà Nam",
  "Tiên Ngoại, Duy Tiên, Hà Nam",
  "Tiên Sơn, Duy Tiên, Hà Nam",
  "Quế, Kim Bảng, Hà Nam",
  "Nguyễn Úy, Kim Bảng, Hà Nam",
  "Đại Cương, Kim Bảng, Hà Nam",
  "Lê Hồ, Kim Bảng, Hà Nam",
  "Tượng Lĩnh, Kim Bảng, Hà Nam",
  "Nhật Tựu, Kim Bảng, Hà Nam",
  "Nhật Tân, Kim Bảng, Hà Nam",
  "Đồng Hóa, Kim Bảng, Hà Nam",
  "Hoàng Tây, Kim Bảng, Hà Nam",
  "Tân Sơn, Kim Bảng, Hà Nam",
  "Thụy Lôi, Kim Bảng, Hà Nam",
  "Văn Xá, Kim Bảng, Hà Nam",
  "Khả Phong, Kim Bảng, Hà Nam",
  "Ngọc Sơn, Kim Bảng, Hà Nam",
  "Ba Sao, Kim Bảng, Hà Nam",
  "Liên Sơn, Kim Bảng, Hà Nam",
  "Thi Sơn, Kim Bảng, Hà Nam",
  "Thanh Sơn, Kim Bảng, Hà Nam",
  "Kiện Khê, Thanh Liêm, Hà Nam",
  "Liêm Phong, Thanh Liêm, Hà Nam",
  "Thanh Hà, Thanh Liêm, Hà Nam",
  "Liêm Cần, Thanh Liêm, Hà Nam",
  "Liêm Thuận, Thanh Liêm, Hà Nam",
  "Thanh Thủy, Thanh Liêm, Hà Nam",
  "Thanh Phong, Thanh Liêm, Hà Nam",
  "Tân Thanh, Thanh Liêm, Hà Nam",
  "Thanh Tân, Thanh Liêm, Hà Nam",
  "Liêm Túc, Thanh Liêm, Hà Nam",
  "Liêm Sơn, Thanh Liêm, Hà Nam",
  "Thanh Hương, Thanh Liêm, Hà Nam",
  "Thanh Nghị, Thanh Liêm, Hà Nam",
  "Thanh Tâm, Thanh Liêm, Hà Nam",
  "Thanh Nguyên, Thanh Liêm, Hà Nam",
  "Thanh Hải, Thanh Liêm, Hà Nam",
  "Bình Mỹ, Bình Lục, Hà Nam",
  "Bình Nghĩa, Bình Lục, Hà Nam",
  "Tràng An, Bình Lục, Hà Nam",
  "Đồng Du, Bình Lục, Hà Nam",
  "Ngọc Lũ, Bình Lục, Hà Nam",
  "Hưng Công, Bình Lục, Hà Nam",
  "Đồn Xá, Bình Lục, Hà Nam",
  "An Ninh, Bình Lục, Hà Nam",
  "Bồ Đề, Bình Lục, Hà Nam",
  "Bối Cầu, Bình Lục, Hà Nam",
  "An Nội, Bình Lục, Hà Nam",
  "Vũ Bản, Bình Lục, Hà Nam",
  "Trung Lương, Bình Lục, Hà Nam",
  "An Đổ, Bình Lục, Hà Nam",
  "La Sơn, Bình Lục, Hà Nam",
  "Tiêu Động, Bình Lục, Hà Nam",
  "An Lão, Bình Lục, Hà Nam",
  "Hợp Lý, Lý Nhân, Hà Nam",
  "Nguyên Lý, Lý Nhân, Hà Nam",
  "Chính Lý, Lý Nhân, Hà Nam",
  "Chân Lý, Lý Nhân, Hà Nam",
  "Đạo Lý, Lý Nhân, Hà Nam",
  "Công Lý, Lý Nhân, Hà Nam",
  "Văn Lý, Lý Nhân, Hà Nam",
  "Bắc Lý, Lý Nhân, Hà Nam",
  "Đức Lý, Lý Nhân, Hà Nam",
  "Trần Hưng Đạo, Lý Nhân, Hà Nam",
  "Vĩnh Trụ, Lý Nhân, Hà Nam",
  "Nhân Thịnh, Lý Nhân, Hà Nam",
  "Nhân Khang, Lý Nhân, Hà Nam",
  "Nhân Mỹ, Lý Nhân, Hà Nam",
  "Nhân Nghĩa, Lý Nhân, Hà Nam",
  "Nhân Chính, Lý Nhân, Hà Nam",
  "Nhân Bình, Lý Nhân, Hà Nam",
  "Phú Phúc, Lý Nhân, Hà Nam",
  "Xuân Khê, Lý Nhân, Hà Nam",
  "Tiến Thắng, Lý Nhân, Hà Nam",
  "Hòa Hậu, Lý Nhân, Hà Nam",
  "Hạ Long, Nam Định, Nam Định",
  "Trần Tế Xương, Nam Định, Nam Định",
  "Vị Hoàng, Nam Định, Nam Định",
  "Vị Xuyên, Nam Định, Nam Định",
  "Quang Trung, Nam Định, Nam Định",
  "Cửa Bắc, Nam Định, Nam Định",
  "Nguyễn Du, Nam Định, Nam Định",
  "Bà Triệu, Nam Định, Nam Định",
  "Trường Thi, Nam Định, Nam Định",
  "Phan Đình Phùng, Nam Định, Nam Định",
  "Ngô Quyền, Nam Định, Nam Định",
  "Trần Hưng Đạo, Nam Định, Nam Định",
  "Trần Đăng Ninh, Nam Định, Nam Định",
  "Năng Tĩnh, Nam Định, Nam Định",
  "Văn Miếu, Nam Định, Nam Định",
  "Trần Quang Khải, Nam Định, Nam Định",
  "Thống Nhất, Nam Định, Nam Định",
  "Lộc Hạ, Nam Định, Nam Định",
  "Lộc Vượng, Nam Định, Nam Định",
  "Cửa Nam, Nam Định, Nam Định",
  "Lộc Hòa, Nam Định, Nam Định",
  "Nam Phong, Nam Định, Nam Định",
  "Mỹ Xá, Nam Định, Nam Định",
  "Lộc An, Nam Định, Nam Định",
  "Nam Vân, Nam Định, Nam Định",
  "Mỹ Lộc, Mỹ Lộc, Nam Định",
  "Mỹ Hà, Mỹ Lộc, Nam Định",
  "Mỹ Tiến, Mỹ Lộc, Nam Định",
  "Mỹ Thắng, Mỹ Lộc, Nam Định",
  "Mỹ Trung, Mỹ Lộc, Nam Định",
  "Mỹ Tân, Mỹ Lộc, Nam Định",
  "Mỹ Phúc, Mỹ Lộc, Nam Định",
  "Mỹ Hưng, Mỹ Lộc, Nam Định",
  "Mỹ Thuận, Mỹ Lộc, Nam Định",
  "Mỹ Thịnh, Mỹ Lộc, Nam Định",
  "Mỹ Thành, Mỹ Lộc, Nam Định",
  "Gôi, Vụ Bản, Nam Định",
  "Minh Thuận, Vụ Bản, Nam Định",
  "Hiển Khánh, Vụ Bản, Nam Định",
  "Tân Khánh, Vụ Bản, Nam Định",
  "Hợp Hưng, Vụ Bản, Nam Định",
  "Đại An, Vụ Bản, Nam Định",
  "Tân Thành, Vụ Bản, Nam Định",
  "Cộng Hòa, Vụ Bản, Nam Định",
  "Trung Thành, Vụ Bản, Nam Định",
  "Quang Trung, Vụ Bản, Nam Định",
  "Minh Tân, Vụ Bản, Nam Định",
  "Liên Bảo, Vụ Bản, Nam Định",
  "Thành Lợi, Vụ Bản, Nam Định",
  "Kim Thái, Vụ Bản, Nam Định",
  "Liên Minh, Vụ Bản, Nam Định",
  "Đại Thắng, Vụ Bản, Nam Định",
  "Tam Thanh, Vụ Bản, Nam Định",
  "Vĩnh Hào, Vụ Bản, Nam Định",
  "Lâm, Ý Yên, Nam Định",
  "Yên Trung, Ý Yên, Nam Định",
  "Yên Thành, Ý Yên, Nam Định",
  "Yên Tân, Ý Yên, Nam Định",
  "Yên Lợi, Ý Yên, Nam Định",
  "Yên Thọ, Ý Yên, Nam Định",
  "Yên Nghĩa, Ý Yên, Nam Định",
  "Yên Minh, Ý Yên, Nam Định",
  "Yên Phương, Ý Yên, Nam Định",
  "Yên Chính, Ý Yên, Nam Định",
  "Yên Bình, Ý Yên, Nam Định",
  "Yên Phú, Ý Yên, Nam Định",
  "Yên Mỹ, Ý Yên, Nam Định",
  "Yên Dương, Ý Yên, Nam Định",
  "Yên Hưng, Ý Yên, Nam Định",
  "Yên Khánh, Ý Yên, Nam Định",
  "Yên Phong, Ý Yên, Nam Định",
  "Yên Ninh, Ý Yên, Nam Định",
  "Yên Lương, Ý Yên, Nam Định",
  "Yên Hồng, Ý Yên, Nam Định",
  "Yên Quang, Ý Yên, Nam Định",
  "Yên Tiến, Ý Yên, Nam Định",
  "Yên Thắng, Ý Yên, Nam Định",
  "Yên Phúc, Ý Yên, Nam Định",
  "Yên Cường, Ý Yên, Nam Định",
  "Yên Lộc, Ý Yên, Nam Định",
  "Yên Bằng, Ý Yên, Nam Định",
  "Yên Đồng, Ý Yên, Nam Định",
  "Yên Khang, Ý Yên, Nam Định",
  "Yên Nhân, Ý Yên, Nam Định",
  "Yên Trị, Ý Yên, Nam Định",
  "Liễu Đề, Nghĩa Hưng, Nam Định",
  "Rạng Đông, Nghĩa Hưng, Nam Định",
  "Nghĩa Đồng, Nghĩa Hưng, Nam Định",
  "Nghĩa Thịnh, Nghĩa Hưng, Nam Định",
  "Nghĩa Minh, Nghĩa Hưng, Nam Định",
  "Nghĩa Thái, Nghĩa Hưng, Nam Định",
  "Hoàng Nam, Nghĩa Hưng, Nam Định",
  "Nghĩa Châu, Nghĩa Hưng, Nam Định",
  "Nghĩa Trung, Nghĩa Hưng, Nam Định",
  "Nghĩa Sơn, Nghĩa Hưng, Nam Định",
  "Nghĩa Lạc, Nghĩa Hưng, Nam Định",
  "Nghĩa Hồng, Nghĩa Hưng, Nam Định",
  "Nghĩa Phong, Nghĩa Hưng, Nam Định",
  "Nghĩa Phú, Nghĩa Hưng, Nam Định",
  "Nghĩa Bình, Nghĩa Hưng, Nam Định",
  "Quỹ Nhất, Nghĩa Hưng, Nam Định",
  "Nghĩa Tân, Nghĩa Hưng, Nam Định",
  "Nghĩa Hùng, Nghĩa Hưng, Nam Định",
  "Nghĩa Lâm, Nghĩa Hưng, Nam Định",
  "Nghĩa Thành, Nghĩa Hưng, Nam Định",
  "Phúc Thắng, Nghĩa Hưng, Nam Định",
  "Nghĩa Lợi, Nghĩa Hưng, Nam Định",
  "Nghĩa Hải, Nghĩa Hưng, Nam Định",
  "Nam Điền, Nghĩa Hưng, Nam Định",
  "Nam Giang, Nam Trực, Nam Định",
  "Nam Mỹ, Nam Trực, Nam Định",
  "Điền Xá, Nam Trực, Nam Định",
  "Nghĩa An, Nam Trực, Nam Định",
  "Nam Thắng, Nam Trực, Nam Định",
  "Nam Toàn, Nam Trực, Nam Định",
  "Hồng Quang, Nam Trực, Nam Định",
  "Tân Thịnh, Nam Trực, Nam Định",
  "Nam Cường, Nam Trực, Nam Định",
  "Nam Hồng, Nam Trực, Nam Định",
  "Nam Hùng, Nam Trực, Nam Định",
  "Nam Hoa, Nam Trực, Nam Định",
  "Nam Dương, Nam Trực, Nam Định",
  "Nam Thanh, Nam Trực, Nam Định",
  "Nam Lợi, Nam Trực, Nam Định",
  "Bình Minh, Nam Trực, Nam Định",
  "Đồng Sơn, Nam Trực, Nam Định",
  "Nam Tiến, Nam Trực, Nam Định",
  "Nam Hải, Nam Trực, Nam Định",
  "Nam Thái, Nam Trực, Nam Định",
  "Cổ Lễ, Trực Ninh, Nam Định",
  "Phương Định, Trực Ninh, Nam Định",
  "Trực Chính, Trực Ninh, Nam Định",
  "Trung Đông, Trực Ninh, Nam Định",
  "Liêm Hải, Trực Ninh, Nam Định",
  "Trực Tuấn, Trực Ninh, Nam Định",
  "Việt Hùng, Trực Ninh, Nam Định",
  "Trực Đạo, Trực Ninh, Nam Định",
  "Trực Hưng, Trực Ninh, Nam Định",
  "Trực Nội, Trực Ninh, Nam Định",
  "Cát Thành, Trực Ninh, Nam Định",
  "Trực Thanh, Trực Ninh, Nam Định",
  "Trực Khang, Trực Ninh, Nam Định",
  "Trực Thuận, Trực Ninh, Nam Định",
  "Trực Mỹ, Trực Ninh, Nam Định",
  "Trực Đại, Trực Ninh, Nam Định",
  "Trực Cường, Trực Ninh, Nam Định",
  "Ninh Cường, Trực Ninh, Nam Định",
  "Trực Thái, Trực Ninh, Nam Định",
  "Trực Hùng, Trực Ninh, Nam Định",
  "Trực Thắng, Trực Ninh, Nam Định",
  "Xuân Trường, Xuân Trường, Nam Định",
  "Xuân Châu, Xuân Trường, Nam Định",
  "Xuân Hồng, Xuân Trường, Nam Định",
  "Xuân Thành, Xuân Trường, Nam Định",
  "Xuân Thượng, Xuân Trường, Nam Định",
  "Xuân Phong, Xuân Trường, Nam Định",
  "Xuân Đài, Xuân Trường, Nam Định",
  "Xuân Tân, Xuân Trường, Nam Định",
  "Xuân Thủy, Xuân Trường, Nam Định",
  "Xuân Ngọc, Xuân Trường, Nam Định",
  "Xuân Bắc, Xuân Trường, Nam Định",
  "Xuân Phương, Xuân Trường, Nam Định",
  "Thọ Nghiệp, Xuân Trường, Nam Định",
  "Xuân Phú, Xuân Trường, Nam Định",
  "Xuân Trung, Xuân Trường, Nam Định",
  "Xuân Vinh, Xuân Trường, Nam Định",
  "Xuân Kiên, Xuân Trường, Nam Định",
  "Xuân Tiến, Xuân Trường, Nam Định",
  "Xuân Ninh, Xuân Trường, Nam Định",
  "Xuân Hòa, Xuân Trường, Nam Định",
  "Ngô Đồng, Giao Thủy, Nam Định",
  "Quất Lâm, Giao Thủy, Nam Định",
  "Giao Hương, Giao Thủy, Nam Định",
  "Hồng Thuận, Giao Thủy, Nam Định",
  "Giao Thiện, Giao Thủy, Nam Định",
  "Giao Thanh, Giao Thủy, Nam Định",
  "Hoành Sơn, Giao Thủy, Nam Định",
  "Bình Hòa, Giao Thủy, Nam Định",
  "Giao Tiến, Giao Thủy, Nam Định",
  "Giao Hà, Giao Thủy, Nam Định",
  "Giao Nhân, Giao Thủy, Nam Định",
  "Giao An, Giao Thủy, Nam Định",
  "Giao Lạc, Giao Thủy, Nam Định",
  "Giao Châu, Giao Thủy, Nam Định",
  "Giao Tân, Giao Thủy, Nam Định",
  "Giao Yến, Giao Thủy, Nam Định",
  "Giao Xuân, Giao Thủy, Nam Định",
  "Giao Thịnh, Giao Thủy, Nam Định",
  "Giao Hải, Giao Thủy, Nam Định",
  "Bạch Long, Giao Thủy, Nam Định",
  "Giao Long, Giao Thủy, Nam Định",
  "Giao Phong, Giao Thủy, Nam Định",
  "Yên Định, Hải Hậu, Nam Định",
  "Cồn, Hải Hậu, Nam Định",
  "Thịnh Long, Hải Hậu, Nam Định",
  "Hải Nam, Hải Hậu, Nam Định",
  "Hải Trung, Hải Hậu, Nam Định",
  "Hải Vân, Hải Hậu, Nam Định",
  "Hải Minh, Hải Hậu, Nam Định",
  "Hải Anh, Hải Hậu, Nam Định",
  "Hải Hưng, Hải Hậu, Nam Định",
  "Hải Bắc, Hải Hậu, Nam Định",
  "Hải Phúc, Hải Hậu, Nam Định",
  "Hải Thanh, Hải Hậu, Nam Định",
  "Hải Hà, Hải Hậu, Nam Định",
  "Hải Long, Hải Hậu, Nam Định",
  "Hải Phương, Hải Hậu, Nam Định",
  "Hải Đường, Hải Hậu, Nam Định",
  "Hải Lộc, Hải Hậu, Nam Định",
  "Hải Quang, Hải Hậu, Nam Định",
  "Hải Đông, Hải Hậu, Nam Định",
  "Hải Sơn, Hải Hậu, Nam Định",
  "Hải Tân, Hải Hậu, Nam Định",
  "Hải Phong, Hải Hậu, Nam Định",
  "Hải An, Hải Hậu, Nam Định",
  "Hải Tây, Hải Hậu, Nam Định",
  "Hải Lý, Hải Hậu, Nam Định",
  "Hải Phú, Hải Hậu, Nam Định",
  "Hải Giang, Hải Hậu, Nam Định",
  "Hải Cường, Hải Hậu, Nam Định",
  "Hải Ninh, Hải Hậu, Nam Định",
  "Hải Chính, Hải Hậu, Nam Định",
  "Hải Xuân, Hải Hậu, Nam Định",
  "Hải Châu, Hải Hậu, Nam Định",
  "Hải Triều, Hải Hậu, Nam Định",
  "Hải Hòa, Hải Hậu, Nam Định",
  "Đông Thành, Ninh Bình, Ninh Bình",
  "Tân Thành, Ninh Bình, Ninh Bình",
  "Thanh Bình, Ninh Bình, Ninh Bình",
  "Vân Giang, Ninh Bình, Ninh Bình",
  "Bích Đào, Ninh Bình, Ninh Bình",
  "Phúc Thành, Ninh Bình, Ninh Bình",
  "Nam Bình, Ninh Bình, Ninh Bình",
  "Nam Thành, Ninh Bình, Ninh Bình",
  "Ninh Khánh, Ninh Bình, Ninh Bình",
  "Ninh Nhất, Ninh Bình, Ninh Bình",
  "Ninh Tiến, Ninh Bình, Ninh Bình",
  "Ninh Phúc, Ninh Bình, Ninh Bình",
  "Ninh Sơn, Ninh Bình, Ninh Bình",
  "Ninh Phong, Ninh Bình, Ninh Bình",
  "Bắc Sơn, Tam Điệp, Ninh Bình",
  "Trung Sơn, Tam Điệp, Ninh Bình",
  "Nam Sơn, Tam Điệp, Ninh Bình",
  "Tây Sơn, Tam Điệp, Ninh Bình",
  "Yên Sơn, Tam Điệp, Ninh Bình",
  "Yên Bình, Tam Điệp, Ninh Bình",
  "Tân Bình, Tam Điệp, Ninh Bình",
  "Quang Sơn, Tam Điệp, Ninh Bình",
  "Đông Sơn, Tam Điệp, Ninh Bình",
  "Nho Quan, Nho Quan, Ninh Bình",
  "Xích Thổ, Nho Quan, Ninh Bình",
  "Gia Lâm, Nho Quan, Ninh Bình",
  "Gia Sơn, Nho Quan, Ninh Bình",
  "Thạch Bình, Nho Quan, Ninh Bình",
  "Gia Thủy, Nho Quan, Ninh Bình",
  "Gia Tường, Nho Quan, Ninh Bình",
  "Cúc Phương, Nho Quan, Ninh Bình",
  "Phú Sơn, Nho Quan, Ninh Bình",
  "Đức Long, Nho Quan, Ninh Bình",
  "Lạc Vân, Nho Quan, Ninh Bình",
  "Đồng Phong, Nho Quan, Ninh Bình",
  "Yên Quang, Nho Quan, Ninh Bình",
  "Lạng Phong, Nho Quan, Ninh Bình",
  "Thượng Hòa, Nho Quan, Ninh Bình",
  "Văn Phong, Nho Quan, Ninh Bình",
  "Văn Phương, Nho Quan, Ninh Bình",
  "Thanh Lạc, Nho Quan, Ninh Bình",
  "Sơn Lai, Nho Quan, Ninh Bình",
  "Sơn Thành, Nho Quan, Ninh Bình",
  "Văn Phú, Nho Quan, Ninh Bình",
  "Phú Lộc, Nho Quan, Ninh Bình",
  "Kỳ Phú, Nho Quan, Ninh Bình",
  "Quỳnh Lưu, Nho Quan, Ninh Bình",
  "Sơn Hà, Nho Quan, Ninh Bình",
  "Phú Long, Nho Quan, Ninh Bình",
  "Quảng Lạc, Nho Quan, Ninh Bình",
  "Me, Gia Viễn, Ninh Bình",
  "Gia Hòa, Gia Viễn, Ninh Bình",
  "Gia Hưng, Gia Viễn, Ninh Bình",
  "Liên Sơn, Gia Viễn, Ninh Bình",
  "Gia Thanh, Gia Viễn, Ninh Bình",
  "Gia Vân, Gia Viễn, Ninh Bình",
  "Gia Phú, Gia Viễn, Ninh Bình",
  "Gia Xuân, Gia Viễn, Ninh Bình",
  "Gia Lập, Gia Viễn, Ninh Bình",
  "Gia Vượng, Gia Viễn, Ninh Bình",
  "Gia Trấn, Gia Viễn, Ninh Bình",
  "Gia Thịnh, Gia Viễn, Ninh Bình",
  "Gia Phương, Gia Viễn, Ninh Bình",
  "Gia Tân, Gia Viễn, Ninh Bình",
  "Gia Thắng, Gia Viễn, Ninh Bình",
  "Gia Trung, Gia Viễn, Ninh Bình",
  "Gia Minh, Gia Viễn, Ninh Bình",
  "Gia Lạc, Gia Viễn, Ninh Bình",
  "Gia Tiến, Gia Viễn, Ninh Bình",
  "Gia Sinh, Gia Viễn, Ninh Bình",
  "Gia Phong, Gia Viễn, Ninh Bình",
  "Thiên Tôn, Hoa Lư, Ninh Bình",
  "Ninh Giang, Hoa Lư, Ninh Bình",
  "Trường Yên, Hoa Lư, Ninh Bình",
  "Ninh Khang, Hoa Lư, Ninh Bình",
  "Ninh Mỹ, Hoa Lư, Ninh Bình",
  "Ninh Hòa, Hoa Lư, Ninh Bình",
  "Ninh Xuân, Hoa Lư, Ninh Bình",
  "Ninh Hải, Hoa Lư, Ninh Bình",
  "Ninh Thắng, Hoa Lư, Ninh Bình",
  "Ninh Vân, Hoa Lư, Ninh Bình",
  "Ninh An, Hoa Lư, Ninh Bình",
  "Yên Ninh, Yên Khánh, Ninh Bình",
  "Khánh Tiên, Yên Khánh, Ninh Bình",
  "Khánh Phú, Yên Khánh, Ninh Bình",
  "Khánh Hòa, Yên Khánh, Ninh Bình",
  "Khánh Lợi, Yên Khánh, Ninh Bình",
  "Khánh An, Yên Khánh, Ninh Bình",
  "Khánh Cường, Yên Khánh, Ninh Bình",
  "Khánh Cư, Yên Khánh, Ninh Bình",
  "Khánh Thiện, Yên Khánh, Ninh Bình",
  "Khánh Hải, Yên Khánh, Ninh Bình",
  "Khánh Trung, Yên Khánh, Ninh Bình",
  "Khánh Mậu, Yên Khánh, Ninh Bình",
  "Khánh Vân, Yên Khánh, Ninh Bình",
  "Khánh Hội, Yên Khánh, Ninh Bình",
  "Khánh Công, Yên Khánh, Ninh Bình",
  "Khánh Thành, Yên Khánh, Ninh Bình",
  "Khánh Nhạc, Yên Khánh, Ninh Bình",
  "Khánh Thủy, Yên Khánh, Ninh Bình",
  "Khánh Hồng, Yên Khánh, Ninh Bình",
  "Phát Diệm, Kim Sơn, Ninh Bình",
  "Bình Minh, Kim Sơn, Ninh Bình",
  "Hồi Ninh, Kim Sơn, Ninh Bình",
  "Xuân Chính, Kim Sơn, Ninh Bình",
  "Kim Định, Kim Sơn, Ninh Bình",
  "Ân Hòa, Kim Sơn, Ninh Bình",
  "Hùng Tiến, Kim Sơn, Ninh Bình",
  "Quang Thiện, Kim Sơn, Ninh Bình",
  "Như Hòa, Kim Sơn, Ninh Bình",
  "Chất Bình, Kim Sơn, Ninh Bình",
  "Đồng Hướng, Kim Sơn, Ninh Bình",
  "Kim Chính, Kim Sơn, Ninh Bình",
  "Thượng Kiệm, Kim Sơn, Ninh Bình",
  "Lưu Phương, Kim Sơn, Ninh Bình",
  "Tân Thành, Kim Sơn, Ninh Bình",
  "Yên Lộc, Kim Sơn, Ninh Bình",
  "Lai Thành, Kim Sơn, Ninh Bình",
  "Định Hóa, Kim Sơn, Ninh Bình",
  "Văn Hải, Kim Sơn, Ninh Bình",
  "Kim Tân, Kim Sơn, Ninh Bình",
  "Kim Mỹ, Kim Sơn, Ninh Bình",
  "Cồn Thoi, Kim Sơn, Ninh Bình",
  "Kim Hải, Kim Sơn, Ninh Bình",
  "Kim Trung, Kim Sơn, Ninh Bình",
  "Kim Đông, Kim Sơn, Ninh Bình",
  "Yên Thịnh, Yên Mô, Ninh Bình",
  "Khánh Thượng, Yên Mô, Ninh Bình",
  "Khánh Dương, Yên Mô, Ninh Bình",
  "Mai Sơn, Yên Mô, Ninh Bình",
  "Khánh Thịnh, Yên Mô, Ninh Bình",
  "Yên Phong, Yên Mô, Ninh Bình",
  "Yên Hòa, Yên Mô, Ninh Bình",
  "Yên Thắng, Yên Mô, Ninh Bình",
  "Yên Từ, Yên Mô, Ninh Bình",
  "Yên Hưng, Yên Mô, Ninh Bình",
  "Yên Thành, Yên Mô, Ninh Bình",
  "Yên Nhân, Yên Mô, Ninh Bình",
  "Yên Mỹ, Yên Mô, Ninh Bình",
  "Yên Mạc, Yên Mô, Ninh Bình",
  "Yên Đồng, Yên Mô, Ninh Bình",
  "Yên Thái, Yên Mô, Ninh Bình",
  "Yên Lâm, Yên Mô, Ninh Bình",
  "Hàm Rồng, Thanh Hóa, Thanh Hóa",
  "Đông Thọ, Thanh Hóa, Thanh Hóa",
  "Nam Ngạn, Thanh Hóa, Thanh Hóa",
  "Trường Thi, Thanh Hóa, Thanh Hóa",
  "Điện Biên, Thanh Hóa, Thanh Hóa",
  "Phú Sơn, Thanh Hóa, Thanh Hóa",
  "Lam Sơn, Thanh Hóa, Thanh Hóa",
  "Ba Đình, Thanh Hóa, Thanh Hóa",
  "Ngọc Trạo, Thanh Hóa, Thanh Hóa",
  "Đông Vệ, Thanh Hóa, Thanh Hóa",
  "Đông Sơn, Thanh Hóa, Thanh Hóa",
  "Tân Sơn, Thanh Hóa, Thanh Hóa",
  "Đông Cương, Thanh Hóa, Thanh Hóa",
  "Đông Hương, Thanh Hóa, Thanh Hóa",
  "Đông Hải, Thanh Hóa, Thanh Hóa",
  "Quảng Hưng, Thanh Hóa, Thanh Hóa",
  "Quảng Thắng, Thanh Hóa, Thanh Hóa",
  "Quảng Thành, Thanh Hóa, Thanh Hóa",
  "Thiệu Vân, Thanh Hóa, Thanh Hóa",
  "Thiệu Khánh, Thanh Hóa, Thanh Hóa",
  "Thiệu Dương, Thanh Hóa, Thanh Hóa",
  "Tào Xuyên, Thanh Hóa, Thanh Hóa",
  "Long Anh, Thanh Hóa, Thanh Hóa",
  "Hoằng Quang, Thanh Hóa, Thanh Hóa",
  "Hoằng Đại, Thanh Hóa, Thanh Hóa",
  "Đông Lĩnh, Thanh Hóa, Thanh Hóa",
  "Đông Vinh, Thanh Hóa, Thanh Hóa",
  "Đông Tân, Thanh Hóa, Thanh Hóa",
  "An Hưng, Thanh Hóa, Thanh Hóa",
  "Quảng Thịnh, Thanh Hóa, Thanh Hóa",
  "Quảng Đông, Thanh Hóa, Thanh Hóa",
  "Quảng Cát, Thanh Hóa, Thanh Hóa",
  "Quảng Phú, Thanh Hóa, Thanh Hóa",
  "Quảng Tâm, Thanh Hóa, Thanh Hóa",
  "Bắc Sơn, Bỉm Sơn, Thanh Hóa",
  "Ba Đình, Bỉm Sơn, Thanh Hóa",
  "Lam Sơn, Bỉm Sơn, Thanh Hóa",
  "Ngọc Trạo, Bỉm Sơn, Thanh Hóa",
  "Đông Sơn, Bỉm Sơn, Thanh Hóa",
  "Phú Sơn, Bỉm Sơn, Thanh Hóa",
  "Quang Trung, Bỉm Sơn, Thanh Hóa",
  "Trung Sơn, Sầm Sơn, Thanh Hóa",
  "Bắc Sơn, Sầm Sơn, Thanh Hóa",
  "Trường Sơn, Sầm Sơn, Thanh Hóa",
  "Quảng Cư, Sầm Sơn, Thanh Hóa",
  "Quảng Tiến, Sầm Sơn, Thanh Hóa",
  "Quảng Minh, Sầm Sơn, Thanh Hóa",
  "Quảng Hùng, Sầm Sơn, Thanh Hóa",
  "Quảng Thọ, Sầm Sơn, Thanh Hóa",
  "Quảng Châu, Sầm Sơn, Thanh Hóa",
  "Quảng Vinh, Sầm Sơn, Thanh Hóa",
  "Quảng Đại, Sầm Sơn, Thanh Hóa",
  "Mường Lát, Mường Lát, Thanh Hóa",
  "Tam Chung, Mường Lát, Thanh Hóa",
  "Mường Lý, Mường Lát, Thanh Hóa",
  "Trung Lý, Mường Lát, Thanh Hóa",
  "Quang Chiểu, Mường Lát, Thanh Hóa",
  "Pù Nhi, Mường Lát, Thanh Hóa",
  "Nhi Sơn, Mường Lát, Thanh Hóa",
  "Mường Chanh, Mường Lát, Thanh Hóa",
  "Hồi Xuân, Quan Hóa, Thanh Hóa",
  "Thành Sơn, Quan Hóa, Thanh Hóa",
  "Trung Sơn, Quan Hóa, Thanh Hóa",
  "Phú Thanh, Quan Hóa, Thanh Hóa",
  "Trung Thành, Quan Hóa, Thanh Hóa",
  "Phú Lệ, Quan Hóa, Thanh Hóa",
  "Phú Sơn, Quan Hóa, Thanh Hóa",
  "Phú Xuân, Quan Hóa, Thanh Hóa",
  "Hiền Chung, Quan Hóa, Thanh Hóa",
  "Hiền Kiệt, Quan Hóa, Thanh Hóa",
  "Nam Tiến, Quan Hóa, Thanh Hóa",
  "Thiên Phủ, Quan Hóa, Thanh Hóa",
  "Phú Nghiêm, Quan Hóa, Thanh Hóa",
  "Nam Xuân, Quan Hóa, Thanh Hóa",
  "Nam Động, Quan Hóa, Thanh Hóa",
  "Cành Nàng, Bá Thước, Thanh Hóa",
  "Điền Thượng, Bá Thước, Thanh Hóa",
  "Điền Hạ, Bá Thước, Thanh Hóa",
  "Điền Quang, Bá Thước, Thanh Hóa",
  "Điền Trung, Bá Thước, Thanh Hóa",
  "Thành Sơn, Bá Thước, Thanh Hóa",
  "Lương Ngoại, Bá Thước, Thanh Hóa",
  "Ái Thượng, Bá Thước, Thanh Hóa",
  "Lương Nội, Bá Thước, Thanh Hóa",
  "Điền Lư, Bá Thước, Thanh Hóa",
  "Lương Trung, Bá Thước, Thanh Hóa",
  "Lũng Niêm, Bá Thước, Thanh Hóa",
  "Lũng Cao, Bá Thước, Thanh Hóa",
  "Hạ Trung, Bá Thước, Thanh Hóa",
  "Cổ Lũng, Bá Thước, Thanh Hóa",
  "Thành Lâm, Bá Thước, Thanh Hóa",
  "Ban Công, Bá Thước, Thanh Hóa",
  "Kỳ Tân, Bá Thước, Thanh Hóa",
  "Văn Nho, Bá Thước, Thanh Hóa",
  "Thiết Ống, Bá Thước, Thanh Hóa",
  "Thiết Kế, Bá Thước, Thanh Hóa",
  "Trung Xuân, Quan Sơn, Thanh Hóa",
  "Trung Thượng, Quan Sơn, Thanh Hóa",
  "Trung Tiến, Quan Sơn, Thanh Hóa",
  "Trung Hạ, Quan Sơn, Thanh Hóa",
  "Sơn Hà, Quan Sơn, Thanh Hóa",
  "Tam Thanh, Quan Sơn, Thanh Hóa",
  "Sơn Thủy, Quan Sơn, Thanh Hóa",
  "Na Mèo, Quan Sơn, Thanh Hóa",
  "Sơn Lư, Quan Sơn, Thanh Hóa",
  "Tam Lư, Quan Sơn, Thanh Hóa",
  "Sơn Điện, Quan Sơn, Thanh Hóa",
  "Mường Mìn, Quan Sơn, Thanh Hóa",
  "Yên Khương, Lang Chánh, Thanh Hóa",
  "Yên Thắng, Lang Chánh, Thanh Hóa",
  "Trí Nang, Lang Chánh, Thanh Hóa",
  "Giao An, Lang Chánh, Thanh Hóa",
  "Giao Thiện, Lang Chánh, Thanh Hóa",
  "Tân Phúc, Lang Chánh, Thanh Hóa",
  "Tam Văn, Lang Chánh, Thanh Hóa",
  "Lâm Phú, Lang Chánh, Thanh Hóa",
  "Lang Chánh, Lang Chánh, Thanh Hóa",
  "Đồng Lương, Lang Chánh, Thanh Hóa",
  "Ngọc Lặc, Ngọc Lặc, Thanh Hóa",
  "Lam Sơn, Ngọc Lặc, Thanh Hóa",
  "Mỹ Tân, Ngọc Lặc, Thanh Hóa",
  "Thúy Sơn, Ngọc Lặc, Thanh Hóa",
  "Thạch Lập, Ngọc Lặc, Thanh Hóa",
  "Vân Âm, Ngọc Lặc, Thanh Hóa",
  "Cao Ngọc, Ngọc Lặc, Thanh Hóa",
  "Quang Trung, Ngọc Lặc, Thanh Hóa",
  "Đồng Thịnh, Ngọc Lặc, Thanh Hóa",
  "Ngọc Liên, Ngọc Lặc, Thanh Hóa",
  "Ngọc Sơn, Ngọc Lặc, Thanh Hóa",
  "Lộc Thịnh, Ngọc Lặc, Thanh Hóa",
  "Cao Thịnh, Ngọc Lặc, Thanh Hóa",
  "Ngọc Trung, Ngọc Lặc, Thanh Hóa",
  "Phùng Giáo, Ngọc Lặc, Thanh Hóa",
  "Phùng Minh, Ngọc Lặc, Thanh Hóa",
  "Phúc Thịnh, Ngọc Lặc, Thanh Hóa",
  "Nguyệt Ấn, Ngọc Lặc, Thanh Hóa",
  "Kiên Thọ, Ngọc Lặc, Thanh Hóa",
  "Minh Tiến, Ngọc Lặc, Thanh Hóa",
  "Minh Sơn, Ngọc Lặc, Thanh Hóa",
  "Phong Sơn, Cẩm Thủy, Thanh Hóa",
  "Cẩm Thành, Cẩm Thủy, Thanh Hóa",
  "Cẩm Quý, Cẩm Thủy, Thanh Hóa",
  "Cẩm Lương, Cẩm Thủy, Thanh Hóa",
  "Cẩm Thạch, Cẩm Thủy, Thanh Hóa",
  "Cẩm Liên, Cẩm Thủy, Thanh Hóa",
  "Cẩm Giang, Cẩm Thủy, Thanh Hóa",
  "Cẩm Bình, Cẩm Thủy, Thanh Hóa",
  "Cẩm Tú, Cẩm Thủy, Thanh Hóa",
  "Cẩm Châu, Cẩm Thủy, Thanh Hóa",
  "Cẩm Tâm, Cẩm Thủy, Thanh Hóa",
  "Cẩm Ngọc, Cẩm Thủy, Thanh Hóa",
  "Cẩm Long, Cẩm Thủy, Thanh Hóa",
  "Cẩm Yên, Cẩm Thủy, Thanh Hóa",
  "Cẩm Tân, Cẩm Thủy, Thanh Hóa",
  "Cẩm Phú, Cẩm Thủy, Thanh Hóa",
  "Cẩm Vân, Cẩm Thủy, Thanh Hóa",
  "Kim Tân, Thạch Thành, Thanh Hóa",
  "Vân Du, Thạch Thành, Thanh Hóa",
  "Thạch Lâm, Thạch Thành, Thanh Hóa",
  "Thạch Quảng, Thạch Thành, Thanh Hóa",
  "Thạch Tượng, Thạch Thành, Thanh Hóa",
  "Thạch Cẩm, Thạch Thành, Thanh Hóa",
  "Thạch Sơn, Thạch Thành, Thanh Hóa",
  "Thạch Bình, Thạch Thành, Thanh Hóa",
  "Thạch Định, Thạch Thành, Thanh Hóa",
  "Thạch Đồng, Thạch Thành, Thanh Hóa",
  "Thạch Long, Thạch Thành, Thanh Hóa",
  "Thành Mỹ, Thạch Thành, Thanh Hóa",
  "Thành Yên, Thạch Thành, Thanh Hóa",
  "Thành Vinh, Thạch Thành, Thanh Hóa",
  "Thành Minh, Thạch Thành, Thanh Hóa",
  "Thành Công, Thạch Thành, Thanh Hóa",
  "Thành Tân, Thạch Thành, Thanh Hóa",
  "Thành Trực, Thạch Thành, Thanh Hóa",
  "Thành Tâm, Thạch Thành, Thanh Hóa",
  "Thành An, Thạch Thành, Thanh Hóa",
  "Thành Thọ, Thạch Thành, Thanh Hóa",
  "Thành Tiến, Thạch Thành, Thanh Hóa",
  "Thành Long, Thạch Thành, Thanh Hóa",
  "Thành Hưng, Thạch Thành, Thanh Hóa",
  "Ngọc Trạo, Thạch Thành, Thanh Hóa",
  "Hà Trung, Hà Trung, Thanh Hóa",
  "Hà Long, Hà Trung, Thanh Hóa",
  "Hà Vinh, Hà Trung, Thanh Hóa",
  "Hà Bắc, Hà Trung, Thanh Hóa",
  "Hoạt Giang, Hà Trung, Thanh Hóa",
  "Yên Dương, Hà Trung, Thanh Hóa",
  "Hà Giang, Hà Trung, Thanh Hóa",
  "Lĩnh Toại, Hà Trung, Thanh Hóa",
  "Hà Ngọc, Hà Trung, Thanh Hóa",
  "Yến Sơn, Hà Trung, Thanh Hóa",
  "Hà Sơn, Hà Trung, Thanh Hóa",
  "Hà Lĩnh, Hà Trung, Thanh Hóa",
  "Hà Đông, Hà Trung, Thanh Hóa",
  "Hà Tân, Hà Trung, Thanh Hóa",
  "Hà Tiến, Hà Trung, Thanh Hóa",
  "Hà Bình, Hà Trung, Thanh Hóa",
  "Hà Lai, Hà Trung, Thanh Hóa",
  "Hà Châu, Hà Trung, Thanh Hóa",
  "Hà Thái, Hà Trung, Thanh Hóa",
  "Hà Hải, Hà Trung, Thanh Hóa",
  "Vĩnh Lộc, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Quang, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Yên, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Tiến, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Long, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Phúc, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Hưng, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Hòa, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Hùng, Vĩnh Lộc, Thanh Hóa",
  "Minh Tân, Vĩnh Lộc, Thanh Hóa",
  "Ninh Khang, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh Thịnh, Vĩnh Lộc, Thanh Hóa",
  "Vĩnh An, Vĩnh Lộc, Thanh Hóa",
  "Thống Nhất, Yên Định, Thanh Hóa",
  "Yên Lâm, Yên Định, Thanh Hóa",
  "Yên Tâm, Yên Định, Thanh Hóa",
  "Yên Phú, Yên Định, Thanh Hóa",
  "Quí Lộc, Yên Định, Thanh Hóa",
  "Yên Thọ, Yên Định, Thanh Hóa",
  "Yên Trung, Yên Định, Thanh Hóa",
  "Yên Trường, Yên Định, Thanh Hóa",
  "Yên Phong, Yên Định, Thanh Hóa",
  "Yên Thái, Yên Định, Thanh Hóa",
  "Yên Hùng, Yên Định, Thanh Hóa",
  "Yên Thịnh, Yên Định, Thanh Hóa",
  "Yên Ninh, Yên Định, Thanh Hóa",
  "Yên Lạc, Yên Định, Thanh Hóa",
  "Định Tăng, Yên Định, Thanh Hóa",
  "Định Hòa, Yên Định, Thanh Hóa",
  "Định Thành, Yên Định, Thanh Hóa",
  "Định Công, Yên Định, Thanh Hóa",
  "Định Tân, Yên Định, Thanh Hóa",
  "Định Tiến, Yên Định, Thanh Hóa",
  "Định Long, Yên Định, Thanh Hóa",
  "Định Liên, Yên Định, Thanh Hóa",
  "Quán Lào, Yên Định, Thanh Hóa",
  "Định Hưng, Yên Định, Thanh Hóa",
  "Định Hải, Yên Định, Thanh Hóa",
  "Định Bình, Yên Định, Thanh Hóa",
  "Xuân Hồng, Thọ Xuân, Thanh Hóa",
  "Thọ Xuân, Thọ Xuân, Thanh Hóa",
  "Bắc Lương, Thọ Xuân, Thanh Hóa",
  "Nam Giang, Thọ Xuân, Thanh Hóa",
  "Xuân Phong, Thọ Xuân, Thanh Hóa",
  "Thọ Lộc, Thọ Xuân, Thanh Hóa",
  "Xuân Trường, Thọ Xuân, Thanh Hóa",
  "Xuân Hòa, Thọ Xuân, Thanh Hóa",
  "Thọ Hải, Thọ Xuân, Thanh Hóa",
  "Tây Hồ, Thọ Xuân, Thanh Hóa",
  "Xuân Giang, Thọ Xuân, Thanh Hóa",
  "Xuân Sinh, Thọ Xuân, Thanh Hóa",
  "Xuân Hưng, Thọ Xuân, Thanh Hóa",
  "Thọ Diên, Thọ Xuân, Thanh Hóa",
  "Thọ Lâm, Thọ Xuân, Thanh Hóa",
  "Thọ Xương, Thọ Xuân, Thanh Hóa",
  "Xuân Bái, Thọ Xuân, Thanh Hóa",
  "Xuân Phú, Thọ Xuân, Thanh Hóa",
  "Sao Vàng, Thọ Xuân, Thanh Hóa",
  "Lam Sơn, Thọ Xuân, Thanh Hóa",
  "Xuân Thiên, Thọ Xuân, Thanh Hóa",
  "Thuận Minh, Thọ Xuân, Thanh Hóa",
  "Thọ Lập, Thọ Xuân, Thanh Hóa",
  "Quảng Phú, Thọ Xuân, Thanh Hóa",
  "Xuân Tín, Thọ Xuân, Thanh Hóa",
  "Phú Xuân, Thọ Xuân, Thanh Hóa",
  "Xuân Lai, Thọ Xuân, Thanh Hóa",
  "Xuân Lập, Thọ Xuân, Thanh Hóa",
  "Xuân Minh, Thọ Xuân, Thanh Hóa",
  "Trường Xuân, Thọ Xuân, Thanh Hóa",
  "Bát Mọt, Thường Xuân, Thanh Hóa",
  "Yên Nhân, Thường Xuân, Thanh Hóa",
  "Xuân Lẹ, Thường Xuân, Thanh Hóa",
  "Vạn Xuân, Thường Xuân, Thanh Hóa",
  "Lương Sơn, Thường Xuân, Thanh Hóa",
  "Xuân Cao, Thường Xuân, Thanh Hóa",
  "Luận Thành, Thường Xuân, Thanh Hóa",
  "Luận Khê, Thường Xuân, Thanh Hóa",
  "Xuân Thắng, Thường Xuân, Thanh Hóa",
  "Xuân Lộc, Thường Xuân, Thanh Hóa",
  "Thường Xuân, Thường Xuân, Thanh Hóa",
  "Xuân Dương, Thường Xuân, Thanh Hóa",
  "Thọ Thanh, Thường Xuân, Thanh Hóa",
  "Ngọc Phụng, Thường Xuân, Thanh Hóa",
  "Xuân Chinh, Thường Xuân, Thanh Hóa",
  "Tân Thành, Thường Xuân, Thanh Hóa",
  "Triệu Sơn, Triệu Sơn, Thanh Hóa",
  "Thọ Sơn, Triệu Sơn, Thanh Hóa",
  "Thọ Bình, Triệu Sơn, Thanh Hóa",
  "Thọ Tiến, Triệu Sơn, Thanh Hóa",
  "Hợp Lý, Triệu Sơn, Thanh Hóa",
  "Hợp Tiến, Triệu Sơn, Thanh Hóa",
  "Hợp Thành, Triệu Sơn, Thanh Hóa",
  "Triệu Thành, Triệu Sơn, Thanh Hóa",
  "Hợp Thắng, Triệu Sơn, Thanh Hóa",
  "Minh Sơn, Triệu Sơn, Thanh Hóa",
  "Dân Lực, Triệu Sơn, Thanh Hóa",
  "Dân Lý, Triệu Sơn, Thanh Hóa",
  "Dân Quyền, Triệu Sơn, Thanh Hóa",
  "An Nông, Triệu Sơn, Thanh Hóa",
  "Văn Sơn, Triệu Sơn, Thanh Hóa",
  "Thái Hòa, Triệu Sơn, Thanh Hóa",
  "Nưa, Triệu Sơn, Thanh Hóa",
  "Đồng Lợi, Triệu Sơn, Thanh Hóa",
  "Đồng Tiến, Triệu Sơn, Thanh Hóa",
  "Đồng Thắng, Triệu Sơn, Thanh Hóa",
  "Tiến Nông, Triệu Sơn, Thanh Hóa",
  "Khuyến Nông, Triệu Sơn, Thanh Hóa",
  "Xuân Thịnh, Triệu Sơn, Thanh Hóa",
  "Xuân Lộc, Triệu Sơn, Thanh Hóa",
  "Thọ Dân, Triệu Sơn, Thanh Hóa",
  "Xuân Thọ, Triệu Sơn, Thanh Hóa",
  "Thọ Tân, Triệu Sơn, Thanh Hóa",
  "Thọ Ngọc, Triệu Sơn, Thanh Hóa",
  "Thọ Cường, Triệu Sơn, Thanh Hóa",
  "Thọ Phú, Triệu Sơn, Thanh Hóa",
  "Thọ Vực, Triệu Sơn, Thanh Hóa",
  "Thọ Thế, Triệu Sơn, Thanh Hóa",
  "Nông Trường, Triệu Sơn, Thanh Hóa",
  "Bình Sơn, Triệu Sơn, Thanh Hóa",
  "Thiệu Hóa, Thiệu Hóa, Thanh Hóa",
  "Thiệu Ngọc, Thiệu Hóa, Thanh Hóa",
  "Thiệu Vũ, Thiệu Hóa, Thanh Hóa",
  "Thiệu Phúc, Thiệu Hóa, Thanh Hóa",
  "Thiệu Tiến, Thiệu Hóa, Thanh Hóa",
  "Thiệu Công, Thiệu Hóa, Thanh Hóa",
  "Thiệu Phú, Thiệu Hóa, Thanh Hóa",
  "Thiệu Long, Thiệu Hóa, Thanh Hóa",
  "Thiệu Giang, Thiệu Hóa, Thanh Hóa",
  "Thiệu Duy, Thiệu Hóa, Thanh Hóa",
  "Thiệu Nguyên, Thiệu Hóa, Thanh Hóa",
  "Thiệu Hợp, Thiệu Hóa, Thanh Hóa",
  "Thiệu Thịnh, Thiệu Hóa, Thanh Hóa",
  "Thiệu Quang, Thiệu Hóa, Thanh Hóa",
  "Thiệu Thành, Thiệu Hóa, Thanh Hóa",
  "Thiệu Toán, Thiệu Hóa, Thanh Hóa",
  "Thiệu Chính, Thiệu Hóa, Thanh Hóa",
  "Thiệu Hòa, Thiệu Hóa, Thanh Hóa",
  "Minh Tâm, Thiệu Hóa, Thanh Hóa",
  "Thiệu Viên, Thiệu Hóa, Thanh Hóa",
  "Thiệu Lý, Thiệu Hóa, Thanh Hóa",
  "Thiệu Vận, Thiệu Hóa, Thanh Hóa",
  "Thiệu Trung, Thiệu Hóa, Thanh Hóa",
  "Tân Châu, Thiệu Hóa, Thanh Hóa",
  "Thiệu Giao, Thiệu Hóa, Thanh Hóa",
  "Bút Sơn, Hoằng Hóa, Thanh Hóa",
  "Hoằng Giang, Hoằng Hóa, Thanh Hóa",
  "Hoằng Xuân, Hoằng Hóa, Thanh Hóa",
  "Hoằng Phượng, Hoằng Hóa, Thanh Hóa",
  "Hoằng Phú, Hoằng Hóa, Thanh Hóa",
  "Hoằng Quỳ, Hoằng Hóa, Thanh Hóa",
  "Hoằng Kim, Hoằng Hóa, Thanh Hóa",
  "Hoằng Trung, Hoằng Hóa, Thanh Hóa",
  "Hoằng Trinh, Hoằng Hóa, Thanh Hóa",
  "Hoằng Sơn, Hoằng Hóa, Thanh Hóa",
  "Hoằng Cát, Hoằng Hóa, Thanh Hóa",
  "Hoằng Xuyên, Hoằng Hóa, Thanh Hóa",
  "Hoằng Quý, Hoằng Hóa, Thanh Hóa",
  "Hoằng Hợp, Hoằng Hóa, Thanh Hóa",
  "Hoằng Đức, Hoằng Hóa, Thanh Hóa",
  "Hoằng Hà, Hoằng Hóa, Thanh Hóa",
  "Hoằng Đạt, Hoằng Hóa, Thanh Hóa",
  "Hoằng Đạo, Hoằng Hóa, Thanh Hóa",
  "Hoằng Thắng, Hoằng Hóa, Thanh Hóa",
  "Hoằng Đồng, Hoằng Hóa, Thanh Hóa",
  "Hoằng Thái, Hoằng Hóa, Thanh Hóa",
  "Hoằng Thịnh, Hoằng Hóa, Thanh Hóa",
  "Hoằng Thành, Hoằng Hóa, Thanh Hóa",
  "Hoằng Lộc, Hoằng Hóa, Thanh Hóa",
  "Hoằng Trạch, Hoằng Hóa, Thanh Hóa",
  "Hoằng Phong, Hoằng Hóa, Thanh Hóa",
  "Hoằng Lưu, Hoằng Hóa, Thanh Hóa",
  "Hoằng Châu, Hoằng Hóa, Thanh Hóa",
  "Hoằng Tân, Hoằng Hóa, Thanh Hóa",
  "Hoằng Yến, Hoằng Hóa, Thanh Hóa",
  "Hoằng Tiến, Hoằng Hóa, Thanh Hóa",
  "Hoằng Hải, Hoằng Hóa, Thanh Hóa",
  "Hoằng Ngọc, Hoằng Hóa, Thanh Hóa",
  "Hoằng Đông, Hoằng Hóa, Thanh Hóa",
  "Hoằng Thanh, Hoằng Hóa, Thanh Hóa",
  "Hoằng Phụ, Hoằng Hóa, Thanh Hóa",
  "Hoằng Trường, Hoằng Hóa, Thanh Hóa",
  "Hậu Lộc, Hậu Lộc, Thanh Hóa",
  "Đồng Lộc, Hậu Lộc, Thanh Hóa",
  "Đại Lộc, Hậu Lộc, Thanh Hóa",
  "Triệu Lộc, Hậu Lộc, Thanh Hóa",
  "Tiến Lộc, Hậu Lộc, Thanh Hóa",
  "Lộc Sơn, Hậu Lộc, Thanh Hóa",
  "Cầu Lộc, Hậu Lộc, Thanh Hóa",
  "Thành Lộc, Hậu Lộc, Thanh Hóa",
  "Tuy Lộc, Hậu Lộc, Thanh Hóa",
  "Phong Lộc, Hậu Lộc, Thanh Hóa",
  "Mỹ Lộc, Hậu Lộc, Thanh Hóa",
  "Thuần Lộc, Hậu Lộc, Thanh Hóa",
  "Xuân Lộc, Hậu Lộc, Thanh Hóa",
  "Hoa Lộc, Hậu Lộc, Thanh Hóa",
  "Liên Lộc, Hậu Lộc, Thanh Hóa",
  "Quang Lộc, Hậu Lộc, Thanh Hóa",
  "Phú Lộc, Hậu Lộc, Thanh Hóa",
  "Hòa Lộc, Hậu Lộc, Thanh Hóa",
  "Minh Lộc, Hậu Lộc, Thanh Hóa",
  "Hưng Lộc, Hậu Lộc, Thanh Hóa",
  "Hải Lộc, Hậu Lộc, Thanh Hóa",
  "Đa Lộc, Hậu Lộc, Thanh Hóa",
  "Ngư Lộc, Hậu Lộc, Thanh Hóa",
  "Nga Sơn, Nga Sơn, Thanh Hóa",
  "Ba Đình, Nga Sơn, Thanh Hóa",
  "Nga Vịnh, Nga Sơn, Thanh Hóa",
  "Nga Văn, Nga Sơn, Thanh Hóa",
  "Nga Thiện, Nga Sơn, Thanh Hóa",
  "Nga Tiến, Nga Sơn, Thanh Hóa",
  "Nga Phượng, Nga Sơn, Thanh Hóa",
  "Nga Trung, Nga Sơn, Thanh Hóa",
  "Nga Bạch, Nga Sơn, Thanh Hóa",
  "Nga Thanh, Nga Sơn, Thanh Hóa",
  "Nga Yên, Nga Sơn, Thanh Hóa",
  "Nga Giáp, Nga Sơn, Thanh Hóa",
  "Nga Hải, Nga Sơn, Thanh Hóa",
  "Nga Thành, Nga Sơn, Thanh Hóa",
  "Nga An, Nga Sơn, Thanh Hóa",
  "Nga Phú, Nga Sơn, Thanh Hóa",
  "Nga Điền, Nga Sơn, Thanh Hóa",
  "Nga Tân, Nga Sơn, Thanh Hóa",
  "Nga Thủy, Nga Sơn, Thanh Hóa",
  "Nga Liên, Nga Sơn, Thanh Hóa",
  "Nga Thái, Nga Sơn, Thanh Hóa",
  "Nga Thạch, Nga Sơn, Thanh Hóa",
  "Nga Thắng, Nga Sơn, Thanh Hóa",
  "Nga Trường, Nga Sơn, Thanh Hóa",
  "Yên Cát, Như Xuân, Thanh Hóa",
  "Bãi Trành, Như Xuân, Thanh Hóa",
  "Xuân Hòa, Như Xuân, Thanh Hóa",
  "Xuân Bình, Như Xuân, Thanh Hóa",
  "Hóa Quỳ, Như Xuân, Thanh Hóa",
  "Cát Vân, Như Xuân, Thanh Hóa",
  "Cát Tân, Như Xuân, Thanh Hóa",
  "Tân Bình, Như Xuân, Thanh Hóa",
  "Bình Lương, Như Xuân, Thanh Hóa",
  "Thanh Quân, Như Xuân, Thanh Hóa",
  "Thanh Xuân, Như Xuân, Thanh Hóa",
  "Thanh Hòa, Như Xuân, Thanh Hóa",
  "Thanh Phong, Như Xuân, Thanh Hóa",
  "Thanh Lâm, Như Xuân, Thanh Hóa",
  "Thanh Sơn, Như Xuân, Thanh Hóa",
  "Thượng Ninh, Như Xuân, Thanh Hóa",
  "Bến Sung, Như Thanh, Thanh Hóa",
  "Cán Khê, Như Thanh, Thanh Hóa",
  "Xuân Du, Như Thanh, Thanh Hóa",
  "Phượng Nghi, Như Thanh, Thanh Hóa",
  "Mậu Lâm, Như Thanh, Thanh Hóa",
  "Xuân Khang, Như Thanh, Thanh Hóa",
  "Phú Nhuận, Như Thanh, Thanh Hóa",
  "Hải Long, Như Thanh, Thanh Hóa",
  "Xuân Thái, Như Thanh, Thanh Hóa",
  "Xuân Phúc, Như Thanh, Thanh Hóa",
  "Yên Thọ, Như Thanh, Thanh Hóa",
  "Yên Lạc, Như Thanh, Thanh Hóa",
  "Thanh Tân, Như Thanh, Thanh Hóa",
  "Thanh Kỳ, Như Thanh, Thanh Hóa",
  "Nông Cống, Nông Cống, Thanh Hóa",
  "Tân Phúc, Nông Cống, Thanh Hóa",
  "Tân Thọ, Nông Cống, Thanh Hóa",
  "Hoàng Sơn, Nông Cống, Thanh Hóa",
  "Tân Khang, Nông Cống, Thanh Hóa",
  "Hoàng Giang, Nông Cống, Thanh Hóa",
  "Trung Chính, Nông Cống, Thanh Hóa",
  "Trung Thành, Nông Cống, Thanh Hóa",
  "Tế Thắng, Nông Cống, Thanh Hóa",
  "Tế Lợi, Nông Cống, Thanh Hóa",
  "Tế Nông, Nông Cống, Thanh Hóa",
  "Minh Nghĩa, Nông Cống, Thanh Hóa",
  "Minh Khôi, Nông Cống, Thanh Hóa",
  "Vạn Hòa, Nông Cống, Thanh Hóa",
  "Trường Trung, Nông Cống, Thanh Hóa",
  "Vạn Thắng, Nông Cống, Thanh Hóa",
  "Trường Giang, Nông Cống, Thanh Hóa",
  "Vạn Thiện, Nông Cống, Thanh Hóa",
  "Thăng Long, Nông Cống, Thanh Hóa",
  "Trường Minh, Nông Cống, Thanh Hóa",
  "Trường Sơn, Nông Cống, Thanh Hóa",
  "Thăng Bình, Nông Cống, Thanh Hóa",
  "Công Liêm, Nông Cống, Thanh Hóa",
  "Tượng Văn, Nông Cống, Thanh Hóa",
  "Thăng Thọ, Nông Cống, Thanh Hóa",
  "Tượng Lĩnh, Nông Cống, Thanh Hóa",
  "Tượng Sơn, Nông Cống, Thanh Hóa",
  "Công Chính, Nông Cống, Thanh Hóa",
  "Yên Mỹ, Nông Cống, Thanh Hóa",
  "Rừng Thông, Đông Sơn, Thanh Hóa",
  "Đông Hoàng, Đông Sơn, Thanh Hóa",
  "Đông Ninh, Đông Sơn, Thanh Hóa",
  "Đông Hòa, Đông Sơn, Thanh Hóa",
  "Đông Yên, Đông Sơn, Thanh Hóa",
  "Đông Minh, Đông Sơn, Thanh Hóa",
  "Đông Thanh, Đông Sơn, Thanh Hóa",
  "Đông Tiến, Đông Sơn, Thanh Hóa",
  "Đông Khê, Đông Sơn, Thanh Hóa",
  "Đông Thịnh, Đông Sơn, Thanh Hóa",
  "Đông Văn, Đông Sơn, Thanh Hóa",
  "Đông Phú, Đông Sơn, Thanh Hóa",
  "Đông Nam, Đông Sơn, Thanh Hóa",
  "Đông Quang, Đông Sơn, Thanh Hóa",
  "Tân Phong, Quảng Xương, Thanh Hóa",
  "Quảng Trạch, Quảng Xương, Thanh Hóa",
  "Quảng Đức, Quảng Xương, Thanh Hóa",
  "Quảng Định, Quảng Xương, Thanh Hóa",
  "Quảng Nhân, Quảng Xương, Thanh Hóa",
  "Quảng Ninh, Quảng Xương, Thanh Hóa",
  "Quảng Bình, Quảng Xương, Thanh Hóa",
  "Quảng Hợp, Quảng Xương, Thanh Hóa",
  "Quảng Văn, Quảng Xương, Thanh Hóa",
  "Quảng Long, Quảng Xương, Thanh Hóa",
  "Quảng Yên, Quảng Xương, Thanh Hóa",
  "Quảng Hòa, Quảng Xương, Thanh Hóa",
  "Quảng Khê, Quảng Xương, Thanh Hóa",
  "Quảng Trung, Quảng Xương, Thanh Hóa",
  "Quảng Chính, Quảng Xương, Thanh Hóa",
  "Quảng Ngọc, Quảng Xương, Thanh Hóa",
  "Quảng Trường, Quảng Xương, Thanh Hóa",
  "Quảng Phúc, Quảng Xương, Thanh Hóa",
  "Quảng Giao, Quảng Xương, Thanh Hóa",
  "Quảng Hải, Quảng Xương, Thanh Hóa",
  "Quảng Lưu, Quảng Xương, Thanh Hóa",
  "Quảng Lộc, Quảng Xương, Thanh Hóa",
  "Tiên Trang, Quảng Xương, Thanh Hóa",
  "Quảng Nham, Quảng Xương, Thanh Hóa",
  "Quảng Thạch, Quảng Xương, Thanh Hóa",
  "Quảng Thái, Quảng Xương, Thanh Hóa",
  "Tĩnh Gia, Tĩnh Gia, Thanh Hóa",
  "Hải Châu, Tĩnh Gia, Thanh Hóa",
  "Thanh Thủy, Tĩnh Gia, Thanh Hóa",
  "Thanh Sơn, Tĩnh Gia, Thanh Hóa",
  "Hải Ninh, Tĩnh Gia, Thanh Hóa",
  "Anh Sơn, Tĩnh Gia, Thanh Hóa",
  "Ngọc Lĩnh, Tĩnh Gia, Thanh Hóa",
  "Hải An, Tĩnh Gia, Thanh Hóa",
  "Các Sơn, Tĩnh Gia, Thanh Hóa",
  "Tân Dân, Tĩnh Gia, Thanh Hóa",
  "Hải Lĩnh, Tĩnh Gia, Thanh Hóa",
  "Định Hải, Tĩnh Gia, Thanh Hóa",
  "Phú Sơn, Tĩnh Gia, Thanh Hóa",
  "Ninh Hải, Tĩnh Gia, Thanh Hóa",
  "Nguyên Bình, Tĩnh Gia, Thanh Hóa",
  "Hải Nhân, Tĩnh Gia, Thanh Hóa",
  "Bình Minh, Tĩnh Gia, Thanh Hóa",
  "Hải Thanh, Tĩnh Gia, Thanh Hóa",
  "Phú Lâm, Tĩnh Gia, Thanh Hóa",
  "Xuân Lâm, Tĩnh Gia, Thanh Hóa",
  "Trúc Lâm, Tĩnh Gia, Thanh Hóa",
  "Hải Bình, Tĩnh Gia, Thanh Hóa",
  "Tân Trường, Tĩnh Gia, Thanh Hóa",
  "Tùng Lâm, Tĩnh Gia, Thanh Hóa",
  "Tĩnh Hải, Tĩnh Gia, Thanh Hóa",
  "Mai Lâm, Tĩnh Gia, Thanh Hóa",
  "Trường Lâm, Tĩnh Gia, Thanh Hóa",
  "Hải Yến, Tĩnh Gia, Thanh Hóa",
  "Hải Thượng, Tĩnh Gia, Thanh Hóa",
  "Nghi Sơn, Tĩnh Gia, Thanh Hóa",
  "Hải Hà, Tĩnh Gia, Thanh Hóa",
  "Đông Vĩnh, Vinh, Nghệ An",
  "Hà Huy Tập, Vinh, Nghệ An",
  "Lê Lợi, Vinh, Nghệ An",
  "Quán Bàu, Vinh, Nghệ An",
  "Hưng Bình, Vinh, Nghệ An",
  "Hưng Phúc, Vinh, Nghệ An",
  "Hưng Dũng, Vinh, Nghệ An",
  "Cửa Nam, Vinh, Nghệ An",
  "Quang Trung, Vinh, Nghệ An",
  "Đội Cung, Vinh, Nghệ An",
  "Lê Mao, Vinh, Nghệ An",
  "Trường Thi, Vinh, Nghệ An",
  "Bến Thủy, Vinh, Nghệ An",
  "Hồng Sơn, Vinh, Nghệ An",
  "Trung Đô, Vinh, Nghệ An",
  "Nghi Phú, Vinh, Nghệ An",
  "Hưng Đông, Vinh, Nghệ An",
  "Hưng Lộc, Vinh, Nghệ An",
  "Hưng Hòa, Vinh, Nghệ An",
  "Vinh Tân, Vinh, Nghệ An",
  "Nghi Liên, Vinh, Nghệ An",
  "Nghi Ân, Vinh, Nghệ An",
  "Nghi Kim, Vinh, Nghệ An",
  "Nghi Đức, Vinh, Nghệ An",
  "Hưng Chính, Vinh, Nghệ An",
  "Nghi Thuỷ, Cửa Lò, Nghệ An",
  "Nghi Tân, Cửa Lò, Nghệ An",
  "Thu Thuỷ, Cửa Lò, Nghệ An",
  "Nghi Hòa, Cửa Lò, Nghệ An",
  "Nghi Hải, Cửa Lò, Nghệ An",
  "Nghi Hương, Cửa Lò, Nghệ An",
  "Nghi Thu, Cửa Lò, Nghệ An",
  "Hoà Hiếu, Thái Hoà, Nghệ An",
  "Quang Phong, Thái Hoà, Nghệ An",
  "Quang Tiến, Thái Hoà, Nghệ An",
  "Long Sơn, Thái Hoà, Nghệ An",
  "Nghĩa Tiến, Thái Hoà, Nghệ An",
  "Nghĩa Mỹ, Thái Hoà, Nghệ An",
  "Tây Hiếu, Thái Hoà, Nghệ An",
  "Nghĩa Thuận, Thái Hoà, Nghệ An",
  "Đông Hiếu, Thái Hoà, Nghệ An",
  "Kim Sơn, Quế Phong, Nghệ An",
  "Thông Thụ, Quế Phong, Nghệ An",
  "Đồng Văn, Quế Phong, Nghệ An",
  "Hạnh Dịch, Quế Phong, Nghệ An",
  "Tiền Phong, Quế Phong, Nghệ An",
  "Nậm Giải, Quế Phong, Nghệ An",
  "Tri Lễ, Quế Phong, Nghệ An",
  "Châu Kim, Quế Phong, Nghệ An",
  "Mường Nọc, Quế Phong, Nghệ An",
  "Châu Thôn, Quế Phong, Nghệ An",
  "Nậm Nhoóng, Quế Phong, Nghệ An",
  "Quang Phong, Quế Phong, Nghệ An",
  "Căm Muộn, Quế Phong, Nghệ An",
  "Tân Lạc, Quỳ Châu, Nghệ An",
  "Châu Bính, Quỳ Châu, Nghệ An",
  "Châu Thuận, Quỳ Châu, Nghệ An",
  "Châu Hội, Quỳ Châu, Nghệ An",
  "Châu Nga, Quỳ Châu, Nghệ An",
  "Châu Tiến, Quỳ Châu, Nghệ An",
  "Châu Hạnh, Quỳ Châu, Nghệ An",
  "Châu Thắng, Quỳ Châu, Nghệ An",
  "Châu Phong, Quỳ Châu, Nghệ An",
  "Châu Bình, Quỳ Châu, Nghệ An",
  "Châu Hoàn, Quỳ Châu, Nghệ An",
  "Diên Lãm, Quỳ Châu, Nghệ An",
  "Mường Xén, Kỳ Sơn, Nghệ An",
  "Mỹ Lý, Kỳ Sơn, Nghệ An",
  "Bắc Lý, Kỳ Sơn, Nghệ An",
  "Keng Đu, Kỳ Sơn, Nghệ An",
  "Đoọc Mạy, Kỳ Sơn, Nghệ An",
  "Huồi Tụ, Kỳ Sơn, Nghệ An",
  "Mường Lống, Kỳ Sơn, Nghệ An",
  "Na Loi, Kỳ Sơn, Nghệ An",
  "Nậm Cắn, Kỳ Sơn, Nghệ An",
  "Bảo Nam, Kỳ Sơn, Nghệ An",
  "Phà Đánh, Kỳ Sơn, Nghệ An",
  "Bảo Thắng, Kỳ Sơn, Nghệ An",
  "Hữu Lập, Kỳ Sơn, Nghệ An",
  "Tà Cạ, Kỳ Sơn, Nghệ An",
  "Chiêu Lưu, Kỳ Sơn, Nghệ An",
  "Mường Típ, Kỳ Sơn, Nghệ An",
  "Hữu Kiệm, Kỳ Sơn, Nghệ An",
  "Tây Sơn, Kỳ Sơn, Nghệ An",
  "Mường Ải, Kỳ Sơn, Nghệ An",
  "Na Ngoi, Kỳ Sơn, Nghệ An",
  "Nậm Càn, Kỳ Sơn, Nghệ An",
  "Thạch Giám, Tương Dương, Nghệ An",
  "Mai Sơn, Tương Dương, Nghệ An",
  "Nhôn Mai, Tương Dương, Nghệ An",
  "Hữu Khuông, Tương Dương, Nghệ An",
  "Yên Tĩnh, Tương Dương, Nghệ An",
  "Nga My, Tương Dương, Nghệ An",
  "Xiêng My, Tương Dương, Nghệ An",
  "Lưỡng Minh, Tương Dương, Nghệ An",
  "Yên Hòa, Tương Dương, Nghệ An",
  "Yên Na, Tương Dương, Nghệ An",
  "Lưu Kiền, Tương Dương, Nghệ An",
  "Xá Lượng, Tương Dương, Nghệ An",
  "Tam Thái, Tương Dương, Nghệ An",
  "Tam Đình, Tương Dương, Nghệ An",
  "Yên Thắng, Tương Dương, Nghệ An",
  "Tam Quang, Tương Dương, Nghệ An",
  "Tam Hợp, Tương Dương, Nghệ An",
  "Nghĩa Đàn, Nghĩa Đàn, Nghệ An",
  "Nghĩa Mai, Nghĩa Đàn, Nghệ An",
  "Nghĩa Yên, Nghĩa Đàn, Nghệ An",
  "Nghĩa Lạc, Nghĩa Đàn, Nghệ An",
  "Nghĩa Lâm, Nghĩa Đàn, Nghệ An",
  "Nghĩa Sơn, Nghĩa Đàn, Nghệ An",
  "Nghĩa Lợi, Nghĩa Đàn, Nghệ An",
  "Nghĩa Bình, Nghĩa Đàn, Nghệ An",
  "Nghĩa Thọ, Nghĩa Đàn, Nghệ An",
  "Nghĩa Minh, Nghĩa Đàn, Nghệ An",
  "Nghĩa Phú, Nghĩa Đàn, Nghệ An",
  "Nghĩa Hưng, Nghĩa Đàn, Nghệ An",
  "Nghĩa Hồng, Nghĩa Đàn, Nghệ An",
  "Nghĩa Thịnh, Nghĩa Đàn, Nghệ An",
  "Nghĩa Trung, Nghĩa Đàn, Nghệ An",
  "Nghĩa Hội, Nghĩa Đàn, Nghệ An",
  "Nghĩa Thành, Nghĩa Đàn, Nghệ An",
  "Nghĩa Hiếu, Nghĩa Đàn, Nghệ An",
  "Nghĩa Đức, Nghĩa Đàn, Nghệ An",
  "Nghĩa An, Nghĩa Đàn, Nghệ An",
  "Nghĩa Long, Nghĩa Đàn, Nghệ An",
  "Nghĩa Lộc, Nghĩa Đàn, Nghệ An",
  "Nghĩa Khánh, Nghĩa Đàn, Nghệ An",
  "Quỳ Hợp, Quỳ Hợp, Nghệ An",
  "Yên Hợp, Quỳ Hợp, Nghệ An",
  "Châu Tiến, Quỳ Hợp, Nghệ An",
  "Châu Hồng, Quỳ Hợp, Nghệ An",
  "Đồng Hợp, Quỳ Hợp, Nghệ An",
  "Châu Thành, Quỳ Hợp, Nghệ An",
  "Liên Hợp, Quỳ Hợp, Nghệ An",
  "Châu Lộc, Quỳ Hợp, Nghệ An",
  "Tam Hợp, Quỳ Hợp, Nghệ An",
  "Châu Cường, Quỳ Hợp, Nghệ An",
  "Châu Quang, Quỳ Hợp, Nghệ An",
  "Thọ Hợp, Quỳ Hợp, Nghệ An",
  "Minh Hợp, Quỳ Hợp, Nghệ An",
  "Nghĩa Xuân, Quỳ Hợp, Nghệ An",
  "Châu Thái, Quỳ Hợp, Nghệ An",
  "Châu Đình, Quỳ Hợp, Nghệ An",
  "Văn Lợi, Quỳ Hợp, Nghệ An",
  "Nam Sơn, Quỳ Hợp, Nghệ An",
  "Châu Lý, Quỳ Hợp, Nghệ An",
  "Hạ Sơn, Quỳ Hợp, Nghệ An",
  "Bắc Sơn, Quỳ Hợp, Nghệ An",
  "Cầu Giát, Quỳnh Lưu, Nghệ An",
  "Quỳnh Thắng, Quỳnh Lưu, Nghệ An",
  "Quỳnh Tân, Quỳnh Lưu, Nghệ An",
  "Quỳnh Châu, Quỳnh Lưu, Nghệ An",
  "Tân Sơn, Quỳnh Lưu, Nghệ An",
  "Quỳnh Văn, Quỳnh Lưu, Nghệ An",
  "Ngọc Sơn, Quỳnh Lưu, Nghệ An",
  "Quỳnh Tam, Quỳnh Lưu, Nghệ An",
  "Quỳnh Hoa, Quỳnh Lưu, Nghệ An",
  "Quỳnh Thạch, Quỳnh Lưu, Nghệ An",
  "Quỳnh Bảng, Quỳnh Lưu, Nghệ An",
  "Quỳnh Mỹ, Quỳnh Lưu, Nghệ An",
  "Quỳnh Thanh, Quỳnh Lưu, Nghệ An",
  "Quỳnh Hậu, Quỳnh Lưu, Nghệ An",
  "Quỳnh Lâm, Quỳnh Lưu, Nghệ An",
  "Quỳnh Đôi, Quỳnh Lưu, Nghệ An",
  "Quỳnh Lương, Quỳnh Lưu, Nghệ An",
  "Quỳnh Hồng, Quỳnh Lưu, Nghệ An",
  "Quỳnh Yên, Quỳnh Lưu, Nghệ An",
  "Quỳnh Bá, Quỳnh Lưu, Nghệ An",
  "Quỳnh Minh, Quỳnh Lưu, Nghệ An",
  "Quỳnh Diễn, Quỳnh Lưu, Nghệ An",
  "Quỳnh Hưng, Quỳnh Lưu, Nghệ An",
  "Quỳnh Giang, Quỳnh Lưu, Nghệ An",
  "Quỳnh Ngọc, Quỳnh Lưu, Nghệ An",
  "Quỳnh Nghĩa, Quỳnh Lưu, Nghệ An",
  "An Hòa, Quỳnh Lưu, Nghệ An",
  "Tiến Thủy, Quỳnh Lưu, Nghệ An",
  "Sơn Hải, Quỳnh Lưu, Nghệ An",
  "Quỳnh Thọ, Quỳnh Lưu, Nghệ An",
  "Quỳnh Thuận, Quỳnh Lưu, Nghệ An",
  "Quỳnh Long, Quỳnh Lưu, Nghệ An",
  "Tân Thắng, Quỳnh Lưu, Nghệ An",
  "Con Cuông, Con Cuông, Nghệ An",
  "Bình Chuẩn, Con Cuông, Nghệ An",
  "Lạng Khê, Con Cuông, Nghệ An",
  "Cam Lâm, Con Cuông, Nghệ An",
  "Thạch Ngàn, Con Cuông, Nghệ An",
  "Đôn Phục, Con Cuông, Nghệ An",
  "Mậu Đức, Con Cuông, Nghệ An",
  "Châu Khê, Con Cuông, Nghệ An",
  "Chi Khê, Con Cuông, Nghệ An",
  "Bồng Khê, Con Cuông, Nghệ An",
  "Yên Khê, Con Cuông, Nghệ An",
  "Lục Dạ, Con Cuông, Nghệ An",
  "Môn Sơn, Con Cuông, Nghệ An",
  "Tân Kỳ, Tân Kỳ, Nghệ An",
  "Tân Hợp, Tân Kỳ, Nghệ An",
  "Tân Phú, Tân Kỳ, Nghệ An",
  "Tân Xuân, Tân Kỳ, Nghệ An",
  "Giai Xuân, Tân Kỳ, Nghệ An",
  "Nghĩa Bình, Tân Kỳ, Nghệ An",
  "Nghĩa Đồng, Tân Kỳ, Nghệ An",
  "Đồng Văn, Tân Kỳ, Nghệ An",
  "Nghĩa Thái, Tân Kỳ, Nghệ An",
  "Nghĩa Hợp, Tân Kỳ, Nghệ An",
  "Nghĩa Hoàn, Tân Kỳ, Nghệ An",
  "Nghĩa Phúc, Tân Kỳ, Nghệ An",
  "Tiên Kỳ, Tân Kỳ, Nghệ An",
  "Tân An, Tân Kỳ, Nghệ An",
  "Nghĩa Dũng, Tân Kỳ, Nghệ An",
  "Tân Long, Tân Kỳ, Nghệ An",
  "Kỳ Sơn, Tân Kỳ, Nghệ An",
  "Hương Sơn, Tân Kỳ, Nghệ An",
  "Kỳ Tân, Tân Kỳ, Nghệ An",
  "Phú Sơn, Tân Kỳ, Nghệ An",
  "Tân Hương, Tân Kỳ, Nghệ An",
  "Nghĩa Hành, Tân Kỳ, Nghệ An",
  "Anh Sơn, Anh Sơn, Nghệ An",
  "Thọ Sơn, Anh Sơn, Nghệ An",
  "Thành Sơn, Anh Sơn, Nghệ An",
  "Bình Sơn, Anh Sơn, Nghệ An",
  "Tam Sơn, Anh Sơn, Nghệ An",
  "Đỉnh Sơn, Anh Sơn, Nghệ An",
  "Hùng Sơn, Anh Sơn, Nghệ An",
  "Cẩm Sơn, Anh Sơn, Nghệ An",
  "Đức Sơn, Anh Sơn, Nghệ An",
  "Tường Sơn, Anh Sơn, Nghệ An",
  "Hoa Sơn, Anh Sơn, Nghệ An",
  "Tào Sơn, Anh Sơn, Nghệ An",
  "Vĩnh Sơn, Anh Sơn, Nghệ An",
  "Lạng Sơn, Anh Sơn, Nghệ An",
  "Hội Sơn, Anh Sơn, Nghệ An",
  "Thạch Sơn, Anh Sơn, Nghệ An",
  "Phúc Sơn, Anh Sơn, Nghệ An",
  "Long Sơn, Anh Sơn, Nghệ An",
  "Khai Sơn, Anh Sơn, Nghệ An",
  "Lĩnh Sơn, Anh Sơn, Nghệ An",
  "Cao Sơn, Anh Sơn, Nghệ An",
  "Diễn Châu, Diễn Châu, Nghệ An",
  "Diễn Lâm, Diễn Châu, Nghệ An",
  "Diễn Đoài, Diễn Châu, Nghệ An",
  "Diễn Trường, Diễn Châu, Nghệ An",
  "Diễn Yên, Diễn Châu, Nghệ An",
  "Diễn Hoàng, Diễn Châu, Nghệ An",
  "Diễn Hùng, Diễn Châu, Nghệ An",
  "Diễn Mỹ, Diễn Châu, Nghệ An",
  "Diễn Hồng, Diễn Châu, Nghệ An",
  "Diễn Phong, Diễn Châu, Nghệ An",
  "Diễn Hải, Diễn Châu, Nghệ An",
  "Diễn Tháp, Diễn Châu, Nghệ An",
  "Diễn Liên, Diễn Châu, Nghệ An",
  "Diễn Vạn, Diễn Châu, Nghệ An",
  "Diễn Kim, Diễn Châu, Nghệ An",
  "Diễn Kỷ, Diễn Châu, Nghệ An",
  "Diễn Xuân, Diễn Châu, Nghệ An",
  "Diễn Thái, Diễn Châu, Nghệ An",
  "Diễn Đồng, Diễn Châu, Nghệ An",
  "Diễn Bích, Diễn Châu, Nghệ An",
  "Diễn Hạnh, Diễn Châu, Nghệ An",
  "Diễn Ngọc, Diễn Châu, Nghệ An",
  "Diễn Quảng, Diễn Châu, Nghệ An",
  "Diễn Nguyên, Diễn Châu, Nghệ An",
  "Diễn Hoa, Diễn Châu, Nghệ An",
  "Diễn Thành, Diễn Châu, Nghệ An",
  "Diễn Phúc, Diễn Châu, Nghệ An",
  "Diễn Cát, Diễn Châu, Nghệ An",
  "Diễn Thịnh, Diễn Châu, Nghệ An",
  "Diễn Tân, Diễn Châu, Nghệ An",
  "Minh Châu, Diễn Châu, Nghệ An",
  "Diễn Thọ, Diễn Châu, Nghệ An",
  "Diễn Lợi, Diễn Châu, Nghệ An",
  "Diễn Lộc, Diễn Châu, Nghệ An",
  "Diễn Trung, Diễn Châu, Nghệ An",
  "Diễn An, Diễn Châu, Nghệ An",
  "Diễn Phú, Diễn Châu, Nghệ An",
  "Yên Thành, Yên Thành, Nghệ An",
  "Mã Thành, Yên Thành, Nghệ An",
  "Tiến Thành, Yên Thành, Nghệ An",
  "Lăng Thành, Yên Thành, Nghệ An",
  "Tân Thành, Yên Thành, Nghệ An",
  "Đức Thành, Yên Thành, Nghệ An",
  "Kim Thành, Yên Thành, Nghệ An",
  "Hậu Thành, Yên Thành, Nghệ An",
  "Hùng Thành, Yên Thành, Nghệ An",
  "Đô Thành, Yên Thành, Nghệ An",
  "Thọ Thành, Yên Thành, Nghệ An",
  "Quang Thành, Yên Thành, Nghệ An",
  "Tây Thành, Yên Thành, Nghệ An",
  "Phúc Thành, Yên Thành, Nghệ An",
  "Hồng Thành, Yên Thành, Nghệ An",
  "Đồng Thành, Yên Thành, Nghệ An",
  "Phú Thành, Yên Thành, Nghệ An",
  "Hoa Thành, Yên Thành, Nghệ An",
  "Tăng Thành, Yên Thành, Nghệ An",
  "Văn Thành, Yên Thành, Nghệ An",
  "Thịnh Thành, Yên Thành, Nghệ An",
  "Hợp Thành, Yên Thành, Nghệ An",
  "Xuân Thành, Yên Thành, Nghệ An",
  "Bắc Thành, Yên Thành, Nghệ An",
  "Nhân Thành, Yên Thành, Nghệ An",
  "Trung Thành, Yên Thành, Nghệ An",
  "Long Thành, Yên Thành, Nghệ An",
  "Minh Thành, Yên Thành, Nghệ An",
  "Nam Thành, Yên Thành, Nghệ An",
  "Vĩnh Thành, Yên Thành, Nghệ An",
  "Lý Thành, Yên Thành, Nghệ An",
  "Khánh Thành, Yên Thành, Nghệ An",
  "Viên Thành, Yên Thành, Nghệ An",
  "Đại Thành, Yên Thành, Nghệ An",
  "Liên Thành, Yên Thành, Nghệ An",
  "Bảo Thành, Yên Thành, Nghệ An",
  "Mỹ Thành, Yên Thành, Nghệ An",
  "Công Thành, Yên Thành, Nghệ An",
  "Sơn Thành, Yên Thành, Nghệ An",
  "Đô Lương, Đô Lương, Nghệ An",
  "Giang Sơn Đông, Đô Lương, Nghệ An",
  "Giang Sơn Tây, Đô Lương, Nghệ An",
  "Lam Sơn, Đô Lương, Nghệ An",
  "Bồi Sơn, Đô Lương, Nghệ An",
  "Hồng Sơn, Đô Lương, Nghệ An",
  "Bài Sơn, Đô Lương, Nghệ An",
  "Ngọc Sơn, Đô Lương, Nghệ An",
  "Bắc Sơn, Đô Lương, Nghệ An",
  "Tràng Sơn, Đô Lương, Nghệ An",
  "Thượng Sơn, Đô Lương, Nghệ An",
  "Hòa Sơn, Đô Lương, Nghệ An",
  "Đặng Sơn, Đô Lương, Nghệ An",
  "Đông Sơn, Đô Lương, Nghệ An",
  "Nam Sơn, Đô Lương, Nghệ An",
  "Lưu Sơn, Đô Lương, Nghệ An",
  "Yên Sơn, Đô Lương, Nghệ An",
  "Văn Sơn, Đô Lương, Nghệ An",
  "Đà Sơn, Đô Lương, Nghệ An",
  "Lạc Sơn, Đô Lương, Nghệ An",
  "Tân Sơn, Đô Lương, Nghệ An",
  "Thái Sơn, Đô Lương, Nghệ An",
  "Quang Sơn, Đô Lương, Nghệ An",
  "Thịnh Sơn, Đô Lương, Nghệ An",
  "Trung Sơn, Đô Lương, Nghệ An",
  "Xuân Sơn, Đô Lương, Nghệ An",
  "Minh Sơn, Đô Lương, Nghệ An",
  "Thuận Sơn, Đô Lương, Nghệ An",
  "Nhân Sơn, Đô Lương, Nghệ An",
  "Hiến Sơn, Đô Lương, Nghệ An",
  "Mỹ Sơn, Đô Lương, Nghệ An",
  "Trù Sơn, Đô Lương, Nghệ An",
  "Đại Sơn, Đô Lương, Nghệ An",
  "Thanh Chương, Thanh Chương, Nghệ An",
  "Cát Văn, Thanh Chương, Nghệ An",
  "Thanh Nho, Thanh Chương, Nghệ An",
  "Hạnh Lâm, Thanh Chương, Nghệ An",
  "Thanh Sơn, Thanh Chương, Nghệ An",
  "Thanh Hòa, Thanh Chương, Nghệ An",
  "Phong Thịnh, Thanh Chương, Nghệ An",
  "Thanh Phong, Thanh Chương, Nghệ An",
  "Thanh Mỹ, Thanh Chương, Nghệ An",
  "Thanh Tiên, Thanh Chương, Nghệ An",
  "Thanh Liên, Thanh Chương, Nghệ An",
  "Đại Đồng, Thanh Chương, Nghệ An",
  "Thanh Đồng, Thanh Chương, Nghệ An",
  "Thanh Ngọc, Thanh Chương, Nghệ An",
  "Thanh Hương, Thanh Chương, Nghệ An",
  "Ngọc Lâm, Thanh Chương, Nghệ An",
  "Thanh Lĩnh, Thanh Chương, Nghệ An",
  "Đồng Văn, Thanh Chương, Nghệ An",
  "Ngọc Sơn, Thanh Chương, Nghệ An",
  "Thanh Thịnh, Thanh Chương, Nghệ An",
  "Thanh An, Thanh Chương, Nghệ An",
  "Thanh Chi, Thanh Chương, Nghệ An",
  "Xuân Tường, Thanh Chương, Nghệ An",
  "Thanh Dương, Thanh Chương, Nghệ An",
  "Thanh Lương, Thanh Chương, Nghệ An",
  "Thanh Khê, Thanh Chương, Nghệ An",
  "Võ Liệt, Thanh Chương, Nghệ An",
  "Thanh Long, Thanh Chương, Nghệ An",
  "Thanh Thủy, Thanh Chương, Nghệ An",
  "Thanh Khai, Thanh Chương, Nghệ An",
  "Thanh Yên, Thanh Chương, Nghệ An",
  "Thanh Hà, Thanh Chương, Nghệ An",
  "Thanh Giang, Thanh Chương, Nghệ An",
  "Thanh Tùng, Thanh Chương, Nghệ An",
  "Thanh Lâm, Thanh Chương, Nghệ An",
  "Thanh Mai, Thanh Chương, Nghệ An",
  "Thanh Xuân, Thanh Chương, Nghệ An",
  "Thanh Đức, Thanh Chương, Nghệ An",
  "Quán Hành, Nghi Lộc, Nghệ An",
  "Nghi Văn, Nghi Lộc, Nghệ An",
  "Nghi Yên, Nghi Lộc, Nghệ An",
  "Nghi Tiến, Nghi Lộc, Nghệ An",
  "Nghi Hưng, Nghi Lộc, Nghệ An",
  "Nghi Đồng, Nghi Lộc, Nghệ An",
  "Nghi Thiết, Nghi Lộc, Nghệ An",
  "Nghi Lâm, Nghi Lộc, Nghệ An",
  "Nghi Quang, Nghi Lộc, Nghệ An",
  "Nghi Kiều, Nghi Lộc, Nghệ An",
  "Nghi Mỹ, Nghi Lộc, Nghệ An",
  "Nghi Phương, Nghi Lộc, Nghệ An",
  "Nghi Thuận, Nghi Lộc, Nghệ An",
  "Nghi Long, Nghi Lộc, Nghệ An",
  "Nghi Xá, Nghi Lộc, Nghệ An",
  "Nghi Hoa, Nghi Lộc, Nghệ An",
  "Khánh Hợp, Nghi Lộc, Nghệ An",
  "Nghi Thịnh, Nghi Lộc, Nghệ An",
  "Nghi Công Bắc, Nghi Lộc, Nghệ An",
  "Nghi Công Nam, Nghi Lộc, Nghệ An",
  "Nghi Thạch, Nghi Lộc, Nghệ An",
  "Nghi Trung, Nghi Lộc, Nghệ An",
  "Nghi Trường, Nghi Lộc, Nghệ An",
  "Nghi Diên, Nghi Lộc, Nghệ An",
  "Nghi Phong, Nghi Lộc, Nghệ An",
  "Nghi Xuân, Nghi Lộc, Nghệ An",
  "Nghi Vạn, Nghi Lộc, Nghệ An",
  "Phúc Thọ, Nghi Lộc, Nghệ An",
  "Nghi Thái, Nghi Lộc, Nghệ An",
  "Nam Hưng, Nam Đàn, Nghệ An",
  "Nam Nghĩa, Nam Đàn, Nghệ An",
  "Nam Thanh, Nam Đàn, Nghệ An",
  "Nam Anh, Nam Đàn, Nghệ An",
  "Nam Xuân, Nam Đàn, Nghệ An",
  "Nam Thái, Nam Đàn, Nghệ An",
  "Nam Đàn, Nam Đàn, Nghệ An",
  "Nam Lĩnh, Nam Đàn, Nghệ An",
  "Nam Giang, Nam Đàn, Nghệ An",
  "Xuân Hòa, Nam Đàn, Nghệ An",
  "Hùng Tiến, Nam Đàn, Nghệ An",
  "Thượng Tân Lộc, Nam Đàn, Nghệ An",
  "Kim Liên, Nam Đàn, Nghệ An",
  "Hồng Long, Nam Đàn, Nghệ An",
  "Xuân Lâm, Nam Đàn, Nghệ An",
  "Nam Cát, Nam Đàn, Nghệ An",
  "Khánh Sơn, Nam Đàn, Nghệ An",
  "Trung Phúc Cường, Nam Đàn, Nghệ An",
  "Nam Kim, Nam Đàn, Nghệ An",
  "Hưng Nguyên, Hưng Nguyên, Nghệ An",
  "Hưng Trung, Hưng Nguyên, Nghệ An",
  "Hưng Yên, Hưng Nguyên, Nghệ An",
  "Hưng Yên Bắc, Hưng Nguyên, Nghệ An",
  "Hưng Tây, Hưng Nguyên, Nghệ An",
  "Hưng Đạo, Hưng Nguyên, Nghệ An",
  "Hưng Mỹ, Hưng Nguyên, Nghệ An",
  "Hưng Thịnh, Hưng Nguyên, Nghệ An",
  "Hưng Lĩnh, Hưng Nguyên, Nghệ An",
  "Hưng Thông, Hưng Nguyên, Nghệ An",
  "Hưng Tân, Hưng Nguyên, Nghệ An",
  "Hưng Lợi, Hưng Nguyên, Nghệ An",
  "Hưng Nghĩa, Hưng Nguyên, Nghệ An",
  "Hưng Phúc, Hưng Nguyên, Nghệ An",
  "Long Xá, Hưng Nguyên, Nghệ An",
  "Châu Nhân, Hưng Nguyên, Nghệ An",
  "Xuân Lam, Hưng Nguyên, Nghệ An",
  "Hưng Thành, Hưng Nguyên, Nghệ An",
  "Quỳnh Vinh, Hoàng Mai, Nghệ An",
  "Quỳnh Lộc, Hoàng Mai, Nghệ An",
  "Quỳnh Thiện, Hoàng Mai, Nghệ An",
  "Quỳnh Lập, Hoàng Mai, Nghệ An",
  "Quỳnh Trang, Hoàng Mai, Nghệ An",
  "Mai Hùng, Hoàng Mai, Nghệ An",
  "Quỳnh Dị, Hoàng Mai, Nghệ An",
  "Quỳnh Xuân, Hoàng Mai, Nghệ An",
  "Quỳnh Phương, Hoàng Mai, Nghệ An",
  "Quỳnh Liên, Hoàng Mai, Nghệ An",
  "Trần Phú, Hà Tĩnh, Hà Tĩnh",
  "Nam Hà, Hà Tĩnh, Hà Tĩnh",
  "Bắc Hà, Hà Tĩnh, Hà Tĩnh",
  "Nguyễn Du, Hà Tĩnh, Hà Tĩnh",
  "Tân Giang, Hà Tĩnh, Hà Tĩnh",
  "Đại Nài, Hà Tĩnh, Hà Tĩnh",
  "Hà Huy Tập, Hà Tĩnh, Hà Tĩnh",
  "Thạch Trung, Hà Tĩnh, Hà Tĩnh",
  "Thạch Quý, Hà Tĩnh, Hà Tĩnh",
  "Thạch Linh, Hà Tĩnh, Hà Tĩnh",
  "Văn Yên, Hà Tĩnh, Hà Tĩnh",
  "Thạch Hạ, Hà Tĩnh, Hà Tĩnh",
  "Đồng Môn, Hà Tĩnh, Hà Tĩnh",
  "Thạch Hưng, Hà Tĩnh, Hà Tĩnh",
  "Thạch Bình, Hà Tĩnh, Hà Tĩnh",
  "Bắc Hồng, Hồng Lĩnh, Hà Tĩnh",
  "Nam Hồng, Hồng Lĩnh, Hà Tĩnh",
  "Trung Lương, Hồng Lĩnh, Hà Tĩnh",
  "Đức Thuận, Hồng Lĩnh, Hà Tĩnh",
  "Đậu Liêu, Hồng Lĩnh, Hà Tĩnh",
  "Thuận Lộc, Hồng Lĩnh, Hà Tĩnh",
  "Phố Châu, Hương Sơn, Hà Tĩnh",
  " Tây Sơn, Hương Sơn, Hà Tĩnh",
  "Sơn Hồng, Hương Sơn, Hà Tĩnh",
  "Sơn Tiến, Hương Sơn, Hà Tĩnh",
  "Sơn Lâm, Hương Sơn, Hà Tĩnh",
  "Sơn Lễ, Hương Sơn, Hà Tĩnh",
  "Sơn Giang, Hương Sơn, Hà Tĩnh",
  "Sơn Lĩnh, Hương Sơn, Hà Tĩnh",
  "An Hòa Thịnh, Hương Sơn, Hà Tĩnh",
  "Sơn Tây, Hương Sơn, Hà Tĩnh",
  "Sơn Ninh, Hương Sơn, Hà Tĩnh",
  "Sơn Châu, Hương Sơn, Hà Tĩnh",
  "Tân Mỹ Hà, Hương Sơn, Hà Tĩnh",
  "Quang Diệm, Hương Sơn, Hà Tĩnh",
  "Sơn Trung, Hương Sơn, Hà Tĩnh",
  "Sơn Bằng, Hương Sơn, Hà Tĩnh",
  "Sơn Bình, Hương Sơn, Hà Tĩnh",
  "Sơn Kim 1, Hương Sơn, Hà Tĩnh",
  "Sơn Kim 2, Hương Sơn, Hà Tĩnh",
  "Sơn Trà, Hương Sơn, Hà Tĩnh",
  "Sơn Long, Hương Sơn, Hà Tĩnh",
  "Kim Hoa, Hương Sơn, Hà Tĩnh",
  "Sơn Hàm, Hương Sơn, Hà Tĩnh",
  "Sơn Phú, Hương Sơn, Hà Tĩnh",
  "Sơn Trường, Hương Sơn, Hà Tĩnh",
  "Đức Thọ, Đức Thọ, Hà Tĩnh",
  "Quang Vĩnh, Đức Thọ, Hà Tĩnh",
  "Tùng Châu, Đức Thọ, Hà Tĩnh",
  "Trường Sơn, Đức Thọ, Hà Tĩnh",
  "Liên Minh, Đức Thọ, Hà Tĩnh",
  "Yên Hồ, Đức Thọ, Hà Tĩnh",
  "Tùng Ảnh, Đức Thọ, Hà Tĩnh",
  "Bùi La Nhân, Đức Thọ, Hà Tĩnh",
  "Thanh Bình Thịnh, Đức Thọ, Hà Tĩnh",
  "Lâm Trung Thủy, Đức Thọ, Hà Tĩnh",
  "Hòa Lạc, Đức Thọ, Hà Tĩnh",
  "Tân Dân, Đức Thọ, Hà Tĩnh",
  "An Dũng, Đức Thọ, Hà Tĩnh",
  "Đức Đồng, Đức Thọ, Hà Tĩnh",
  "Đức Lạng, Đức Thọ, Hà Tĩnh",
  "Tân Hương, Đức Thọ, Hà Tĩnh",
  "Vũ Quang, Vũ Quang, Hà Tĩnh",
  "Ân Phú, Vũ Quang, Hà Tĩnh",
  "Đức Giang, Vũ Quang, Hà Tĩnh",
  "Đức Lĩnh, Vũ Quang, Hà Tĩnh",
  "Thọ Điền, Vũ Quang, Hà Tĩnh",
  "Đức Hương, Vũ Quang, Hà Tĩnh",
  "Đức Bồng, Vũ Quang, Hà Tĩnh",
  "Đức Liên, Vũ Quang, Hà Tĩnh",
  "Hương Minh, Vũ Quang, Hà Tĩnh",
  "Quang Thọ, Vũ Quang, Hà Tĩnh",
  "Xuân An, Nghi Xuân, Hà Tĩnh",
  "Xuân Hội, Nghi Xuân, Hà Tĩnh",
  "Đan Trường, Nghi Xuân, Hà Tĩnh",
  "Xuân Phổ, Nghi Xuân, Hà Tĩnh",
  "Xuân Hải, Nghi Xuân, Hà Tĩnh",
  "Xuân Giang, Nghi Xuân, Hà Tĩnh",
  "Tiên Điền, Nghi Xuân, Hà Tĩnh",
  "Xuân Yên, Nghi Xuân, Hà Tĩnh",
  "Xuân Mỹ, Nghi Xuân, Hà Tĩnh",
  "Xuân Thành, Nghi Xuân, Hà Tĩnh",
  "Xuân Viên, Nghi Xuân, Hà Tĩnh",
  "Xuân Hồng, Nghi Xuân, Hà Tĩnh",
  "Cỗ Đạm, Nghi Xuân, Hà Tĩnh",
  "Xuân Liên, Nghi Xuân, Hà Tĩnh",
  "Xuân Lĩnh, Nghi Xuân, Hà Tĩnh",
  "Xuân Lam, Nghi Xuân, Hà Tĩnh",
  "Cương Gián, Nghi Xuân, Hà Tĩnh",
  "Nghèn, Can Lộc, Hà Tĩnh",
  "Thiên Lộc, Can Lộc, Hà Tĩnh",
  "Thuần Thiện, Can Lộc, Hà Tĩnh",
  "Vượng Lộc, Can Lộc, Hà Tĩnh",
  "Thanh Lộc, Can Lộc, Hà Tĩnh",
  "Kim Song Trường, Can Lộc, Hà Tĩnh",
  "Thường Nga, Can Lộc, Hà Tĩnh",
  "Tùng Lộc, Can Lộc, Hà Tĩnh",
  "Phú Lộc, Can Lộc, Hà Tĩnh",
  "Gia Hanh, Can Lộc, Hà Tĩnh",
  "Khánh Vĩnh Yên, Can Lộc, Hà Tĩnh",
  "Trung Lộc, Can Lộc, Hà Tĩnh",
  "Xuân Lộc, Can Lộc, Hà Tĩnh",
  "Thượng Lộc, Can Lộc, Hà Tĩnh",
  "Quang Lộc, Can Lộc, Hà Tĩnh",
  "Đồng Lộc, Can Lộc, Hà Tĩnh",
  "Mỹ Lộc, Can Lộc, Hà Tĩnh",
  "Sơn Lộc, Can Lộc, Hà Tĩnh",
  "Hương Khê, Hương Khê, Hà Tĩnh",
  "Điền Mỹ, Hương Khê, Hà Tĩnh",
  "Hà Linh, Hương Khê, Hà Tĩnh",
  "Hương Thủy, Hương Khê, Hà Tĩnh",
  "Hòa Hải, Hương Khê, Hà Tĩnh",
  "Phúc Đồng, Hương Khê, Hà Tĩnh",
  "Hương Giang, Hương Khê, Hà Tĩnh",
  "Lộc Yên, Hương Khê, Hà Tĩnh",
  "Hương Bình, Hương Khê, Hà Tĩnh",
  "Hương Long, Hương Khê, Hà Tĩnh",
  "Phú Gia, Hương Khê, Hà Tĩnh",
  "Gia Phố, Hương Khê, Hà Tĩnh",
  "Phú Phong, Hương Khê, Hà Tĩnh",
  "Hương Đô, Hương Khê, Hà Tĩnh",
  "Hương Vĩnh, Hương Khê, Hà Tĩnh",
  "Hương Xuân, Hương Khê, Hà Tĩnh",
  "Phúc Trạch, Hương Khê, Hà Tĩnh",
  "Hương Trà, Hương Khê, Hà Tĩnh",
  "Hương Trạch, Hương Khê, Hà Tĩnh",
  "Hương Lâm, Hương Khê, Hà Tĩnh",
  "Hương Liên, Hương Khê, Hà Tĩnh",
  "Thạch Hà, Thạch Hà, Hà Tĩnh",
  "Ngọc Sơn, Thạch Hà, Hà Tĩnh",
  "Thạch Hải, Thạch Hà, Hà Tĩnh",
  "Thạch Kênh, Thạch Hà, Hà Tĩnh",
  "Thạch Sơn, Thạch Hà, Hà Tĩnh",
  "Thạch Liên, Thạch Hà, Hà Tĩnh",
  "Đỉnh Bàn, Thạch Hà, Hà Tĩnh",
  "Việt Tiến, Thạch Hà, Hà Tĩnh",
  "Thạch Khê, Thạch Hà, Hà Tĩnh",
  "Thạch Long, Thạch Hà, Hà Tĩnh",
  "Thạch Trị, Thạch Hà, Hà Tĩnh",
  "Thạch Lạc, Thạch Hà, Hà Tĩnh",
  "Thạch Ngọc, Thạch Hà, Hà Tĩnh",
  "Tượng Sơn, Thạch Hà, Hà Tĩnh",
  "Thạch Văn, Thạch Hà, Hà Tĩnh",
  "Lưu Vĩnh Sơn, Thạch Hà, Hà Tĩnh",
  "Thạch Thắng, Thạch Hà, Hà Tĩnh",
  "Thạch Đài, Thạch Hà, Hà Tĩnh",
  "Thạch Hội, Thạch Hà, Hà Tĩnh",
  "Tân Lâm Hương, Thạch Hà, Hà Tĩnh",
  "Thạch Xuân, Thạch Hà, Hà Tĩnh",
  "Nam Điền, Thạch Hà, Hà Tĩnh",
  "Cẩm Xuyên, Cẩm Xuyên, Hà Tĩnh",
  "Thiên Cầm, Cẩm Xuyên, Hà Tĩnh",
  "Yên Hòa, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Dương, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Bình, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Vĩnh, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Thành, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Quang, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Thạch, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Nhượng, Cẩm Xuyên, Hà Tĩnh",
  "Nam Phúc Thăng, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Duệ, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Lĩnh, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Quan, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Hà, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Lộc, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Hưng, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Thịnh, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Mỹ, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Trung, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Sơn, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Lạc, Cẩm Xuyên, Hà Tĩnh",
  "Cẩm Minh, Cẩm Xuyên, Hà Tĩnh",
  "Kỳ Xuân, Kỳ Anh, Hà Tĩnh",
  "Kỳ Bắc, Kỳ Anh, Hà Tĩnh",
  "Kỳ Phú, Kỳ Anh, Hà Tĩnh",
  "Kỳ Phong, Kỳ Anh, Hà Tĩnh",
  "Kỳ Tiến, Kỳ Anh, Hà Tĩnh",
  "Kỳ Giang, Kỳ Anh, Hà Tĩnh",
  "Kỳ Đồng, Kỳ Anh, Hà Tĩnh",
  "Kỳ Khang, Kỳ Anh, Hà Tĩnh",
  "Kỳ Văn, Kỳ Anh, Hà Tĩnh",
  "Kỳ Trung, Kỳ Anh, Hà Tĩnh",
  "Kỳ Thọ, Kỳ Anh, Hà Tĩnh",
  "Kỳ Tây, Kỳ Anh, Hà Tĩnh",
  "Kỳ Thượng, Kỳ Anh, Hà Tĩnh",
  "Kỳ Hải, Kỳ Anh, Hà Tĩnh",
  "Kỳ Thư, Kỳ Anh, Hà Tĩnh",
  "Kỳ Châu, Kỳ Anh, Hà Tĩnh",
  "Kỳ Tân, Kỳ Anh, Hà Tĩnh",
  "Lâm Hợp, Kỳ Anh, Hà Tĩnh",
  "Kỳ Sơn, Kỳ Anh, Hà Tĩnh",
  "Kỳ Lạc, Kỳ Anh, Hà Tĩnh",
  "Tân Lộc, Lộc Hà, Hà Tĩnh",
  "Hồng Lộc, Lộc Hà, Hà Tĩnh",
  "Thịnh Lộc, Lộc Hà, Hà Tĩnh",
  "Bình An, Lộc Hà, Hà Tĩnh",
  "Ích Hậu, Lộc Hà, Hà Tĩnh",
  "Phù Lưu, Lộc Hà, Hà Tĩnh",
  "Lộc Hà, Lộc Hà, Hà Tĩnh",
  "Thạch Mỹ, Lộc Hà, Hà Tĩnh",
  "Thạch Kim, Lộc Hà, Hà Tĩnh",
  "Thạch Châu, Lộc Hà, Hà Tĩnh",
  "Hộ Độ, Lộc Hà, Hà Tĩnh",
  "Mai Phụ, Lộc Hà, Hà Tĩnh",
  "Hưng Trí, Kỳ Anh, Hà Tĩnh",
  "Kỳ Ninh, Kỳ Anh, Hà Tĩnh",
  "Kỳ Lợi, Kỳ Anh, Hà Tĩnh",
  "Kỳ Hà, Kỳ Anh, Hà Tĩnh",
  "Kỳ Trinh, Kỳ Anh, Hà Tĩnh",
  "Kỳ Thịnh, Kỳ Anh, Hà Tĩnh",
  "Kỳ Hoa, Kỳ Anh, Hà Tĩnh",
  "Kỳ Phương, Kỳ Anh, Hà Tĩnh",
  "Kỳ Long, Kỳ Anh, Hà Tĩnh",
  "Kỳ Liên, Kỳ Anh, Hà Tĩnh",
  "Kỳ Nam, Kỳ Anh, Hà Tĩnh",
  "Hải Thành, Đồng Hới, Quảng Bình",
  "Đồng Phú, Đồng Hới, Quảng Bình",
  "Bắc Lý, Đồng Hới, Quảng Bình",
  "Nam Lý, Đồng Hới, Quảng Bình",
  "Đồng Hải, Đồng Hới, Quảng Bình",
  "Đồng Sơn, Đồng Hới, Quảng Bình",
  "Phú Hải, Đồng Hới, Quảng Bình",
  "Bắc Nghĩa, Đồng Hới, Quảng Bình",
  "Đức Ninh Đông, Đồng Hới, Quảng Bình",
  "Quang Phú, Đồng Hới, Quảng Bình",
  "Lộc Ninh, Đồng Hới, Quảng Bình",
  "Bảo Ninh, Đồng Hới, Quảng Bình",
  "Nghĩa Ninh, Đồng Hới, Quảng Bình",
  "Thuận Đức, Đồng Hới, Quảng Bình",
  "Đức Ninh, Đồng Hới, Quảng Bình",
  "Quy Đạt, Minh Hóa, Quảng Bình",
  "Dân Hóa, Minh Hóa, Quảng Bình",
  "Trọng Hóa, Minh Hóa, Quảng Bình",
  "Hóa Phúc, Minh Hóa, Quảng Bình",
  "Hồng Hóa, Minh Hóa, Quảng Bình",
  "Hóa Thanh, Minh Hóa, Quảng Bình",
  "Hóa Tiến, Minh Hóa, Quảng Bình",
  "Hóa Hợp, Minh Hóa, Quảng Bình",
  "Xuân Hóa, Minh Hóa, Quảng Bình",
  "Yên Hóa, Minh Hóa, Quảng Bình",
  "Minh Hóa, Minh Hóa, Quảng Bình",
  "Tân Hóa, Minh Hóa, Quảng Bình",
  "Hóa Sơn, Minh Hóa, Quảng Bình",
  "Trung Hóa, Minh Hóa, Quảng Bình",
  "Thượng Hóa, Minh Hóa, Quảng Bình",
  "Đồng Lê, Tuyên Hóa, Quảng Bình",
  "Hương Hóa, Tuyên Hóa, Quảng Bình",
  "Kim Hóa, Tuyên Hóa, Quảng Bình",
  "Thanh Hóa, Tuyên Hóa, Quảng Bình",
  "Thanh Thạch, Tuyên Hóa, Quảng Bình",
  "Thuận Hóa, Tuyên Hóa, Quảng Bình",
  "Lâm Hóa, Tuyên Hóa, Quảng Bình",
  "Lê Hóa, Tuyên Hóa, Quảng Bình",
  "Sơn Hóa, Tuyên Hóa, Quảng Bình",
  "Đồng Hóa, Tuyên Hóa, Quảng Bình",
  "Ngư Hóa, Tuyên Hóa, Quảng Bình",
  "Thạch Hóa, Tuyên Hóa, Quảng Bình",
  "Đức Hóa, Tuyên Hóa, Quảng Bình",
  "Phong Hóa, Tuyên Hóa, Quảng Bình",
  "Mai Hóa, Tuyên Hóa, Quảng Bình",
  "Tiến Hóa, Tuyên Hóa, Quảng Bình",
  "Châu Hóa, Tuyên Hóa, Quảng Bình",
  "Cao Quảng, Tuyên Hóa, Quảng Bình",
  "Văn Hóa, Tuyên Hóa, Quảng Bình",
  "Quảng Hợp, Quảng Trạch, Quảng Bình",
  "Quảng Kim, Quảng Trạch, Quảng Bình",
  "Quảng Đông, Quảng Trạch, Quảng Bình",
  "Quảng Phú, Quảng Trạch, Quảng Bình",
  "Quảng Châu, Quảng Trạch, Quảng Bình",
  "Quảng Thạch, Quảng Trạch, Quảng Bình",
  "Quảng Lưu, Quảng Trạch, Quảng Bình",
  "Quảng Tùng, Quảng Trạch, Quảng Bình",
  "Cảnh Dương, Quảng Trạch, Quảng Bình",
  "Quảng Tiến, Quảng Trạch, Quảng Bình",
  "Quảng Hưng, Quảng Trạch, Quảng Bình",
  "Quảng Xuân, Quảng Trạch, Quảng Bình",
  "Cảnh Hóa, Quảng Trạch, Quảng Bình",
  "Liên Trường, Quảng Trạch, Quảng Bình",
  "Quảng Phương, Quảng Trạch, Quảng Bình",
  "Phù Hóa, Quảng Trạch, Quảng Bình",
  "Quảng Thanh, Quảng Trạch, Quảng Bình",
  "Hoàn Lão, Bố Trạch, Quảng Bình",
  "NT Việt Trung, Bố Trạch, Quảng Bình",
  "Xuân Trạch, Bố Trạch, Quảng Bình",
  "Mỹ Trạch, Bố Trạch, Quảng Bình",
  "Hạ Trạch, Bố Trạch, Quảng Bình",
  "Bắc Trạch, Bố Trạch, Quảng Bình",
  "Lâm Trạch, Bố Trạch, Quảng Bình",
  "Thanh Trạch, Bố Trạch, Quảng Bình",
  "Liên Trạch, Bố Trạch, Quảng Bình",
  "Phúc Trạch, Bố Trạch, Quảng Bình",
  "Cự Nẫm, Bố Trạch, Quảng Bình",
  "Hải Phú, Bố Trạch, Quảng Bình",
  "Thượng Trạch, Bố Trạch, Quảng Bình",
  "Sơn Lộc, Bố Trạch, Quảng Bình",
  "Hưng Trạch, Bố Trạch, Quảng Bình",
  "Đồng Trạch, Bố Trạch, Quảng Bình",
  "Đức Trạch, Bố Trạch, Quảng Bình",
  "Phong Nha, Bố Trạch, Quảng Bình",
  "Vạn Trạch, Bố Trạch, Quảng Bình",
  "Phú Định, Bố Trạch, Quảng Bình",
  "Trung Trạch, Bố Trạch, Quảng Bình",
  "Tây Trạch, Bố Trạch, Quảng Bình",
  "Hòa Trạch, Bố Trạch, Quảng Bình",
  "Đại Trạch, Bố Trạch, Quảng Bình",
  "Nhân Trạch, Bố Trạch, Quảng Bình",
  "Tân Trạch, Bố Trạch, Quảng Bình",
  "Nam Trạch, Bố Trạch, Quảng Bình",
  "Lý Trạch, Bố Trạch, Quảng Bình",
  "Quán Hàu, Quảng Ninh, Quảng Bình",
  "Trường Sơn, Quảng Ninh, Quảng Bình",
  "Lương Ninh, Quảng Ninh, Quảng Bình",
  "Vĩnh Ninh, Quảng Ninh, Quảng Bình",
  "Võ Ninh, Quảng Ninh, Quảng Bình",
  "Hải Ninh, Quảng Ninh, Quảng Bình",
  "Hàm Ninh, Quảng Ninh, Quảng Bình",
  "Duy Ninh, Quảng Ninh, Quảng Bình",
  "Gia Ninh, Quảng Ninh, Quảng Bình",
  "Trường Xuân, Quảng Ninh, Quảng Bình",
  "Hiền Ninh, Quảng Ninh, Quảng Bình",
  "Tân Ninh, Quảng Ninh, Quảng Bình",
  "Xuân Ninh, Quảng Ninh, Quảng Bình",
  "An Ninh, Quảng Ninh, Quảng Bình",
  "Vạn Ninh, Quảng Ninh, Quảng Bình",
  "NT Lệ Ninh, Lệ Thủy, Quảng Bình",
  "Kiến Giang, Lệ Thủy, Quảng Bình",
  "Hồng Thủy, Lệ Thủy, Quảng Bình",
  "Ngư Thủy Bắc, Lệ Thủy, Quảng Bình",
  "Hoa Thủy, Lệ Thủy, Quảng Bình",
  "Thanh Thủy, Lệ Thủy, Quảng Bình",
  "An Thủy, Lệ Thủy, Quảng Bình",
  "Phong Thủy, Lệ Thủy, Quảng Bình",
  "Cam Thủy, Lệ Thủy, Quảng Bình",
  "Ngân Thủy, Lệ Thủy, Quảng Bình",
  "Sơn Thủy, Lệ Thủy, Quảng Bình",
  "Lộc Thủy, Lệ Thủy, Quảng Bình",
  "Liên Thủy, Lệ Thủy, Quảng Bình",
  "Hưng Thủy, Lệ Thủy, Quảng Bình",
  "Dương Thủy, Lệ Thủy, Quảng Bình",
  "Tân Thủy, Lệ Thủy, Quảng Bình",
  "Phú Thủy, Lệ Thủy, Quảng Bình",
  "Xuân Thủy, Lệ Thủy, Quảng Bình",
  "Mỹ Thủy, Lệ Thủy, Quảng Bình",
  "Ngư Thủy , Lệ Thủy, Quảng Bình",
  "Mai Thủy, Lệ Thủy, Quảng Bình",
  "Sen Thủy, Lệ Thủy, Quảng Bình",
  "Thái Thủy, Lệ Thủy, Quảng Bình",
  "Kim Thủy, Lệ Thủy, Quảng Bình",
  "Trường Thủy, Lệ Thủy, Quảng Bình",
  "Lâm Thủy, Lệ Thủy, Quảng Bình",
  "Ba Đồn, Ba Đồn, Quảng Bình",
  "Quảng Long, Ba Đồn, Quảng Bình",
  "Quảng Thọ, Ba Đồn, Quảng Bình",
  "Quảng Tiên, Ba Đồn, Quảng Bình",
  "Quảng Trung, Ba Đồn, Quảng Bình",
  "Quảng Phong, Ba Đồn, Quảng Bình",
  "Quảng Thuận, Ba Đồn, Quảng Bình",
  "Quảng Tân, Ba Đồn, Quảng Bình",
  "Quảng Hải, Ba Đồn, Quảng Bình",
  "Quảng Sơn, Ba Đồn, Quảng Bình",
  "Quảng Lộc, Ba Đồn, Quảng Bình",
  "Quảng Thủy, Ba Đồn, Quảng Bình",
  "Quảng Văn, Ba Đồn, Quảng Bình",
  "Quảng Phúc, Ba Đồn, Quảng Bình",
  "Quảng Hòa, Ba Đồn, Quảng Bình",
  "Quảng Minh, Ba Đồn, Quảng Bình",
  "Đông Giang, Đông Hà, Quảng Trị",
  "Phường 1, Đông Hà, Quảng Trị",
  "Đông Lễ, Đông Hà, Quảng Trị",
  "Đông Thanh, Đông Hà, Quảng Trị",
  "Phường 2, Đông Hà, Quảng Trị",
  "Phường 4, Đông Hà, Quảng Trị",
  "Phường 5, Đông Hà, Quảng Trị",
  "Đông Lương, Đông Hà, Quảng Trị",
  "Phường 3, Đông Hà, Quảng Trị",
  "Phường 1, Quảng Trị, Quảng Trị",
  "An Đôn, Quảng Trị, Quảng Trị",
  "Phường 2, Quảng Trị, Quảng Trị",
  "Phường 3, Quảng Trị, Quảng Trị",
  "Hải Lệ, Quảng Trị, Quảng Trị",
  "Hồ Xá, Vĩnh Linh, Quảng Trị",
  "Bến Quan, Vĩnh Linh, Quảng Trị",
  "Vĩnh Thái, Vĩnh Linh, Quảng Trị",
  "Vĩnh Tú, Vĩnh Linh, Quảng Trị",
  "Vĩnh Chấp, Vĩnh Linh, Quảng Trị",
  "Trung Nam, Vĩnh Linh, Quảng Trị",
  "Kim Thạch, Vĩnh Linh, Quảng Trị",
  "Vĩnh Long, Vĩnh Linh, Quảng Trị",
  "Vĩnh Khê, Vĩnh Linh, Quảng Trị",
  "Vĩnh Hòa, Vĩnh Linh, Quảng Trị",
  "Vĩnh Thủy, Vĩnh Linh, Quảng Trị",
  "Vĩnh Lâm, Vĩnh Linh, Quảng Trị",
  "Hiền Thành, Vĩnh Linh, Quảng Trị",
  "Cửa Tùng, Vĩnh Linh, Quảng Trị",
  "Vĩnh Hà, Vĩnh Linh, Quảng Trị",
  "Vĩnh Sơn, Vĩnh Linh, Quảng Trị",
  "Vĩnh Giang, Vĩnh Linh, Quảng Trị",
  "Vĩnh Ô, Vĩnh Linh, Quảng Trị",
  "Khe Sanh, Hướng Hóa, Quảng Trị",
  "Lao Bảo, Hướng Hóa, Quảng Trị",
  "Hướng Lập, Hướng Hóa, Quảng Trị",
  "Hướng Việt, Hướng Hóa, Quảng Trị",
  "Hướng Phùng, Hướng Hóa, Quảng Trị",
  "Hướng Sơn, Hướng Hóa, Quảng Trị",
  "Hướng Linh, Hướng Hóa, Quảng Trị",
  "Tân Hợp, Hướng Hóa, Quảng Trị",
  "Hướng Tân, Hướng Hóa, Quảng Trị",
  "Tân Thành, Hướng Hóa, Quảng Trị",
  "Tân Long, Hướng Hóa, Quảng Trị",
  "Tân Lập, Hướng Hóa, Quảng Trị",
  "Tân Liên, Hướng Hóa, Quảng Trị",
  "Húc, Hướng Hóa, Quảng Trị",
  "Thuận, Hướng Hóa, Quảng Trị",
  "Hướng Lộc, Hướng Hóa, Quảng Trị",
  "Ba Tầng, Hướng Hóa, Quảng Trị",
  "Thanh, Hướng Hóa, Quảng Trị",
  " A Dơi, Hướng Hóa, Quảng Trị",
  "Lìa, Hướng Hóa, Quảng Trị",
  "Xy, Hướng Hóa, Quảng Trị",
  "Gio Linh, Gio Linh, Quảng Trị",
  "Cửa Việt, Gio Linh, Quảng Trị",
  "Trung Giang, Gio Linh, Quảng Trị",
  "Trung Hải, Gio Linh, Quảng Trị",
  "Trung Sơn, Gio Linh, Quảng Trị",
  "Phong Bình, Gio Linh, Quảng Trị",
  "Gio Mỹ, Gio Linh, Quảng Trị",
  "Gio Hải, Gio Linh, Quảng Trị",
  "Gio An, Gio Linh, Quảng Trị",
  "Gio Châu, Gio Linh, Quảng Trị",
  "Gio Việt, Gio Linh, Quảng Trị",
  "Linh Trường, Gio Linh, Quảng Trị",
  "Gio Sơn, Gio Linh, Quảng Trị",
  "Gio Mai, Gio Linh, Quảng Trị",
  "Hải Thái, Gio Linh, Quảng Trị",
  "Linh Hải, Gio Linh, Quảng Trị",
  "Gio Quang, Gio Linh, Quảng Trị",
  "Krông Klang, Đa Krông, Quảng Trị",
  "Mò Ó, Đa Krông, Quảng Trị",
  "Hướng Hiệp, Đa Krông, Quảng Trị",
  "Đa Krông, Đa Krông, Quảng Trị",
  "Triệu Nguyên, Đa Krông, Quảng Trị",
  "Ba Lòng, Đa Krông, Quảng Trị",
  "Ba Nang, Đa Krông, Quảng Trị",
  "Tà Long, Đa Krông, Quảng Trị",
  "Húc Nghì, Đa Krông, Quảng Trị",
  "A Vao, Đa Krông, Quảng Trị",
  "Tà Rụt, Đa Krông, Quảng Trị",
  "A Bung, Đa Krông, Quảng Trị",
  "A Ngo, Đa Krông, Quảng Trị",
  "Cam Lộ, Cam Lộ, Quảng Trị",
  "Cam Tuyền, Cam Lộ, Quảng Trị",
  "Thanh An, Cam Lộ, Quảng Trị",
  "Cam Thủy, Cam Lộ, Quảng Trị",
  "Cam Thành, Cam Lộ, Quảng Trị",
  "Cam Hiếu, Cam Lộ, Quảng Trị",
  "Cam Chính, Cam Lộ, Quảng Trị",
  "Cam Nghĩa, Cam Lộ, Quảng Trị",
  "Ái Tử, Triệu Phong, Quảng Trị",
  "Triệu An, Triệu Phong, Quảng Trị",
  "Triệu Vân, Triệu Phong, Quảng Trị",
  "Triệu Phước, Triệu Phong, Quảng Trị",
  "Triệu Độ, Triệu Phong, Quảng Trị",
  "Triệu Trạch, Triệu Phong, Quảng Trị",
  "Triệu Thuận, Triệu Phong, Quảng Trị",
  "Triệu Đại, Triệu Phong, Quảng Trị",
  "Triệu Hòa, Triệu Phong, Quảng Trị",
  "Triệu Lăng, Triệu Phong, Quảng Trị",
  "Triệu Sơn, Triệu Phong, Quảng Trị",
  "Triệu Long, Triệu Phong, Quảng Trị",
  "Triệu Tài, Triệu Phong, Quảng Trị",
  "Triệu Trung, Triệu Phong, Quảng Trị",
  "Triệu Ái, Triệu Phong, Quảng Trị",
  "Triệu Thượng, Triệu Phong, Quảng Trị",
  "Triệu Giang, Triệu Phong, Quảng Trị",
  "Triệu Thành, Triệu Phong, Quảng Trị",
  "Diên Sanh, Hải Lăng, Quảng Trị",
  "Hải An, Hải Lăng, Quảng Trị",
  "Hải Ba, Hải Lăng, Quảng Trị",
  "Hải Quy, Hải Lăng, Quảng Trị",
  "Hải Quế, Hải Lăng, Quảng Trị",
  "Hải Hưng, Hải Lăng, Quảng Trị",
  "Hải Phú, Hải Lăng, Quảng Trị",
  "Hải Thượng, Hải Lăng, Quảng Trị",
  "Hải Dương, Hải Lăng, Quảng Trị",
  "Hải Định, Hải Lăng, Quảng Trị",
  "Hải Lâm, Hải Lăng, Quảng Trị",
  "Hải Phong, Hải Lăng, Quảng Trị",
  "Hải Trường, Hải Lăng, Quảng Trị",
  "Hải Sơn, Hải Lăng, Quảng Trị",
  "Hải Chánh, Hải Lăng, Quảng Trị",
  "Hải Khê, Hải Lăng, Quảng Trị",
  ", Cồn Cỏ, Quảng Trị",
  "Phú Thuận, Huế, Thừa Thiên Huế",
  "Phú Bình, Huế, Thừa Thiên Huế",
  "Tây Lộc, Huế, Thừa Thiên Huế",
  "Thuận Lộc, Huế, Thừa Thiên Huế",
  "Phú Hiệp, Huế, Thừa Thiên Huế",
  "Phú Hậu, Huế, Thừa Thiên Huế",
  "Thuận Hòa, Huế, Thừa Thiên Huế",
  "Thuận Thành, Huế, Thừa Thiên Huế",
  "Phú Hòa, Huế, Thừa Thiên Huế",
  "Phú Cát, Huế, Thừa Thiên Huế",
  "Kim Long, Huế, Thừa Thiên Huế",
  "Vĩ Dạ, Huế, Thừa Thiên Huế",
  "Phường Đúc, Huế, Thừa Thiên Huế",
  "Vĩnh Ninh, Huế, Thừa Thiên Huế",
  "Phú Hội, Huế, Thừa Thiên Huế",
  "Phú Nhuận, Huế, Thừa Thiên Huế",
  "Xuân Phú, Huế, Thừa Thiên Huế",
  "Trường An, Huế, Thừa Thiên Huế",
  "Phước Vĩnh, Huế, Thừa Thiên Huế",
  "An Cựu, Huế, Thừa Thiên Huế",
  "An Hòa, Huế, Thừa Thiên Huế",
  "Hương Sơ, Huế, Thừa Thiên Huế",
  "Thuỷ Biều, Huế, Thừa Thiên Huế",
  "Hương Long, Huế, Thừa Thiên Huế",
  "Thuỷ Xuân, Huế, Thừa Thiên Huế",
  "An Đông, Huế, Thừa Thiên Huế",
  "An Tây, Huế, Thừa Thiên Huế",
  "Phong Điền, Phong Điền, Thừa Thiên Huế",
  "Điền Hương, Phong Điền, Thừa Thiên Huế",
  "Điền Môn, Phong Điền, Thừa Thiên Huế",
  "Điền Lộc, Phong Điền, Thừa Thiên Huế",
  "Phong Bình, Phong Điền, Thừa Thiên Huế",
  "Điền Hòa, Phong Điền, Thừa Thiên Huế",
  "Phong Chương, Phong Điền, Thừa Thiên Huế",
  "Phong Hải, Phong Điền, Thừa Thiên Huế",
  "Điền Hải, Phong Điền, Thừa Thiên Huế",
  "Phong Hòa, Phong Điền, Thừa Thiên Huế",
  "Phong Thu, Phong Điền, Thừa Thiên Huế",
  "Phong Hiền, Phong Điền, Thừa Thiên Huế",
  "Phong Mỹ, Phong Điền, Thừa Thiên Huế",
  "Phong An, Phong Điền, Thừa Thiên Huế",
  "Phong Xuân, Phong Điền, Thừa Thiên Huế",
  "Phong Sơn, Phong Điền, Thừa Thiên Huế",
  "Sịa, Quảng Điền, Thừa Thiên Huế",
  "Quảng Thái, Quảng Điền, Thừa Thiên Huế",
  "Quảng Ngạn, Quảng Điền, Thừa Thiên Huế",
  "Quảng Lợi, Quảng Điền, Thừa Thiên Huế",
  "Quảng Công, Quảng Điền, Thừa Thiên Huế",
  "Quảng Phước, Quảng Điền, Thừa Thiên Huế",
  "Quảng Vinh, Quảng Điền, Thừa Thiên Huế",
  "Quảng An, Quảng Điền, Thừa Thiên Huế",
  "Quảng Thành, Quảng Điền, Thừa Thiên Huế",
  "Quảng Thọ, Quảng Điền, Thừa Thiên Huế",
  "Quảng Phú, Quảng Điền, Thừa Thiên Huế",
  "Thuận An, Phú Vang, Thừa Thiên Huế",
  "Phú Thuận, Phú Vang, Thừa Thiên Huế",
  "Phú Dương, Phú Vang, Thừa Thiên Huế",
  "Phú Mậu, Phú Vang, Thừa Thiên Huế",
  "Phú An, Phú Vang, Thừa Thiên Huế",
  "Phú Hải, Phú Vang, Thừa Thiên Huế",
  "Phú Xuân, Phú Vang, Thừa Thiên Huế",
  "Phú Diên, Phú Vang, Thừa Thiên Huế",
  "Phú Thanh, Phú Vang, Thừa Thiên Huế",
  "Phú Mỹ, Phú Vang, Thừa Thiên Huế",
  "Phú Thượng, Phú Vang, Thừa Thiên Huế",
  "Phú Hồ, Phú Vang, Thừa Thiên Huế",
  "Vinh Xuân, Phú Vang, Thừa Thiên Huế",
  "Phú Lương, Phú Vang, Thừa Thiên Huế",
  "Phú Đa, Phú Vang, Thừa Thiên Huế",
  "Vinh Thanh, Phú Vang, Thừa Thiên Huế",
  "Vinh An, Phú Vang, Thừa Thiên Huế",
  "Phú Gia, Phú Vang, Thừa Thiên Huế",
  "Vinh Hà, Phú Vang, Thừa Thiên Huế",
  "Phú Bài, Hương Thủy, Thừa Thiên Huế",
  "Thủy Vân, Hương Thủy, Thừa Thiên Huế",
  "Thủy Thanh, Hương Thủy, Thừa Thiên Huế",
  "Thủy Dương, Hương Thủy, Thừa Thiên Huế",
  "Thủy Phương, Hương Thủy, Thừa Thiên Huế",
  "Thủy Châu, Hương Thủy, Thừa Thiên Huế",
  "Thủy Lương, Hương Thủy, Thừa Thiên Huế",
  "Thủy Bằng, Hương Thủy, Thừa Thiên Huế",
  "Thủy Tân, Hương Thủy, Thừa Thiên Huế",
  "Thủy Phù, Hương Thủy, Thừa Thiên Huế",
  "Phú Sơn, Hương Thủy, Thừa Thiên Huế",
  "Dương Hòa, Hương Thủy, Thừa Thiên Huế",
  "Tứ Hạ, Hương Trà, Thừa Thiên Huế",
  "Hải Dương, Hương Trà, Thừa Thiên Huế",
  "Hương Phong, Hương Trà, Thừa Thiên Huế",
  "Hương Toàn, Hương Trà, Thừa Thiên Huế",
  "Hương Vân, Hương Trà, Thừa Thiên Huế",
  "Hương Văn, Hương Trà, Thừa Thiên Huế",
  "Hương Vinh, Hương Trà, Thừa Thiên Huế",
  "Hương Xuân, Hương Trà, Thừa Thiên Huế",
  "Hương Chữ, Hương Trà, Thừa Thiên Huế",
  "Hương An, Hương Trà, Thừa Thiên Huế",
  "Hương Bình, Hương Trà, Thừa Thiên Huế",
  "Hương Hồ, Hương Trà, Thừa Thiên Huế",
  "Hương Thọ, Hương Trà, Thừa Thiên Huế",
  "Bình Tiến, Hương Trà, Thừa Thiên Huế",
  "Bình Thành, Hương Trà, Thừa Thiên Huế",
  "A Lưới, A Lưới, Thừa Thiên Huế",
  "Hồng Vân, A Lưới, Thừa Thiên Huế",
  "Hồng Hạ, A Lưới, Thừa Thiên Huế",
  "Hồng Kim, A Lưới, Thừa Thiên Huế",
  "Trung Sơn, A Lưới, Thừa Thiên Huế",
  "Hương Nguyên, A Lưới, Thừa Thiên Huế",
  "Hồng Bắc, A Lưới, Thừa Thiên Huế",
  "A Ngo, A Lưới, Thừa Thiên Huế",
  "Sơn Thủy, A Lưới, Thừa Thiên Huế",
  "Phú Vinh, A Lưới, Thừa Thiên Huế",
  "Hương Phong, A Lưới, Thừa Thiên Huế",
  "Quảng Nhâm, A Lưới, Thừa Thiên Huế",
  "Hồng Thượng, A Lưới, Thừa Thiên Huế",
  "Hồng Thái, A Lưới, Thừa Thiên Huế",
  "A Roằng, A Lưới, Thừa Thiên Huế",
  "Đông Sơn, A Lưới, Thừa Thiên Huế",
  "Lâm Đớt, A Lưới, Thừa Thiên Huế",
  "Hồng Thủy, A Lưới, Thừa Thiên Huế",
  "Phú Lộc, Phú Lộc, Thừa Thiên Huế",
  "Lăng Cô, Phú Lộc, Thừa Thiên Huế",
  "Vinh Mỹ, Phú Lộc, Thừa Thiên Huế",
  "Vinh Hưng, Phú Lộc, Thừa Thiên Huế",
  "Giang Hải, Phú Lộc, Thừa Thiên Huế",
  "Vinh Hiền, Phú Lộc, Thừa Thiên Huế",
  "Lộc Bổn, Phú Lộc, Thừa Thiên Huế",
  "Lộc Sơn, Phú Lộc, Thừa Thiên Huế",
  "Lộc Bình, Phú Lộc, Thừa Thiên Huế",
  "Lộc Vĩnh, Phú Lộc, Thừa Thiên Huế",
  "Lộc An, Phú Lộc, Thừa Thiên Huế",
  "Lộc Điền, Phú Lộc, Thừa Thiên Huế",
  "Lộc Thủy, Phú Lộc, Thừa Thiên Huế",
  "Lộc Trì, Phú Lộc, Thừa Thiên Huế",
  "Lộc Tiến, Phú Lộc, Thừa Thiên Huế",
  "Lộc Hòa, Phú Lộc, Thừa Thiên Huế",
  "Xuân Lộc, Phú Lộc, Thừa Thiên Huế",
  "Khe Tre, Nam Đông, Thừa Thiên Huế",
  "Hương Phú, Nam Đông, Thừa Thiên Huế",
  "Hương Sơn, Nam Đông, Thừa Thiên Huế",
  "Hương Lộc, Nam Đông, Thừa Thiên Huế",
  "Thượng Quảng, Nam Đông, Thừa Thiên Huế",
  "Hương Xuân, Nam Đông, Thừa Thiên Huế",
  "Hương Hữu, Nam Đông, Thừa Thiên Huế",
  "Thượng Lộ, Nam Đông, Thừa Thiên Huế",
  "Thượng Long, Nam Đông, Thừa Thiên Huế",
  "Thượng Nhật, Nam Đông, Thừa Thiên Huế",
  "Hòa Hiệp Bắc, Liên Chiểu, Đà Nẵng",
  "Hòa Hiệp Nam, Liên Chiểu, Đà Nẵng",
  "Hòa Khánh Bắc, Liên Chiểu, Đà Nẵng",
  "Hòa Khánh Nam, Liên Chiểu, Đà Nẵng",
  "Hòa Minh, Liên Chiểu, Đà Nẵng",
  "Tam Thuận, Thanh Khê, Đà Nẵng",
  "Thanh Khê Tây, Thanh Khê, Đà Nẵng",
  "Thanh Khê Đông, Thanh Khê, Đà Nẵng",
  "Xuân Hà, Thanh Khê, Đà Nẵng",
  "Tân Chính, Thanh Khê, Đà Nẵng",
  "Chính Gián, Thanh Khê, Đà Nẵng",
  "Vĩnh Trung, Thanh Khê, Đà Nẵng",
  "Thạc Gián, Thanh Khê, Đà Nẵng",
  "An Khê, Thanh Khê, Đà Nẵng",
  "Hòa Khê, Thanh Khê, Đà Nẵng",
  "Thanh Bình, Hải Châu, Đà Nẵng",
  "Thuận Phước, Hải Châu, Đà Nẵng",
  "Thạch Thang, Hải Châu, Đà Nẵng",
  "Hải Châu  I, Hải Châu, Đà Nẵng",
  "Hải Châu II, Hải Châu, Đà Nẵng",
  "Phước Ninh, Hải Châu, Đà Nẵng",
  "Hòa Thuận Tây, Hải Châu, Đà Nẵng",
  "Hòa Thuận Đông, Hải Châu, Đà Nẵng",
  "Nam Dương, Hải Châu, Đà Nẵng",
  "Bình Hiên, Hải Châu, Đà Nẵng",
  "Bình Thuận, Hải Châu, Đà Nẵng",
  "Hòa Cường Bắc, Hải Châu, Đà Nẵng",
  "Hòa Cường Nam, Hải Châu, Đà Nẵng",
  "Thọ Quang, Sơn Trà, Đà Nẵng",
  "Nại Hiên Đông, Sơn Trà, Đà Nẵng",
  "Mân Thái, Sơn Trà, Đà Nẵng",
  "An Hải Bắc, Sơn Trà, Đà Nẵng",
  "Phước Mỹ, Sơn Trà, Đà Nẵng",
  "An Hải Tây, Sơn Trà, Đà Nẵng",
  "An Hải Đông, Sơn Trà, Đà Nẵng",
  "Mỹ An, Ngũ Hành Sơn, Đà Nẵng",
  "Khuê Mỹ, Ngũ Hành Sơn, Đà Nẵng",
  "Hoà Quý, Ngũ Hành Sơn, Đà Nẵng",
  "Hoà Hải, Ngũ Hành Sơn, Đà Nẵng",
  "Khuê Trung, Cẩm Lệ, Đà Nẵng",
  "Hòa Phát, Cẩm Lệ, Đà Nẵng",
  "Hòa An, Cẩm Lệ, Đà Nẵng",
  "Hòa Thọ Tây, Cẩm Lệ, Đà Nẵng",
  "Hòa Thọ Đông, Cẩm Lệ, Đà Nẵng",
  "Hòa Xuân, Cẩm Lệ, Đà Nẵng",
  "Hòa Bắc, Hòa Vang, Đà Nẵng",
  "Hòa Liên, Hòa Vang, Đà Nẵng",
  "Hòa Ninh, Hòa Vang, Đà Nẵng",
  "Hòa Sơn, Hòa Vang, Đà Nẵng",
  "Hòa Nhơn, Hòa Vang, Đà Nẵng",
  "Hòa Phú, Hòa Vang, Đà Nẵng",
  "Hòa Phong, Hòa Vang, Đà Nẵng",
  "Hòa Châu, Hòa Vang, Đà Nẵng",
  "Hòa Tiến, Hòa Vang, Đà Nẵng",
  "Hòa Phước, Hòa Vang, Đà Nẵng",
  "Hòa Khương, Hòa Vang, Đà Nẵng",
  ", Hoàng Sa, Đà Nẵng",
  "Tân Thạnh, Tam Kỳ, Quảng Nam",
  "Phước Hòa, Tam Kỳ, Quảng Nam",
  "An Mỹ, Tam Kỳ, Quảng Nam",
  "Hòa Hương, Tam Kỳ, Quảng Nam",
  "An Xuân, Tam Kỳ, Quảng Nam",
  "An Sơn, Tam Kỳ, Quảng Nam",
  "Trường Xuân, Tam Kỳ, Quảng Nam",
  "An Phú, Tam Kỳ, Quảng Nam",
  "Tam Thanh, Tam Kỳ, Quảng Nam",
  "Tam Thăng, Tam Kỳ, Quảng Nam",
  "Tam Phú, Tam Kỳ, Quảng Nam",
  "Hoà Thuận, Tam Kỳ, Quảng Nam",
  "Tam Ngọc, Tam Kỳ, Quảng Nam",
  "Minh An, Hội An, Quảng Nam",
  "Tân An, Hội An, Quảng Nam",
  "Cẩm Phô, Hội An, Quảng Nam",
  "Thanh Hà, Hội An, Quảng Nam",
  "Sơn Phong, Hội An, Quảng Nam",
  "Cẩm Châu, Hội An, Quảng Nam",
  "Cửa Đại, Hội An, Quảng Nam",
  "Cẩm An, Hội An, Quảng Nam",
  "Cẩm Hà, Hội An, Quảng Nam",
  "Cẩm Kim, Hội An, Quảng Nam",
  "Cẩm Nam, Hội An, Quảng Nam",
  "Cẩm Thanh, Hội An, Quảng Nam",
  "Tân Hiệp, Hội An, Quảng Nam",
  "Ch'ơm, Tây Giang, Quảng Nam",
  "Ga Ri, Tây Giang, Quảng Nam",
  "A Xan, Tây Giang, Quảng Nam",
  "Tr'Hy, Tây Giang, Quảng Nam",
  "Lăng, Tây Giang, Quảng Nam",
  "A Nông, Tây Giang, Quảng Nam",
  "A Tiêng, Tây Giang, Quảng Nam",
  "Bha Lê, Tây Giang, Quảng Nam",
  "A Vương, Tây Giang, Quảng Nam",
  "Dang, Tây Giang, Quảng Nam",
  "P Rao, Đông Giang, Quảng Nam",
  "Tà Lu, Đông Giang, Quảng Nam",
  "Sông Kôn, Đông Giang, Quảng Nam",
  "Jơ Ngây, Đông Giang, Quảng Nam",
  "A Ting, Đông Giang, Quảng Nam",
  " Tư, Đông Giang, Quảng Nam",
  "Ba, Đông Giang, Quảng Nam",
  "A Rooi, Đông Giang, Quảng Nam",
  "Za Hung, Đông Giang, Quảng Nam",
  "Mà Cooi, Đông Giang, Quảng Nam",
  "Ka Dăng, Đông Giang, Quảng Nam",
  "Ái Nghĩa, Đại Lộc, Quảng Nam",
  "Đại Sơn, Đại Lộc, Quảng Nam",
  "Đại Lãnh, Đại Lộc, Quảng Nam",
  "Đại Hưng, Đại Lộc, Quảng Nam",
  "Đại Hồng, Đại Lộc, Quảng Nam",
  "Đại Đồng, Đại Lộc, Quảng Nam",
  "Đại Quang, Đại Lộc, Quảng Nam",
  "Đại Nghĩa, Đại Lộc, Quảng Nam",
  "Đại Hiệp, Đại Lộc, Quảng Nam",
  "Đại Thạnh, Đại Lộc, Quảng Nam",
  "Đại Chánh, Đại Lộc, Quảng Nam",
  "Đại Tân, Đại Lộc, Quảng Nam",
  "Đại Phong, Đại Lộc, Quảng Nam",
  "Đại Minh, Đại Lộc, Quảng Nam",
  "Đại Thắng, Đại Lộc, Quảng Nam",
  "Đại Cường, Đại Lộc, Quảng Nam",
  "Đại An, Đại Lộc, Quảng Nam",
  "Đại Hòa, Đại Lộc, Quảng Nam",
  "Vĩnh Điện, Điện Bàn, Quảng Nam",
  "Điện Tiến, Điện Bàn, Quảng Nam",
  "Điện Hòa, Điện Bàn, Quảng Nam",
  "Điện Thắng Bắc, Điện Bàn, Quảng Nam",
  "Điện Thắng Trung, Điện Bàn, Quảng Nam",
  "Điện Thắng Nam, Điện Bàn, Quảng Nam",
  "Điện Ngọc, Điện Bàn, Quảng Nam",
  "Điện Hồng, Điện Bàn, Quảng Nam",
  "Điện Thọ, Điện Bàn, Quảng Nam",
  "Điện Phước, Điện Bàn, Quảng Nam",
  "Điện An, Điện Bàn, Quảng Nam",
  "Điện Nam Bắc, Điện Bàn, Quảng Nam",
  "Điện Nam Trung, Điện Bàn, Quảng Nam",
  "Điện Nam Đông, Điện Bàn, Quảng Nam",
  "Điện Dương, Điện Bàn, Quảng Nam",
  "Điện Quang, Điện Bàn, Quảng Nam",
  "Điện Trung, Điện Bàn, Quảng Nam",
  "Điện Phong, Điện Bàn, Quảng Nam",
  "Điện Minh, Điện Bàn, Quảng Nam",
  "Điện Phương, Điện Bàn, Quảng Nam",
  "Nam Phước, Duy Xuyên, Quảng Nam",
  "Duy Thu, Duy Xuyên, Quảng Nam",
  "Duy Phú, Duy Xuyên, Quảng Nam",
  "Duy Tân, Duy Xuyên, Quảng Nam",
  "Duy Hòa, Duy Xuyên, Quảng Nam",
  "Duy Châu, Duy Xuyên, Quảng Nam",
  "Duy Trinh, Duy Xuyên, Quảng Nam",
  "Duy Sơn, Duy Xuyên, Quảng Nam",
  "Duy Trung, Duy Xuyên, Quảng Nam",
  "Duy Phước, Duy Xuyên, Quảng Nam",
  "Duy Thành, Duy Xuyên, Quảng Nam",
  "Duy Vinh, Duy Xuyên, Quảng Nam",
  "Duy Nghĩa, Duy Xuyên, Quảng Nam",
  "Duy Hải, Duy Xuyên, Quảng Nam",
  "Đông Phú, Quế Sơn, Quảng Nam",
  "Quế Xuân 1, Quế Sơn, Quảng Nam",
  "Quế Xuân 2, Quế Sơn, Quảng Nam",
  "Quế Phú, Quế Sơn, Quảng Nam",
  "Hương An, Quế Sơn, Quảng Nam",
  "Quế Hiệp, Quế Sơn, Quảng Nam",
  "Quế Thuận, Quế Sơn, Quảng Nam",
  "Quế Mỹ, Quế Sơn, Quảng Nam",
  "Quế Long, Quế Sơn, Quảng Nam",
  "Quế Châu, Quế Sơn, Quảng Nam",
  "Quế Phong, Quế Sơn, Quảng Nam",
  "Quế An, Quế Sơn, Quảng Nam",
  "Quế Minh, Quế Sơn, Quảng Nam",
  "Thạnh Mỹ, Nam Giang, Quảng Nam",
  "Laêê, Nam Giang, Quảng Nam",
  "Chơ Chun, Nam Giang, Quảng Nam",
  "Zuôich, Nam Giang, Quảng Nam",
  "Tà Pơơ, Nam Giang, Quảng Nam",
  "La Dêê, Nam Giang, Quảng Nam",
  "Đắc Tôi, Nam Giang, Quảng Nam",
  "Chà Vàl, Nam Giang, Quảng Nam",
  "Tà Bhinh, Nam Giang, Quảng Nam",
  "Cà Dy, Nam Giang, Quảng Nam",
  "Đắc Pre, Nam Giang, Quảng Nam",
  "Đắc Pring, Nam Giang, Quảng Nam",
  "Khâm Đức, Phước Sơn, Quảng Nam",
  "Phước Xuân, Phước Sơn, Quảng Nam",
  "Phước Hiệp, Phước Sơn, Quảng Nam",
  "Phước Hoà, Phước Sơn, Quảng Nam",
  "Phước Đức, Phước Sơn, Quảng Nam",
  "Phước Năng, Phước Sơn, Quảng Nam",
  "Phước Mỹ, Phước Sơn, Quảng Nam",
  "Phước Chánh, Phước Sơn, Quảng Nam",
  "Phước Công, Phước Sơn, Quảng Nam",
  "Phước Kim, Phước Sơn, Quảng Nam",
  "Phước Lộc, Phước Sơn, Quảng Nam",
  "Phước Thành, Phước Sơn, Quảng Nam",
  "Hiệp Hòa, Hiệp Đức, Quảng Nam",
  "Hiệp Thuận, Hiệp Đức, Quảng Nam",
  "Quế Thọ, Hiệp Đức, Quảng Nam",
  "Bình Lâm, Hiệp Đức, Quảng Nam",
  "Sông Trà, Hiệp Đức, Quảng Nam",
  "Phước Trà, Hiệp Đức, Quảng Nam",
  "Phước Gia, Hiệp Đức, Quảng Nam",
  "Tân Bình, Hiệp Đức, Quảng Nam",
  "Quế Lưu, Hiệp Đức, Quảng Nam",
  "Thăng Phước, Hiệp Đức, Quảng Nam",
  "Bình Sơn, Hiệp Đức, Quảng Nam",
  "Hà Lam, Thăng Bình, Quảng Nam",
  "Bình Dương, Thăng Bình, Quảng Nam",
  "Bình Giang, Thăng Bình, Quảng Nam",
  "Bình Nguyên, Thăng Bình, Quảng Nam",
  "Bình Phục, Thăng Bình, Quảng Nam",
  "Bình Triều, Thăng Bình, Quảng Nam",
  "Bình Đào, Thăng Bình, Quảng Nam",
  "Bình Minh, Thăng Bình, Quảng Nam",
  "Bình Lãnh, Thăng Bình, Quảng Nam",
  "Bình Trị, Thăng Bình, Quảng Nam",
  "Bình Định Bắc, Thăng Bình, Quảng Nam",
  "Bình Định Nam, Thăng Bình, Quảng Nam",
  "Bình Quý, Thăng Bình, Quảng Nam",
  "Bình Phú, Thăng Bình, Quảng Nam",
  "Bình Chánh, Thăng Bình, Quảng Nam",
  "Bình Tú, Thăng Bình, Quảng Nam",
  "Bình Sa, Thăng Bình, Quảng Nam",
  "Bình Hải, Thăng Bình, Quảng Nam",
  "Bình Quế, Thăng Bình, Quảng Nam",
  "Bình An, Thăng Bình, Quảng Nam",
  "Bình Trung, Thăng Bình, Quảng Nam",
  "Bình Nam, Thăng Bình, Quảng Nam",
  "Tiên Kỳ, Tiên Phước, Quảng Nam",
  "Tiên Sơn, Tiên Phước, Quảng Nam",
  "Tiên Hà, Tiên Phước, Quảng Nam",
  "Tiên Cẩm, Tiên Phước, Quảng Nam",
  "Tiên Châu, Tiên Phước, Quảng Nam",
  "Tiên Lãnh, Tiên Phước, Quảng Nam",
  "Tiên Ngọc, Tiên Phước, Quảng Nam",
  "Tiên Hiệp, Tiên Phước, Quảng Nam",
  "Tiên Cảnh, Tiên Phước, Quảng Nam",
  "Tiên Mỹ, Tiên Phước, Quảng Nam",
  "Tiên Phong, Tiên Phước, Quảng Nam",
  "Tiên Thọ, Tiên Phước, Quảng Nam",
  "Tiên An, Tiên Phước, Quảng Nam",
  "Tiên Lộc, Tiên Phước, Quảng Nam",
  "Tiên Lập, Tiên Phước, Quảng Nam",
  "Trà My, Bắc Trà My, Quảng Nam",
  "Trà Sơn, Bắc Trà My, Quảng Nam",
  "Trà Kót, Bắc Trà My, Quảng Nam",
  "Trà Nú, Bắc Trà My, Quảng Nam",
  "Trà Đông, Bắc Trà My, Quảng Nam",
  "Trà Dương, Bắc Trà My, Quảng Nam",
  "Trà Giang, Bắc Trà My, Quảng Nam",
  "Trà Bui, Bắc Trà My, Quảng Nam",
  "Trà Đốc, Bắc Trà My, Quảng Nam",
  "Trà Tân, Bắc Trà My, Quảng Nam",
  "Trà Giác, Bắc Trà My, Quảng Nam",
  "Trà Giáp, Bắc Trà My, Quảng Nam",
  "Trà Ka, Bắc Trà My, Quảng Nam",
  "Trà Leng, Nam Trà My, Quảng Nam",
  "Trà Dơn, Nam Trà My, Quảng Nam",
  "Trà Tập, Nam Trà My, Quảng Nam",
  "Trà Mai, Nam Trà My, Quảng Nam",
  "Trà Cang, Nam Trà My, Quảng Nam",
  "Trà Linh, Nam Trà My, Quảng Nam",
  "Trà Nam, Nam Trà My, Quảng Nam",
  "Trà Don, Nam Trà My, Quảng Nam",
  "Trà Vân, Nam Trà My, Quảng Nam",
  "Trà Vinh, Nam Trà My, Quảng Nam",
  "Núi Thành, Núi Thành, Quảng Nam",
  "Tam Xuân I, Núi Thành, Quảng Nam",
  "Tam Xuân II, Núi Thành, Quảng Nam",
  "Tam Tiến, Núi Thành, Quảng Nam",
  "Tam Sơn, Núi Thành, Quảng Nam",
  "Tam Thạnh, Núi Thành, Quảng Nam",
  "Tam Anh Bắc, Núi Thành, Quảng Nam",
  "Tam Anh Nam, Núi Thành, Quảng Nam",
  "Tam Hòa, Núi Thành, Quảng Nam",
  "Tam Hiệp, Núi Thành, Quảng Nam",
  "Tam Hải, Núi Thành, Quảng Nam",
  "Tam Giang, Núi Thành, Quảng Nam",
  "Tam Quang, Núi Thành, Quảng Nam",
  "Tam Nghĩa, Núi Thành, Quảng Nam",
  "Tam Mỹ Tây, Núi Thành, Quảng Nam",
  "Tam Mỹ Đông, Núi Thành, Quảng Nam",
  "Tam Trà, Núi Thành, Quảng Nam",
  "Phú Thịnh, Phú Ninh, Quảng Nam",
  "Tam Thành, Phú Ninh, Quảng Nam",
  "Tam An, Phú Ninh, Quảng Nam",
  "Tam Đàn, Phú Ninh, Quảng Nam",
  "Tam Lộc, Phú Ninh, Quảng Nam",
  "Tam Phước, Phú Ninh, Quảng Nam",
  "Tam Vinh, Phú Ninh, Quảng Nam",
  "Tam Thái, Phú Ninh, Quảng Nam",
  "Tam Đại, Phú Ninh, Quảng Nam",
  "Tam Dân, Phú Ninh, Quảng Nam",
  "Tam Lãnh, Phú Ninh, Quảng Nam",
  "Quế Trung, Nông Sơn, Quảng Nam",
  "Ninh Phước, Nông Sơn, Quảng Nam",
  "Phước Ninh, Nông Sơn, Quảng Nam",
  "Quế Lộc, Nông Sơn, Quảng Nam",
  "Sơn Viên, Nông Sơn, Quảng Nam",
  "Quế Lâm, Nông Sơn, Quảng Nam",
  "Lê Hồng Phong, Quảng Ngãi, Quảng Ngãi",
  "Trần Phú, Quảng Ngãi, Quảng Ngãi",
  "Quảng Phú, Quảng Ngãi, Quảng Ngãi",
  "Nghĩa Chánh, Quảng Ngãi, Quảng Ngãi",
  "Trần Hưng Đạo, Quảng Ngãi, Quảng Ngãi",
  "Nguyễn Nghiêm, Quảng Ngãi, Quảng Ngãi",
  "Nghĩa Lộ, Quảng Ngãi, Quảng Ngãi",
  "Chánh Lộ, Quảng Ngãi, Quảng Ngãi",
  "Nghĩa Dũng, Quảng Ngãi, Quảng Ngãi",
  "Nghĩa Dõng, Quảng Ngãi, Quảng Ngãi",
  "Trương Quang Trọng, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Hòa, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Kỳ, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Thiện, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Ấn Đông, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Châu, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Khê, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Long, Quảng Ngãi, Quảng Ngãi",
  "Tịnh Ấn Tây, Quảng Ngãi, Quảng Ngãi",
  "Tịnh An, Quảng Ngãi, Quảng Ngãi",
  "Nghĩa Phú, Quảng Ngãi, Quảng Ngãi",
  "Nghĩa Hà, Quảng Ngãi, Quảng Ngãi",
  "Nghĩa An, Quảng Ngãi, Quảng Ngãi",
  "Châu Ổ, Bình Sơn, Quảng Ngãi",
  "Bình Thuận, Bình Sơn, Quảng Ngãi",
  "Bình Thạnh, Bình Sơn, Quảng Ngãi",
  "Bình Đông, Bình Sơn, Quảng Ngãi",
  "Bình Chánh, Bình Sơn, Quảng Ngãi",
  "Bình Nguyên, Bình Sơn, Quảng Ngãi",
  "Bình Khương, Bình Sơn, Quảng Ngãi",
  "Bình Trị, Bình Sơn, Quảng Ngãi",
  "Bình An, Bình Sơn, Quảng Ngãi",
  "Bình Hải, Bình Sơn, Quảng Ngãi",
  "Bình Dương, Bình Sơn, Quảng Ngãi",
  "Bình Phước, Bình Sơn, Quảng Ngãi",
  "Bình Hòa, Bình Sơn, Quảng Ngãi",
  "Bình Trung, Bình Sơn, Quảng Ngãi",
  "Bình Minh, Bình Sơn, Quảng Ngãi",
  "Bình Long, Bình Sơn, Quảng Ngãi",
  "Bình Thanh , Bình Sơn, Quảng Ngãi",
  "Bình Chương, Bình Sơn, Quảng Ngãi",
  "Bình Hiệp, Bình Sơn, Quảng Ngãi",
  "Bình Mỹ, Bình Sơn, Quảng Ngãi",
  "Bình Tân Phú, Bình Sơn, Quảng Ngãi",
  "Bình Châu, Bình Sơn, Quảng Ngãi",
  "Trà Xuân, Trà Bồng, Quảng Ngãi",
  "Trà Giang, Trà Bồng, Quảng Ngãi",
  "Trà Thủy, Trà Bồng, Quảng Ngãi",
  "Trà Hiệp, Trà Bồng, Quảng Ngãi",
  "Trà Bình, Trà Bồng, Quảng Ngãi",
  "Trà Phú, Trà Bồng, Quảng Ngãi",
  "Trà Lâm, Trà Bồng, Quảng Ngãi",
  "Trà Tân, Trà Bồng, Quảng Ngãi",
  "Trà Sơn, Trà Bồng, Quảng Ngãi",
  "Trà Bùi, Trà Bồng, Quảng Ngãi",
  "Trà Thanh, Trà Bồng, Quảng Ngãi",
  "Sơn Trà, Trà Bồng, Quảng Ngãi",
  "Trà Phong, Trà Bồng, Quảng Ngãi",
  "Hương Trà, Trà Bồng, Quảng Ngãi",
  "Trà Xinh, Trà Bồng, Quảng Ngãi",
  "Trà Tây, Trà Bồng, Quảng Ngãi",
  "Tịnh Thọ, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Trà, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Phong, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Hiệp, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Bình, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Đông, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Bắc, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Sơn, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Hà, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Giang, Sơn Tịnh, Quảng Ngãi",
  "Tịnh Minh, Sơn Tịnh, Quảng Ngãi",
  "La Hà, Tư Nghĩa, Quảng Ngãi",
  "Sông Vệ, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Lâm, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Thắng, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Thuận, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Kỳ, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Sơn, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Hòa, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Điền, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Thương, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Trung, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Hiệp, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Phương, Tư Nghĩa, Quảng Ngãi",
  "Nghĩa Mỹ, Tư Nghĩa, Quảng Ngãi",
  "Di Lăng, Sơn Hà, Quảng Ngãi",
  "Sơn Hạ, Sơn Hà, Quảng Ngãi",
  "Sơn Thành, Sơn Hà, Quảng Ngãi",
  "Sơn Nham, Sơn Hà, Quảng Ngãi",
  "Sơn Bao, Sơn Hà, Quảng Ngãi",
  "Sơn Linh, Sơn Hà, Quảng Ngãi",
  "Sơn Giang, Sơn Hà, Quảng Ngãi",
  "Sơn Trung, Sơn Hà, Quảng Ngãi",
  "Sơn Thượng, Sơn Hà, Quảng Ngãi",
  "Sơn Cao, Sơn Hà, Quảng Ngãi",
  "Sơn Hải, Sơn Hà, Quảng Ngãi",
  "Sơn Thủy, Sơn Hà, Quảng Ngãi",
  "Sơn Kỳ, Sơn Hà, Quảng Ngãi",
  "Sơn Ba, Sơn Hà, Quảng Ngãi",
  "Sơn Bua, Sơn Tây, Quảng Ngãi",
  "Sơn Mùa, Sơn Tây, Quảng Ngãi",
  "Sơn Liên, Sơn Tây, Quảng Ngãi",
  "Sơn Tân, Sơn Tây, Quảng Ngãi",
  "Sơn Màu, Sơn Tây, Quảng Ngãi",
  "Sơn Dung, Sơn Tây, Quảng Ngãi",
  "Sơn Long, Sơn Tây, Quảng Ngãi",
  "Sơn Tinh, Sơn Tây, Quảng Ngãi",
  "Sơn Lập, Sơn Tây, Quảng Ngãi",
  "Long Sơn, Minh Long, Quảng Ngãi",
  "Long Mai, Minh Long, Quảng Ngãi",
  "Thanh An, Minh Long, Quảng Ngãi",
  "Long Môn, Minh Long, Quảng Ngãi",
  "Long Hiệp, Minh Long, Quảng Ngãi",
  "Chợ Chùa, Nghĩa Hành, Quảng Ngãi",
  "Hành Thuận, Nghĩa Hành, Quảng Ngãi",
  "Hành Dũng, Nghĩa Hành, Quảng Ngãi",
  "Hành Trung, Nghĩa Hành, Quảng Ngãi",
  "Hành Nhân, Nghĩa Hành, Quảng Ngãi",
  "Hành Đức, Nghĩa Hành, Quảng Ngãi",
  "Hành Minh, Nghĩa Hành, Quảng Ngãi",
  "Hành Phước, Nghĩa Hành, Quảng Ngãi",
  "Hành Thiện, Nghĩa Hành, Quảng Ngãi",
  "Hành Thịnh, Nghĩa Hành, Quảng Ngãi",
  "Hành Tín Tây, Nghĩa Hành, Quảng Ngãi",
  "Hành Tín  Đông, Nghĩa Hành, Quảng Ngãi",
  "Mộ Đức, Mộ Đức, Quảng Ngãi",
  "Đức Lợi, Mộ Đức, Quảng Ngãi",
  "Đức Thắng, Mộ Đức, Quảng Ngãi",
  "Đức Nhuận, Mộ Đức, Quảng Ngãi",
  "Đức Chánh, Mộ Đức, Quảng Ngãi",
  "Đức Hiệp, Mộ Đức, Quảng Ngãi",
  "Đức Minh, Mộ Đức, Quảng Ngãi",
  "Đức Thạnh, Mộ Đức, Quảng Ngãi",
  "Đức Hòa, Mộ Đức, Quảng Ngãi",
  "Đức Tân, Mộ Đức, Quảng Ngãi",
  "Đức Phú, Mộ Đức, Quảng Ngãi",
  "Đức Phong, Mộ Đức, Quảng Ngãi",
  "Đức Lân, Mộ Đức, Quảng Ngãi",
  "Nguyễn Nghiêm, Đức Phổ, Quảng Ngãi",
  "Phổ An, Đức Phổ, Quảng Ngãi",
  "Phổ Phong, Đức Phổ, Quảng Ngãi",
  "Phổ Thuận, Đức Phổ, Quảng Ngãi",
  "Phổ Văn, Đức Phổ, Quảng Ngãi",
  "Phổ Quang, Đức Phổ, Quảng Ngãi",
  "Phổ Nhơn, Đức Phổ, Quảng Ngãi",
  "Phổ Ninh, Đức Phổ, Quảng Ngãi",
  "Phổ Minh, Đức Phổ, Quảng Ngãi",
  "Phổ Vinh, Đức Phổ, Quảng Ngãi",
  "Phổ Hòa, Đức Phổ, Quảng Ngãi",
  "Phổ Cường, Đức Phổ, Quảng Ngãi",
  "Phổ Khánh, Đức Phổ, Quảng Ngãi",
  "Phổ Thạnh, Đức Phổ, Quảng Ngãi",
  "Phổ Châu, Đức Phổ, Quảng Ngãi",
  "Ba Tơ, Ba Tơ, Quảng Ngãi",
  "Ba Điền, Ba Tơ, Quảng Ngãi",
  "Ba Vinh, Ba Tơ, Quảng Ngãi",
  "Ba Thành, Ba Tơ, Quảng Ngãi",
  "Ba Động, Ba Tơ, Quảng Ngãi",
  "Ba Dinh, Ba Tơ, Quảng Ngãi",
  "Ba Giang, Ba Tơ, Quảng Ngãi",
  "Ba Liên, Ba Tơ, Quảng Ngãi",
  "Ba Ngạc, Ba Tơ, Quảng Ngãi",
  "Ba Khâm, Ba Tơ, Quảng Ngãi",
  "Ba Cung, Ba Tơ, Quảng Ngãi",
  "Ba Tiêu, Ba Tơ, Quảng Ngãi",
  "Ba Trang, Ba Tơ, Quảng Ngãi",
  "Ba Tô, Ba Tơ, Quảng Ngãi",
  "Ba Bích, Ba Tơ, Quảng Ngãi",
  "Ba Vì, Ba Tơ, Quảng Ngãi",
  "Ba Lế, Ba Tơ, Quảng Ngãi",
  "Ba Nam, Ba Tơ, Quảng Ngãi",
  "Ba Xa, Ba Tơ, Quảng Ngãi",
  ", Lý Sơn, Quảng Ngãi",
  "Nhơn Bình, Qui Nhơn, Bình Định",
  "Nhơn Phú, Qui Nhơn, Bình Định",
  "Đống Đa, Qui Nhơn, Bình Định",
  "Trần Quang Diệu, Qui Nhơn, Bình Định",
  "Hải Cảng, Qui Nhơn, Bình Định",
  "Quang Trung, Qui Nhơn, Bình Định",
  "Thị Nại, Qui Nhơn, Bình Định",
  "Lê Hồng Phong, Qui Nhơn, Bình Định",
  "Trần Hưng Đạo, Qui Nhơn, Bình Định",
  "Ngô Mây, Qui Nhơn, Bình Định",
  "Lý Thường Kiệt, Qui Nhơn, Bình Định",
  "Lê Lợi, Qui Nhơn, Bình Định",
  "Trần Phú, Qui Nhơn, Bình Định",
  "Bùi Thị Xuân, Qui Nhơn, Bình Định",
  "Nguyễn Văn Cừ, Qui Nhơn, Bình Định",
  "Ghềnh Ráng, Qui Nhơn, Bình Định",
  "Nhơn Lý, Qui Nhơn, Bình Định",
  "Nhơn Hội, Qui Nhơn, Bình Định",
  "Nhơn Hải, Qui Nhơn, Bình Định",
  "Nhơn Châu, Qui Nhơn, Bình Định",
  "Phước Mỹ, Qui Nhơn, Bình Định",
  "An Lão, An Lão, Bình Định",
  "An Hưng, An Lão, Bình Định",
  "An Trung, An Lão, Bình Định",
  "An Dũng, An Lão, Bình Định",
  "An Vinh, An Lão, Bình Định",
  "An Toàn, An Lão, Bình Định",
  "An Tân, An Lão, Bình Định",
  "An Hòa, An Lão, Bình Định",
  "An Quang, An Lão, Bình Định",
  "An Nghĩa, An Lão, Bình Định",
  " Tam Quan, Hoài Nhơn, Bình Định",
  "Bồng Sơn, Hoài Nhơn, Bình Định",
  "Hoài Sơn, Hoài Nhơn, Bình Định",
  "Hoài Châu Bắc, Hoài Nhơn, Bình Định",
  "Hoài Châu, Hoài Nhơn, Bình Định",
  "Hoài Phú, Hoài Nhơn, Bình Định",
  "Tam Quan Bắc, Hoài Nhơn, Bình Định",
  "Tam Quan Nam, Hoài Nhơn, Bình Định",
  "Hoài Hảo, Hoài Nhơn, Bình Định",
  "Hoài Thanh Tây, Hoài Nhơn, Bình Định",
  "Hoài Thanh, Hoài Nhơn, Bình Định",
  "Hoài Hương, Hoài Nhơn, Bình Định",
  "Hoài Tân, Hoài Nhơn, Bình Định",
  "Hoài Hải, Hoài Nhơn, Bình Định",
  "Hoài Xuân, Hoài Nhơn, Bình Định",
  "Hoài Mỹ, Hoài Nhơn, Bình Định",
  "Hoài Đức, Hoài Nhơn, Bình Định",
  "Tăng Bạt Hổ, Hoài Ân, Bình Định",
  "Ân Hảo Tây, Hoài Ân, Bình Định",
  "Ân Hảo Đông, Hoài Ân, Bình Định",
  "Ân Sơn, Hoài Ân, Bình Định",
  "Ân Mỹ, Hoài Ân, Bình Định",
  "Dak Mang, Hoài Ân, Bình Định",
  "Ân Tín, Hoài Ân, Bình Định",
  "Ân Thạnh, Hoài Ân, Bình Định",
  "Ân Phong, Hoài Ân, Bình Định",
  "Ân Đức, Hoài Ân, Bình Định",
  "Ân Hữu, Hoài Ân, Bình Định",
  "Bok Tới, Hoài Ân, Bình Định",
  "Ân Tường Tây, Hoài Ân, Bình Định",
  "Ân Tường Đông, Hoài Ân, Bình Định",
  "Ân Nghĩa, Hoài Ân, Bình Định",
  "Phù Mỹ, Phù Mỹ, Bình Định",
  "Bình Dương, Phù Mỹ, Bình Định",
  "Mỹ Đức, Phù Mỹ, Bình Định",
  "Mỹ Châu, Phù Mỹ, Bình Định",
  "Mỹ Thắng, Phù Mỹ, Bình Định",
  "Mỹ Lộc, Phù Mỹ, Bình Định",
  "Mỹ Lợi, Phù Mỹ, Bình Định",
  "Mỹ An, Phù Mỹ, Bình Định",
  "Mỹ Phong, Phù Mỹ, Bình Định",
  "Mỹ Trinh, Phù Mỹ, Bình Định",
  "Mỹ Thọ, Phù Mỹ, Bình Định",
  "Mỹ Hòa, Phù Mỹ, Bình Định",
  "Mỹ Thành, Phù Mỹ, Bình Định",
  "Mỹ Chánh, Phù Mỹ, Bình Định",
  "Mỹ Quang, Phù Mỹ, Bình Định",
  "Mỹ Hiệp, Phù Mỹ, Bình Định",
  "Mỹ Tài, Phù Mỹ, Bình Định",
  "Mỹ Cát, Phù Mỹ, Bình Định",
  "Mỹ Chánh Tây, Phù Mỹ, Bình Định",
  "Vĩnh Thạnh, Vĩnh Thạnh, Bình Định",
  "Vĩnh Sơn, Vĩnh Thạnh, Bình Định",
  "Vĩnh Kim, Vĩnh Thạnh, Bình Định",
  "Vĩnh Hiệp, Vĩnh Thạnh, Bình Định",
  "Vĩnh Hảo, Vĩnh Thạnh, Bình Định",
  "Vĩnh Hòa, Vĩnh Thạnh, Bình Định",
  "Vĩnh Thịnh, Vĩnh Thạnh, Bình Định",
  "Vĩnh Thuận, Vĩnh Thạnh, Bình Định",
  "Vĩnh Quang, Vĩnh Thạnh, Bình Định",
  "Phú Phong, Tây Sơn, Bình Định",
  "Bình Tân, Tây Sơn, Bình Định",
  "Tây Thuận, Tây Sơn, Bình Định",
  "Bình Thuận, Tây Sơn, Bình Định",
  "Tây Giang, Tây Sơn, Bình Định",
  "Bình Thành, Tây Sơn, Bình Định",
  "Tây An, Tây Sơn, Bình Định",
  "Bình Hòa, Tây Sơn, Bình Định",
  "Tây Bình, Tây Sơn, Bình Định",
  "Bình Tường, Tây Sơn, Bình Định",
  "Tây Vinh, Tây Sơn, Bình Định",
  "Vĩnh An, Tây Sơn, Bình Định",
  "Tây Xuân, Tây Sơn, Bình Định",
  "Bình Nghi, Tây Sơn, Bình Định",
  "Tây Phú, Tây Sơn, Bình Định",
  "Ngô Mây, Phù Cát, Bình Định",
  "Cát Sơn, Phù Cát, Bình Định",
  "Cát Minh, Phù Cát, Bình Định",
  "Cát Khánh, Phù Cát, Bình Định",
  "Cát Tài, Phù Cát, Bình Định",
  "Cát Lâm, Phù Cát, Bình Định",
  "Cát Hanh, Phù Cát, Bình Định",
  "Cát Thành, Phù Cát, Bình Định",
  "Cát Trinh, Phù Cát, Bình Định",
  "Cát Hải, Phù Cát, Bình Định",
  "Cát Hiệp, Phù Cát, Bình Định",
  "Cát Nhơn, Phù Cát, Bình Định",
  "Cát Hưng, Phù Cát, Bình Định",
  "Cát Tường, Phù Cát, Bình Định",
  "Cát Tân, Phù Cát, Bình Định",
  "Cát Tiến, Phù Cát, Bình Định",
  "Cát Thắng, Phù Cát, Bình Định",
  "Cát Chánh, Phù Cát, Bình Định",
  "Bình Định, An Nhơn, Bình Định",
  "Đập Đá, An Nhơn, Bình Định",
  "Nhơn Mỹ, An Nhơn, Bình Định",
  "Nhơn Thành, An Nhơn, Bình Định",
  "Nhơn Hạnh, An Nhơn, Bình Định",
  "Nhơn Hậu, An Nhơn, Bình Định",
  "Nhơn Phong, An Nhơn, Bình Định",
  "Nhơn An, An Nhơn, Bình Định",
  "Nhơn Phúc, An Nhơn, Bình Định",
  "Nhơn Hưng, An Nhơn, Bình Định",
  "Nhơn Khánh, An Nhơn, Bình Định",
  "Nhơn Lộc, An Nhơn, Bình Định",
  "Nhơn Hoà, An Nhơn, Bình Định",
  "Nhơn Tân, An Nhơn, Bình Định",
  "Nhơn Thọ, An Nhơn, Bình Định",
  "Tuy Phước, Tuy Phước, Bình Định",
  "Diêu Trì, Tuy Phước, Bình Định",
  "Phước Thắng, Tuy Phước, Bình Định",
  "Phước Hưng, Tuy Phước, Bình Định",
  "Phước Quang, Tuy Phước, Bình Định",
  "Phước Hòa, Tuy Phước, Bình Định",
  "Phước Sơn, Tuy Phước, Bình Định",
  "Phước Hiệp, Tuy Phước, Bình Định",
  "Phước Lộc, Tuy Phước, Bình Định",
  "Phước Nghĩa, Tuy Phước, Bình Định",
  "Phước Thuận, Tuy Phước, Bình Định",
  "Phước An, Tuy Phước, Bình Định",
  "Phước Thành, Tuy Phước, Bình Định",
  "Vân Canh, Vân Canh, Bình Định",
  "Canh Liên, Vân Canh, Bình Định",
  "Canh Hiệp, Vân Canh, Bình Định",
  "Canh Vinh, Vân Canh, Bình Định",
  "Canh Hiển, Vân Canh, Bình Định",
  "Canh Thuận, Vân Canh, Bình Định",
  "Canh Hòa, Vân Canh, Bình Định",
  "Phường 1, Tuy Hoà, Phú Yên",
  "Phường 8, Tuy Hoà, Phú Yên",
  "Phường 2, Tuy Hoà, Phú Yên",
  "Phường 9, Tuy Hoà, Phú Yên",
  "Phường 3, Tuy Hoà, Phú Yên",
  "Phường 4, Tuy Hoà, Phú Yên",
  "Phường 5, Tuy Hoà, Phú Yên",
  "Phường 7, Tuy Hoà, Phú Yên",
  "Phường 6, Tuy Hoà, Phú Yên",
  "Phú Thạnh, Tuy Hoà, Phú Yên",
  "Phú Đông, Tuy Hoà, Phú Yên",
  "Hòa Kiến, Tuy Hoà, Phú Yên",
  "Bình Kiến, Tuy Hoà, Phú Yên",
  "Bình Ngọc, Tuy Hoà, Phú Yên",
  "An Phú, Tuy Hoà, Phú Yên",
  "Phú Lâm, Tuy Hoà, Phú Yên",
  "Xuân Phú, Sông Cầu, Phú Yên",
  "Xuân Lâm, Sông Cầu, Phú Yên",
  "Xuân Thành, Sông Cầu, Phú Yên",
  "Xuân Hải, Sông Cầu, Phú Yên",
  "Xuân Lộc, Sông Cầu, Phú Yên",
  "Xuân Bình, Sông Cầu, Phú Yên",
  "Xuân Cảnh, Sông Cầu, Phú Yên",
  "Xuân Thịnh, Sông Cầu, Phú Yên",
  "Xuân Phương, Sông Cầu, Phú Yên",
  "Xuân Yên, Sông Cầu, Phú Yên",
  "Xuân Thọ 1, Sông Cầu, Phú Yên",
  "Xuân Đài, Sông Cầu, Phú Yên",
  "Xuân Thọ 2, Sông Cầu, Phú Yên",
  "La Hai, Đồng Xuân, Phú Yên",
  "Đa Lộc, Đồng Xuân, Phú Yên",
  "Phú Mỡ, Đồng Xuân, Phú Yên",
  "Xuân Lãnh, Đồng Xuân, Phú Yên",
  "Xuân Long, Đồng Xuân, Phú Yên",
  "Xuân Quang 1, Đồng Xuân, Phú Yên",
  "Xuân Sơn Bắc, Đồng Xuân, Phú Yên",
  "Xuân Quang 2, Đồng Xuân, Phú Yên",
  "Xuân Sơn Nam, Đồng Xuân, Phú Yên",
  "Xuân Quang 3, Đồng Xuân, Phú Yên",
  "Xuân Phước, Đồng Xuân, Phú Yên",
  "Chí Thạnh, Tuy An, Phú Yên",
  "An Dân, Tuy An, Phú Yên",
  "An Ninh Tây, Tuy An, Phú Yên",
  "An Ninh Đông, Tuy An, Phú Yên",
  "An Thạch, Tuy An, Phú Yên",
  "An Định, Tuy An, Phú Yên",
  "An Nghiệp, Tuy An, Phú Yên",
  "An Cư, Tuy An, Phú Yên",
  "An Xuân, Tuy An, Phú Yên",
  "An Lĩnh, Tuy An, Phú Yên",
  "An Hòa Hải, Tuy An, Phú Yên",
  "An Hiệp, Tuy An, Phú Yên",
  "An Mỹ, Tuy An, Phú Yên",
  "An Chấn, Tuy An, Phú Yên",
  "An Thọ, Tuy An, Phú Yên",
  "Củng Sơn, Sơn Hòa, Phú Yên",
  "Phước Tân, Sơn Hòa, Phú Yên",
  "Sơn Hội, Sơn Hòa, Phú Yên",
  "Sơn Định, Sơn Hòa, Phú Yên",
  "Sơn Long, Sơn Hòa, Phú Yên",
  "Cà Lúi, Sơn Hòa, Phú Yên",
  "Sơn Phước, Sơn Hòa, Phú Yên",
  "Sơn Xuân, Sơn Hòa, Phú Yên",
  "Sơn Nguyên, Sơn Hòa, Phú Yên",
  "Eachà Rang, Sơn Hòa, Phú Yên",
  "Krông Pa, Sơn Hòa, Phú Yên",
  "Suối Bạc, Sơn Hòa, Phú Yên",
  "Sơn Hà, Sơn Hòa, Phú Yên",
  "Suối Trai, Sơn Hòa, Phú Yên",
  "Hai Riêng, Sông Hinh, Phú Yên",
  "Ea Lâm, Sông Hinh, Phú Yên",
  "Đức Bình Tây, Sông Hinh, Phú Yên",
  "Ea Bá, Sông Hinh, Phú Yên",
  "Sơn Giang, Sông Hinh, Phú Yên",
  "Đức Bình Đông, Sông Hinh, Phú Yên",
  "EaBar, Sông Hinh, Phú Yên",
  "EaBia, Sông Hinh, Phú Yên",
  "EaTrol, Sông Hinh, Phú Yên",
  "Sông Hinh, Sông Hinh, Phú Yên",
  "Ealy, Sông Hinh, Phú Yên",
  "Sơn Thành Tây, Tây Hoà, Phú Yên",
  "Sơn Thành Đông, Tây Hoà, Phú Yên",
  "Hòa Bình 1, Tây Hoà, Phú Yên",
  "Phú Thứ, Tây Hoà, Phú Yên",
  "Hòa Phong, Tây Hoà, Phú Yên",
  "Hòa Phú, Tây Hoà, Phú Yên",
  "Hòa Tân Tây, Tây Hoà, Phú Yên",
  "Hòa Đồng, Tây Hoà, Phú Yên",
  "Hòa Mỹ Đông, Tây Hoà, Phú Yên",
  "Hòa Mỹ Tây, Tây Hoà, Phú Yên",
  "Hòa Thịnh, Tây Hoà, Phú Yên",
  "Hòa Quang Bắc, Phú Hoà, Phú Yên",
  "Hòa Quang Nam, Phú Hoà, Phú Yên",
  "Hòa Hội, Phú Hoà, Phú Yên",
  "Hòa Trị, Phú Hoà, Phú Yên",
  "Hòa An, Phú Hoà, Phú Yên",
  "Hòa Định Đông, Phú Hoà, Phú Yên",
  "Phú Hoà, Phú Hoà, Phú Yên",
  "Hòa Định Tây, Phú Hoà, Phú Yên",
  "Hòa Thắng, Phú Hoà, Phú Yên",
  "Hòa Thành, Đông Hòa, Phú Yên",
  "Hòa Hiệp Bắc, Đông Hòa, Phú Yên",
  "Hoà Vinh, Đông Hòa, Phú Yên",
  "Hoà Hiệp Trung, Đông Hòa, Phú Yên",
  "Hòa Tân Đông, Đông Hòa, Phú Yên",
  "Hòa Xuân Tây, Đông Hòa, Phú Yên",
  "Hòa Hiệp Nam, Đông Hòa, Phú Yên",
  "Hòa Xuân Đông, Đông Hòa, Phú Yên",
  "Hòa Tâm, Đông Hòa, Phú Yên",
  "Hòa Xuân Nam, Đông Hòa, Phú Yên",
  "Vĩnh Hòa, Nha Trang, Khánh Hòa",
  "Vĩnh Hải, Nha Trang, Khánh Hòa",
  "Vĩnh Phước, Nha Trang, Khánh Hòa",
  "Ngọc Hiệp, Nha Trang, Khánh Hòa",
  "Vĩnh Thọ, Nha Trang, Khánh Hòa",
  "Xương Huân, Nha Trang, Khánh Hòa",
  "Vạn Thắng, Nha Trang, Khánh Hòa",
  "Vạn Thạnh, Nha Trang, Khánh Hòa",
  "Phương Sài, Nha Trang, Khánh Hòa",
  "Phương Sơn, Nha Trang, Khánh Hòa",
  "Phước Hải, Nha Trang, Khánh Hòa",
  "Phước Tân, Nha Trang, Khánh Hòa",
  "Lộc Thọ, Nha Trang, Khánh Hòa",
  "Phước Tiến, Nha Trang, Khánh Hòa",
  "Tân Lập, Nha Trang, Khánh Hòa",
  "Phước Hòa, Nha Trang, Khánh Hòa",
  "Vĩnh Nguyên, Nha Trang, Khánh Hòa",
  "Phước Long, Nha Trang, Khánh Hòa",
  "Vĩnh Trường, Nha Trang, Khánh Hòa",
  "Vĩnh Lương, Nha Trang, Khánh Hòa",
  "Vĩnh Phương, Nha Trang, Khánh Hòa",
  "Vĩnh Ngọc, Nha Trang, Khánh Hòa",
  "Vĩnh Thạnh, Nha Trang, Khánh Hòa",
  "Vĩnh Trung, Nha Trang, Khánh Hòa",
  "Vĩnh Hiệp, Nha Trang, Khánh Hòa",
  "Vĩnh Thái, Nha Trang, Khánh Hòa",
  "Phước Đồng, Nha Trang, Khánh Hòa",
  "Cam Nghĩa, Cam Ranh, Khánh Hòa",
  "Cam Phúc Bắc, Cam Ranh, Khánh Hòa",
  "Cam Phúc Nam, Cam Ranh, Khánh Hòa",
  "Cam Lộc, Cam Ranh, Khánh Hòa",
  "Cam Phú, Cam Ranh, Khánh Hòa",
  "Ba Ngòi, Cam Ranh, Khánh Hòa",
  "Cam Thuận, Cam Ranh, Khánh Hòa",
  "Cam Lợi, Cam Ranh, Khánh Hòa",
  "Cam Linh, Cam Ranh, Khánh Hòa",
  "Cam Thành Nam, Cam Ranh, Khánh Hòa",
  "Cam Phước Đông, Cam Ranh, Khánh Hòa",
  "Cam Thịnh Tây, Cam Ranh, Khánh Hòa",
  "Cam Thịnh Đông, Cam Ranh, Khánh Hòa",
  "Cam Lập, Cam Ranh, Khánh Hòa",
  "Cam Bình, Cam Ranh, Khánh Hòa",
  "Cam Tân, Cam Lâm, Khánh Hòa",
  "Cam Hòa, Cam Lâm, Khánh Hòa",
  "Cam Hải Đông, Cam Lâm, Khánh Hòa",
  "Cam Hải Tây, Cam Lâm, Khánh Hòa",
  "Sơn Tân, Cam Lâm, Khánh Hòa",
  "Cam Hiệp Bắc, Cam Lâm, Khánh Hòa",
  "Cam Đức, Cam Lâm, Khánh Hòa",
  "Cam Hiệp Nam, Cam Lâm, Khánh Hòa",
  "Cam Phước Tây, Cam Lâm, Khánh Hòa",
  "Cam Thành Bắc, Cam Lâm, Khánh Hòa",
  "Cam An Bắc, Cam Lâm, Khánh Hòa",
  "Cam An Nam, Cam Lâm, Khánh Hòa",
  "Suối Cát, Cam Lâm, Khánh Hòa",
  "Suối Tân, Cam Lâm, Khánh Hòa",
  "Vạn Giã, Vạn Ninh, Khánh Hòa",
  "Đại Lãnh, Vạn Ninh, Khánh Hòa",
  "Vạn Phước, Vạn Ninh, Khánh Hòa",
  "Vạn Long, Vạn Ninh, Khánh Hòa",
  "Vạn Bình, Vạn Ninh, Khánh Hòa",
  "Vạn Thọ, Vạn Ninh, Khánh Hòa",
  "Vạn Khánh, Vạn Ninh, Khánh Hòa",
  "Vạn Phú, Vạn Ninh, Khánh Hòa",
  "Vạn Lương, Vạn Ninh, Khánh Hòa",
  "Vạn Thắng, Vạn Ninh, Khánh Hòa",
  "Vạn Thạnh, Vạn Ninh, Khánh Hòa",
  "Xuân Sơn, Vạn Ninh, Khánh Hòa",
  "Vạn Hưng, Vạn Ninh, Khánh Hòa",
  "Ninh Hiệp, Ninh Hòa, Khánh Hòa",
  "Ninh Sơn, Ninh Hòa, Khánh Hòa",
  "Ninh Tây, Ninh Hòa, Khánh Hòa",
  "Ninh Thượng, Ninh Hòa, Khánh Hòa",
  "Ninh An, Ninh Hòa, Khánh Hòa",
  "Ninh Hải, Ninh Hòa, Khánh Hòa",
  "Ninh Thọ, Ninh Hòa, Khánh Hòa",
  "Ninh Trung, Ninh Hòa, Khánh Hòa",
  "Ninh Sim, Ninh Hòa, Khánh Hòa",
  "Ninh Xuân, Ninh Hòa, Khánh Hòa",
  "Ninh Thân, Ninh Hòa, Khánh Hòa",
  "Ninh Diêm, Ninh Hòa, Khánh Hòa",
  "Ninh Đông, Ninh Hòa, Khánh Hòa",
  "Ninh Thủy, Ninh Hòa, Khánh Hòa",
  "Ninh Đa, Ninh Hòa, Khánh Hòa",
  "Ninh Phụng, Ninh Hòa, Khánh Hòa",
  "Ninh Bình, Ninh Hòa, Khánh Hòa",
  "Ninh Phước, Ninh Hòa, Khánh Hòa",
  "Ninh Phú, Ninh Hòa, Khánh Hòa",
  "Ninh Tân, Ninh Hòa, Khánh Hòa",
  "Ninh Quang, Ninh Hòa, Khánh Hòa",
  "Ninh Giang, Ninh Hòa, Khánh Hòa",
  "Ninh Hà, Ninh Hòa, Khánh Hòa",
  "Ninh Hưng, Ninh Hòa, Khánh Hòa",
  "Ninh Lộc, Ninh Hòa, Khánh Hòa",
  "Ninh Ích, Ninh Hòa, Khánh Hòa",
  "Ninh Vân, Ninh Hòa, Khánh Hòa",
  "Khánh Vĩnh, Khánh Vĩnh, Khánh Hòa",
  "Khánh Hiệp, Khánh Vĩnh, Khánh Hòa",
  "Khánh Bình, Khánh Vĩnh, Khánh Hòa",
  "Khánh Trung, Khánh Vĩnh, Khánh Hòa",
  "Khánh Đông, Khánh Vĩnh, Khánh Hòa",
  "Khánh Thượng, Khánh Vĩnh, Khánh Hòa",
  "Khánh Nam, Khánh Vĩnh, Khánh Hòa",
  "Sông Cầu, Khánh Vĩnh, Khánh Hòa",
  "Giang Ly, Khánh Vĩnh, Khánh Hòa",
  "Cầu Bà, Khánh Vĩnh, Khánh Hòa",
  "Liên Sang, Khánh Vĩnh, Khánh Hòa",
  "Khánh Thành, Khánh Vĩnh, Khánh Hòa",
  "Khánh Phú, Khánh Vĩnh, Khánh Hòa",
  "Sơn Thái, Khánh Vĩnh, Khánh Hòa",
  "Diên Khánh, Diên Khánh, Khánh Hòa",
  "Diên Lâm, Diên Khánh, Khánh Hòa",
  "Diên Điền, Diên Khánh, Khánh Hòa",
  "Diên Xuân, Diên Khánh, Khánh Hòa",
  "Diên Sơn, Diên Khánh, Khánh Hòa",
  "Diên Đồng, Diên Khánh, Khánh Hòa",
  "Diên Phú, Diên Khánh, Khánh Hòa",
  "Diên Thọ, Diên Khánh, Khánh Hòa",
  "Diên Phước, Diên Khánh, Khánh Hòa",
  "Diên Lạc, Diên Khánh, Khánh Hòa",
  "Diên Tân, Diên Khánh, Khánh Hòa",
  "Diên Hòa, Diên Khánh, Khánh Hòa",
  "Diên Thạnh, Diên Khánh, Khánh Hòa",
  "Diên Toàn, Diên Khánh, Khánh Hòa",
  "Diên An, Diên Khánh, Khánh Hòa",
  "Bình Lộc, Diên Khánh, Khánh Hòa",
  "Suối Hiệp, Diên Khánh, Khánh Hòa",
  "Suối Tiên, Diên Khánh, Khánh Hòa",
  "Tô Hạp, Khánh Sơn, Khánh Hòa",
  "Thành Sơn, Khánh Sơn, Khánh Hòa",
  "Sơn Lâm, Khánh Sơn, Khánh Hòa",
  "Sơn Hiệp, Khánh Sơn, Khánh Hòa",
  "Sơn Bình, Khánh Sơn, Khánh Hòa",
  "Sơn Trung, Khánh Sơn, Khánh Hòa",
  "Ba Cụm Bắc, Khánh Sơn, Khánh Hòa",
  "Ba Cụm Nam, Khánh Sơn, Khánh Hòa",
  "Trường Sa, Trường Sa, Khánh Hòa",
  "Song Tử Tây, Trường Sa, Khánh Hòa",
  "Sinh Tồn, Trường Sa, Khánh Hòa",
  "Đô Vinh, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Phước Mỹ, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Bảo An, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Phủ Hà, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Thanh Sơn, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Mỹ Hương, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Tấn Tài, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Kinh Dinh, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Đạo Long, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Đài Sơn, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Đông Hải, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Mỹ Đông, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Thành Hải, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Văn Hải, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Mỹ Bình, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Mỹ Hải, Phan Rang-Tháp Chàm, Ninh Thuận",
  "Phước Bình, Bác Ái, Ninh Thuận",
  "Phước Hòa, Bác Ái, Ninh Thuận",
  "Phước Tân, Bác Ái, Ninh Thuận",
  "Phước Tiến, Bác Ái, Ninh Thuận",
  "Phước Thắng, Bác Ái, Ninh Thuận",
  "Phước Thành, Bác Ái, Ninh Thuận",
  "Phước Đại, Bác Ái, Ninh Thuận",
  "Phước Chính, Bác Ái, Ninh Thuận",
  "Phước Trung, Bác Ái, Ninh Thuận",
  "Tân Sơn, Ninh Sơn, Ninh Thuận",
  "Lâm Sơn, Ninh Sơn, Ninh Thuận",
  "Lương Sơn, Ninh Sơn, Ninh Thuận",
  "Quảng Sơn, Ninh Sơn, Ninh Thuận",
  "Mỹ Sơn, Ninh Sơn, Ninh Thuận",
  "Hòa Sơn, Ninh Sơn, Ninh Thuận",
  "Ma Nới, Ninh Sơn, Ninh Thuận",
  "Nhơn Sơn, Ninh Sơn, Ninh Thuận",
  "Khánh Hải, Ninh Hải, Ninh Thuận",
  "Vĩnh Hải, Ninh Hải, Ninh Thuận",
  "Phương Hải, Ninh Hải, Ninh Thuận",
  "Tân Hải, Ninh Hải, Ninh Thuận",
  "Xuân Hải, Ninh Hải, Ninh Thuận",
  "Hộ Hải, Ninh Hải, Ninh Thuận",
  "Tri Hải, Ninh Hải, Ninh Thuận",
  "Nhơn Hải, Ninh Hải, Ninh Thuận",
  "Thanh Hải, Ninh Hải, Ninh Thuận",
  "Phước Dân, Ninh Phước, Ninh Thuận",
  "Phước Sơn, Ninh Phước, Ninh Thuận",
  "Phước Thái, Ninh Phước, Ninh Thuận",
  "Phước Hậu, Ninh Phước, Ninh Thuận",
  "Phước Thuận, Ninh Phước, Ninh Thuận",
  "An Hải, Ninh Phước, Ninh Thuận",
  "Phước Hữu, Ninh Phước, Ninh Thuận",
  "Phước Hải, Ninh Phước, Ninh Thuận",
  "Phước Vinh, Ninh Phước, Ninh Thuận",
  "Phước Chiến, Thuận Bắc, Ninh Thuận",
  "Công Hải, Thuận Bắc, Ninh Thuận",
  "Phước Kháng, Thuận Bắc, Ninh Thuận",
  "Lợi Hải, Thuận Bắc, Ninh Thuận",
  "Bắc Sơn, Thuận Bắc, Ninh Thuận",
  "Bắc Phong, Thuận Bắc, Ninh Thuận",
  "Phước Hà, Thuận Nam, Ninh Thuận",
  "Phước Nam, Thuận Nam, Ninh Thuận",
  "Phước Ninh, Thuận Nam, Ninh Thuận",
  "Nhị Hà, Thuận Nam, Ninh Thuận",
  "Phước Dinh, Thuận Nam, Ninh Thuận",
  "Phước Minh, Thuận Nam, Ninh Thuận",
  "Phước Diêm, Thuận Nam, Ninh Thuận",
  "Cà Ná, Thuận Nam, Ninh Thuận",
  "Mũi Né, Phan Thiết, Bình Thuận",
  "Hàm Tiến, Phan Thiết, Bình Thuận",
  "Phú Hài, Phan Thiết, Bình Thuận",
  "Phú Thủy, Phan Thiết, Bình Thuận",
  "Phú Tài, Phan Thiết, Bình Thuận",
  "Phú Trinh, Phan Thiết, Bình Thuận",
  "Xuân An, Phan Thiết, Bình Thuận",
  "Thanh Hải, Phan Thiết, Bình Thuận",
  "Bình Hưng, Phan Thiết, Bình Thuận",
  "Đức Nghĩa, Phan Thiết, Bình Thuận",
  "Lạc Đạo, Phan Thiết, Bình Thuận",
  "Đức Thắng, Phan Thiết, Bình Thuận",
  "Hưng Long, Phan Thiết, Bình Thuận",
  "Đức Long, Phan Thiết, Bình Thuận",
  "Thiện Nghiệp, Phan Thiết, Bình Thuận",
  "Phong Nẫm, Phan Thiết, Bình Thuận",
  "Tiến Lợi, Phan Thiết, Bình Thuận",
  "Tiến Thành, Phan Thiết, Bình Thuận",
  "Phước Hội, La Gi, Bình Thuận",
  "Phước Lộc, La Gi, Bình Thuận",
  "Tân Thiện, La Gi, Bình Thuận",
  "Tân An, La Gi, Bình Thuận",
  "Bình Tân, La Gi, Bình Thuận",
  "Tân Hải, La Gi, Bình Thuận",
  "Tân Tiến, La Gi, Bình Thuận",
  "Tân Bình, La Gi, Bình Thuận",
  "Tân Phước, La Gi, Bình Thuận",
  "Liên Hương, Tuy Phong, Bình Thuận",
  "Phan Rí Cửa, Tuy Phong, Bình Thuận",
  "Phan Dũng, Tuy Phong, Bình Thuận",
  "Phong Phú, Tuy Phong, Bình Thuận",
  "Vĩnh Hảo, Tuy Phong, Bình Thuận",
  "Vĩnh Tân, Tuy Phong, Bình Thuận",
  "Phú Lạc, Tuy Phong, Bình Thuận",
  "Phước Thể, Tuy Phong, Bình Thuận",
  "Hòa Minh, Tuy Phong, Bình Thuận",
  "Chí Công, Tuy Phong, Bình Thuận",
  "Bình Thạnh, Tuy Phong, Bình Thuận",
  "Chợ Lầu, Bắc Bình, Bình Thuận",
  "Phan Sơn, Bắc Bình, Bình Thuận",
  "Phan Lâm, Bắc Bình, Bình Thuận",
  "Bình An, Bắc Bình, Bình Thuận",
  "Phan Điền, Bắc Bình, Bình Thuận",
  "Hải Ninh, Bắc Bình, Bình Thuận",
  "Sông Lũy, Bắc Bình, Bình Thuận",
  "Phan Tiến, Bắc Bình, Bình Thuận",
  "Sông Bình, Bắc Bình, Bình Thuận",
  "Lương Sơn, Bắc Bình, Bình Thuận",
  "Phan Hòa, Bắc Bình, Bình Thuận",
  "Phan Thanh, Bắc Bình, Bình Thuận",
  "Hồng Thái, Bắc Bình, Bình Thuận",
  "Phan Hiệp, Bắc Bình, Bình Thuận",
  "Bình Tân, Bắc Bình, Bình Thuận",
  "Phan Rí Thành, Bắc Bình, Bình Thuận",
  "Hòa Thắng, Bắc Bình, Bình Thuận",
  "Hồng Phong, Bắc Bình, Bình Thuận",
  "Ma Lâm, Hàm Thuận Bắc, Bình Thuận",
  "Phú Long, Hàm Thuận Bắc, Bình Thuận",
  "La Dạ, Hàm Thuận Bắc, Bình Thuận",
  "Đông Tiến, Hàm Thuận Bắc, Bình Thuận",
  "Thuận Hòa, Hàm Thuận Bắc, Bình Thuận",
  "Đông Giang, Hàm Thuận Bắc, Bình Thuận",
  "Hàm Phú, Hàm Thuận Bắc, Bình Thuận",
  "Hồng Liêm, Hàm Thuận Bắc, Bình Thuận",
  "Thuận Minh, Hàm Thuận Bắc, Bình Thuận",
  "Hồng Sơn, Hàm Thuận Bắc, Bình Thuận",
  "Hàm Trí, Hàm Thuận Bắc, Bình Thuận",
  "Hàm Đức, Hàm Thuận Bắc, Bình Thuận",
  "Hàm Liêm, Hàm Thuận Bắc, Bình Thuận",
  "Hàm Chính, Hàm Thuận Bắc, Bình Thuận",
  "Hàm Hiệp, Hàm Thuận Bắc, Bình Thuận",
  "Hàm Thắng, Hàm Thuận Bắc, Bình Thuận",
  "Đa Mi, Hàm Thuận Bắc, Bình Thuận",
  "Thuận Nam, Hàm Thuận Nam, Bình Thuận",
  "Mỹ Thạnh, Hàm Thuận Nam, Bình Thuận",
  "Hàm Cần, Hàm Thuận Nam, Bình Thuận",
  "Mương Mán, Hàm Thuận Nam, Bình Thuận",
  "Hàm Thạnh, Hàm Thuận Nam, Bình Thuận",
  "Hàm Kiệm, Hàm Thuận Nam, Bình Thuận",
  "Hàm Cường, Hàm Thuận Nam, Bình Thuận",
  "Hàm Mỹ, Hàm Thuận Nam, Bình Thuận",
  "Tân Lập, Hàm Thuận Nam, Bình Thuận",
  "Hàm Minh, Hàm Thuận Nam, Bình Thuận",
  "Thuận Quí, Hàm Thuận Nam, Bình Thuận",
  "Tân Thuận, Hàm Thuận Nam, Bình Thuận",
  "Tân Thành, Hàm Thuận Nam, Bình Thuận",
  "Lạc Tánh, Tánh Linh, Bình Thuận",
  "Bắc Ruộng, Tánh Linh, Bình Thuận",
  "Nghị Đức, Tánh Linh, Bình Thuận",
  "La Ngâu, Tánh Linh, Bình Thuận",
  "Huy Khiêm, Tánh Linh, Bình Thuận",
  "Măng Tố, Tánh Linh, Bình Thuận",
  "Đức Phú, Tánh Linh, Bình Thuận",
  "Đồng Kho, Tánh Linh, Bình Thuận",
  "Gia An, Tánh Linh, Bình Thuận",
  "Đức Bình, Tánh Linh, Bình Thuận",
  "Gia Huynh, Tánh Linh, Bình Thuận",
  "Đức Thuận, Tánh Linh, Bình Thuận",
  "Suối Kiết, Tánh Linh, Bình Thuận",
  "Võ Xu, Đức Linh, Bình Thuận",
  "Đức Tài, Đức Linh, Bình Thuận",
  "Đa Kai, Đức Linh, Bình Thuận",
  "Sùng Nhơn, Đức Linh, Bình Thuận",
  "Mê Pu, Đức Linh, Bình Thuận",
  "Nam Chính, Đức Linh, Bình Thuận",
  "Đức Hạnh, Đức Linh, Bình Thuận",
  "Đức Tín, Đức Linh, Bình Thuận",
  "Vũ Hoà, Đức Linh, Bình Thuận",
  "Tân Hà, Đức Linh, Bình Thuận",
  "Đông Hà, Đức Linh, Bình Thuận",
  "Trà Tân, Đức Linh, Bình Thuận",
  "Tân Minh, Hàm Tân, Bình Thuận",
  "Tân Nghĩa, Hàm Tân, Bình Thuận",
  "Sông Phan, Hàm Tân, Bình Thuận",
  "Tân Phúc, Hàm Tân, Bình Thuận",
  "Tân Đức, Hàm Tân, Bình Thuận",
  "Tân Thắng, Hàm Tân, Bình Thuận",
  "Thắng Hải, Hàm Tân, Bình Thuận",
  "Tân Hà, Hàm Tân, Bình Thuận",
  "Tân Xuân, Hàm Tân, Bình Thuận",
  "Sơn Mỹ, Hàm Tân, Bình Thuận",
  "Ngũ Phụng, Phú Quí, Bình Thuận",
  "Long Hải, Phú Quí, Bình Thuận",
  "Tam Thanh, Phú Quí, Bình Thuận",
  "Quang Trung, Kon Tum, Kon Tum",
  "Duy Tân, Kon Tum, Kon Tum",
  "Quyết Thắng, Kon Tum, Kon Tum",
  "Trường Chinh, Kon Tum, Kon Tum",
  "Thắng Lợi, Kon Tum, Kon Tum",
  "Ngô Mây, Kon Tum, Kon Tum",
  "Thống Nhất, Kon Tum, Kon Tum",
  "Lê Lợi, Kon Tum, Kon Tum",
  "Nguyễn Trãi, Kon Tum, Kon Tum",
  "Trần Hưng Đạo, Kon Tum, Kon Tum",
  "Đắk Cấm, Kon Tum, Kon Tum",
  "Kroong, Kon Tum, Kon Tum",
  "Ngọk Bay, Kon Tum, Kon Tum",
  "Vinh Quang, Kon Tum, Kon Tum",
  "Đắk Blà, Kon Tum, Kon Tum",
  "Ia Chim, Kon Tum, Kon Tum",
  "Đăk Năng, Kon Tum, Kon Tum",
  "Đoàn Kết, Kon Tum, Kon Tum",
  "Chư Hreng, Kon Tum, Kon Tum",
  "Đắk Rơ Wa, Kon Tum, Kon Tum",
  "Hòa Bình, Kon Tum, Kon Tum",
  "Đắk Glei, Đắk Glei, Kon Tum",
  "Đắk Blô, Đắk Glei, Kon Tum",
  "Đắk Man, Đắk Glei, Kon Tum",
  "Đắk Nhoong, Đắk Glei, Kon Tum",
  "Đắk Pék, Đắk Glei, Kon Tum",
  "Đắk Choong, Đắk Glei, Kon Tum",
  "Xốp, Đắk Glei, Kon Tum",
  "Mường Hoong, Đắk Glei, Kon Tum",
  "Ngọc Linh, Đắk Glei, Kon Tum",
  "Đắk Long, Đắk Glei, Kon Tum",
  "Đắk KRoong, Đắk Glei, Kon Tum",
  "Đắk Môn, Đắk Glei, Kon Tum",
  "Plei Kần, Ngọc Hồi, Kon Tum",
  "Đắk Ang, Ngọc Hồi, Kon Tum",
  "Đắk Dục, Ngọc Hồi, Kon Tum",
  "Đắk Nông, Ngọc Hồi, Kon Tum",
  "Đắk Xú, Ngọc Hồi, Kon Tum",
  "Đắk Kan, Ngọc Hồi, Kon Tum",
  "Bờ Y, Ngọc Hồi, Kon Tum",
  "Sa Loong, Ngọc Hồi, Kon Tum",
  "Đắk Tô, Đắk Tô, Kon Tum",
  "Đắk Rơ Nga, Đắk Tô, Kon Tum",
  "Ngọk Tụ, Đắk Tô, Kon Tum",
  "Đắk Trăm, Đắk Tô, Kon Tum",
  "Văn Lem, Đắk Tô, Kon Tum",
  "Kon Đào, Đắk Tô, Kon Tum",
  "Tân Cảnh, Đắk Tô, Kon Tum",
  "Diên Bình, Đắk Tô, Kon Tum",
  "Pô Kô, Đắk Tô, Kon Tum",
  "Đắk Nên, Kon Plông, Kon Tum",
  "Đắk Ring, Kon Plông, Kon Tum",
  "Măng Buk, Kon Plông, Kon Tum",
  "Đắk Tăng, Kon Plông, Kon Tum",
  "Ngok Tem, Kon Plông, Kon Tum",
  "Pờ Ê, Kon Plông, Kon Tum",
  "Măng Cành, Kon Plông, Kon Tum",
  "Măng Đen, Kon Plông, Kon Tum",
  "Hiếu, Kon Plông, Kon Tum",
  "Đắk Rve, Kon Rẫy, Kon Tum",
  "Đắk Kôi, Kon Rẫy, Kon Tum",
  "Đắk Tơ Lung, Kon Rẫy, Kon Tum",
  "Đắk Ruồng, Kon Rẫy, Kon Tum",
  "Đắk Pne, Kon Rẫy, Kon Tum",
  "Đắk Tờ Re, Kon Rẫy, Kon Tum",
  "Tân Lập, Kon Rẫy, Kon Tum",
  "Đắk Hà, Đắk Hà, Kon Tum",
  "Đắk PXi, Đắk Hà, Kon Tum",
  "Đăk Long, Đắk Hà, Kon Tum",
  "Đắk HRing, Đắk Hà, Kon Tum",
  "Đắk Ui, Đắk Hà, Kon Tum",
  "Đăk Ngọk, Đắk Hà, Kon Tum",
  "Đắk Mar, Đắk Hà, Kon Tum",
  "Ngok Wang, Đắk Hà, Kon Tum",
  "Ngok Réo, Đắk Hà, Kon Tum",
  "Hà Mòn, Đắk Hà, Kon Tum",
  "Đắk La, Đắk Hà, Kon Tum",
  "Sa Thầy, Sa Thầy, Kon Tum",
  "Rơ Kơi, Sa Thầy, Kon Tum",
  "Sa Nhơn, Sa Thầy, Kon Tum",
  "Hơ Moong, Sa Thầy, Kon Tum",
  "Mô Rai, Sa Thầy, Kon Tum",
  "Sa Sơn, Sa Thầy, Kon Tum",
  "Sa Nghĩa, Sa Thầy, Kon Tum",
  "Sa Bình, Sa Thầy, Kon Tum",
  "Ya Xiêr, Sa Thầy, Kon Tum",
  "Ya Tăng, Sa Thầy, Kon Tum",
  "Ya ly, Sa Thầy, Kon Tum",
  "Ngọc Lây, Tu Mơ Rông, Kon Tum",
  "Đắk Na, Tu Mơ Rông, Kon Tum",
  "Măng Ri, Tu Mơ Rông, Kon Tum",
  "Ngọc Yêu, Tu Mơ Rông, Kon Tum",
  "Đắk Sao, Tu Mơ Rông, Kon Tum",
  "Đắk Rơ Ông, Tu Mơ Rông, Kon Tum",
  "Đắk Tờ Kan, Tu Mơ Rông, Kon Tum",
  "Tu Mơ Rông, Tu Mơ Rông, Kon Tum",
  "Đắk Hà, Tu Mơ Rông, Kon Tum",
  "Tê Xăng, Tu Mơ Rông, Kon Tum",
  "Văn Xuôi, Tu Mơ Rông, Kon Tum",
  "Ia Đal, Ia H' Drai, Kon Tum",
  "Ia Dom, Ia H' Drai, Kon Tum",
  "Ia Tơi, Ia H' Drai, Kon Tum",
  "Yên Đỗ, Pleiku, Gia Lai",
  "Diên Hồng, Pleiku, Gia Lai",
  "Ia Kring, Pleiku, Gia Lai",
  "Hội Thương, Pleiku, Gia Lai",
  "Hội Phú, Pleiku, Gia Lai",
  "Phù Đổng, Pleiku, Gia Lai",
  "Hoa Lư, Pleiku, Gia Lai",
  "Tây Sơn, Pleiku, Gia Lai",
  "Thống Nhất, Pleiku, Gia Lai",
  "Đống Đa, Pleiku, Gia Lai",
  "Trà Bá, Pleiku, Gia Lai",
  "Thắng Lợi, Pleiku, Gia Lai",
  "Yên Thế, Pleiku, Gia Lai",
  "Chi Lăng, Pleiku, Gia Lai",
  "Biển Hồ, Pleiku, Gia Lai",
  "Tân Sơn, Pleiku, Gia Lai",
  "Trà Đa, Pleiku, Gia Lai",
  "Chư Á, Pleiku, Gia Lai",
  "An Phú, Pleiku, Gia Lai",
  "Diên Phú, Pleiku, Gia Lai",
  "Ia Kênh, Pleiku, Gia Lai",
  "Gào, Pleiku, Gia Lai",
  "An Bình, An Khê, Gia Lai",
  "Tây Sơn, An Khê, Gia Lai",
  "An Phú, An Khê, Gia Lai",
  "An Tân, An Khê, Gia Lai",
  "Tú An, An Khê, Gia Lai",
  "Xuân An, An Khê, Gia Lai",
  "Cửu An, An Khê, Gia Lai",
  "An Phước, An Khê, Gia Lai",
  "Song An, An Khê, Gia Lai",
  "Ngô Mây, An Khê, Gia Lai",
  "Thành An, An Khê, Gia Lai",
  "Cheo Reo, Ayun Pa, Gia Lai",
  "Hòa Bình, Ayun Pa, Gia Lai",
  "Đoàn Kết, Ayun Pa, Gia Lai",
  "Sông Bờ, Ayun Pa, Gia Lai",
  "Ia RBol, Ayun Pa, Gia Lai",
  "Chư Băh, Ayun Pa, Gia Lai",
  "Ia RTô, Ayun Pa, Gia Lai",
  "Ia Sao, Ayun Pa, Gia Lai",
  "KBang, KBang, Gia Lai",
  "Kon Pne, KBang, Gia Lai",
  "Đăk Roong, KBang, Gia Lai",
  "Sơn Lang, KBang, Gia Lai",
  "KRong, KBang, Gia Lai",
  "Sơ Pai, KBang, Gia Lai",
  "Lơ Ku, KBang, Gia Lai",
  "Đông, KBang, Gia Lai",
  "Đak SMar, KBang, Gia Lai",
  "Nghĩa An, KBang, Gia Lai",
  "Tơ Tung, KBang, Gia Lai",
  "Kông Lơng Khơng, KBang, Gia Lai",
  "Kông Pla, KBang, Gia Lai",
  "Đăk HLơ, KBang, Gia Lai",
  "Đăk Đoa, Đăk Đoa, Gia Lai",
  "Hà Đông, Đăk Đoa, Gia Lai",
  "Đăk Sơmei, Đăk Đoa, Gia Lai",
  "Đăk Krong, Đăk Đoa, Gia Lai",
  "Hải Yang, Đăk Đoa, Gia Lai",
  "Kon Gang, Đăk Đoa, Gia Lai",
  "Hà Bầu, Đăk Đoa, Gia Lai",
  "Nam Yang, Đăk Đoa, Gia Lai",
  "K' Dang, Đăk Đoa, Gia Lai",
  "H' Neng, Đăk Đoa, Gia Lai",
  "Tân Bình, Đăk Đoa, Gia Lai",
  "Glar, Đăk Đoa, Gia Lai",
  "A Dơk, Đăk Đoa, Gia Lai",
  "Trang, Đăk Đoa, Gia Lai",
  "HNol, Đăk Đoa, Gia Lai",
  "Ia Pết, Đăk Đoa, Gia Lai",
  "Ia Băng, Đăk Đoa, Gia Lai",
  "Phú Hòa, Chư Păh, Gia Lai",
  "Hà Tây, Chư Păh, Gia Lai",
  "Ia Khươl, Chư Păh, Gia Lai",
  "Ia Phí, Chư Păh, Gia Lai",
  "Ia Ly, Chư Păh, Gia Lai",
  "Ia Mơ Nông, Chư Păh, Gia Lai",
  "Ia Kreng, Chư Păh, Gia Lai",
  "Đăk Tơ Ver, Chư Păh, Gia Lai",
  "Hòa Phú, Chư Păh, Gia Lai",
  "Chư Đăng Ya, Chư Păh, Gia Lai",
  "Ia Ka, Chư Păh, Gia Lai",
  "Ia Nhin, Chư Păh, Gia Lai",
  "Nghĩa Hòa, Chư Păh, Gia Lai",
  "Nghĩa Hưng, Chư Păh, Gia Lai",
  "Ia Kha, Ia Grai, Gia Lai",
  "Ia Sao, Ia Grai, Gia Lai",
  "Ia Yok, Ia Grai, Gia Lai",
  "Ia Hrung, Ia Grai, Gia Lai",
  "Ia Bă, Ia Grai, Gia Lai",
  "Ia Khai, Ia Grai, Gia Lai",
  "Ia KRai, Ia Grai, Gia Lai",
  "Ia Grăng, Ia Grai, Gia Lai",
  "Ia Tô, Ia Grai, Gia Lai",
  "Ia O, Ia Grai, Gia Lai",
  "Ia Dêr, Ia Grai, Gia Lai",
  "Ia Chia, Ia Grai, Gia Lai",
  "Ia Pếch, Ia Grai, Gia Lai",
  "Kon Dơng, Mang Yang, Gia Lai",
  "Ayun, Mang Yang, Gia Lai",
  "Đak Jơ Ta, Mang Yang, Gia Lai",
  "Đak Ta Ley, Mang Yang, Gia Lai",
  "Hra, Mang Yang, Gia Lai",
  "Đăk Yă, Mang Yang, Gia Lai",
  "Đăk Djrăng, Mang Yang, Gia Lai",
  "Lơ Pang, Mang Yang, Gia Lai",
  "Kon Thụp, Mang Yang, Gia Lai",
  "Đê Ar, Mang Yang, Gia Lai",
  "Kon Chiêng, Mang Yang, Gia Lai",
  "Đăk Trôi, Mang Yang, Gia Lai",
  "Kông Chro, Kông Chro, Gia Lai",
  "Chư Krêy, Kông Chro, Gia Lai",
  "An Trung, Kông Chro, Gia Lai",
  "Kông Yang, Kông Chro, Gia Lai",
  "Đăk Tơ Pang, Kông Chro, Gia Lai",
  "SRó, Kông Chro, Gia Lai",
  "Đắk Kơ Ning, Kông Chro, Gia Lai",
  "Đăk Song, Kông Chro, Gia Lai",
  "Đăk Pling, Kông Chro, Gia Lai",
  "Yang Trung, Kông Chro, Gia Lai",
  "Đăk Pơ Pho, Kông Chro, Gia Lai",
  "Ya Ma, Kông Chro, Gia Lai",
  "Chơ Long, Kông Chro, Gia Lai",
  "Yang Nam, Kông Chro, Gia Lai",
  "Chư Ty, Đức Cơ, Gia Lai",
  "Ia Dơk, Đức Cơ, Gia Lai",
  "Ia Krêl, Đức Cơ, Gia Lai",
  "Ia Din, Đức Cơ, Gia Lai",
  "Ia Kla, Đức Cơ, Gia Lai",
  "Ia Dom, Đức Cơ, Gia Lai",
  "Ia Lang, Đức Cơ, Gia Lai",
  "Ia Kriêng, Đức Cơ, Gia Lai",
  "Ia Pnôn, Đức Cơ, Gia Lai",
  "Ia Nan, Đức Cơ, Gia Lai",
  "Chư Prông, Chư Prông, Gia Lai",
  "Ia Kly, Chư Prông, Gia Lai",
  "Bình Giáo, Chư Prông, Gia Lai",
  "Ia Drăng, Chư Prông, Gia Lai",
  "Thăng Hưng, Chư Prông, Gia Lai",
  "Bàu Cạn, Chư Prông, Gia Lai",
  "Ia Phìn, Chư Prông, Gia Lai",
  "Ia Băng, Chư Prông, Gia Lai",
  "Ia Tôr, Chư Prông, Gia Lai",
  "Ia Boòng, Chư Prông, Gia Lai",
  "Ia O, Chư Prông, Gia Lai",
  "Ia Púch, Chư Prông, Gia Lai",
  "Ia Me, Chư Prông, Gia Lai",
  "Ia Vê, Chư Prông, Gia Lai",
  "Ia Bang, Chư Prông, Gia Lai",
  "Ia Pia, Chư Prông, Gia Lai",
  "Ia Ga, Chư Prông, Gia Lai",
  "Ia Lâu, Chư Prông, Gia Lai",
  "Ia Piơr, Chư Prông, Gia Lai",
  "Ia Mơ, Chư Prông, Gia Lai",
  "Chư Sê, Chư Sê, Gia Lai",
  "Ia Tiêm, Chư Sê, Gia Lai",
  "Chư Pơng, Chư Sê, Gia Lai",
  "Bar Măih, Chư Sê, Gia Lai",
  "Bờ Ngoong, Chư Sê, Gia Lai",
  "Ia Glai, Chư Sê, Gia Lai",
  "AL Bá, Chư Sê, Gia Lai",
  "Kông HTok, Chư Sê, Gia Lai",
  "AYun, Chư Sê, Gia Lai",
  "Ia HLốp, Chư Sê, Gia Lai",
  "Ia Blang, Chư Sê, Gia Lai",
  "Dun, Chư Sê, Gia Lai",
  "Ia Pal, Chư Sê, Gia Lai",
  "H Bông, Chư Sê, Gia Lai",
  "Ia Ko, Chư Sê, Gia Lai",
  "Hà Tam, Đăk Pơ, Gia Lai",
  "An Thành, Đăk Pơ, Gia Lai",
  "Đak Pơ, Đăk Pơ, Gia Lai",
  "Yang Bắc, Đăk Pơ, Gia Lai",
  "Cư An, Đăk Pơ, Gia Lai",
  "Tân An, Đăk Pơ, Gia Lai",
  "Phú An, Đăk Pơ, Gia Lai",
  "Ya Hội, Đăk Pơ, Gia Lai",
  "Pờ Tó, Ia Pa, Gia Lai",
  "Chư Răng, Ia Pa, Gia Lai",
  "Ia KDăm, Ia Pa, Gia Lai",
  "Kim Tân, Ia Pa, Gia Lai",
  "Chư Mố, Ia Pa, Gia Lai",
  "Ia Tul, Ia Pa, Gia Lai",
  "Ia Ma Rơn, Ia Pa, Gia Lai",
  "Ia Broăi, Ia Pa, Gia Lai",
  "Ia Trok, Ia Pa, Gia Lai",
  "Phú Túc, Krông Pa, Gia Lai",
  "Ia RSai, Krông Pa, Gia Lai",
  "Ia RSươm, Krông Pa, Gia Lai",
  "Chư Gu, Krông Pa, Gia Lai",
  "Đất Bằng, Krông Pa, Gia Lai",
  "Ia Mláh, Krông Pa, Gia Lai",
  "Chư Drăng, Krông Pa, Gia Lai",
  "Phú Cần, Krông Pa, Gia Lai",
  "Ia HDreh, Krông Pa, Gia Lai",
  "Ia RMok, Krông Pa, Gia Lai",
  "Chư Ngọc, Krông Pa, Gia Lai",
  "Uar, Krông Pa, Gia Lai",
  "Chư Rcăm, Krông Pa, Gia Lai",
  "Krông Năng, Krông Pa, Gia Lai",
  "Phú Thiện, Phú Thiện, Gia Lai",
  "Chư A Thai, Phú Thiện, Gia Lai",
  "Ayun Hạ, Phú Thiện, Gia Lai",
  "Ia Ake, Phú Thiện, Gia Lai",
  "Ia Sol, Phú Thiện, Gia Lai",
  "Ia Piar, Phú Thiện, Gia Lai",
  "Ia Peng, Phú Thiện, Gia Lai",
  "Chrôh Pơnan, Phú Thiện, Gia Lai",
  "Ia Hiao, Phú Thiện, Gia Lai",
  "Ia Yeng, Phú Thiện, Gia Lai",
  "Nhơn Hoà, Chư Pưh, Gia Lai",
  "Ia Hrú, Chư Pưh, Gia Lai",
  "Ia Rong, Chư Pưh, Gia Lai",
  "Ia Dreng, Chư Pưh, Gia Lai",
  "Ia Hla, Chư Pưh, Gia Lai",
  "Chư Don, Chư Pưh, Gia Lai",
  "Ia Phang, Chư Pưh, Gia Lai",
  "Ia Le, Chư Pưh, Gia Lai",
  "Ia BLứ, Chư Pưh, Gia Lai",
  "Tân Lập, Buôn Ma Thuột, Đắk Lắk",
  "Tân Hòa, Buôn Ma Thuột, Đắk Lắk",
  "Tân An, Buôn Ma Thuột, Đắk Lắk",
  "Thống Nhất, Buôn Ma Thuột, Đắk Lắk",
  "Thành Nhất, Buôn Ma Thuột, Đắk Lắk",
  "Thắng Lợi, Buôn Ma Thuột, Đắk Lắk",
  "Tân Lợi, Buôn Ma Thuột, Đắk Lắk",
  "Thành Công, Buôn Ma Thuột, Đắk Lắk",
  "Tân Thành, Buôn Ma Thuột, Đắk Lắk",
  "Tân Tiến, Buôn Ma Thuột, Đắk Lắk",
  "Tự An, Buôn Ma Thuột, Đắk Lắk",
  "Ea Tam, Buôn Ma Thuột, Đắk Lắk",
  "Khánh Xuân, Buôn Ma Thuột, Đắk Lắk",
  "Hòa Thuận, Buôn Ma Thuột, Đắk Lắk",
  "Cư ÊBur, Buôn Ma Thuột, Đắk Lắk",
  "Ea Tu, Buôn Ma Thuột, Đắk Lắk",
  "Hòa Thắng, Buôn Ma Thuột, Đắk Lắk",
  "Ea Kao, Buôn Ma Thuột, Đắk Lắk",
  "Hòa Phú, Buôn Ma Thuột, Đắk Lắk",
  "Hòa Khánh, Buôn Ma Thuột, Đắk Lắk",
  "Hòa Xuân, Buôn Ma Thuột, Đắk Lắk",
  "An Lạc, Buôn Hồ, Đắk Lắk",
  "An Bình, Buôn Hồ, Đắk Lắk",
  "Thiện An, Buôn Hồ, Đắk Lắk",
  "Đạt Hiếu, Buôn Hồ, Đắk Lắk",
  "Đoàn Kết, Buôn Hồ, Đắk Lắk",
  "Ea Blang, Buôn Hồ, Đắk Lắk",
  "Ea Drông, Buôn Hồ, Đắk Lắk",
  "Thống Nhất, Buôn Hồ, Đắk Lắk",
  "Bình Tân, Buôn Hồ, Đắk Lắk",
  "Ea Siên, Buôn Hồ, Đắk Lắk",
  "Bình Thuận, Buôn Hồ, Đắk Lắk",
  "Cư Bao, Buôn Hồ, Đắk Lắk",
  "Ea Drăng, Ea H'leo, Đắk Lắk",
  "Ea H'leo, Ea H'leo, Đắk Lắk",
  "Ea Sol, Ea H'leo, Đắk Lắk",
  "Ea Ral, Ea H'leo, Đắk Lắk",
  "Ea Wy, Ea H'leo, Đắk Lắk",
  "Cư A Mung, Ea H'leo, Đắk Lắk",
  "Cư Mốt, Ea H'leo, Đắk Lắk",
  "Ea Hiao, Ea H'leo, Đắk Lắk",
  "Ea Khal, Ea H'leo, Đắk Lắk",
  "Dliê Yang, Ea H'leo, Đắk Lắk",
  "Ea Tir, Ea H'leo, Đắk Lắk",
  "Ea Nam, Ea H'leo, Đắk Lắk",
  "Ea Súp, Ea Súp, Đắk Lắk",
  "Ia Lốp, Ea Súp, Đắk Lắk",
  "Ia JLơi, Ea Súp, Đắk Lắk",
  "Ea Rốk, Ea Súp, Đắk Lắk",
  "Ya Tờ Mốt, Ea Súp, Đắk Lắk",
  "Ia RVê, Ea Súp, Đắk Lắk",
  "Ea Lê, Ea Súp, Đắk Lắk",
  "Cư KBang, Ea Súp, Đắk Lắk",
  "Ea Bung, Ea Súp, Đắk Lắk",
  "Cư M'Lan, Ea Súp, Đắk Lắk",
  "Krông Na, Buôn Đôn, Đắk Lắk",
  "Ea Huar, Buôn Đôn, Đắk Lắk",
  "Ea Wer, Buôn Đôn, Đắk Lắk",
  "Tân Hoà, Buôn Đôn, Đắk Lắk",
  "Cuôr KNia, Buôn Đôn, Đắk Lắk",
  "Ea Bar, Buôn Đôn, Đắk Lắk",
  "Ea Nuôl, Buôn Đôn, Đắk Lắk",
  "Ea Pốk, Cư M'gar, Đắk Lắk",
  "Quảng Phú, Cư M'gar, Đắk Lắk",
  "Quảng Tiến, Cư M'gar, Đắk Lắk",
  "Ea Kuêh, Cư M'gar, Đắk Lắk",
  "Ea Kiết, Cư M'gar, Đắk Lắk",
  "Ea Tar, Cư M'gar, Đắk Lắk",
  "Cư Dliê M'nông, Cư M'gar, Đắk Lắk",
  "Ea H'đinh, Cư M'gar, Đắk Lắk",
  "Ea Tul, Cư M'gar, Đắk Lắk",
  "Ea KPam, Cư M'gar, Đắk Lắk",
  "Ea M'DRóh, Cư M'gar, Đắk Lắk",
  "Quảng Hiệp, Cư M'gar, Đắk Lắk",
  "Cư M'gar, Cư M'gar, Đắk Lắk",
  "Ea D'Rơng, Cư M'gar, Đắk Lắk",
  "Ea M'nang, Cư M'gar, Đắk Lắk",
  "Cư Suê, Cư M'gar, Đắk Lắk",
  "Cuor Đăng, Cư M'gar, Đắk Lắk",
  "Cư Né, Krông Búk, Đắk Lắk",
  "Chư KBô, Krông Búk, Đắk Lắk",
  "Cư Pơng, Krông Búk, Đắk Lắk",
  "Ea Sin, Krông Búk, Đắk Lắk",
  "Pơng Drang, Krông Búk, Đắk Lắk",
  "Tân Lập, Krông Búk, Đắk Lắk",
  "Ea Ngai, Krông Búk, Đắk Lắk",
  "Krông Năng, Krông Năng, Đắk Lắk",
  "ĐLiê Ya, Krông Năng, Đắk Lắk",
  "Ea Tóh, Krông Năng, Đắk Lắk",
  "Ea Tam, Krông Năng, Đắk Lắk",
  "Phú Lộc, Krông Năng, Đắk Lắk",
  "Tam Giang, Krông Năng, Đắk Lắk",
  "Ea Puk, Krông Năng, Đắk Lắk",
  "Ea Dăh, Krông Năng, Đắk Lắk",
  "Ea Hồ, Krông Năng, Đắk Lắk",
  "Phú Xuân, Krông Năng, Đắk Lắk",
  "Cư Klông, Krông Năng, Đắk Lắk",
  "Ea Tân, Krông Năng, Đắk Lắk",
  "Ea Kar, Ea Kar, Đắk Lắk",
  "Ea Knốp, Ea Kar, Đắk Lắk",
  "Ea Sô, Ea Kar, Đắk Lắk",
  "Ea Sar, Ea Kar, Đắk Lắk",
  "Xuân Phú, Ea Kar, Đắk Lắk",
  "Cư Huê, Ea Kar, Đắk Lắk",
  "Ea Tih, Ea Kar, Đắk Lắk",
  "Ea Đar, Ea Kar, Đắk Lắk",
  "Ea Kmút, Ea Kar, Đắk Lắk",
  "Cư Ni, Ea Kar, Đắk Lắk",
  "Ea Păl, Ea Kar, Đắk Lắk",
  "Cư Prông, Ea Kar, Đắk Lắk",
  "Ea Ô, Ea Kar, Đắk Lắk",
  "Cư ELang, Ea Kar, Đắk Lắk",
  "Cư Bông, Ea Kar, Đắk Lắk",
  "Cư Jang, Ea Kar, Đắk Lắk",
  "M'Đrắk, M'Đrắk, Đắk Lắk",
  "Cư Prao, M'Đrắk, Đắk Lắk",
  "Ea Pil, M'Đrắk, Đắk Lắk",
  "Ea Lai, M'Đrắk, Đắk Lắk",
  "Ea H'MLay, M'Đrắk, Đắk Lắk",
  "Krông Jing, M'Đrắk, Đắk Lắk",
  "Ea M' Doal, M'Đrắk, Đắk Lắk",
  "Ea Riêng, M'Đrắk, Đắk Lắk",
  "Cư M'ta, M'Đrắk, Đắk Lắk",
  "Cư K Róa, M'Đrắk, Đắk Lắk",
  "Krông Á, M'Đrắk, Đắk Lắk",
  "Cư San, M'Đrắk, Đắk Lắk",
  "Ea Trang, M'Đrắk, Đắk Lắk",
  "Krông Kmar, Krông Bông, Đắk Lắk",
  "Dang Kang, Krông Bông, Đắk Lắk",
  "Cư KTy, Krông Bông, Đắk Lắk",
  "Hòa Thành, Krông Bông, Đắk Lắk",
  "Hòa Tân, Krông Bông, Đắk Lắk",
  "Hòa Phong, Krông Bông, Đắk Lắk",
  "Hòa Lễ, Krông Bông, Đắk Lắk",
  "Yang Reh, Krông Bông, Đắk Lắk",
  "Ea Trul, Krông Bông, Đắk Lắk",
  "Khuê Ngọc Điền, Krông Bông, Đắk Lắk",
  "Cư Pui, Krông Bông, Đắk Lắk",
  "Hòa Sơn, Krông Bông, Đắk Lắk",
  "Cư Drăm, Krông Bông, Đắk Lắk",
  "Yang Mao, Krông Bông, Đắk Lắk",
  "Phước An, Krông Pắc, Đắk Lắk",
  "KRông Búk, Krông Pắc, Đắk Lắk",
  "Ea Kly, Krông Pắc, Đắk Lắk",
  "Ea Kênh, Krông Pắc, Đắk Lắk",
  "Ea Phê, Krông Pắc, Đắk Lắk",
  "Ea KNuec, Krông Pắc, Đắk Lắk",
  "Ea Yông, Krông Pắc, Đắk Lắk",
  "Hòa An, Krông Pắc, Đắk Lắk",
  "Ea Kuăng, Krông Pắc, Đắk Lắk",
  "Hòa Đông, Krông Pắc, Đắk Lắk",
  "Ea Hiu, Krông Pắc, Đắk Lắk",
  "Hòa Tiến, Krông Pắc, Đắk Lắk",
  "Tân Tiến, Krông Pắc, Đắk Lắk",
  "Vụ Bổn, Krông Pắc, Đắk Lắk",
  "Ea Uy, Krông Pắc, Đắk Lắk",
  "Ea Yiêng, Krông Pắc, Đắk Lắk",
  "Buôn Trấp, Krông A Na, Đắk Lắk",
  "Dray Sáp, Krông A Na, Đắk Lắk",
  "Ea Na, Krông A Na, Đắk Lắk",
  "Ea Bông, Krông A Na, Đắk Lắk",
  "Băng A Drênh, Krông A Na, Đắk Lắk",
  "Dur KMăl, Krông A Na, Đắk Lắk",
  "Bình Hòa, Krông A Na, Đắk Lắk",
  "Quảng Điền, Krông A Na, Đắk Lắk",
  "Liên Sơn, Lắk, Đắk Lắk",
  "Yang Tao, Lắk, Đắk Lắk",
  "Bông Krang, Lắk, Đắk Lắk",
  "Đắk Liêng, Lắk, Đắk Lắk",
  "Buôn Triết, Lắk, Đắk Lắk",
  "Buôn Tría, Lắk, Đắk Lắk",
  "Đắk Phơi, Lắk, Đắk Lắk",
  "Đắk Nuê, Lắk, Đắk Lắk",
  "Krông Nô, Lắk, Đắk Lắk",
  "Nam Ka, Lắk, Đắk Lắk",
  "Ea R'Bin, Lắk, Đắk Lắk",
  "Ea Ning, Cư Kuin, Đắk Lắk",
  "Cư Ê Wi, Cư Kuin, Đắk Lắk",
  "Ea Ktur, Cư Kuin, Đắk Lắk",
  "Ea Tiêu, Cư Kuin, Đắk Lắk",
  "Ea BHốk, Cư Kuin, Đắk Lắk",
  "Ea Hu, Cư Kuin, Đắk Lắk",
  "Dray Bhăng, Cư Kuin, Đắk Lắk",
  "Hòa Hiệp, Cư Kuin, Đắk Lắk",
  "Nghĩa Đức, Gia Nghĩa, Đắk Nông",
  "Nghĩa Thành, Gia Nghĩa, Đắk Nông",
  "Nghĩa Phú, Gia Nghĩa, Đắk Nông",
  "Nghĩa Tân, Gia Nghĩa, Đắk Nông",
  "Nghĩa Trung, Gia Nghĩa, Đắk Nông",
  "Đăk R'Moan, Gia Nghĩa, Đắk Nông",
  "Quảng Thành, Gia Nghĩa, Đắk Nông",
  "Đắk Nia, Gia Nghĩa, Đắk Nông",
  "Quảng Sơn, Đăk Glong, Đắk Nông",
  "Quảng Hoà, Đăk Glong, Đắk Nông",
  "Đắk Ha, Đăk Glong, Đắk Nông",
  "Đắk R'Măng, Đăk Glong, Đắk Nông",
  "Quảng Khê, Đăk Glong, Đắk Nông",
  "Đắk Plao, Đăk Glong, Đắk Nông",
  "Đắk Som, Đăk Glong, Đắk Nông",
  "Ea T'Ling, Cư Jút, Đắk Nông",
  "Đắk Wil, Cư Jút, Đắk Nông",
  "Ea Pô, Cư Jút, Đắk Nông",
  "Nam Dong, Cư Jút, Đắk Nông",
  "Đắk DRông, Cư Jút, Đắk Nông",
  "Tâm Thắng, Cư Jút, Đắk Nông",
  "Cư Knia, Cư Jút, Đắk Nông",
  "Trúc Sơn, Cư Jút, Đắk Nông",
  "Đắk Mil, Đắk Mil, Đắk Nông",
  " Đắk Lao, Đắk Mil, Đắk Nông",
  "Đắk R'La, Đắk Mil, Đắk Nông",
  "Đắk Gằn, Đắk Mil, Đắk Nông",
  "Đức Mạnh, Đắk Mil, Đắk Nông",
  "Đắk N'Drót, Đắk Mil, Đắk Nông",
  "Long Sơn, Đắk Mil, Đắk Nông",
  "Đắk Sắk, Đắk Mil, Đắk Nông",
  "Thuận An, Đắk Mil, Đắk Nông",
  "Đức Minh, Đắk Mil, Đắk Nông",
  "Đắk Mâm, Krông Nô, Đắk Nông",
  "Đắk Sôr, Krông Nô, Đắk Nông",
  "Nam Xuân, Krông Nô, Đắk Nông",
  "Buôn Choah, Krông Nô, Đắk Nông",
  "Nam Đà, Krông Nô, Đắk Nông",
  "Tân Thành, Krông Nô, Đắk Nông",
  "Đắk Drô, Krông Nô, Đắk Nông",
  "Nâm Nung, Krông Nô, Đắk Nông",
  "Đức Xuyên, Krông Nô, Đắk Nông",
  "Đắk Nang, Krông Nô, Đắk Nông",
  "Quảng Phú, Krông Nô, Đắk Nông",
  "Nâm N'Đir, Krông Nô, Đắk Nông",
  "Đức An, Đắk Song, Đắk Nông",
  "Đắk Môl, Đắk Song, Đắk Nông",
  "Đắk Hòa, Đắk Song, Đắk Nông",
  "Nam Bình, Đắk Song, Đắk Nông",
  "Thuận Hà, Đắk Song, Đắk Nông",
  "Thuận Hạnh, Đắk Song, Đắk Nông",
  "Đắk N'Dung, Đắk Song, Đắk Nông",
  "Nâm N'Jang, Đắk Song, Đắk Nông",
  "Trường Xuân, Đắk Song, Đắk Nông",
  "Kiến Đức, Đắk R'Lấp, Đắk Nông",
  "Quảng Tín, Đắk R'Lấp, Đắk Nông",
  "Đắk Wer, Đắk R'Lấp, Đắk Nông",
  "Nhân Cơ, Đắk R'Lấp, Đắk Nông",
  "Kiến Thành, Đắk R'Lấp, Đắk Nông",
  "Nghĩa Thắng, Đắk R'Lấp, Đắk Nông",
  "Đạo Nghĩa, Đắk R'Lấp, Đắk Nông",
  "Đắk Sin, Đắk R'Lấp, Đắk Nông",
  "Hưng Bình, Đắk R'Lấp, Đắk Nông",
  "Đắk Ru, Đắk R'Lấp, Đắk Nông",
  "Nhân Đạo, Đắk R'Lấp, Đắk Nông",
  "Quảng Trực, Tuy Đức, Đắk Nông",
  "Đắk Búk So, Tuy Đức, Đắk Nông",
  "Quảng Tâm, Tuy Đức, Đắk Nông",
  "Đắk R'Tíh, Tuy Đức, Đắk Nông",
  "Đắk Ngo, Tuy Đức, Đắk Nông",
  "Quảng Tân, Tuy Đức, Đắk Nông",
  "Phường 7, Đà Lạt, Lâm Đồng",
  "Phường 8, Đà Lạt, Lâm Đồng",
  "Phường 12, Đà Lạt, Lâm Đồng",
  "Phường 9, Đà Lạt, Lâm Đồng",
  "Phường 2, Đà Lạt, Lâm Đồng",
  "Phường 1, Đà Lạt, Lâm Đồng",
  "Phường 6, Đà Lạt, Lâm Đồng",
  "Phường 5, Đà Lạt, Lâm Đồng",
  "Phường 4, Đà Lạt, Lâm Đồng",
  "Phường 10, Đà Lạt, Lâm Đồng",
  "Phường 11, Đà Lạt, Lâm Đồng",
  "Phường 3, Đà Lạt, Lâm Đồng",
  "Xuân Thọ, Đà Lạt, Lâm Đồng",
  "Tà Nung, Đà Lạt, Lâm Đồng",
  "Trạm Hành, Đà Lạt, Lâm Đồng",
  "Xuân Trường, Đà Lạt, Lâm Đồng",
  "Lộc Phát, Bảo Lộc, Lâm Đồng",
  "Lộc Tiến, Bảo Lộc, Lâm Đồng",
  "Phường 2, Bảo Lộc, Lâm Đồng",
  "Phường 1, Bảo Lộc, Lâm Đồng",
  "B'lao, Bảo Lộc, Lâm Đồng",
  "Lộc Sơn, Bảo Lộc, Lâm Đồng",
  "Đạm Bri, Bảo Lộc, Lâm Đồng",
  "Lộc Thanh, Bảo Lộc, Lâm Đồng",
  "Lộc Nga, Bảo Lộc, Lâm Đồng",
  "Lộc Châu, Bảo Lộc, Lâm Đồng",
  "Đại Lào, Bảo Lộc, Lâm Đồng",
  "Đạ Tông, Đam Rông, Lâm Đồng",
  "Đạ Long, Đam Rông, Lâm Đồng",
  "Đạ M' Rong, Đam Rông, Lâm Đồng",
  "Liêng Srônh, Đam Rông, Lâm Đồng",
  "Đạ Rsal, Đam Rông, Lâm Đồng",
  "Rô Men, Đam Rông, Lâm Đồng",
  "Phi Liêng, Đam Rông, Lâm Đồng",
  "Đạ K' Nàng, Đam Rông, Lâm Đồng",
  "Lạc Dương, Lạc Dương, Lâm Đồng",
  "Đạ Chais, Lạc Dương, Lâm Đồng",
  "Đạ Nhim, Lạc Dương, Lâm Đồng",
  "Đưng KNớ, Lạc Dương, Lâm Đồng",
  "Lát, Lạc Dương, Lâm Đồng",
  "Đạ Sar, Lạc Dương, Lâm Đồng",
  "Nam Ban, Lâm Hà, Lâm Đồng",
  "Đinh Văn, Lâm Hà, Lâm Đồng",
  "Phú Sơn, Lâm Hà, Lâm Đồng",
  "Phi Tô, Lâm Hà, Lâm Đồng",
  "Mê Linh, Lâm Hà, Lâm Đồng",
  "Đạ Đờn, Lâm Hà, Lâm Đồng",
  "Phúc Thọ, Lâm Hà, Lâm Đồng",
  "Đông Thanh, Lâm Hà, Lâm Đồng",
  "Gia Lâm, Lâm Hà, Lâm Đồng",
  "Tân Thanh, Lâm Hà, Lâm Đồng",
  "Tân Văn, Lâm Hà, Lâm Đồng",
  "Hoài Đức, Lâm Hà, Lâm Đồng",
  "Tân Hà, Lâm Hà, Lâm Đồng",
  "Liên Hà, Lâm Hà, Lâm Đồng",
  "Đan Phượng, Lâm Hà, Lâm Đồng",
  "Nam Hà, Lâm Hà, Lâm Đồng",
  "D'Ran, Đơn Dương, Lâm Đồng",
  "Thạnh Mỹ, Đơn Dương, Lâm Đồng",
  "Lạc Xuân, Đơn Dương, Lâm Đồng",
  "Đạ Ròn, Đơn Dương, Lâm Đồng",
  "Lạc Lâm, Đơn Dương, Lâm Đồng",
  "Ka Đô, Đơn Dương, Lâm Đồng",
  "Quảng Lập, Đơn Dương, Lâm Đồng",
  "Ka Đơn, Đơn Dương, Lâm Đồng",
  "Tu Tra, Đơn Dương, Lâm Đồng",
  "Pró, Đơn Dương, Lâm Đồng",
  "Liên Nghĩa, Đức Trọng, Lâm Đồng",
  "Hiệp An, Đức Trọng, Lâm Đồng",
  "Liên Hiệp, Đức Trọng, Lâm Đồng",
  "Hiệp Thạnh, Đức Trọng, Lâm Đồng",
  "Bình Thạnh, Đức Trọng, Lâm Đồng",
  "N'Thol Hạ, Đức Trọng, Lâm Đồng",
  "Tân Hội, Đức Trọng, Lâm Đồng",
  "Tân Thành, Đức Trọng, Lâm Đồng",
  "Phú Hội, Đức Trọng, Lâm Đồng",
  "Ninh Gia, Đức Trọng, Lâm Đồng",
  "Tà Năng, Đức Trọng, Lâm Đồng",
  "Đa Quyn, Đức Trọng, Lâm Đồng",
  "Tà Hine, Đức Trọng, Lâm Đồng",
  "Đà Loan, Đức Trọng, Lâm Đồng",
  "Ninh Loan, Đức Trọng, Lâm Đồng",
  "Di Linh, Di Linh, Lâm Đồng",
  "Đinh Trang Thượng, Di Linh, Lâm Đồng",
  "Tân Thượng, Di Linh, Lâm Đồng",
  "Tân Lâm, Di Linh, Lâm Đồng",
  "Tân Châu, Di Linh, Lâm Đồng",
  "Tân Nghĩa, Di Linh, Lâm Đồng",
  "Gia Hiệp, Di Linh, Lâm Đồng",
  "Đinh Lạc, Di Linh, Lâm Đồng",
  "Tam Bố, Di Linh, Lâm Đồng",
  "Đinh Trang Hòa, Di Linh, Lâm Đồng",
  "Liên Đầm, Di Linh, Lâm Đồng",
  "Gung Ré, Di Linh, Lâm Đồng",
  "Bảo Thuận, Di Linh, Lâm Đồng",
  "Hòa Ninh, Di Linh, Lâm Đồng",
  "Hòa Trung, Di Linh, Lâm Đồng",
  "Hòa Nam, Di Linh, Lâm Đồng",
  "Hòa Bắc, Di Linh, Lâm Đồng",
  "Sơn Điền, Di Linh, Lâm Đồng",
  "Gia Bắc, Di Linh, Lâm Đồng",
  "Lộc Thắng, Bảo Lâm, Lâm Đồng",
  "Lộc Bảo, Bảo Lâm, Lâm Đồng",
  "Lộc Lâm, Bảo Lâm, Lâm Đồng",
  "Lộc Phú, Bảo Lâm, Lâm Đồng",
  "Lộc Bắc, Bảo Lâm, Lâm Đồng",
  "B' Lá, Bảo Lâm, Lâm Đồng",
  "Lộc Ngãi, Bảo Lâm, Lâm Đồng",
  "Lộc Quảng, Bảo Lâm, Lâm Đồng",
  "Lộc Tân, Bảo Lâm, Lâm Đồng",
  "Lộc Đức, Bảo Lâm, Lâm Đồng",
  "Lộc An, Bảo Lâm, Lâm Đồng",
  "Tân Lạc, Bảo Lâm, Lâm Đồng",
  "Lộc Thành, Bảo Lâm, Lâm Đồng",
  "Lộc Nam, Bảo Lâm, Lâm Đồng",
  "Đạ M'ri, Đạ Huoai, Lâm Đồng",
  "Ma Đa Guôi, Đạ Huoai, Lâm Đồng",
  "Hà Lâm, Đạ Huoai, Lâm Đồng",
  "Đạ Tồn, Đạ Huoai, Lâm Đồng",
  "Đạ Oai, Đạ Huoai, Lâm Đồng",
  "Đạ Ploa, Đạ Huoai, Lâm Đồng",
  "Ma Đa Guôi, Đạ Huoai, Lâm Đồng",
  "Đoàn Kết, Đạ Huoai, Lâm Đồng",
  "Phước Lộc, Đạ Huoai, Lâm Đồng",
  "Đạ Tẻh, Đạ Tẻh, Lâm Đồng",
  "An Nhơn, Đạ Tẻh, Lâm Đồng",
  "Quốc Oai, Đạ Tẻh, Lâm Đồng",
  "Mỹ Đức, Đạ Tẻh, Lâm Đồng",
  "Quảng Trị, Đạ Tẻh, Lâm Đồng",
  "Đạ Lây, Đạ Tẻh, Lâm Đồng",
  "Triệu Hải, Đạ Tẻh, Lâm Đồng",
  "Đạ Kho, Đạ Tẻh, Lâm Đồng",
  "Đạ Pal, Đạ Tẻh, Lâm Đồng",
  "Cát Tiên, Cát Tiên, Lâm Đồng",
  "Tiên Hoàng, Cát Tiên, Lâm Đồng",
  "Phước Cát 2, Cát Tiên, Lâm Đồng",
  "Gia Viễn, Cát Tiên, Lâm Đồng",
  "Nam Ninh, Cát Tiên, Lâm Đồng",
  "Phước Cát , Cát Tiên, Lâm Đồng",
  "Đức Phổ, Cát Tiên, Lâm Đồng",
  "Quảng Ngãi, Cát Tiên, Lâm Đồng",
  "Đồng Nai Thượng, Cát Tiên, Lâm Đồng",
  "Thác Mơ, Phước Long, Bình Phước",
  "Long Thủy, Phước Long, Bình Phước",
  "Phước Bình, Phước Long, Bình Phước",
  "Long Phước, Phước Long, Bình Phước",
  "Sơn Giang, Phước Long, Bình Phước",
  "Long Giang, Phước Long, Bình Phước",
  "Phước Tín, Phước Long, Bình Phước",
  "Tân Phú, Đồng Xoài, Bình Phước",
  "Tân Đồng, Đồng Xoài, Bình Phước",
  "Tân Bình, Đồng Xoài, Bình Phước",
  "Tân Xuân, Đồng Xoài, Bình Phước",
  "Tân Thiện, Đồng Xoài, Bình Phước",
  "Tân Thành, Đồng Xoài, Bình Phước",
  "Tiến Thành, Đồng Xoài, Bình Phước",
  "Tiến Hưng, Đồng Xoài, Bình Phước",
  "Hưng Chiến, Bình Long, Bình Phước",
  "An Lộc, Bình Long, Bình Phước",
  "Phú Thịnh, Bình Long, Bình Phước",
  "Phú Đức, Bình Long, Bình Phước",
  "Thanh Lương, Bình Long, Bình Phước",
  "Thanh Phú, Bình Long, Bình Phước",
  "Bù Gia Mập, Bù Gia Mập, Bình Phước",
  "Đak Ơ, Bù Gia Mập, Bình Phước",
  "Đức Hạnh, Bù Gia Mập, Bình Phước",
  "Phú Văn, Bù Gia Mập, Bình Phước",
  "Đa Kia, Bù Gia Mập, Bình Phước",
  "Phước Minh, Bù Gia Mập, Bình Phước",
  "Bình Thắng, Bù Gia Mập, Bình Phước",
  "Phú Nghĩa, Bù Gia Mập, Bình Phước",
  "Lộc Ninh, Lộc Ninh, Bình Phước",
  "Lộc Hòa, Lộc Ninh, Bình Phước",
  "Lộc An, Lộc Ninh, Bình Phước",
  "Lộc Tấn, Lộc Ninh, Bình Phước",
  "Lộc Thạnh, Lộc Ninh, Bình Phước",
  "Lộc Hiệp, Lộc Ninh, Bình Phước",
  "Lộc Thiện, Lộc Ninh, Bình Phước",
  "Lộc Thuận, Lộc Ninh, Bình Phước",
  "Lộc Quang, Lộc Ninh, Bình Phước",
  "Lộc Phú, Lộc Ninh, Bình Phước",
  "Lộc Thành, Lộc Ninh, Bình Phước",
  "Lộc Thái, Lộc Ninh, Bình Phước",
  "Lộc Điền, Lộc Ninh, Bình Phước",
  "Lộc Hưng, Lộc Ninh, Bình Phước",
  "Lộc Thịnh, Lộc Ninh, Bình Phước",
  "Lộc Khánh, Lộc Ninh, Bình Phước",
  "Thanh Bình, Bù Đốp, Bình Phước",
  "Hưng Phước, Bù Đốp, Bình Phước",
  "Phước Thiện, Bù Đốp, Bình Phước",
  "Thiện Hưng, Bù Đốp, Bình Phước",
  "Thanh Hòa, Bù Đốp, Bình Phước",
  "Tân Thành, Bù Đốp, Bình Phước",
  "Tân Tiến, Bù Đốp, Bình Phước",
  "Thanh An, Hớn Quản, Bình Phước",
  "An Khương, Hớn Quản, Bình Phước",
  "An Phú, Hớn Quản, Bình Phước",
  "Tân Lợi, Hớn Quản, Bình Phước",
  "Tân Hưng, Hớn Quản, Bình Phước",
  "Minh Đức, Hớn Quản, Bình Phước",
  "Minh Tâm, Hớn Quản, Bình Phước",
  "Phước An, Hớn Quản, Bình Phước",
  "Thanh Bình, Hớn Quản, Bình Phước",
  "Tân Khai, Hớn Quản, Bình Phước",
  "Đồng Nơ, Hớn Quản, Bình Phước",
  "Tân Hiệp, Hớn Quản, Bình Phước",
  "Tân Quan, Hớn Quản, Bình Phước",
  "Tân Phú, Đồng Phú, Bình Phước",
  "Thuận Lợi, Đồng Phú, Bình Phước",
  "Đồng Tâm, Đồng Phú, Bình Phước",
  "Tân Phước, Đồng Phú, Bình Phước",
  "Tân Hưng, Đồng Phú, Bình Phước",
  "Tân Lợi, Đồng Phú, Bình Phước",
  "Tân Lập, Đồng Phú, Bình Phước",
  "Tân Hòa, Đồng Phú, Bình Phước",
  "Thuận Phú, Đồng Phú, Bình Phước",
  "Đồng Tiến, Đồng Phú, Bình Phước",
  "Tân Tiến, Đồng Phú, Bình Phước",
  "Đức Phong, Bù Đăng, Bình Phước",
  "Đường 10, Bù Đăng, Bình Phước",
  "Đak Nhau, Bù Đăng, Bình Phước",
  "Phú Sơn, Bù Đăng, Bình Phước",
  "Thọ Sơn, Bù Đăng, Bình Phước",
  "Bình Minh, Bù Đăng, Bình Phước",
  "Bom Bo, Bù Đăng, Bình Phước",
  "Minh Hưng, Bù Đăng, Bình Phước",
  "Đoàn Kết, Bù Đăng, Bình Phước",
  "Đồng Nai, Bù Đăng, Bình Phước",
  "Đức Liễu, Bù Đăng, Bình Phước",
  "Thống Nhất, Bù Đăng, Bình Phước",
  "Nghĩa Trung, Bù Đăng, Bình Phước",
  "Nghĩa Bình, Bù Đăng, Bình Phước",
  "Đăng Hà, Bù Đăng, Bình Phước",
  "Phước Sơn, Bù Đăng, Bình Phước",
  "Chơn Thành, Chơn Thành, Bình Phước",
  "Thành Tâm, Chơn Thành, Bình Phước",
  "Minh Lập, Chơn Thành, Bình Phước",
  "Quang Minh, Chơn Thành, Bình Phước",
  "Minh Hưng, Chơn Thành, Bình Phước",
  "Minh Long, Chơn Thành, Bình Phước",
  "Minh Thành, Chơn Thành, Bình Phước",
  "Nha Bích, Chơn Thành, Bình Phước",
  "Minh Thắng, Chơn Thành, Bình Phước",
  "Long Bình, Phú Riềng, Bình Phước",
  "Bình Tân, Phú Riềng, Bình Phước",
  "Bình Sơn, Phú Riềng, Bình Phước",
  "Long Hưng, Phú Riềng, Bình Phước",
  "Phước Tân, Phú Riềng, Bình Phước",
  "Bù Nho, Phú Riềng, Bình Phước",
  "Long Hà, Phú Riềng, Bình Phước",
  "Long Tân, Phú Riềng, Bình Phước",
  "Phú Trung, Phú Riềng, Bình Phước",
  "Phú Riềng, Phú Riềng, Bình Phước",
  "Phường 1, Tây Ninh, Tây Ninh",
  "Phường 3, Tây Ninh, Tây Ninh",
  "Phường 4, Tây Ninh, Tây Ninh",
  "Hiệp Ninh, Tây Ninh, Tây Ninh",
  "Phường 2, Tây Ninh, Tây Ninh",
  "Thạnh Tân, Tây Ninh, Tây Ninh",
  "Tân Bình, Tây Ninh, Tây Ninh",
  "Bình Minh, Tây Ninh, Tây Ninh",
  "Ninh Sơn, Tây Ninh, Tây Ninh",
  "Ninh Thạnh, Tây Ninh, Tây Ninh",
  "Tân Biên, Tân Biên, Tây Ninh",
  "Tân Lập, Tân Biên, Tây Ninh",
  "Thạnh Bắc, Tân Biên, Tây Ninh",
  "Tân Bình, Tân Biên, Tây Ninh",
  "Thạnh Bình, Tân Biên, Tây Ninh",
  "Thạnh Tây, Tân Biên, Tây Ninh",
  "Hòa Hiệp, Tân Biên, Tây Ninh",
  "Tân Phong, Tân Biên, Tây Ninh",
  "Mỏ Công, Tân Biên, Tây Ninh",
  "Trà Vong, Tân Biên, Tây Ninh",
  "Tân Châu, Tân Châu, Tây Ninh",
  "Tân Hà, Tân Châu, Tây Ninh",
  "Tân Đông, Tân Châu, Tây Ninh",
  "Tân Hội, Tân Châu, Tây Ninh",
  "Tân Hòa, Tân Châu, Tây Ninh",
  "Suối Ngô, Tân Châu, Tây Ninh",
  "Suối Dây, Tân Châu, Tây Ninh",
  "Tân Hiệp, Tân Châu, Tây Ninh",
  "Thạnh Đông, Tân Châu, Tây Ninh",
  "Tân Thành, Tân Châu, Tây Ninh",
  "Tân Phú, Tân Châu, Tây Ninh",
  "Tân Hưng, Tân Châu, Tây Ninh",
  "Dương Minh Châu, Dương Minh Châu, Tây Ninh",
  "Suối Đá, Dương Minh Châu, Tây Ninh",
  "Phan, Dương Minh Châu, Tây Ninh",
  "Phước Ninh, Dương Minh Châu, Tây Ninh",
  "Phước Minh, Dương Minh Châu, Tây Ninh",
  "Bàu Năng, Dương Minh Châu, Tây Ninh",
  "Chà Là, Dương Minh Châu, Tây Ninh",
  "Cầu Khởi, Dương Minh Châu, Tây Ninh",
  "Bến Củi, Dương Minh Châu, Tây Ninh",
  "Lộc Ninh, Dương Minh Châu, Tây Ninh",
  "Truông Mít, Dương Minh Châu, Tây Ninh",
  "Châu Thành, Châu Thành, Tây Ninh",
  "Hảo Đước, Châu Thành, Tây Ninh",
  "Phước Vinh, Châu Thành, Tây Ninh",
  "Đồng Khởi, Châu Thành, Tây Ninh",
  "Thái Bình, Châu Thành, Tây Ninh",
  "An Cơ, Châu Thành, Tây Ninh",
  "Biên Giới, Châu Thành, Tây Ninh",
  "Hòa Thạnh, Châu Thành, Tây Ninh",
  "Trí Bình, Châu Thành, Tây Ninh",
  "Hòa Hội, Châu Thành, Tây Ninh",
  "An Bình, Châu Thành, Tây Ninh",
  "Thanh Điền, Châu Thành, Tây Ninh",
  "Thành Long, Châu Thành, Tây Ninh",
  "Ninh Điền, Châu Thành, Tây Ninh",
  "Long Vĩnh, Châu Thành, Tây Ninh",
  "Long Hoa, Hòa Thành, Tây Ninh",
  "Hiệp Tân, Hòa Thành, Tây Ninh",
  "Long Thành Bắc, Hòa Thành, Tây Ninh",
  "Trường Hòa, Hòa Thành, Tây Ninh",
  "Trường Đông, Hòa Thành, Tây Ninh",
  "Long Thành Trung, Hòa Thành, Tây Ninh",
  "Trường Tây, Hòa Thành, Tây Ninh",
  "Long Thành Nam, Hòa Thành, Tây Ninh",
  "Gò Dầu, Gò Dầu, Tây Ninh",
  "Thạnh Đức, Gò Dầu, Tây Ninh",
  "Cẩm Giang, Gò Dầu, Tây Ninh",
  "Hiệp Thạnh, Gò Dầu, Tây Ninh",
  "Bàu Đồn, Gò Dầu, Tây Ninh",
  "Phước Thạnh, Gò Dầu, Tây Ninh",
  "Phước Đông, Gò Dầu, Tây Ninh",
  "Phước Trạch, Gò Dầu, Tây Ninh",
  "Thanh Phước, Gò Dầu, Tây Ninh",
  "Bến Cầu, Bến Cầu, Tây Ninh",
  "Long Chữ, Bến Cầu, Tây Ninh",
  "Long Phước, Bến Cầu, Tây Ninh",
  "Long Giang, Bến Cầu, Tây Ninh",
  "Tiên Thuận, Bến Cầu, Tây Ninh",
  "Long Khánh, Bến Cầu, Tây Ninh",
  "Lợi Thuận, Bến Cầu, Tây Ninh",
  "Long Thuận, Bến Cầu, Tây Ninh",
  "An Thạnh, Bến Cầu, Tây Ninh",
  "Trảng Bàng, Trảng Bàng, Tây Ninh",
  "Đôn Thuận, Trảng Bàng, Tây Ninh",
  "Hưng Thuận, Trảng Bàng, Tây Ninh",
  "Lộc Hưng, Trảng Bàng, Tây Ninh",
  "Gia Lộc, Trảng Bàng, Tây Ninh",
  "Gia Bình, Trảng Bàng, Tây Ninh",
  "Phước Bình, Trảng Bàng, Tây Ninh",
  "An Tịnh, Trảng Bàng, Tây Ninh",
  "An Hòa, Trảng Bàng, Tây Ninh",
  "Phước Chỉ, Trảng Bàng, Tây Ninh",
  "Hiệp Thành, Thủ Dầu Một, Bình Dương",
  "Phú Lợi, Thủ Dầu Một, Bình Dương",
  "Phú Cường, Thủ Dầu Một, Bình Dương",
  "Phú Hòa, Thủ Dầu Một, Bình Dương",
  "Phú Thọ, Thủ Dầu Một, Bình Dương",
  "Chánh Nghĩa, Thủ Dầu Một, Bình Dương",
  "Định Hoà, Thủ Dầu Một, Bình Dương",
  "Hoà Phú, Thủ Dầu Một, Bình Dương",
  "Phú Mỹ, Thủ Dầu Một, Bình Dương",
  "Phú Tân, Thủ Dầu Một, Bình Dương",
  "Tân An, Thủ Dầu Một, Bình Dương",
  "Hiệp An, Thủ Dầu Một, Bình Dương",
  "Tương Bình Hiệp, Thủ Dầu Một, Bình Dương",
  "Chánh Mỹ, Thủ Dầu Một, Bình Dương",
  "Trừ Văn Thố, Bàu Bàng, Bình Dương",
  "Cây Trường II, Bàu Bàng, Bình Dương",
  "Lai Uyên, Bàu Bàng, Bình Dương",
  "Tân Hưng, Bàu Bàng, Bình Dương",
  "Long Nguyên, Bàu Bàng, Bình Dương",
  "Hưng Hòa, Bàu Bàng, Bình Dương",
  "Lai Hưng, Bàu Bàng, Bình Dương",
  "Dầu Tiếng, Dầu Tiếng, Bình Dương",
  "Minh Hoà, Dầu Tiếng, Bình Dương",
  "Minh Thạnh, Dầu Tiếng, Bình Dương",
  "Minh Tân, Dầu Tiếng, Bình Dương",
  "Định An, Dầu Tiếng, Bình Dương",
  "Long Hoà, Dầu Tiếng, Bình Dương",
  "Định Thành, Dầu Tiếng, Bình Dương",
  "Định Hiệp, Dầu Tiếng, Bình Dương",
  "An Lập, Dầu Tiếng, Bình Dương",
  "Long Tân, Dầu Tiếng, Bình Dương",
  "Thanh An, Dầu Tiếng, Bình Dương",
  "Thanh Tuyền, Dầu Tiếng, Bình Dương",
  "Mỹ Phước, Bến Cát, Bình Dương",
  "Chánh Phú Hòa, Bến Cát, Bình Dương",
  "An Điền, Bến Cát, Bình Dương",
  "An Tây, Bến Cát, Bình Dương",
  "Thới Hòa, Bến Cát, Bình Dương",
  "Hòa Lợi, Bến Cát, Bình Dương",
  "Tân Định, Bến Cát, Bình Dương",
  "Phú An, Bến Cát, Bình Dương",
  "Phước Vĩnh, Phú Giáo, Bình Dương",
  "An Linh, Phú Giáo, Bình Dương",
  "Phước Sang, Phú Giáo, Bình Dương",
  "An Thái, Phú Giáo, Bình Dương",
  "An Long, Phú Giáo, Bình Dương",
  "An Bình, Phú Giáo, Bình Dương",
  "Tân Hiệp, Phú Giáo, Bình Dương",
  "Tam Lập, Phú Giáo, Bình Dương",
  "Tân Long, Phú Giáo, Bình Dương",
  "Vĩnh Hoà, Phú Giáo, Bình Dương",
  "Phước Hoà, Phú Giáo, Bình Dương",
  "Uyên Hưng, Tân Uyên, Bình Dương",
  "Tân Phước Khánh, Tân Uyên, Bình Dương",
  "Vĩnh Tân, Tân Uyên, Bình Dương",
  "Hội Nghĩa, Tân Uyên, Bình Dương",
  "Tân Hiệp, Tân Uyên, Bình Dương",
  "Khánh Bình, Tân Uyên, Bình Dương",
  "Phú Chánh, Tân Uyên, Bình Dương",
  "Bạch Đằng, Tân Uyên, Bình Dương",
  "Tân Vĩnh Hiệp, Tân Uyên, Bình Dương",
  "Thạnh Phước, Tân Uyên, Bình Dương",
  "Thạnh Hội, Tân Uyên, Bình Dương",
  "Thái Hòa, Tân Uyên, Bình Dương",
  "Dĩ An, Dĩ An, Bình Dương",
  "Tân Bình, Dĩ An, Bình Dương",
  "Tân Đông Hiệp, Dĩ An, Bình Dương",
  "Bình An, Dĩ An, Bình Dương",
  "Bình Thắng, Dĩ An, Bình Dương",
  "Đông Hòa, Dĩ An, Bình Dương",
  "An Bình, Dĩ An, Bình Dương",
  "An Thạnh, Thuận An, Bình Dương",
  "Lái Thiêu, Thuận An, Bình Dương",
  "Bình Chuẩn, Thuận An, Bình Dương",
  "Thuận Giao, Thuận An, Bình Dương",
  "An Phú, Thuận An, Bình Dương",
  "Hưng Định, Thuận An, Bình Dương",
  "An Sơn, Thuận An, Bình Dương",
  "Bình Nhâm, Thuận An, Bình Dương",
  "Bình Hòa, Thuận An, Bình Dương",
  "Vĩnh Phú, Thuận An, Bình Dương",
  "Tân Định, Bắc Tân Uyên, Bình Dương",
  "Bình Mỹ, Bắc Tân Uyên, Bình Dương",
  "Tân Bình, Bắc Tân Uyên, Bình Dương",
  "Tân Lập, Bắc Tân Uyên, Bình Dương",
  "Tân Thành, Bắc Tân Uyên, Bình Dương",
  "Đất Cuốc, Bắc Tân Uyên, Bình Dương",
  "Hiếu Liêm, Bắc Tân Uyên, Bình Dương",
  "Lạc An, Bắc Tân Uyên, Bình Dương",
  "Tân Mỹ, Bắc Tân Uyên, Bình Dương",
  "Thường Tân, Bắc Tân Uyên, Bình Dương",
  "Trảng Dài, Biên Hòa, Đồng Nai",
  "Tân Phong, Biên Hòa, Đồng Nai",
  "Tân Biên, Biên Hòa, Đồng Nai",
  "Hố Nai, Biên Hòa, Đồng Nai",
  "Tân Hòa, Biên Hòa, Đồng Nai",
  "Tân Hiệp, Biên Hòa, Đồng Nai",
  "Bửu Long, Biên Hòa, Đồng Nai",
  "Tân Tiến, Biên Hòa, Đồng Nai",
  "Tam Hiệp, Biên Hòa, Đồng Nai",
  "Long Bình, Biên Hòa, Đồng Nai",
  "Quang Vinh, Biên Hòa, Đồng Nai",
  "Tân Mai, Biên Hòa, Đồng Nai",
  "Thống Nhất, Biên Hòa, Đồng Nai",
  "Trung Dũng, Biên Hòa, Đồng Nai",
  "Tam Hòa, Biên Hòa, Đồng Nai",
  "Hòa Bình, Biên Hòa, Đồng Nai",
  "Quyết Thắng, Biên Hòa, Đồng Nai",
  "Thanh Bình, Biên Hòa, Đồng Nai",
  "Bình Đa, Biên Hòa, Đồng Nai",
  "An Bình, Biên Hòa, Đồng Nai",
  "Bửu Hòa, Biên Hòa, Đồng Nai",
  "Long Bình Tân, Biên Hòa, Đồng Nai",
  "Tân Vạn, Biên Hòa, Đồng Nai",
  "Tân Hạnh, Biên Hòa, Đồng Nai",
  "Hiệp Hòa, Biên Hòa, Đồng Nai",
  "Hóa An, Biên Hòa, Đồng Nai",
  "An Hòa, Biên Hòa, Đồng Nai",
  "Tam Phước, Biên Hòa, Đồng Nai",
  "Phước Tân, Biên Hòa, Đồng Nai",
  "Long Hưng, Biên Hòa, Đồng Nai",
  "Xuân Trung, Long Khánh, Đồng Nai",
  "Xuân Thanh, Long Khánh, Đồng Nai",
  "Xuân Bình, Long Khánh, Đồng Nai",
  "Xuân An, Long Khánh, Đồng Nai",
  "Xuân Hoà, Long Khánh, Đồng Nai",
  "Phú Bình, Long Khánh, Đồng Nai",
  "Bình Lộc, Long Khánh, Đồng Nai",
  "Bảo Quang, Long Khánh, Đồng Nai",
  "Suối Tre, Long Khánh, Đồng Nai",
  "Bảo Vinh, Long Khánh, Đồng Nai",
  "Xuân Lập, Long Khánh, Đồng Nai",
  "Bàu Sen, Long Khánh, Đồng Nai",
  "Bàu Trâm, Long Khánh, Đồng Nai",
  "Xuân Tân, Long Khánh, Đồng Nai",
  "Hàng Gòn, Long Khánh, Đồng Nai",
  "Tân Phú, Tân Phú, Đồng Nai",
  "Dak Lua, Tân Phú, Đồng Nai",
  "Nam Cát Tiên, Tân Phú, Đồng Nai",
  "Phú An, Tân Phú, Đồng Nai",
  "Núi Tượng, Tân Phú, Đồng Nai",
  "Tà Lài, Tân Phú, Đồng Nai",
  "Phú Lập, Tân Phú, Đồng Nai",
  "Phú Sơn, Tân Phú, Đồng Nai",
  "Phú Thịnh, Tân Phú, Đồng Nai",
  "Thanh Sơn, Tân Phú, Đồng Nai",
  "Phú Trung, Tân Phú, Đồng Nai",
  "Phú Xuân, Tân Phú, Đồng Nai",
  "Phú Lộc, Tân Phú, Đồng Nai",
  "Phú Lâm, Tân Phú, Đồng Nai",
  "Phú Bình, Tân Phú, Đồng Nai",
  "Phú Thanh, Tân Phú, Đồng Nai",
  "Trà Cổ, Tân Phú, Đồng Nai",
  "Phú Điền, Tân Phú, Đồng Nai",
  "Vĩnh An, Vĩnh Cửu, Đồng Nai",
  "Phú Lý, Vĩnh Cửu, Đồng Nai",
  "Trị An, Vĩnh Cửu, Đồng Nai",
  "Tân An, Vĩnh Cửu, Đồng Nai",
  "Vĩnh Tân, Vĩnh Cửu, Đồng Nai",
  "Bình Lợi, Vĩnh Cửu, Đồng Nai",
  "Thạnh Phú, Vĩnh Cửu, Đồng Nai",
  "Thiện Tân, Vĩnh Cửu, Đồng Nai",
  "Tân Bình, Vĩnh Cửu, Đồng Nai",
  "Bình Hòa, Vĩnh Cửu, Đồng Nai",
  "Mã Đà, Vĩnh Cửu, Đồng Nai",
  "Hiếu Liêm, Vĩnh Cửu, Đồng Nai",
  "Định Quán, Định Quán, Đồng Nai",
  "Thanh Sơn, Định Quán, Đồng Nai",
  "Phú Tân, Định Quán, Đồng Nai",
  "Phú Vinh, Định Quán, Đồng Nai",
  "Phú Lợi, Định Quán, Đồng Nai",
  "Phú Hòa, Định Quán, Đồng Nai",
  "Ngọc Định, Định Quán, Đồng Nai",
  "La Ngà, Định Quán, Đồng Nai",
  "Gia Canh, Định Quán, Đồng Nai",
  "Phú Ngọc, Định Quán, Đồng Nai",
  "Phú Cường, Định Quán, Đồng Nai",
  "Túc Trưng, Định Quán, Đồng Nai",
  "Phú Túc, Định Quán, Đồng Nai",
  "Suối Nho, Định Quán, Đồng Nai",
  "Trảng Bom, Trảng Bom, Đồng Nai",
  "Thanh Bình, Trảng Bom, Đồng Nai",
  "Cây Gáo, Trảng Bom, Đồng Nai",
  "Bàu Hàm, Trảng Bom, Đồng Nai",
  "Sông Thao, Trảng Bom, Đồng Nai",
  "Sông Trầu, Trảng Bom, Đồng Nai",
  "Đông Hoà, Trảng Bom, Đồng Nai",
  "Bắc Sơn, Trảng Bom, Đồng Nai",
  "Hố Nai 3, Trảng Bom, Đồng Nai",
  "Tây Hoà, Trảng Bom, Đồng Nai",
  "Bình Minh, Trảng Bom, Đồng Nai",
  "Trung Hoà, Trảng Bom, Đồng Nai",
  "Đồi 61, Trảng Bom, Đồng Nai",
  "Hưng Thịnh, Trảng Bom, Đồng Nai",
  "Quảng Tiến, Trảng Bom, Đồng Nai",
  "Giang Điền, Trảng Bom, Đồng Nai",
  "An Viễn, Trảng Bom, Đồng Nai",
  "Gia Tân 1, Thống Nhất, Đồng Nai",
  "Gia Tân 2, Thống Nhất, Đồng Nai",
  "Gia Tân 3, Thống Nhất, Đồng Nai",
  "Gia Kiệm, Thống Nhất, Đồng Nai",
  "Quang Trung, Thống Nhất, Đồng Nai",
  "Bàu Hàm 2, Thống Nhất, Đồng Nai",
  "Hưng Lộc, Thống Nhất, Đồng Nai",
  "Lộ 25, Thống Nhất, Đồng Nai",
  "Xuân Thiện, Thống Nhất, Đồng Nai",
  "Dầu Giây, Thống Nhất, Đồng Nai",
  "Sông Nhạn, Cẩm Mỹ, Đồng Nai",
  "Xuân Quế, Cẩm Mỹ, Đồng Nai",
  "Nhân Nghĩa, Cẩm Mỹ, Đồng Nai",
  "Xuân Đường, Cẩm Mỹ, Đồng Nai",
  "Long Giao, Cẩm Mỹ, Đồng Nai",
  "Xuân Mỹ, Cẩm Mỹ, Đồng Nai",
  "Thừa Đức, Cẩm Mỹ, Đồng Nai",
  "Bảo Bình, Cẩm Mỹ, Đồng Nai",
  "Xuân Bảo, Cẩm Mỹ, Đồng Nai",
  "Xuân Tây, Cẩm Mỹ, Đồng Nai",
  "Xuân Đông, Cẩm Mỹ, Đồng Nai",
  "Sông Ray, Cẩm Mỹ, Đồng Nai",
  "Lâm San, Cẩm Mỹ, Đồng Nai",
  "Long Thành, Long Thành, Đồng Nai",
  "An Phước, Long Thành, Đồng Nai",
  "Bình An, Long Thành, Đồng Nai",
  "Long Đức, Long Thành, Đồng Nai",
  "Lộc An, Long Thành, Đồng Nai",
  "Bình Sơn, Long Thành, Đồng Nai",
  "Tam An, Long Thành, Đồng Nai",
  "Cẩm Đường, Long Thành, Đồng Nai",
  "Long An, Long Thành, Đồng Nai",
  "Bàu Cạn, Long Thành, Đồng Nai",
  "Long Phước, Long Thành, Đồng Nai",
  "Phước Bình, Long Thành, Đồng Nai",
  "Tân Hiệp, Long Thành, Đồng Nai",
  "Phước Thái, Long Thành, Đồng Nai",
  "Gia Ray, Xuân Lộc, Đồng Nai",
  "Xuân Bắc, Xuân Lộc, Đồng Nai",
  "Suối Cao, Xuân Lộc, Đồng Nai",
  "Xuân Thành, Xuân Lộc, Đồng Nai",
  "Xuân Thọ, Xuân Lộc, Đồng Nai",
  "Xuân Trường, Xuân Lộc, Đồng Nai",
  "Xuân Hòa, Xuân Lộc, Đồng Nai",
  "Xuân Hưng, Xuân Lộc, Đồng Nai",
  "Xuân Tâm, Xuân Lộc, Đồng Nai",
  "Suối Cát, Xuân Lộc, Đồng Nai",
  "Xuân Hiệp, Xuân Lộc, Đồng Nai",
  "Xuân Phú, Xuân Lộc, Đồng Nai",
  "Xuân Định, Xuân Lộc, Đồng Nai",
  "Bảo Hoà, Xuân Lộc, Đồng Nai",
  "Lang Minh, Xuân Lộc, Đồng Nai",
  "Phước Thiền, Nhơn Trạch, Đồng Nai",
  "Long Tân, Nhơn Trạch, Đồng Nai",
  "Đại Phước, Nhơn Trạch, Đồng Nai",
  "Hiệp Phước, Nhơn Trạch, Đồng Nai",
  "Phú Hữu, Nhơn Trạch, Đồng Nai",
  "Phú Hội, Nhơn Trạch, Đồng Nai",
  "Phú Thạnh, Nhơn Trạch, Đồng Nai",
  "Phú Đông, Nhơn Trạch, Đồng Nai",
  "Long Thọ, Nhơn Trạch, Đồng Nai",
  "Vĩnh Thanh, Nhơn Trạch, Đồng Nai",
  "Phước Khánh, Nhơn Trạch, Đồng Nai",
  "Phước An, Nhơn Trạch, Đồng Nai",
  "Phường 1, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Thắng Tam, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 2, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 3, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 4, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 5, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Thắng Nhì, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 7, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Nguyễn An Ninh, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 8, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 9, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Thắng Nhất, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Rạch Dừa, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 10, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 11, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phường 12, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Long Sơn, Vũng Tàu, Bà Rịa - Vũng Tàu",
  "Phước Hưng, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Phước Hiệp, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Phước Nguyên, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Long Toàn, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Long Tâm, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Phước Trung, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Long Hương, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Kim Dinh, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Tân Hưng, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Long Phước, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Hoà Long, Bà Rịa, Bà Rịa - Vũng Tàu",
  "Bàu Chinh, Châu Đức, Bà Rịa - Vũng Tàu",
  "Ngãi Giao, Châu Đức, Bà Rịa - Vũng Tàu",
  "Bình Ba, Châu Đức, Bà Rịa - Vũng Tàu",
  "Suối Nghệ, Châu Đức, Bà Rịa - Vũng Tàu",
  "Xuân Sơn, Châu Đức, Bà Rịa - Vũng Tàu",
  "Sơn Bình, Châu Đức, Bà Rịa - Vũng Tàu",
  "Bình Giã, Châu Đức, Bà Rịa - Vũng Tàu",
  "Bình Trung, Châu Đức, Bà Rịa - Vũng Tàu",
  "Xà Bang, Châu Đức, Bà Rịa - Vũng Tàu",
  "Cù Bị, Châu Đức, Bà Rịa - Vũng Tàu",
  "Láng Lớn, Châu Đức, Bà Rịa - Vũng Tàu",
  "Quảng Thành, Châu Đức, Bà Rịa - Vũng Tàu",
  "Kim Long, Châu Đức, Bà Rịa - Vũng Tàu",
  "Suối Rao, Châu Đức, Bà Rịa - Vũng Tàu",
  "Đá Bạc, Châu Đức, Bà Rịa - Vũng Tàu",
  "Nghĩa Thành, Châu Đức, Bà Rịa - Vũng Tàu",
  "Phước Bửu, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Phước Thuận, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Phước Tân, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Xuyên Mộc, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Bông Trang, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Tân Lâm, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Bàu Lâm, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Hòa Bình, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Hòa Hưng, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Hòa Hiệp, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Hòa Hội, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Bưng Riềng, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Bình Châu, Xuyên Mộc, Bà Rịa - Vũng Tàu",
  "Long Điền, Long Điền, Bà Rịa - Vũng Tàu",
  "Long Hải, Long Điền, Bà Rịa - Vũng Tàu",
  "An Ngãi, Long Điền, Bà Rịa - Vũng Tàu",
  "Tam Phước, Long Điền, Bà Rịa - Vũng Tàu",
  "An Nhứt, Long Điền, Bà Rịa - Vũng Tàu",
  "Phước Tỉnh, Long Điền, Bà Rịa - Vũng Tàu",
  "Phước Hưng, Long Điền, Bà Rịa - Vũng Tàu",
  "Đất Đỏ, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Phước Long Thọ, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Phước Hội, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Long Mỹ, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Phước Hải, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Long Tân, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Láng Dài, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Lộc An, Đất Đỏ, Bà Rịa - Vũng Tàu",
  "Phú Mỹ, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Tân Hoà, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Tân Hải, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Phước Hoà, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Tân Phước, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Mỹ Xuân, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Sông Xoài, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Hắc Dịch, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Châu Pha, Phú Mỹ, Bà Rịa - Vũng Tàu",
  "Tóc Tiên, Phú Mỹ, Bà Rịa - Vũng Tàu",
  ", Côn Đảo, Bà Rịa - Vũng Tàu",
  "Tân Định, Quận 1, Hồ Chí Minh",
  "Đa Kao, Quận 1, Hồ Chí Minh",
  "Bến Nghé, Quận 1, Hồ Chí Minh",
  "Bến Thành, Quận 1, Hồ Chí Minh",
  "Nguyễn Thái Bình, Quận 1, Hồ Chí Minh",
  "Phạm Ngũ Lão, Quận 1, Hồ Chí Minh",
  "Cầu Ông Lãnh, Quận 1, Hồ Chí Minh",
  "Cô Giang, Quận 1, Hồ Chí Minh",
  "Nguyễn Cư Trinh, Quận 1, Hồ Chí Minh",
  "Cầu Kho, Quận 1, Hồ Chí Minh",
  "Thạnh Xuân, Quận 12, Hồ Chí Minh",
  "Thạnh Lộc, Quận 12, Hồ Chí Minh",
  "Hiệp Thành, Quận 12, Hồ Chí Minh",
  "Thới An, Quận 12, Hồ Chí Minh",
  "Tân Chánh Hiệp, Quận 12, Hồ Chí Minh",
  "An Phú Đông, Quận 12, Hồ Chí Minh",
  "Tân Thới Hiệp, Quận 12, Hồ Chí Minh",
  "Trung Mỹ Tây, Quận 12, Hồ Chí Minh",
  "Tân Hưng Thuận, Quận 12, Hồ Chí Minh",
  "Đông Hưng Thuận, Quận 12, Hồ Chí Minh",
  "Tân Thới Nhất, Quận 12, Hồ Chí Minh",
  "Linh Xuân, Thủ Đức, Hồ Chí Minh",
  "Bình Chiểu, Thủ Đức, Hồ Chí Minh",
  "Linh Trung, Thủ Đức, Hồ Chí Minh",
  "Tam Bình, Thủ Đức, Hồ Chí Minh",
  "Tam Phú, Thủ Đức, Hồ Chí Minh",
  "Hiệp Bình Phước, Thủ Đức, Hồ Chí Minh",
  "Hiệp Bình Chánh, Thủ Đức, Hồ Chí Minh",
  "Linh Chiểu, Thủ Đức, Hồ Chí Minh",
  "Linh Tây, Thủ Đức, Hồ Chí Minh",
  "Linh Đông, Thủ Đức, Hồ Chí Minh",
  "Bình Thọ, Thủ Đức, Hồ Chí Minh",
  "Trường Thọ, Thủ Đức, Hồ Chí Minh",
  "Long Bình, Quận 9, Hồ Chí Minh",
  "Long Thạnh Mỹ, Quận 9, Hồ Chí Minh",
  "Tân Phú, Quận 9, Hồ Chí Minh",
  "Hiệp Phú, Quận 9, Hồ Chí Minh",
  "Tăng Nhơn Phú A, Quận 9, Hồ Chí Minh",
  "Tăng Nhơn Phú B, Quận 9, Hồ Chí Minh",
  "Phước Long B, Quận 9, Hồ Chí Minh",
  "Phước Long A, Quận 9, Hồ Chí Minh",
  "Trường Thạnh, Quận 9, Hồ Chí Minh",
  "Long Phước, Quận 9, Hồ Chí Minh",
  "Long Trường, Quận 9, Hồ Chí Minh",
  "Phước Bình, Quận 9, Hồ Chí Minh",
  "Phú Hữu, Quận 9, Hồ Chí Minh",
  "Phường 15, Gò Vấp, Hồ Chí Minh",
  "Phường 13, Gò Vấp, Hồ Chí Minh",
  "Phường 17, Gò Vấp, Hồ Chí Minh",
  "Phường 6, Gò Vấp, Hồ Chí Minh",
  "Phường 16, Gò Vấp, Hồ Chí Minh",
  "Phường 12, Gò Vấp, Hồ Chí Minh",
  "Phường 14, Gò Vấp, Hồ Chí Minh",
  "Phường 10, Gò Vấp, Hồ Chí Minh",
  "Phường 05, Gò Vấp, Hồ Chí Minh",
  "Phường 07, Gò Vấp, Hồ Chí Minh",
  "Phường 04, Gò Vấp, Hồ Chí Minh",
  "Phường 01, Gò Vấp, Hồ Chí Minh",
  "Phường 9, Gò Vấp, Hồ Chí Minh",
  "Phường 8, Gò Vấp, Hồ Chí Minh",
  "Phường 11, Gò Vấp, Hồ Chí Minh",
  "Phường 03, Gò Vấp, Hồ Chí Minh",
  "Phường 13, Bình Thạnh, Hồ Chí Minh",
  "Phường 11, Bình Thạnh, Hồ Chí Minh",
  "Phường 27, Bình Thạnh, Hồ Chí Minh",
  "Phường 26, Bình Thạnh, Hồ Chí Minh",
  "Phường 12, Bình Thạnh, Hồ Chí Minh",
  "Phường 25, Bình Thạnh, Hồ Chí Minh",
  "Phường 05, Bình Thạnh, Hồ Chí Minh",
  "Phường 07, Bình Thạnh, Hồ Chí Minh",
  "Phường 24, Bình Thạnh, Hồ Chí Minh",
  "Phường 06, Bình Thạnh, Hồ Chí Minh",
  "Phường 14, Bình Thạnh, Hồ Chí Minh",
  "Phường 15, Bình Thạnh, Hồ Chí Minh",
  "Phường 02, Bình Thạnh, Hồ Chí Minh",
  "Phường 01, Bình Thạnh, Hồ Chí Minh",
  "Phường 03, Bình Thạnh, Hồ Chí Minh",
  "Phường 17, Bình Thạnh, Hồ Chí Minh",
  "Phường 21, Bình Thạnh, Hồ Chí Minh",
  "Phường 22, Bình Thạnh, Hồ Chí Minh",
  "Phường 19, Bình Thạnh, Hồ Chí Minh",
  "Phường 28, Bình Thạnh, Hồ Chí Minh",
  "Phường 02, Tân Bình, Hồ Chí Minh",
  "Phường 04, Tân Bình, Hồ Chí Minh",
  "Phường 12, Tân Bình, Hồ Chí Minh",
  "Phường 13, Tân Bình, Hồ Chí Minh",
  "Phường 01, Tân Bình, Hồ Chí Minh",
  "Phường 03, Tân Bình, Hồ Chí Minh",
  "Phường 11, Tân Bình, Hồ Chí Minh",
  "Phường 07, Tân Bình, Hồ Chí Minh",
  "Phường 05, Tân Bình, Hồ Chí Minh",
  "Phường 10, Tân Bình, Hồ Chí Minh",
  "Phường 06, Tân Bình, Hồ Chí Minh",
  "Phường 08, Tân Bình, Hồ Chí Minh",
  "Phường 09, Tân Bình, Hồ Chí Minh",
  "Phường 14, Tân Bình, Hồ Chí Minh",
  "Phường 15, Tân Bình, Hồ Chí Minh",
  "Tân Sơn Nhì, Tân Phú, Hồ Chí Minh",
  "Tây Thạnh, Tân Phú, Hồ Chí Minh",
  "Sơn Kỳ, Tân Phú, Hồ Chí Minh",
  "Tân Quý, Tân Phú, Hồ Chí Minh",
  "Tân Thành, Tân Phú, Hồ Chí Minh",
  "Phú Thọ Hòa, Tân Phú, Hồ Chí Minh",
  "Phú Thạnh, Tân Phú, Hồ Chí Minh",
  "Phú Trung, Tân Phú, Hồ Chí Minh",
  "Hòa Thạnh, Tân Phú, Hồ Chí Minh",
  "Hiệp Tân, Tân Phú, Hồ Chí Minh",
  "Tân Thới Hòa, Tân Phú, Hồ Chí Minh",
  "Phường 04, Phú Nhuận, Hồ Chí Minh",
  "Phường 05, Phú Nhuận, Hồ Chí Minh",
  "Phường 09, Phú Nhuận, Hồ Chí Minh",
  "Phường 07, Phú Nhuận, Hồ Chí Minh",
  "Phường 03, Phú Nhuận, Hồ Chí Minh",
  "Phường 01, Phú Nhuận, Hồ Chí Minh",
  "Phường 02, Phú Nhuận, Hồ Chí Minh",
  "Phường 08, Phú Nhuận, Hồ Chí Minh",
  "Phường 15, Phú Nhuận, Hồ Chí Minh",
  "Phường 10, Phú Nhuận, Hồ Chí Minh",
  "Phường 11, Phú Nhuận, Hồ Chí Minh",
  "Phường 17, Phú Nhuận, Hồ Chí Minh",
  "Phường 14, Phú Nhuận, Hồ Chí Minh",
  "Phường 12, Phú Nhuận, Hồ Chí Minh",
  "Phường 13, Phú Nhuận, Hồ Chí Minh",
  "Thảo Điền, Quận 2, Hồ Chí Minh",
  "An Phú, Quận 2, Hồ Chí Minh",
  "Bình An, Quận 2, Hồ Chí Minh",
  "Bình Trưng Đông, Quận 2, Hồ Chí Minh",
  "Bình Trưng Tây, Quận 2, Hồ Chí Minh",
  "Bình Khánh, Quận 2, Hồ Chí Minh",
  "An Khánh, Quận 2, Hồ Chí Minh",
  "Cát Lái, Quận 2, Hồ Chí Minh",
  "Thạnh Mỹ Lợi, Quận 2, Hồ Chí Minh",
  "An Lợi Đông, Quận 2, Hồ Chí Minh",
  "Thủ Thiêm, Quận 2, Hồ Chí Minh",
  "Phường 08, Quận 3, Hồ Chí Minh",
  "Phường 07, Quận 3, Hồ Chí Minh",
  "Phường 14, Quận 3, Hồ Chí Minh",
  "Phường 12, Quận 3, Hồ Chí Minh",
  "Phường 11, Quận 3, Hồ Chí Minh",
  "Phường 13, Quận 3, Hồ Chí Minh",
  "Phường 06, Quận 3, Hồ Chí Minh",
  "Phường 09, Quận 3, Hồ Chí Minh",
  "Phường 10, Quận 3, Hồ Chí Minh",
  "Phường 04, Quận 3, Hồ Chí Minh",
  "Phường 05, Quận 3, Hồ Chí Minh",
  "Phường 03, Quận 3, Hồ Chí Minh",
  "Phường 02, Quận 3, Hồ Chí Minh",
  "Phường 01, Quận 3, Hồ Chí Minh",
  "Phường 15, Quận 10, Hồ Chí Minh",
  "Phường 13, Quận 10, Hồ Chí Minh",
  "Phường 14, Quận 10, Hồ Chí Minh",
  "Phường 12, Quận 10, Hồ Chí Minh",
  "Phường 11, Quận 10, Hồ Chí Minh",
  "Phường 10, Quận 10, Hồ Chí Minh",
  "Phường 09, Quận 10, Hồ Chí Minh",
  "Phường 01, Quận 10, Hồ Chí Minh",
  "Phường 08, Quận 10, Hồ Chí Minh",
  "Phường 02, Quận 10, Hồ Chí Minh",
  "Phường 04, Quận 10, Hồ Chí Minh",
  "Phường 07, Quận 10, Hồ Chí Minh",
  "Phường 05, Quận 10, Hồ Chí Minh",
  "Phường 06, Quận 10, Hồ Chí Minh",
  "Phường 03, Quận 10, Hồ Chí Minh",
  "Phường 15, Quận 11, Hồ Chí Minh",
  "Phường 05, Quận 11, Hồ Chí Minh",
  "Phường 14, Quận 11, Hồ Chí Minh",
  "Phường 11, Quận 11, Hồ Chí Minh",
  "Phường 03, Quận 11, Hồ Chí Minh",
  "Phường 10, Quận 11, Hồ Chí Minh",
  "Phường 13, Quận 11, Hồ Chí Minh",
  "Phường 08, Quận 11, Hồ Chí Minh",
  "Phường 09, Quận 11, Hồ Chí Minh",
  "Phường 12, Quận 11, Hồ Chí Minh",
  "Phường 07, Quận 11, Hồ Chí Minh",
  "Phường 06, Quận 11, Hồ Chí Minh",
  "Phường 04, Quận 11, Hồ Chí Minh",
  "Phường 01, Quận 11, Hồ Chí Minh",
  "Phường 02, Quận 11, Hồ Chí Minh",
  "Phường 16, Quận 11, Hồ Chí Minh",
  "Phường 12, Quận 4, Hồ Chí Minh",
  "Phường 13, Quận 4, Hồ Chí Minh",
  "Phường 09, Quận 4, Hồ Chí Minh",
  "Phường 06, Quận 4, Hồ Chí Minh",
  "Phường 08, Quận 4, Hồ Chí Minh",
  "Phường 10, Quận 4, Hồ Chí Minh",
  "Phường 05, Quận 4, Hồ Chí Minh",
  "Phường 18, Quận 4, Hồ Chí Minh",
  "Phường 14, Quận 4, Hồ Chí Minh",
  "Phường 04, Quận 4, Hồ Chí Minh",
  "Phường 03, Quận 4, Hồ Chí Minh",
  "Phường 16, Quận 4, Hồ Chí Minh",
  "Phường 02, Quận 4, Hồ Chí Minh",
  "Phường 15, Quận 4, Hồ Chí Minh",
  "Phường 01, Quận 4, Hồ Chí Minh",
  "Phường 04, Quận 5, Hồ Chí Minh",
  "Phường 09, Quận 5, Hồ Chí Minh",
  "Phường 03, Quận 5, Hồ Chí Minh",
  "Phường 12, Quận 5, Hồ Chí Minh",
  "Phường 02, Quận 5, Hồ Chí Minh",
  "Phường 08, Quận 5, Hồ Chí Minh",
  "Phường 15, Quận 5, Hồ Chí Minh",
  "Phường 07, Quận 5, Hồ Chí Minh",
  "Phường 01, Quận 5, Hồ Chí Minh",
  "Phường 11, Quận 5, Hồ Chí Minh",
  "Phường 14, Quận 5, Hồ Chí Minh",
  "Phường 05, Quận 5, Hồ Chí Minh",
  "Phường 06, Quận 5, Hồ Chí Minh",
  "Phường 10, Quận 5, Hồ Chí Minh",
  "Phường 13, Quận 5, Hồ Chí Minh",
  "Phường 14, Quận 6, Hồ Chí Minh",
  "Phường 13, Quận 6, Hồ Chí Minh",
  "Phường 09, Quận 6, Hồ Chí Minh",
  "Phường 06, Quận 6, Hồ Chí Minh",
  "Phường 12, Quận 6, Hồ Chí Minh",
  "Phường 05, Quận 6, Hồ Chí Minh",
  "Phường 11, Quận 6, Hồ Chí Minh",
  "Phường 02, Quận 6, Hồ Chí Minh",
  "Phường 01, Quận 6, Hồ Chí Minh",
  "Phường 04, Quận 6, Hồ Chí Minh",
  "Phường 08, Quận 6, Hồ Chí Minh",
  "Phường 03, Quận 6, Hồ Chí Minh",
  "Phường 07, Quận 6, Hồ Chí Minh",
  "Phường 10, Quận 6, Hồ Chí Minh",
  "Phường 08, Quận 8, Hồ Chí Minh",
  "Phường 02, Quận 8, Hồ Chí Minh",
  "Phường 01, Quận 8, Hồ Chí Minh",
  "Phường 03, Quận 8, Hồ Chí Minh",
  "Phường 11, Quận 8, Hồ Chí Minh",
  "Phường 09, Quận 8, Hồ Chí Minh",
  "Phường 10, Quận 8, Hồ Chí Minh",
  "Phường 04, Quận 8, Hồ Chí Minh",
  "Phường 13, Quận 8, Hồ Chí Minh",
  "Phường 12, Quận 8, Hồ Chí Minh",
  "Phường 05, Quận 8, Hồ Chí Minh",
  "Phường 14, Quận 8, Hồ Chí Minh",
  "Phường 06, Quận 8, Hồ Chí Minh",
  "Phường 15, Quận 8, Hồ Chí Minh",
  "Phường 16, Quận 8, Hồ Chí Minh",
  "Phường 07, Quận 8, Hồ Chí Minh",
  "Bình Hưng Hòa, Bình Tân, Hồ Chí Minh",
  "Bình Hưng Hoà A, Bình Tân, Hồ Chí Minh",
  "Bình Hưng Hoà B, Bình Tân, Hồ Chí Minh",
  "Bình Trị Đông, Bình Tân, Hồ Chí Minh",
  "Bình Trị Đông A, Bình Tân, Hồ Chí Minh",
  "Bình Trị Đông B, Bình Tân, Hồ Chí Minh",
  "Tân Tạo, Bình Tân, Hồ Chí Minh",
  "Tân Tạo A, Bình Tân, Hồ Chí Minh",
  " An Lạc, Bình Tân, Hồ Chí Minh",
  "An Lạc A, Bình Tân, Hồ Chí Minh",
  "Tân Thuận Đông, Quận 7, Hồ Chí Minh",
  "Tân Thuận Tây, Quận 7, Hồ Chí Minh",
  "Tân Kiểng, Quận 7, Hồ Chí Minh",
  "Tân Hưng, Quận 7, Hồ Chí Minh",
  "Bình Thuận, Quận 7, Hồ Chí Minh",
  "Tân Quy, Quận 7, Hồ Chí Minh",
  "Phú Thuận, Quận 7, Hồ Chí Minh",
  "Tân Phú, Quận 7, Hồ Chí Minh",
  "Tân Phong, Quận 7, Hồ Chí Minh",
  "Phú Mỹ, Quận 7, Hồ Chí Minh",
  "Củ Chi, Củ Chi, Hồ Chí Minh",
  "Phú Mỹ Hưng, Củ Chi, Hồ Chí Minh",
  "An Phú, Củ Chi, Hồ Chí Minh",
  "Trung Lập Thượng, Củ Chi, Hồ Chí Minh",
  "An Nhơn Tây, Củ Chi, Hồ Chí Minh",
  "Nhuận Đức, Củ Chi, Hồ Chí Minh",
  "Phạm Văn Cội, Củ Chi, Hồ Chí Minh",
  "Phú Hòa Đông, Củ Chi, Hồ Chí Minh",
  "Trung Lập Hạ, Củ Chi, Hồ Chí Minh",
  "Trung An, Củ Chi, Hồ Chí Minh",
  "Phước Thạnh, Củ Chi, Hồ Chí Minh",
  "Phước Hiệp, Củ Chi, Hồ Chí Minh",
  "Tân An Hội, Củ Chi, Hồ Chí Minh",
  "Phước Vĩnh An, Củ Chi, Hồ Chí Minh",
  "Thái Mỹ, Củ Chi, Hồ Chí Minh",
  "Tân Thạnh Tây, Củ Chi, Hồ Chí Minh",
  "Hòa Phú, Củ Chi, Hồ Chí Minh",
  "Tân Thạnh Đông, Củ Chi, Hồ Chí Minh",
  "Bình Mỹ, Củ Chi, Hồ Chí Minh",
  "Tân Phú Trung, Củ Chi, Hồ Chí Minh",
  "Tân Thông Hội, Củ Chi, Hồ Chí Minh",
  "Hóc Môn, Hóc Môn, Hồ Chí Minh",
  "Tân Hiệp, Hóc Môn, Hồ Chí Minh",
  "Nhị Bình, Hóc Môn, Hồ Chí Minh",
  "Đông Thạnh, Hóc Môn, Hồ Chí Minh",
  "Tân Thới Nhì, Hóc Môn, Hồ Chí Minh",
  "Thới Tam Thôn, Hóc Môn, Hồ Chí Minh",
  "Xuân Thới Sơn, Hóc Môn, Hồ Chí Minh",
  "Tân Xuân, Hóc Môn, Hồ Chí Minh",
  "Xuân Thới Đông, Hóc Môn, Hồ Chí Minh",
  "Trung Chánh, Hóc Môn, Hồ Chí Minh",
  "Xuân Thới Thượng, Hóc Môn, Hồ Chí Minh",
  "Bà Điểm, Hóc Môn, Hồ Chí Minh",
  "Tân Túc, Bình Chánh, Hồ Chí Minh",
  "Phạm Văn Hai, Bình Chánh, Hồ Chí Minh",
  "Vĩnh Lộc A, Bình Chánh, Hồ Chí Minh",
  "Vĩnh Lộc B, Bình Chánh, Hồ Chí Minh",
  "Bình Lợi, Bình Chánh, Hồ Chí Minh",
  "Lê Minh Xuân, Bình Chánh, Hồ Chí Minh",
  "Tân Nhựt, Bình Chánh, Hồ Chí Minh",
  "Tân Kiên, Bình Chánh, Hồ Chí Minh",
  "Bình Hưng, Bình Chánh, Hồ Chí Minh",
  "Phong Phú, Bình Chánh, Hồ Chí Minh",
  "An Phú Tây, Bình Chánh, Hồ Chí Minh",
  "Hưng Long, Bình Chánh, Hồ Chí Minh",
  "Đa Phước, Bình Chánh, Hồ Chí Minh",
  "Tân Quý Tây, Bình Chánh, Hồ Chí Minh",
  "Bình Chánh, Bình Chánh, Hồ Chí Minh",
  "Quy Đức, Bình Chánh, Hồ Chí Minh",
  "Nhà Bè, Nhà Bè, Hồ Chí Minh",
  "Phước Kiển, Nhà Bè, Hồ Chí Minh",
  "Phước Lộc, Nhà Bè, Hồ Chí Minh",
  "Nhơn Đức, Nhà Bè, Hồ Chí Minh",
  "Phú Xuân, Nhà Bè, Hồ Chí Minh",
  "Long Thới, Nhà Bè, Hồ Chí Minh",
  "Hiệp Phước, Nhà Bè, Hồ Chí Minh",
  "Cần Thạnh, Cần Giờ, Hồ Chí Minh",
  "Bình Khánh, Cần Giờ, Hồ Chí Minh",
  "Tam Thôn Hiệp, Cần Giờ, Hồ Chí Minh",
  "An Thới Đông, Cần Giờ, Hồ Chí Minh",
  "Thạnh An, Cần Giờ, Hồ Chí Minh",
  "Long Hòa, Cần Giờ, Hồ Chí Minh",
  "Lý Nhơn, Cần Giờ, Hồ Chí Minh",
  "Phường 5, Tân An, Long An",
  "Phường 2, Tân An, Long An",
  "Phường 4, Tân An, Long An",
  "Tân Khánh, Tân An, Long An",
  "Phường 1, Tân An, Long An",
  "Phường 3, Tân An, Long An",
  "Phường 7, Tân An, Long An",
  "Phường 6, Tân An, Long An",
  "Hướng Thọ Phú, Tân An, Long An",
  "Nhơn Thạnh Trung, Tân An, Long An",
  "Lợi Bình Nhơn, Tân An, Long An",
  "Bình Tâm, Tân An, Long An",
  "Khánh Hậu, Tân An, Long An",
  "An Vĩnh Ngãi, Tân An, Long An",
  "Phường 1, Kiến Tường, Long An",
  "Phường 2, Kiến Tường, Long An",
  "Thạnh Trị, Kiến Tường, Long An",
  "Bình Hiệp, Kiến Tường, Long An",
  "Bình Tân, Kiến Tường, Long An",
  "Tuyên Thạnh, Kiến Tường, Long An",
  "Phường 3, Kiến Tường, Long An",
  "Thạnh Hưng, Kiến Tường, Long An",
  "Tân Hưng, Tân Hưng, Long An",
  "Hưng Hà, Tân Hưng, Long An",
  "Hưng Điền B, Tân Hưng, Long An",
  "Hưng Điền, Tân Hưng, Long An",
  "Thạnh Hưng, Tân Hưng, Long An",
  "Hưng Thạnh, Tân Hưng, Long An",
  "Vĩnh Thạnh, Tân Hưng, Long An",
  "Vĩnh Châu B, Tân Hưng, Long An",
  "Vĩnh Lợi, Tân Hưng, Long An",
  "Vĩnh Đại, Tân Hưng, Long An",
  "Vĩnh Châu A, Tân Hưng, Long An",
  "Vĩnh Bửu, Tân Hưng, Long An",
  "Vĩnh Hưng, Vĩnh Hưng, Long An",
  "Hưng Điền A, Vĩnh Hưng, Long An",
  "Khánh Hưng, Vĩnh Hưng, Long An",
  "Thái Trị, Vĩnh Hưng, Long An",
  "Vĩnh Trị, Vĩnh Hưng, Long An",
  "Thái Bình Trung, Vĩnh Hưng, Long An",
  "Vĩnh Bình, Vĩnh Hưng, Long An",
  "Vĩnh Thuận, Vĩnh Hưng, Long An",
  "Tuyên Bình, Vĩnh Hưng, Long An",
  "Tuyên Bình Tây, Vĩnh Hưng, Long An",
  "Bình Hòa Tây, Mộc Hóa, Long An",
  "Bình Thạnh, Mộc Hóa, Long An",
  "Bình Hòa Trung, Mộc Hóa, Long An",
  "Bình Hòa Đông, Mộc Hóa, Long An",
  "Bình Phong Thạnh, Mộc Hóa, Long An",
  "Tân Lập, Mộc Hóa, Long An",
  "Tân Thành, Mộc Hóa, Long An",
  "Tân Thạnh, Tân Thạnh, Long An",
  "Bắc Hòa, Tân Thạnh, Long An",
  "Hậu Thạnh Tây, Tân Thạnh, Long An",
  "Nhơn Hòa Lập, Tân Thạnh, Long An",
  "Tân Lập, Tân Thạnh, Long An",
  "Hậu Thạnh Đông, Tân Thạnh, Long An",
  "Nhơn Hoà, Tân Thạnh, Long An",
  "Kiến Bình, Tân Thạnh, Long An",
  "Tân Thành, Tân Thạnh, Long An",
  "Tân Bình, Tân Thạnh, Long An",
  "Tân Ninh, Tân Thạnh, Long An",
  "Nhơn Ninh, Tân Thạnh, Long An",
  "Tân Hòa, Tân Thạnh, Long An",
  "Thạnh Hóa, Thạnh Hóa, Long An",
  "Tân Hiệp, Thạnh Hóa, Long An",
  "Thuận Bình, Thạnh Hóa, Long An",
  "Thạnh Phước, Thạnh Hóa, Long An",
  "Thạnh Phú, Thạnh Hóa, Long An",
  "Thuận Nghĩa Hòa, Thạnh Hóa, Long An",
  "Thủy Đông, Thạnh Hóa, Long An",
  "Thủy Tây, Thạnh Hóa, Long An",
  "Tân Tây, Thạnh Hóa, Long An",
  "Tân Đông, Thạnh Hóa, Long An",
  "Thạnh An, Thạnh Hóa, Long An",
  "Đông Thành, Đức Huệ, Long An",
  "Mỹ Quý Đông, Đức Huệ, Long An",
  "Mỹ Thạnh Bắc, Đức Huệ, Long An",
  "Mỹ Quý Tây, Đức Huệ, Long An",
  "Mỹ Thạnh Tây, Đức Huệ, Long An",
  "Mỹ Thạnh Đông, Đức Huệ, Long An",
  "Bình Thành, Đức Huệ, Long An",
  "Bình Hòa Bắc, Đức Huệ, Long An",
  "Bình Hòa Hưng, Đức Huệ, Long An",
  "Bình Hòa Nam, Đức Huệ, Long An",
  "Mỹ Bình, Đức Huệ, Long An",
  "Hậu Nghĩa, Đức Hòa, Long An",
  "Hiệp Hòa, Đức Hòa, Long An",
  "Đức Hòa, Đức Hòa, Long An",
  "Lộc Giang, Đức Hòa, Long An",
  "An Ninh Đông, Đức Hòa, Long An",
  "An Ninh Tây, Đức Hòa, Long An",
  "Tân Mỹ, Đức Hòa, Long An",
  "Hiệp Hòa, Đức Hòa, Long An",
  "Đức Lập Thượng, Đức Hòa, Long An",
  "Đức Lập Hạ, Đức Hòa, Long An",
  "Tân Phú, Đức Hòa, Long An",
  "Mỹ Hạnh Bắc, Đức Hòa, Long An",
  "Đức Hòa Thượng, Đức Hòa, Long An",
  "Hòa Khánh Tây, Đức Hòa, Long An",
  "Hòa Khánh Đông, Đức Hòa, Long An",
  "Mỹ Hạnh Nam, Đức Hòa, Long An",
  "Hòa Khánh Nam, Đức Hòa, Long An",
  "Đức Hòa Đông, Đức Hòa, Long An",
  "Đức Hòa Hạ, Đức Hòa, Long An",
  "Hựu Thạnh, Đức Hòa, Long An",
  "Bến Lức, Bến Lức, Long An",
  "Thạnh Lợi, Bến Lức, Long An",
  "Lương Bình, Bến Lức, Long An",
  "Thạnh Hòa, Bến Lức, Long An",
  "Lương Hòa, Bến Lức, Long An",
  "Tân Hòa, Bến Lức, Long An",
  "Tân Bửu, Bến Lức, Long An",
  "An Thạnh, Bến Lức, Long An",
  "Bình Đức, Bến Lức, Long An",
  "Mỹ Yên, Bến Lức, Long An",
  "Thanh Phú, Bến Lức, Long An",
  "Long Hiệp, Bến Lức, Long An",
  "Thạnh Đức, Bến Lức, Long An",
  "Phước Lợi, Bến Lức, Long An",
  "Nhựt Chánh, Bến Lức, Long An",
  "Thủ Thừa, Thủ Thừa, Long An",
  "Long Thạnh, Thủ Thừa, Long An",
  "Tân Thành, Thủ Thừa, Long An",
  "Long Thuận, Thủ Thừa, Long An",
  "Mỹ Lạc, Thủ Thừa, Long An",
  "Mỹ Thạnh, Thủ Thừa, Long An",
  "Bình An, Thủ Thừa, Long An",
  "Nhị Thành, Thủ Thừa, Long An",
  "Mỹ An, Thủ Thừa, Long An",
  "Bình Thạnh, Thủ Thừa, Long An",
  "Mỹ Phú, Thủ Thừa, Long An",
  "Tân Long, Thủ Thừa, Long An",
  "Tân Trụ, Tân Trụ, Long An",
  "Tân Bình, Tân Trụ, Long An",
  "Quê Mỹ Thạnh, Tân Trụ, Long An",
  "Lạc Tấn, Tân Trụ, Long An",
  "Bình Trinh Đông, Tân Trụ, Long An",
  "Tân Phước Tây, Tân Trụ, Long An",
  "Bình Lãng, Tân Trụ, Long An",
  "Bình Tịnh, Tân Trụ, Long An",
  "Đức Tân, Tân Trụ, Long An",
  "Nhựt Ninh, Tân Trụ, Long An",
  "Cần Đước, Cần Đước, Long An",
  "Long Trạch, Cần Đước, Long An",
  "Long Khê, Cần Đước, Long An",
  "Long Định, Cần Đước, Long An",
  "Phước Vân, Cần Đước, Long An",
  "Long Hòa, Cần Đước, Long An",
  "Long Cang, Cần Đước, Long An",
  "Long Sơn, Cần Đước, Long An",
  "Tân Trạch, Cần Đước, Long An",
  "Mỹ Lệ, Cần Đước, Long An",
  "Tân Lân, Cần Đước, Long An",
  "Phước Tuy, Cần Đước, Long An",
  "Long Hựu Đông, Cần Đước, Long An",
  "Tân Ân, Cần Đước, Long An",
  "Phước Đông, Cần Đước, Long An",
  "Long Hựu Tây, Cần Đước, Long An",
  "Tân Chánh, Cần Đước, Long An",
  "Cần Giuộc, Cần Giuộc, Long An",
  "Phước Lý, Cần Giuộc, Long An",
  "Long Thượng, Cần Giuộc, Long An",
  "Long Hậu, Cần Giuộc, Long An",
  "Phước Hậu, Cần Giuộc, Long An",
  "Mỹ Lộc, Cần Giuộc, Long An",
  "Phước Lại, Cần Giuộc, Long An",
  "Phước Lâm, Cần Giuộc, Long An",
  "Thuận Thành, Cần Giuộc, Long An",
  "Phước Vĩnh Tây, Cần Giuộc, Long An",
  "Phước Vĩnh Đông, Cần Giuộc, Long An",
  "Long An, Cần Giuộc, Long An",
  "Long Phụng, Cần Giuộc, Long An",
  "Đông Thạnh, Cần Giuộc, Long An",
  "Tân Tập, Cần Giuộc, Long An",
  "Tầm Vu, Châu Thành, Long An",
  "Bình Quới, Châu Thành, Long An",
  "Hòa Phú, Châu Thành, Long An",
  "Phú Ngãi Trị, Châu Thành, Long An",
  "Vĩnh Công, Châu Thành, Long An",
  "Thuận Mỹ, Châu Thành, Long An",
  "Hiệp Thạnh, Châu Thành, Long An",
  "Phước Tân Hưng, Châu Thành, Long An",
  "Thanh Phú Long, Châu Thành, Long An",
  "Dương Xuân Hội, Châu Thành, Long An",
  "An Lục Long, Châu Thành, Long An",
  "Long Trì, Châu Thành, Long An",
  "Thanh Vĩnh Đông, Châu Thành, Long An",
  "Phường 5, Mỹ Tho, Tiền Giang",
  "Phường 4, Mỹ Tho, Tiền Giang",
  "Phường 7, Mỹ Tho, Tiền Giang",
  "Phường 3, Mỹ Tho, Tiền Giang",
  "Phường 1, Mỹ Tho, Tiền Giang",
  "Phường 2, Mỹ Tho, Tiền Giang",
  "Phường 8, Mỹ Tho, Tiền Giang",
  "Phường 6, Mỹ Tho, Tiền Giang",
  "Phường 9, Mỹ Tho, Tiền Giang",
  "Phường 10, Mỹ Tho, Tiền Giang",
  "Tân Long, Mỹ Tho, Tiền Giang",
  "Đạo Thạnh, Mỹ Tho, Tiền Giang",
  "Trung An, Mỹ Tho, Tiền Giang",
  "Mỹ Phong, Mỹ Tho, Tiền Giang",
  "Tân Mỹ Chánh, Mỹ Tho, Tiền Giang",
  "Phước Thạnh, Mỹ Tho, Tiền Giang",
  "Thới Sơn, Mỹ Tho, Tiền Giang",
  "Phường 3, Gò Công, Tiền Giang",
  "Phường 2, Gò Công, Tiền Giang",
  "Phường 4, Gò Công, Tiền Giang",
  "Phường 1, Gò Công, Tiền Giang",
  "Phường 5, Gò Công, Tiền Giang",
  "Long Hưng, Gò Công, Tiền Giang",
  "Long Thuận, Gò Công, Tiền Giang",
  "Long Chánh, Gò Công, Tiền Giang",
  "Long Hòa, Gò Công, Tiền Giang",
  "Bình Đông, Gò Công, Tiền Giang",
  "Bình Xuân, Gò Công, Tiền Giang",
  "Tân Trung, Gò Công, Tiền Giang",
  "Phường 1, Cai Lậy, Tiền Giang",
  "Phường 2, Cai Lậy, Tiền Giang",
  "Phường 3, Cai Lậy, Tiền Giang",
  "Phường 4, Cai Lậy, Tiền Giang",
  "Phường 5, Cai Lậy, Tiền Giang",
  "Mỹ Phước Tây, Cai Lậy, Tiền Giang",
  "Mỹ Hạnh Đông, Cai Lậy, Tiền Giang",
  "Mỹ Hạnh Trung, Cai Lậy, Tiền Giang",
  "Tân Phú, Cai Lậy, Tiền Giang",
  "Tân Bình, Cai Lậy, Tiền Giang",
  "Tân Hội, Cai Lậy, Tiền Giang",
  "Nhị Mỹ, Cai Lậy, Tiền Giang",
  "Nhị Quý, Cai Lậy, Tiền Giang",
  "Thanh Hòa, Cai Lậy, Tiền Giang",
  "Phú Quý, Cai Lậy, Tiền Giang",
  "Long Khánh, Cai Lậy, Tiền Giang",
  "Mỹ Phước, Tân Phước, Tiền Giang",
  "Tân Hòa Đông, Tân Phước, Tiền Giang",
  "Thạnh Tân, Tân Phước, Tiền Giang",
  "Thạnh Mỹ, Tân Phước, Tiền Giang",
  "Thạnh Hoà, Tân Phước, Tiền Giang",
  "Phú Mỹ, Tân Phước, Tiền Giang",
  "Tân Hòa Thành, Tân Phước, Tiền Giang",
  "Hưng Thạnh, Tân Phước, Tiền Giang",
  "Tân Lập 1, Tân Phước, Tiền Giang",
  "Tân Hòa Tây, Tân Phước, Tiền Giang",
  "Tân Lập 2, Tân Phước, Tiền Giang",
  "Phước Lập, Tân Phước, Tiền Giang",
  "Cái Bè, Cái Bè, Tiền Giang",
  "Hậu Mỹ Bắc B, Cái Bè, Tiền Giang",
  "Hậu Mỹ Bắc A, Cái Bè, Tiền Giang",
  "Mỹ Trung, Cái Bè, Tiền Giang",
  "Hậu Mỹ Trinh, Cái Bè, Tiền Giang",
  "Hậu Mỹ Phú, Cái Bè, Tiền Giang",
  "Mỹ Tân, Cái Bè, Tiền Giang",
  "Mỹ Lợi B, Cái Bè, Tiền Giang",
  "Thiện Trung, Cái Bè, Tiền Giang",
  "Mỹ Hội, Cái Bè, Tiền Giang",
  "An Cư, Cái Bè, Tiền Giang",
  "Hậu Thành, Cái Bè, Tiền Giang",
  "Mỹ Lợi A, Cái Bè, Tiền Giang",
  "Hòa Khánh, Cái Bè, Tiền Giang",
  "Thiện Trí, Cái Bè, Tiền Giang",
  "Mỹ Đức Đông, Cái Bè, Tiền Giang",
  "Mỹ Đức Tây, Cái Bè, Tiền Giang",
  "Đông Hòa Hiệp, Cái Bè, Tiền Giang",
  "An Thái Đông, Cái Bè, Tiền Giang",
  "Tân Hưng, Cái Bè, Tiền Giang",
  "Mỹ Lương, Cái Bè, Tiền Giang",
  "Tân Thanh, Cái Bè, Tiền Giang",
  "An Thái Trung, Cái Bè, Tiền Giang",
  "An Hữu, Cái Bè, Tiền Giang",
  "Hòa Hưng, Cái Bè, Tiền Giang",
  "Thạnh Lộc, Cai Lậy, Tiền Giang",
  "Mỹ Thành Bắc, Cai Lậy, Tiền Giang",
  "Phú Cường, Cai Lậy, Tiền Giang",
  "Mỹ Thành Nam, Cai Lậy, Tiền Giang",
  "Phú Nhuận, Cai Lậy, Tiền Giang",
  "Bình Phú, Cai Lậy, Tiền Giang",
  "Cẩm Sơn, Cai Lậy, Tiền Giang",
  "Phú An, Cai Lậy, Tiền Giang",
  "Mỹ Long, Cai Lậy, Tiền Giang",
  "Long Tiên, Cai Lậy, Tiền Giang",
  "Hiệp Đức, Cai Lậy, Tiền Giang",
  "Long Trung, Cai Lậy, Tiền Giang",
  "Hội Xuân, Cai Lậy, Tiền Giang",
  "Tân Phong, Cai Lậy, Tiền Giang",
  "Tam Bình, Cai Lậy, Tiền Giang",
  "Ngũ Hiệp, Cai Lậy, Tiền Giang",
  "Tân Hiệp, Châu Thành, Tiền Giang",
  "Tân Hội Đông, Châu Thành, Tiền Giang",
  "Tân Hương, Châu Thành, Tiền Giang",
  "Tân Lý Đông, Châu Thành, Tiền Giang",
  "Tân Lý Tây, Châu Thành, Tiền Giang",
  "Thân Cửu Nghĩa, Châu Thành, Tiền Giang",
  "Tam Hiệp, Châu Thành, Tiền Giang",
  "Điềm Hy, Châu Thành, Tiền Giang",
  "Nhị Bình, Châu Thành, Tiền Giang",
  "Dưỡng Điềm, Châu Thành, Tiền Giang",
  "Đông Hòa, Châu Thành, Tiền Giang",
  "Long Định, Châu Thành, Tiền Giang",
  "Hữu Đạo, Châu Thành, Tiền Giang",
  "Long An, Châu Thành, Tiền Giang",
  "Long Hưng, Châu Thành, Tiền Giang",
  "Bình Trưng, Châu Thành, Tiền Giang",
  "Thạnh Phú, Châu Thành, Tiền Giang",
  "Bàn Long, Châu Thành, Tiền Giang",
  "Vĩnh Kim, Châu Thành, Tiền Giang",
  "Bình Đức, Châu Thành, Tiền Giang",
  "Song Thuận, Châu Thành, Tiền Giang",
  "Kim Sơn, Châu Thành, Tiền Giang",
  "Phú Phong, Châu Thành, Tiền Giang",
  "Chợ Gạo, Chợ Gạo, Tiền Giang",
  "Trung Hòa, Chợ Gạo, Tiền Giang",
  "Hòa Tịnh, Chợ Gạo, Tiền Giang",
  "Mỹ Tịnh An, Chợ Gạo, Tiền Giang",
  "Tân Bình Thạnh, Chợ Gạo, Tiền Giang",
  "Phú Kiết, Chợ Gạo, Tiền Giang",
  "Lương Hòa Lạc, Chợ Gạo, Tiền Giang",
  "Thanh Bình, Chợ Gạo, Tiền Giang",
  "Quơn Long, Chợ Gạo, Tiền Giang",
  "Bình Phục Nhứt, Chợ Gạo, Tiền Giang",
  "Đăng Hưng Phước, Chợ Gạo, Tiền Giang",
  "Tân Thuận Bình, Chợ Gạo, Tiền Giang",
  "Song Bình, Chợ Gạo, Tiền Giang",
  "Bình Phan, Chợ Gạo, Tiền Giang",
  "Long Bình Điền, Chợ Gạo, Tiền Giang",
  "An Thạnh Thủy, Chợ Gạo, Tiền Giang",
  "Xuân Đông, Chợ Gạo, Tiền Giang",
  "Hòa Định, Chợ Gạo, Tiền Giang",
  "Bình Ninh, Chợ Gạo, Tiền Giang",
  "Vĩnh Bình, Gò Công Tây, Tiền Giang",
  "Đồng Sơn, Gò Công Tây, Tiền Giang",
  "Bình Phú, Gò Công Tây, Tiền Giang",
  "Đồng Thạnh, Gò Công Tây, Tiền Giang",
  "Thành Công, Gò Công Tây, Tiền Giang",
  "Bình Nhì, Gò Công Tây, Tiền Giang",
  "Yên Luông, Gò Công Tây, Tiền Giang",
  "Thạnh Trị, Gò Công Tây, Tiền Giang",
  "Thạnh Nhựt, Gò Công Tây, Tiền Giang",
  "Long Vĩnh, Gò Công Tây, Tiền Giang",
  "Bình Tân, Gò Công Tây, Tiền Giang",
  "Vĩnh Hựu, Gò Công Tây, Tiền Giang",
  "Long Bình, Gò Công Tây, Tiền Giang",
  "Tân Hòa, Gò Công Đông, Tiền Giang",
  "Tăng Hoà, Gò Công Đông, Tiền Giang",
  "Tân Phước, Gò Công Đông, Tiền Giang",
  "Gia Thuận, Gò Công Đông, Tiền Giang",
  "Vàm Láng, Gò Công Đông, Tiền Giang",
  "Tân Tây, Gò Công Đông, Tiền Giang",
  "Kiểng Phước, Gò Công Đông, Tiền Giang",
  "Tân Đông, Gò Công Đông, Tiền Giang",
  "Bình Ân, Gò Công Đông, Tiền Giang",
  "Tân Điền, Gò Công Đông, Tiền Giang",
  "Bình Nghị, Gò Công Đông, Tiền Giang",
  "Phước Trung, Gò Công Đông, Tiền Giang",
  "Tân Thành, Gò Công Đông, Tiền Giang",
  "Tân Thới, Tân Phú Đông, Tiền Giang",
  "Tân Phú, Tân Phú Đông, Tiền Giang",
  "Phú Thạnh, Tân Phú Đông, Tiền Giang",
  "Tân Thạnh, Tân Phú Đông, Tiền Giang",
  "Phú Đông, Tân Phú Đông, Tiền Giang",
  "Phú Tân, Tân Phú Đông, Tiền Giang",
  "Phú Khương, Bến Tre, Bến Tre",
  "Phú Tân, Bến Tre, Bến Tre",
  "Phường 8, Bến Tre, Bến Tre",
  "Phường 6, Bến Tre, Bến Tre",
  "Phường 4, Bến Tre, Bến Tre",
  "Phường 5, Bến Tre, Bến Tre",
  "An Hội, Bến Tre, Bến Tre",
  "Phường 7, Bến Tre, Bến Tre",
  "Sơn Đông, Bến Tre, Bến Tre",
  "Phú Hưng, Bến Tre, Bến Tre",
  "Bình Phú, Bến Tre, Bến Tre",
  "Mỹ Thạnh An, Bến Tre, Bến Tre",
  "Nhơn Thạnh, Bến Tre, Bến Tre",
  "Phú Nhuận, Bến Tre, Bến Tre",
  "Châu Thành, Châu Thành, Bến Tre",
  "Tân Thạch, Châu Thành, Bến Tre",
  "Qưới Sơn, Châu Thành, Bến Tre",
  "An Khánh, Châu Thành, Bến Tre",
  "Giao Long, Châu Thành, Bến Tre",
  "Phú Túc, Châu Thành, Bến Tre",
  "Phú Đức, Châu Thành, Bến Tre",
  "Phú An Hòa, Châu Thành, Bến Tre",
  "An Phước, Châu Thành, Bến Tre",
  "Tam Phước, Châu Thành, Bến Tre",
  "Thành Triệu, Châu Thành, Bến Tre",
  "Tường Đa, Châu Thành, Bến Tre",
  "Tân Phú, Châu Thành, Bến Tre",
  "Quới Thành, Châu Thành, Bến Tre",
  "Phước Thạnh, Châu Thành, Bến Tre",
  "An Hóa, Châu Thành, Bến Tre",
  "Tiên Long, Châu Thành, Bến Tre",
  "An Hiệp, Châu Thành, Bến Tre",
  "Hữu Định, Châu Thành, Bến Tre",
  "Tiên Thủy, Châu Thành, Bến Tre",
  "Sơn Hòa, Châu Thành, Bến Tre",
  "Chợ Lách, Chợ Lách, Bến Tre",
  "Phú Phụng, Chợ Lách, Bến Tre",
  "Sơn Định, Chợ Lách, Bến Tre",
  "Vĩnh Bình, Chợ Lách, Bến Tre",
  "Hòa Nghĩa, Chợ Lách, Bến Tre",
  "Long Thới, Chợ Lách, Bến Tre",
  "Phú Sơn, Chợ Lách, Bến Tre",
  "Tân Thiềng, Chợ Lách, Bến Tre",
  "Vĩnh Thành, Chợ Lách, Bến Tre",
  "Vĩnh Hòa, Chợ Lách, Bến Tre",
  "Hưng Khánh Trung B, Chợ Lách, Bến Tre",
  "Mỏ Cày, Mỏ Cày Nam, Bến Tre",
  "Định Thủy, Mỏ Cày Nam, Bến Tre",
  "Đa Phước Hội, Mỏ Cày Nam, Bến Tre",
  "Tân Hội, Mỏ Cày Nam, Bến Tre",
  "Phước Hiệp, Mỏ Cày Nam, Bến Tre",
  "Bình Khánh , Mỏ Cày Nam, Bến Tre",
  "An Thạnh, Mỏ Cày Nam, Bến Tre",
  "An Định, Mỏ Cày Nam, Bến Tre",
  "Thành Thới B, Mỏ Cày Nam, Bến Tre",
  "Tân Trung, Mỏ Cày Nam, Bến Tre",
  "An Thới, Mỏ Cày Nam, Bến Tre",
  "Thành Thới A, Mỏ Cày Nam, Bến Tre",
  "Minh Đức, Mỏ Cày Nam, Bến Tre",
  "Ngãi Đăng, Mỏ Cày Nam, Bến Tre",
  "Cẩm Sơn, Mỏ Cày Nam, Bến Tre",
  "Hương Mỹ, Mỏ Cày Nam, Bến Tre",
  "Giồng Trôm, Giồng Trôm, Bến Tre",
  "Phong Nẫm, Giồng Trôm, Bến Tre",
  "Mỹ Thạnh, Giồng Trôm, Bến Tre",
  "Châu Hòa, Giồng Trôm, Bến Tre",
  "Lương Hòa, Giồng Trôm, Bến Tre",
  "Lương Quới, Giồng Trôm, Bến Tre",
  "Lương Phú, Giồng Trôm, Bến Tre",
  "Châu Bình, Giồng Trôm, Bến Tre",
  "Thuận Điền, Giồng Trôm, Bến Tre",
  "Sơn Phú, Giồng Trôm, Bến Tre",
  "Bình Hoà, Giồng Trôm, Bến Tre",
  "Phước Long, Giồng Trôm, Bến Tre",
  "Hưng Phong, Giồng Trôm, Bến Tre",
  "Long Mỹ, Giồng Trôm, Bến Tre",
  "Tân Hào, Giồng Trôm, Bến Tre",
  "Bình Thành, Giồng Trôm, Bến Tre",
  "Tân Thanh, Giồng Trôm, Bến Tre",
  "Tân Lợi Thạnh, Giồng Trôm, Bến Tre",
  "Thạnh Phú Đông, Giồng Trôm, Bến Tre",
  "Hưng Nhượng, Giồng Trôm, Bến Tre",
  "Hưng Lễ, Giồng Trôm, Bến Tre",
  "Bình Đại, Bình Đại, Bến Tre",
  "Tam Hiệp, Bình Đại, Bến Tre",
  "Long Định, Bình Đại, Bến Tre",
  "Long Hòa, Bình Đại, Bến Tre",
  "Phú Thuận, Bình Đại, Bến Tre",
  "Vang Quới Tây, Bình Đại, Bến Tre",
  "Vang Quới Đông, Bình Đại, Bến Tre",
  "Châu Hưng, Bình Đại, Bến Tre",
  "Phú Vang, Bình Đại, Bến Tre",
  "Lộc Thuận, Bình Đại, Bến Tre",
  "Định Trung, Bình Đại, Bến Tre",
  "Thới Lai, Bình Đại, Bến Tre",
  "Bình Thới, Bình Đại, Bến Tre",
  "Phú Long, Bình Đại, Bến Tre",
  "Bình Thắng, Bình Đại, Bến Tre",
  "Thạnh Trị, Bình Đại, Bến Tre",
  "Đại Hòa Lộc, Bình Đại, Bến Tre",
  "Thừa Đức, Bình Đại, Bến Tre",
  "Thạnh Phước, Bình Đại, Bến Tre",
  "Thới Thuận, Bình Đại, Bến Tre",
  "Ba Tri, Ba Tri, Bến Tre",
  "Tân Mỹ, Ba Tri, Bến Tre",
  "Mỹ Hòa, Ba Tri, Bến Tre",
  "Tân Xuân, Ba Tri, Bến Tre",
  "Mỹ Chánh, Ba Tri, Bến Tre",
  "Bảo Thạnh, Ba Tri, Bến Tre",
  "An Phú Trung, Ba Tri, Bến Tre",
  "Mỹ Thạnh, Ba Tri, Bến Tre",
  "Mỹ Nhơn, Ba Tri, Bến Tre",
  "Phước Ngãi, Ba Tri, Bến Tre",
  "An Ngãi Trung, Ba Tri, Bến Tre",
  "Phú Lễ, Ba Tri, Bến Tre",
  "An Bình Tây, Ba Tri, Bến Tre",
  "Bảo Thuận, Ba Tri, Bến Tre",
  "Tân Hưng, Ba Tri, Bến Tre",
  "An Ngãi Tây, Ba Tri, Bến Tre",
  "An Hiệp, Ba Tri, Bến Tre",
  "Vĩnh Hòa, Ba Tri, Bến Tre",
  "Tân Thủy, Ba Tri, Bến Tre",
  "Vĩnh An, Ba Tri, Bến Tre",
  "An Đức, Ba Tri, Bến Tre",
  "An Hòa Tây, Ba Tri, Bến Tre",
  "An Thủy, Ba Tri, Bến Tre",
  "Thạnh Phú, Thạnh Phú, Bến Tre",
  "Phú Khánh, Thạnh Phú, Bến Tre",
  "Đại Điền, Thạnh Phú, Bến Tre",
  "Quới Điền, Thạnh Phú, Bến Tre",
  "Tân Phong, Thạnh Phú, Bến Tre",
  "Mỹ Hưng, Thạnh Phú, Bến Tre",
  "An Thạnh, Thạnh Phú, Bến Tre",
  "Thới Thạnh, Thạnh Phú, Bến Tre",
  "Hòa Lợi, Thạnh Phú, Bến Tre",
  "An Điền, Thạnh Phú, Bến Tre",
  "Bình Thạnh, Thạnh Phú, Bến Tre",
  "An Thuận, Thạnh Phú, Bến Tre",
  "An Quy, Thạnh Phú, Bến Tre",
  "Thạnh Hải, Thạnh Phú, Bến Tre",
  "An Nhơn, Thạnh Phú, Bến Tre",
  "Giao Thạnh, Thạnh Phú, Bến Tre",
  "Thạnh Phong, Thạnh Phú, Bến Tre",
  "Mỹ An, Thạnh Phú, Bến Tre",
  "Phú Mỹ, Mỏ Cày Bắc, Bến Tre",
  "Hưng Khánh Trung A, Mỏ Cày Bắc, Bến Tre",
  "Thanh Tân, Mỏ Cày Bắc, Bến Tre",
  "Thạnh Ngãi, Mỏ Cày Bắc, Bến Tre",
  "Tân Phú Tây, Mỏ Cày Bắc, Bến Tre",
  "Phước Mỹ Trung, Mỏ Cày Bắc, Bến Tre",
  "Tân Thành Bình, Mỏ Cày Bắc, Bến Tre",
  "Thành An, Mỏ Cày Bắc, Bến Tre",
  "Hòa Lộc, Mỏ Cày Bắc, Bến Tre",
  "Tân Thanh Tây, Mỏ Cày Bắc, Bến Tre",
  "Tân Bình, Mỏ Cày Bắc, Bến Tre",
  "Nhuận Phú Tân, Mỏ Cày Bắc, Bến Tre",
  "Khánh Thạnh Tân, Mỏ Cày Bắc, Bến Tre",
  "Phường 4, Trà Vinh, Trà Vinh",
  "Phường 1, Trà Vinh, Trà Vinh",
  "Phường 3, Trà Vinh, Trà Vinh",
  "Phường 2, Trà Vinh, Trà Vinh",
  "Phường 5, Trà Vinh, Trà Vinh",
  "Phường 6, Trà Vinh, Trà Vinh",
  "Phường 7, Trà Vinh, Trà Vinh",
  "Phường 8, Trà Vinh, Trà Vinh",
  "Phường 9, Trà Vinh, Trà Vinh",
  "Long Đức, Trà Vinh, Trà Vinh",
  "Càng Long, Càng Long, Trà Vinh",
  "Mỹ Cẩm, Càng Long, Trà Vinh",
  "An Trường A, Càng Long, Trà Vinh",
  "An Trường, Càng Long, Trà Vinh",
  "Huyền Hội, Càng Long, Trà Vinh",
  "Tân An, Càng Long, Trà Vinh",
  "Tân Bình, Càng Long, Trà Vinh",
  "Bình Phú, Càng Long, Trà Vinh",
  "Phương Thạnh, Càng Long, Trà Vinh",
  "Đại Phúc, Càng Long, Trà Vinh",
  "Đại Phước, Càng Long, Trà Vinh",
  "Nhị Long Phú, Càng Long, Trà Vinh",
  "Nhị Long, Càng Long, Trà Vinh",
  "Đức Mỹ, Càng Long, Trà Vinh",
  "Cầu Kè, Cầu Kè, Trà Vinh",
  "Hòa Ân, Cầu Kè, Trà Vinh",
  "Châu Điền, Cầu Kè, Trà Vinh",
  "An Phú Tân, Cầu Kè, Trà Vinh",
  "Hoà Tân, Cầu Kè, Trà Vinh",
  "Ninh Thới, Cầu Kè, Trà Vinh",
  "Phong Phú, Cầu Kè, Trà Vinh",
  "Phong Thạnh, Cầu Kè, Trà Vinh",
  "Tam Ngãi, Cầu Kè, Trà Vinh",
  "Thông Hòa, Cầu Kè, Trà Vinh",
  "Thạnh Phú, Cầu Kè, Trà Vinh",
  "Tiểu Cần, Tiểu Cần, Trà Vinh",
  "Cầu Quan, Tiểu Cần, Trà Vinh",
  "Phú Cần, Tiểu Cần, Trà Vinh",
  "Hiếu Tử, Tiểu Cần, Trà Vinh",
  "Hiếu Trung, Tiểu Cần, Trà Vinh",
  "Long Thới, Tiểu Cần, Trà Vinh",
  "Hùng Hòa, Tiểu Cần, Trà Vinh",
  "Tân Hùng, Tiểu Cần, Trà Vinh",
  "Tập Ngãi, Tiểu Cần, Trà Vinh",
  "Ngãi Hùng, Tiểu Cần, Trà Vinh",
  "Tân Hòa, Tiểu Cần, Trà Vinh",
  "Châu Thành, Châu Thành, Trà Vinh",
  "Đa Lộc, Châu Thành, Trà Vinh",
  "Mỹ Chánh, Châu Thành, Trà Vinh",
  "Thanh Mỹ, Châu Thành, Trà Vinh",
  "Lương Hoà A, Châu Thành, Trà Vinh",
  "Lương Hòa, Châu Thành, Trà Vinh",
  "Song Lộc, Châu Thành, Trà Vinh",
  "Nguyệt Hóa, Châu Thành, Trà Vinh",
  "Hòa Thuận, Châu Thành, Trà Vinh",
  "Hòa Lợi, Châu Thành, Trà Vinh",
  "Phước Hảo, Châu Thành, Trà Vinh",
  "Hưng Mỹ, Châu Thành, Trà Vinh",
  "Hòa Minh, Châu Thành, Trà Vinh",
  "Long Hòa, Châu Thành, Trà Vinh",
  "Cầu Ngang, Cầu Ngang, Trà Vinh",
  "Mỹ Long, Cầu Ngang, Trà Vinh",
  "Mỹ Long Bắc, Cầu Ngang, Trà Vinh",
  "Mỹ Long Nam, Cầu Ngang, Trà Vinh",
  "Mỹ Hòa, Cầu Ngang, Trà Vinh",
  "Vĩnh Kim, Cầu Ngang, Trà Vinh",
  "Kim Hòa, Cầu Ngang, Trà Vinh",
  "Hiệp Hòa, Cầu Ngang, Trà Vinh",
  "Thuận Hòa, Cầu Ngang, Trà Vinh",
  "Long Sơn, Cầu Ngang, Trà Vinh",
  "Nhị Trường, Cầu Ngang, Trà Vinh",
  "Trường Thọ, Cầu Ngang, Trà Vinh",
  "Hiệp Mỹ Đông, Cầu Ngang, Trà Vinh",
  "Hiệp Mỹ Tây, Cầu Ngang, Trà Vinh",
  "Thạnh Hòa Sơn, Cầu Ngang, Trà Vinh",
  "Trà Cú, Trà Cú, Trà Vinh",
  "Định An, Trà Cú, Trà Vinh",
  "Phước Hưng, Trà Cú, Trà Vinh",
  "Tập Sơn, Trà Cú, Trà Vinh",
  "Tân Sơn, Trà Cú, Trà Vinh",
  "An Quảng Hữu, Trà Cú, Trà Vinh",
  "Lưu Nghiệp Anh, Trà Cú, Trà Vinh",
  "Ngãi Xuyên, Trà Cú, Trà Vinh",
  "Kim Sơn, Trà Cú, Trà Vinh",
  "Thanh Sơn, Trà Cú, Trà Vinh",
  "Hàm Giang, Trà Cú, Trà Vinh",
  "Hàm Tân, Trà Cú, Trà Vinh",
  "Đại An, Trà Cú, Trà Vinh",
  "Định An, Trà Cú, Trà Vinh",
  "Ngọc Biên, Trà Cú, Trà Vinh",
  "Long Hiệp, Trà Cú, Trà Vinh",
  "Tân Hiệp, Trà Cú, Trà Vinh",
  "Đôn Xuân, Duyên Hải, Trà Vinh",
  "Đôn Châu, Duyên Hải, Trà Vinh",
  "Long Thành, Duyên Hải, Trà Vinh",
  "Long Khánh, Duyên Hải, Trà Vinh",
  "Ngũ Lạc, Duyên Hải, Trà Vinh",
  "Long Vĩnh, Duyên Hải, Trà Vinh",
  "Đông Hải, Duyên Hải, Trà Vinh",
  "Phường 1, Duyên Hải, Trà Vinh",
  "Long Toàn, Duyên Hải, Trà Vinh",
  "Phường 2, Duyên Hải, Trà Vinh",
  "Long Hữu, Duyên Hải, Trà Vinh",
  "Dân Thành, Duyên Hải, Trà Vinh",
  "Trường Long Hòa, Duyên Hải, Trà Vinh",
  "Hiệp Thạnh, Duyên Hải, Trà Vinh",
  "Phường 9, Vĩnh Long, Vĩnh Long",
  "Phường 5, Vĩnh Long, Vĩnh Long",
  "Phường 1, Vĩnh Long, Vĩnh Long",
  "Phường 2, Vĩnh Long, Vĩnh Long",
  "Phường 4, Vĩnh Long, Vĩnh Long",
  "Phường 3, Vĩnh Long, Vĩnh Long",
  "Phường 8, Vĩnh Long, Vĩnh Long",
  "Tân Ngãi, Vĩnh Long, Vĩnh Long",
  "Tân Hòa, Vĩnh Long, Vĩnh Long",
  "Tân Hội, Vĩnh Long, Vĩnh Long",
  "Trường An, Vĩnh Long, Vĩnh Long",
  "Long Hồ, Long Hồ, Vĩnh Long",
  "Đồng Phú, Long Hồ, Vĩnh Long",
  "Bình Hòa Phước, Long Hồ, Vĩnh Long",
  "Hòa Ninh, Long Hồ, Vĩnh Long",
  "An Bình, Long Hồ, Vĩnh Long",
  "Thanh Đức, Long Hồ, Vĩnh Long",
  "Tân Hạnh, Long Hồ, Vĩnh Long",
  "Phước Hậu, Long Hồ, Vĩnh Long",
  "Long Phước, Long Hồ, Vĩnh Long",
  "Phú Đức, Long Hồ, Vĩnh Long",
  "Lộc Hòa, Long Hồ, Vĩnh Long",
  "Long An, Long Hồ, Vĩnh Long",
  "Phú Quới, Long Hồ, Vĩnh Long",
  "Thạnh Quới, Long Hồ, Vĩnh Long",
  "Hòa Phú, Long Hồ, Vĩnh Long",
  "Mỹ An, Mang Thít, Vĩnh Long",
  "Mỹ Phước, Mang Thít, Vĩnh Long",
  "An Phước, Mang Thít, Vĩnh Long",
  "Nhơn Phú, Mang Thít, Vĩnh Long",
  "Long Mỹ, Mang Thít, Vĩnh Long",
  "Hòa Tịnh, Mang Thít, Vĩnh Long",
  "Cái Nhum, Mang Thít, Vĩnh Long",
  "Bình Phước, Mang Thít, Vĩnh Long",
  "Chánh An, Mang Thít, Vĩnh Long",
  "Tân An Hội, Mang Thít, Vĩnh Long",
  "Tân Long, Mang Thít, Vĩnh Long",
  "Tân Long Hội, Mang Thít, Vĩnh Long",
  "Vũng Liêm,  Vũng Liêm, Vĩnh Long",
  "Tân Quới Trung,  Vũng Liêm, Vĩnh Long",
  "Quới Thiện,  Vũng Liêm, Vĩnh Long",
  "Quới An,  Vũng Liêm, Vĩnh Long",
  "Trung Chánh,  Vũng Liêm, Vĩnh Long",
  "Tân An Luông,  Vũng Liêm, Vĩnh Long",
  "Thanh Bình,  Vũng Liêm, Vĩnh Long",
  "Trung Thành Tây,  Vũng Liêm, Vĩnh Long",
  "Trung Hiệp,  Vũng Liêm, Vĩnh Long",
  "Hiếu Phụng,  Vũng Liêm, Vĩnh Long",
  "Trung Thành Đông,  Vũng Liêm, Vĩnh Long",
  "Trung Thành,  Vũng Liêm, Vĩnh Long",
  "Trung Hiếu,  Vũng Liêm, Vĩnh Long",
  "Trung Ngãi,  Vũng Liêm, Vĩnh Long",
  "Hiếu Thuận,  Vũng Liêm, Vĩnh Long",
  "Trung Nghĩa,  Vũng Liêm, Vĩnh Long",
  "Trung An,  Vũng Liêm, Vĩnh Long",
  "Hiếu Nhơn,  Vũng Liêm, Vĩnh Long",
  "Hiếu Thành,  Vũng Liêm, Vĩnh Long",
  "Hiếu Nghĩa,  Vũng Liêm, Vĩnh Long",
  "Tam Bình, Tam Bình, Vĩnh Long",
  "Tân Lộc, Tam Bình, Vĩnh Long",
  "Phú Thịnh, Tam Bình, Vĩnh Long",
  "Hậu Lộc, Tam Bình, Vĩnh Long",
  "Hòa Thạnh, Tam Bình, Vĩnh Long",
  "Hoà Lộc, Tam Bình, Vĩnh Long",
  "Phú Lộc, Tam Bình, Vĩnh Long",
  "Song Phú, Tam Bình, Vĩnh Long",
  "Hòa Hiệp, Tam Bình, Vĩnh Long",
  "Mỹ Lộc, Tam Bình, Vĩnh Long",
  "Tân Phú, Tam Bình, Vĩnh Long",
  "Long Phú, Tam Bình, Vĩnh Long",
  "Mỹ Thạnh Trung, Tam Bình, Vĩnh Long",
  "Tường Lộc, Tam Bình, Vĩnh Long",
  "Loan Mỹ, Tam Bình, Vĩnh Long",
  "Ngãi Tứ, Tam Bình, Vĩnh Long",
  "Bình Ninh, Tam Bình, Vĩnh Long",
  "Cái Vồn, Bình Minh, Vĩnh Long",
  "Thành Phước, Bình Minh, Vĩnh Long",
  "Thuận An, Bình Minh, Vĩnh Long",
  "Đông Thạnh, Bình Minh, Vĩnh Long",
  "Đông Bình, Bình Minh, Vĩnh Long",
  "Đông Thuận, Bình Minh, Vĩnh Long",
  "Mỹ Hòa, Bình Minh, Vĩnh Long",
  "Đông Thành, Bình Minh, Vĩnh Long",
  "Trà Ôn, Trà Ôn, Vĩnh Long",
  "Xuân Hiệp, Trà Ôn, Vĩnh Long",
  "Nhơn Bình, Trà Ôn, Vĩnh Long",
  "Hòa Bình, Trà Ôn, Vĩnh Long",
  "Thới Hòa, Trà Ôn, Vĩnh Long",
  "Trà Côn, Trà Ôn, Vĩnh Long",
  "Tân Mỹ, Trà Ôn, Vĩnh Long",
  "Hựu Thành, Trà Ôn, Vĩnh Long",
  "Vĩnh Xuân, Trà Ôn, Vĩnh Long",
  "Thuận Thới, Trà Ôn, Vĩnh Long",
  "Phú Thành, Trà Ôn, Vĩnh Long",
  "Thiện Mỹ, Trà Ôn, Vĩnh Long",
  "Lục Sỹ Thành, Trà Ôn, Vĩnh Long",
  "Tích Thiện, Trà Ôn, Vĩnh Long",
  "Tân Hưng, Bình Tân, Vĩnh Long",
  "Tân Thành, Bình Tân, Vĩnh Long",
  "Thành Trung, Bình Tân, Vĩnh Long",
  "Tân An Thạnh, Bình Tân, Vĩnh Long",
  "Tân Lược, Bình Tân, Vĩnh Long",
  "Nguyễn Văn Thảnh, Bình Tân, Vĩnh Long",
  "Thành Lợi, Bình Tân, Vĩnh Long",
  "Mỹ Thuận, Bình Tân, Vĩnh Long",
  "Tân Bình, Bình Tân, Vĩnh Long",
  "Tân Quới, Bình Tân, Vĩnh Long",
  "Phường 11, Cao Lãnh, Đồng Tháp",
  "Phường 1, Cao Lãnh, Đồng Tháp",
  "Phường 2, Cao Lãnh, Đồng Tháp",
  "Phường 4, Cao Lãnh, Đồng Tháp",
  "Phường 3, Cao Lãnh, Đồng Tháp",
  "Phường 6, Cao Lãnh, Đồng Tháp",
  "Mỹ Ngãi, Cao Lãnh, Đồng Tháp",
  "Mỹ Tân, Cao Lãnh, Đồng Tháp",
  "Mỹ Trà, Cao Lãnh, Đồng Tháp",
  "Mỹ Phú, Cao Lãnh, Đồng Tháp",
  "Tân Thuận Tây, Cao Lãnh, Đồng Tháp",
  "Hoà Thuận, Cao Lãnh, Đồng Tháp",
  "Hòa An, Cao Lãnh, Đồng Tháp",
  "Tân Thuận Đông, Cao Lãnh, Đồng Tháp",
  "Tịnh Thới, Cao Lãnh, Đồng Tháp",
  "Phường 3, Sa Đéc, Đồng Tháp",
  "Phường 1, Sa Đéc, Đồng Tháp",
  "Phường 4, Sa Đéc, Đồng Tháp",
  "Phường 2, Sa Đéc, Đồng Tháp",
  "Tân Khánh Đông, Sa Đéc, Đồng Tháp",
  "Tân Quy Đông, Sa Đéc, Đồng Tháp",
  "An Hoà, Sa Đéc, Đồng Tháp",
  "Tân Quy Tây, Sa Đéc, Đồng Tháp",
  "Tân Phú Đông, Sa Đéc, Đồng Tháp",
  "An Lộc, Hồng Ngự, Đồng Tháp",
  "An Thạnh, Hồng Ngự, Đồng Tháp",
  "Bình Thạnh, Hồng Ngự, Đồng Tháp",
  "Tân Hội, Hồng Ngự, Đồng Tháp",
  "An Lạc, Hồng Ngự, Đồng Tháp",
  "An Bình B, Hồng Ngự, Đồng Tháp",
  "An Bình A, Hồng Ngự, Đồng Tháp",
  "Sa Rài, Tân Hồng, Đồng Tháp",
  "Tân Hộ Cơ, Tân Hồng, Đồng Tháp",
  "Thông Bình, Tân Hồng, Đồng Tháp",
  "Bình Phú, Tân Hồng, Đồng Tháp",
  "Tân Thành A, Tân Hồng, Đồng Tháp",
  "Tân Thành B, Tân Hồng, Đồng Tháp",
  "Tân Phước, Tân Hồng, Đồng Tháp",
  "Tân Công Chí, Tân Hồng, Đồng Tháp",
  "An Phước, Tân Hồng, Đồng Tháp",
  "Thường Phước 1, Hồng Ngự, Đồng Tháp",
  "Thường Thới Hậu A, Hồng Ngự, Đồng Tháp",
  "Thường Thới Tiền, Hồng Ngự, Đồng Tháp",
  "Thường Phước 2, Hồng Ngự, Đồng Tháp",
  "Thường Lạc, Hồng Ngự, Đồng Tháp",
  "Long Khánh A, Hồng Ngự, Đồng Tháp",
  "Long Khánh B, Hồng Ngự, Đồng Tháp",
  "Long Thuận, Hồng Ngự, Đồng Tháp",
  "Phú Thuận B, Hồng Ngự, Đồng Tháp",
  "Phú Thuận A, Hồng Ngự, Đồng Tháp",
  "Tràm Chim, Tam Nông, Đồng Tháp",
  "Hoà Bình, Tam Nông, Đồng Tháp",
  "Tân Công Sính, Tam Nông, Đồng Tháp",
  "Phú Hiệp, Tam Nông, Đồng Tháp",
  "Phú Đức, Tam Nông, Đồng Tháp",
  "Phú Thành B, Tam Nông, Đồng Tháp",
  "An Hòa, Tam Nông, Đồng Tháp",
  "An Long, Tam Nông, Đồng Tháp",
  "Phú Cường, Tam Nông, Đồng Tháp",
  "Phú Ninh, Tam Nông, Đồng Tháp",
  "Phú Thọ, Tam Nông, Đồng Tháp",
  "Phú Thành A, Tam Nông, Đồng Tháp",
  "Mỹ An, Tháp Mười, Đồng Tháp",
  "Thạnh Lợi, Tháp Mười, Đồng Tháp",
  "Hưng Thạnh, Tháp Mười, Đồng Tháp",
  "Trường Xuân, Tháp Mười, Đồng Tháp",
  "Tân Kiều, Tháp Mười, Đồng Tháp",
  "Mỹ Hòa, Tháp Mười, Đồng Tháp",
  "Mỹ Quý, Tháp Mười, Đồng Tháp",
  "Mỹ Đông, Tháp Mười, Đồng Tháp",
  "Đốc Binh Kiều, Tháp Mười, Đồng Tháp",
  "Mỹ An, Tháp Mười, Đồng Tháp",
  "Phú Điền, Tháp Mười, Đồng Tháp",
  "Láng Biển, Tháp Mười, Đồng Tháp",
  "Thanh Mỹ, Tháp Mười, Đồng Tháp",
  "Mỹ Thọ, Cao Lãnh, Đồng Tháp",
  "Gáo Giồng, Cao Lãnh, Đồng Tháp",
  "Phương Thịnh, Cao Lãnh, Đồng Tháp",
  "Ba Sao, Cao Lãnh, Đồng Tháp",
  "Phong Mỹ, Cao Lãnh, Đồng Tháp",
  "Tân Nghĩa, Cao Lãnh, Đồng Tháp",
  "Phương Trà, Cao Lãnh, Đồng Tháp",
  "Nhị Mỹ, Cao Lãnh, Đồng Tháp",
  "Mỹ Thọ, Cao Lãnh, Đồng Tháp",
  "Tân Hội Trung, Cao Lãnh, Đồng Tháp",
  "An Bình, Cao Lãnh, Đồng Tháp",
  "Mỹ Hội, Cao Lãnh, Đồng Tháp",
  "Mỹ Hiệp, Cao Lãnh, Đồng Tháp",
  "Mỹ Long, Cao Lãnh, Đồng Tháp",
  "Bình Hàng Trung, Cao Lãnh, Đồng Tháp",
  "Mỹ Xương, Cao Lãnh, Đồng Tháp",
  "Bình Hàng Tây, Cao Lãnh, Đồng Tháp",
  "Bình Thạnh, Cao Lãnh, Đồng Tháp",
  "Thanh Bình, Thanh Bình, Đồng Tháp",
  "Tân Quới, Thanh Bình, Đồng Tháp",
  "Tân Hòa, Thanh Bình, Đồng Tháp",
  "An Phong, Thanh Bình, Đồng Tháp",
  "Phú Lợi, Thanh Bình, Đồng Tháp",
  "Tân Mỹ, Thanh Bình, Đồng Tháp",
  "Bình Tấn, Thanh Bình, Đồng Tháp",
  "Tân Huề, Thanh Bình, Đồng Tháp",
  "Tân Bình, Thanh Bình, Đồng Tháp",
  "Tân Thạnh, Thanh Bình, Đồng Tháp",
  "Tân Phú, Thanh Bình, Đồng Tháp",
  "Bình Thành, Thanh Bình, Đồng Tháp",
  "Tân Long, Thanh Bình, Đồng Tháp",
  "Lấp Vò, Lấp Vò, Đồng Tháp",
  "Mỹ An Hưng A, Lấp Vò, Đồng Tháp",
  "Tân Mỹ, Lấp Vò, Đồng Tháp",
  "Mỹ An Hưng B, Lấp Vò, Đồng Tháp",
  "Tân  Khánh Trung, Lấp Vò, Đồng Tháp",
  "Long Hưng A, Lấp Vò, Đồng Tháp",
  "Vĩnh Thạnh, Lấp Vò, Đồng Tháp",
  "Long Hưng B, Lấp Vò, Đồng Tháp",
  "Bình Thành, Lấp Vò, Đồng Tháp",
  "Định An, Lấp Vò, Đồng Tháp",
  "Định Yên, Lấp Vò, Đồng Tháp",
  "Hội An Đông, Lấp Vò, Đồng Tháp",
  "Bình Thạnh Trung, Lấp Vò, Đồng Tháp",
  "Lai Vung, Lai Vung, Đồng Tháp",
  "Tân Dương, Lai Vung, Đồng Tháp",
  "Hòa Thành, Lai Vung, Đồng Tháp",
  "Long Hậu, Lai Vung, Đồng Tháp",
  "Tân Phước, Lai Vung, Đồng Tháp",
  "Hòa Long, Lai Vung, Đồng Tháp",
  "Tân Thành, Lai Vung, Đồng Tháp",
  "Long Thắng, Lai Vung, Đồng Tháp",
  "Vĩnh Thới, Lai Vung, Đồng Tháp",
  "Tân Hòa, Lai Vung, Đồng Tháp",
  "Định Hòa, Lai Vung, Đồng Tháp",
  "Phong Hòa, Lai Vung, Đồng Tháp",
  "Cái Tàu Hạ, Châu Thành, Đồng Tháp",
  "An Hiệp, Châu Thành, Đồng Tháp",
  "An Nhơn, Châu Thành, Đồng Tháp",
  "Tân Nhuận Đông, Châu Thành, Đồng Tháp",
  "Tân Bình, Châu Thành, Đồng Tháp",
  "Tân Phú Trung, Châu Thành, Đồng Tháp",
  "Phú Long, Châu Thành, Đồng Tháp",
  "An Phú Thuận, Châu Thành, Đồng Tháp",
  "Phú Hựu, Châu Thành, Đồng Tháp",
  "An Khánh, Châu Thành, Đồng Tháp",
  "Tân Phú, Châu Thành, Đồng Tháp",
  "Hòa Tân, Châu Thành, Đồng Tháp",
  "Mỹ Bình, Long Xuyên, An Giang",
  "Mỹ Long, Long Xuyên, An Giang",
  "Đông Xuyên, Long Xuyên, An Giang",
  "Mỹ Xuyên, Long Xuyên, An Giang",
  "Bình Đức, Long Xuyên, An Giang",
  "Bình Khánh, Long Xuyên, An Giang",
  "Mỹ Phước, Long Xuyên, An Giang",
  "Mỹ Quý, Long Xuyên, An Giang",
  "Mỹ Thới, Long Xuyên, An Giang",
  "Mỹ Thạnh, Long Xuyên, An Giang",
  "Mỹ Hòa, Long Xuyên, An Giang",
  "Mỹ Khánh, Long Xuyên, An Giang",
  "Mỹ Hoà Hưng, Long Xuyên, An Giang",
  "Châu Phú B, Châu Đốc, An Giang",
  "Châu Phú A, Châu Đốc, An Giang",
  "Vĩnh Mỹ, Châu Đốc, An Giang",
  "Núi Sam, Châu Đốc, An Giang",
  "Vĩnh Ngươn, Châu Đốc, An Giang",
  "Vĩnh Tế, Châu Đốc, An Giang",
  "Vĩnh Châu, Châu Đốc, An Giang",
  "An Phú, An Phú, An Giang",
  "Khánh An, An Phú, An Giang",
  "Long Bình, An Phú, An Giang",
  "Khánh Bình, An Phú, An Giang",
  "Quốc Thái, An Phú, An Giang",
  "Nhơn Hội, An Phú, An Giang",
  "Phú Hữu, An Phú, An Giang",
  "Phú Hội, An Phú, An Giang",
  "Phước Hưng, An Phú, An Giang",
  "Vĩnh Lộc, An Phú, An Giang",
  "Vĩnh Hậu, An Phú, An Giang",
  "Vĩnh Trường, An Phú, An Giang",
  "Vĩnh Hội Đông, An Phú, An Giang",
  "Đa Phước, An Phú, An Giang",
  "Long Thạnh, Tân Châu, An Giang",
  "Long Hưng, Tân Châu, An Giang",
  "Long Châu, Tân Châu, An Giang",
  "Phú Lộc, Tân Châu, An Giang",
  "Vĩnh Xương, Tân Châu, An Giang",
  "Vĩnh Hòa, Tân Châu, An Giang",
  "Tân Thạnh, Tân Châu, An Giang",
  "Tân An, Tân Châu, An Giang",
  "Long An, Tân Châu, An Giang",
  "Long Phú, Tân Châu, An Giang",
  "Châu Phong, Tân Châu, An Giang",
  "Phú Vĩnh, Tân Châu, An Giang",
  "Lê Chánh, Tân Châu, An Giang",
  "Long Sơn, Tân Châu, An Giang",
  "Phú Mỹ, Phú Tân, An Giang",
  "Chợ Vàm, Phú Tân, An Giang",
  "Long Hoà, Phú Tân, An Giang",
  "Phú Long, Phú Tân, An Giang",
  "Phú Lâm, Phú Tân, An Giang",
  "Phú Hiệp, Phú Tân, An Giang",
  "Phú Thạnh, Phú Tân, An Giang",
  "Hoà Lạc, Phú Tân, An Giang",
  "Phú Thành, Phú Tân, An Giang",
  "Phú An, Phú Tân, An Giang",
  "Phú Xuân, Phú Tân, An Giang",
  "Hiệp Xương, Phú Tân, An Giang",
  "Phú Bình, Phú Tân, An Giang",
  "Phú Thọ, Phú Tân, An Giang",
  "Phú Hưng, Phú Tân, An Giang",
  "Bình Thạnh Đông, Phú Tân, An Giang",
  "Tân Hòa, Phú Tân, An Giang",
  "Tân Trung, Phú Tân, An Giang",
  "Cái Dầu, Châu Phú, An Giang",
  "Khánh Hòa, Châu Phú, An Giang",
  "Mỹ Đức, Châu Phú, An Giang",
  "Mỹ Phú, Châu Phú, An Giang",
  "Ô Long Vỹ, Châu Phú, An Giang",
  "Vĩnh Thạnh Trung, Châu Phú, An Giang",
  "Thạnh Mỹ Tây, Châu Phú, An Giang",
  "Bình Long, Châu Phú, An Giang",
  "Bình Mỹ, Châu Phú, An Giang",
  "Bình Thủy, Châu Phú, An Giang",
  "Đào Hữu Cảnh, Châu Phú, An Giang",
  "Bình Phú, Châu Phú, An Giang",
  "Bình Chánh, Châu Phú, An Giang",
  "Nhà Bàng, Tịnh Biên, An Giang",
  "Chi Lăng, Tịnh Biên, An Giang",
  "Núi Voi, Tịnh Biên, An Giang",
  "Nhơn Hưng, Tịnh Biên, An Giang",
  "An Phú, Tịnh Biên, An Giang",
  "Thới Sơn, Tịnh Biên, An Giang",
  "Tịnh Biên, Tịnh Biên, An Giang",
  "Văn Giáo, Tịnh Biên, An Giang",
  "An Cư, Tịnh Biên, An Giang",
  "An Nông, Tịnh Biên, An Giang",
  "Vĩnh Trung, Tịnh Biên, An Giang",
  "Tân Lợi, Tịnh Biên, An Giang",
  "An Hảo, Tịnh Biên, An Giang",
  "Tân Lập, Tịnh Biên, An Giang",
  "Tri Tôn, Tri Tôn, An Giang",
  "Ba Chúc, Tri Tôn, An Giang",
  "Lạc Quới, Tri Tôn, An Giang",
  "Lê Trì, Tri Tôn, An Giang",
  "Vĩnh Gia, Tri Tôn, An Giang",
  "Vĩnh Phước, Tri Tôn, An Giang",
  "Châu Lăng, Tri Tôn, An Giang",
  "Lương Phi, Tri Tôn, An Giang",
  "Lương An Trà, Tri Tôn, An Giang",
  "Tà Đảnh, Tri Tôn, An Giang",
  "Núi Tô, Tri Tôn, An Giang",
  "An Tức, Tri Tôn, An Giang",
  "Cô Tô, Tri Tôn, An Giang",
  "Tân Tuyến, Tri Tôn, An Giang",
  "Ô Lâm, Tri Tôn, An Giang",
  "An Châu, Châu Thành, An Giang",
  "An Hòa, Châu Thành, An Giang",
  "Cần Đăng, Châu Thành, An Giang",
  "Vĩnh Hanh, Châu Thành, An Giang",
  "Bình Thạnh, Châu Thành, An Giang",
  "Vĩnh Bình, Châu Thành, An Giang",
  "Bình Hòa, Châu Thành, An Giang",
  "Vĩnh An, Châu Thành, An Giang",
  "Hòa Bình Thạnh, Châu Thành, An Giang",
  "Vĩnh Lợi, Châu Thành, An Giang",
  "Vĩnh Nhuận, Châu Thành, An Giang",
  "Tân Phú, Châu Thành, An Giang",
  "Vĩnh Thành, Châu Thành, An Giang",
  "Chợ Mới, Chợ Mới, An Giang",
  "Mỹ Luông, Chợ Mới, An Giang",
  "Kiến An, Chợ Mới, An Giang",
  "Mỹ Hội Đông, Chợ Mới, An Giang",
  "Long Điền A, Chợ Mới, An Giang",
  "Tấn Mỹ, Chợ Mới, An Giang",
  "Long Điền B, Chợ Mới, An Giang",
  "Kiến Thành, Chợ Mới, An Giang",
  "Mỹ Hiệp, Chợ Mới, An Giang",
  "Mỹ An, Chợ Mới, An Giang",
  "Nhơn Mỹ, Chợ Mới, An Giang",
  "Long Giang, Chợ Mới, An Giang",
  "Long Kiến, Chợ Mới, An Giang",
  "Bình Phước Xuân, Chợ Mới, An Giang",
  "An Thạnh Trung, Chợ Mới, An Giang",
  "Hội An, Chợ Mới, An Giang",
  "Hòa Bình, Chợ Mới, An Giang",
  "Hòa An, Chợ Mới, An Giang",
  "Núi Sập, Thoại Sơn, An Giang",
  "Phú Hoà, Thoại Sơn, An Giang",
  "Óc Eo, Thoại Sơn, An Giang",
  "Tây Phú, Thoại Sơn, An Giang",
  "An Bình, Thoại Sơn, An Giang",
  "Vĩnh Phú, Thoại Sơn, An Giang",
  "Vĩnh Trạch, Thoại Sơn, An Giang",
  "Phú Thuận, Thoại Sơn, An Giang",
  "Vĩnh Chánh, Thoại Sơn, An Giang",
  "Định Mỹ, Thoại Sơn, An Giang",
  "Định Thành, Thoại Sơn, An Giang",
  "Mỹ Phú Đông, Thoại Sơn, An Giang",
  "Vọng Đông, Thoại Sơn, An Giang",
  "Vĩnh Khánh, Thoại Sơn, An Giang",
  "Thoại Giang, Thoại Sơn, An Giang",
  "Bình Thành, Thoại Sơn, An Giang",
  "Vọng Thê, Thoại Sơn, An Giang",
  "Vĩnh Thanh Vân, Rạch Giá, Kiên Giang",
  "Vĩnh Thanh, Rạch Giá, Kiên Giang",
  "Vĩnh Quang, Rạch Giá, Kiên Giang",
  "Vĩnh Hiệp, Rạch Giá, Kiên Giang",
  "Vĩnh Bảo, Rạch Giá, Kiên Giang",
  "Vĩnh Lạc, Rạch Giá, Kiên Giang",
  "An Hòa, Rạch Giá, Kiên Giang",
  "An Bình, Rạch Giá, Kiên Giang",
  "Rạch Sỏi, Rạch Giá, Kiên Giang",
  "Vĩnh Lợi, Rạch Giá, Kiên Giang",
  "Vĩnh Thông, Rạch Giá, Kiên Giang",
  "Phi Thông, Rạch Giá, Kiên Giang",
  "Tô Châu, Hà Tiên, Kiên Giang",
  "Đông Hồ, Hà Tiên, Kiên Giang",
  "Bình San, Hà Tiên, Kiên Giang",
  "Pháo Đài, Hà Tiên, Kiên Giang",
  "Mỹ Đức, Hà Tiên, Kiên Giang",
  "Tiên Hải, Hà Tiên, Kiên Giang",
  "Thuận Yên, Hà Tiên, Kiên Giang",
  "Kiên Lương, Kiên Lương, Kiên Giang",
  "Kiên Bình, Kiên Lương, Kiên Giang",
  "Hòa Điền, Kiên Lương, Kiên Giang",
  "Dương Hòa, Kiên Lương, Kiên Giang",
  "Bình An, Kiên Lương, Kiên Giang",
  "Bình Trị, Kiên Lương, Kiên Giang",
  "Sơn Hải, Kiên Lương, Kiên Giang",
  "Hòn Nghệ, Kiên Lương, Kiên Giang",
  "Hòn Đất, Hòn Đất, Kiên Giang",
  "Sóc Sơn, Hòn Đất, Kiên Giang",
  "Bình Sơn, Hòn Đất, Kiên Giang",
  "Bình Giang, Hòn Đất, Kiên Giang",
  "Mỹ Thái, Hòn Đất, Kiên Giang",
  "Nam Thái Sơn, Hòn Đất, Kiên Giang",
  "Mỹ Hiệp Sơn, Hòn Đất, Kiên Giang",
  "Sơn Kiên, Hòn Đất, Kiên Giang",
  "Sơn Bình, Hòn Đất, Kiên Giang",
  "Mỹ Thuận, Hòn Đất, Kiên Giang",
  "Lình Huỳnh, Hòn Đất, Kiên Giang",
  "Thổ Sơn, Hòn Đất, Kiên Giang",
  "Mỹ Lâm, Hòn Đất, Kiên Giang",
  "Mỹ Phước, Hòn Đất, Kiên Giang",
  "Tân Hiệp, Tân Hiệp, Kiên Giang",
  "Tân Hội, Tân Hiệp, Kiên Giang",
  "Tân Thành, Tân Hiệp, Kiên Giang",
  "Tân Hiệp B, Tân Hiệp, Kiên Giang",
  "Tân Hoà, Tân Hiệp, Kiên Giang",
  "Thạnh Đông B, Tân Hiệp, Kiên Giang",
  "Thạnh Đông, Tân Hiệp, Kiên Giang",
  "Tân Hiệp A, Tân Hiệp, Kiên Giang",
  "Tân An, Tân Hiệp, Kiên Giang",
  "Thạnh Đông A, Tân Hiệp, Kiên Giang",
  "Thạnh Trị, Tân Hiệp, Kiên Giang",
  "Minh Lương, Châu Thành, Kiên Giang",
  "Mong Thọ A, Châu Thành, Kiên Giang",
  "Mong Thọ B, Châu Thành, Kiên Giang",
  "Mong Thọ, Châu Thành, Kiên Giang",
  "Giục Tượng, Châu Thành, Kiên Giang",
  "Vĩnh Hòa Hiệp, Châu Thành, Kiên Giang",
  "Vĩnh Hoà Phú, Châu Thành, Kiên Giang",
  "Minh Hòa, Châu Thành, Kiên Giang",
  "Bình An, Châu Thành, Kiên Giang",
  "Thạnh Lộc, Châu Thành, Kiên Giang",
  "Giồng Riềng, Giồng Riềng, Kiên Giang",
  "Thạnh Hưng, Giồng Riềng, Kiên Giang",
  "Thạnh Phước, Giồng Riềng, Kiên Giang",
  "Thạnh Lộc, Giồng Riềng, Kiên Giang",
  "Thạnh Hòa, Giồng Riềng, Kiên Giang",
  "Thạnh Bình, Giồng Riềng, Kiên Giang",
  "Bàn Thạch, Giồng Riềng, Kiên Giang",
  "Bàn Tân Định, Giồng Riềng, Kiên Giang",
  "Ngọc Thành, Giồng Riềng, Kiên Giang",
  "Ngọc Chúc, Giồng Riềng, Kiên Giang",
  "Ngọc Thuận, Giồng Riềng, Kiên Giang",
  "Hòa Hưng, Giồng Riềng, Kiên Giang",
  "Hoà Lợi, Giồng Riềng, Kiên Giang",
  "Hoà An, Giồng Riềng, Kiên Giang",
  "Long Thạnh, Giồng Riềng, Kiên Giang",
  "Vĩnh Thạnh, Giồng Riềng, Kiên Giang",
  "Vĩnh Phú, Giồng Riềng, Kiên Giang",
  " Hòa Thuận, Giồng Riềng, Kiên Giang",
  "Ngọc Hoà, Giồng Riềng, Kiên Giang",
  "Gò Quao, Gò Quao, Kiên Giang",
  "Vĩnh Hòa Hưng Bắc, Gò Quao, Kiên Giang",
  "Định Hòa, Gò Quao, Kiên Giang",
  "Thới Quản, Gò Quao, Kiên Giang",
  "Định An, Gò Quao, Kiên Giang",
  "Thủy Liễu, Gò Quao, Kiên Giang",
  "Vĩnh Hòa Hưng Nam, Gò Quao, Kiên Giang",
  "Vĩnh Phước A, Gò Quao, Kiên Giang",
  "Vĩnh Phước B, Gò Quao, Kiên Giang",
  "Vĩnh Tuy, Gò Quao, Kiên Giang",
  "Vĩnh Thắng, Gò Quao, Kiên Giang",
  "Thứ Ba, An Biên, Kiên Giang",
  "Tây Yên, An Biên, Kiên Giang",
  "Tây Yên A, An Biên, Kiên Giang",
  "Nam Yên, An Biên, Kiên Giang",
  "Hưng Yên, An Biên, Kiên Giang",
  "Nam Thái, An Biên, Kiên Giang",
  "Nam Thái A, An Biên, Kiên Giang",
  "Đông Thái, An Biên, Kiên Giang",
  "Đông Yên, An Biên, Kiên Giang",
  "Thứ Mười Một, An Minh, Kiên Giang",
  "Thuận Hoà, An Minh, Kiên Giang",
  "Đông Hòa, An Minh, Kiên Giang",
  "Đông Thạnh, An Minh, Kiên Giang",
  "Tân Thạnh, An Minh, Kiên Giang",
  "Đông Hưng, An Minh, Kiên Giang",
  "Đông Hưng A, An Minh, Kiên Giang",
  "Đông Hưng B, An Minh, Kiên Giang",
  "Vân Khánh, An Minh, Kiên Giang",
  "Vân Khánh Đông, An Minh, Kiên Giang",
  "Vân Khánh Tây, An Minh, Kiên Giang",
  "Vĩnh Thuận, Vĩnh Thuận, Kiên Giang",
  "Vĩnh Bình Bắc, Vĩnh Thuận, Kiên Giang",
  "Vĩnh Bình Nam, Vĩnh Thuận, Kiên Giang",
  "Bình Minh, Vĩnh Thuận, Kiên Giang",
  "Vĩnh Thuận, Vĩnh Thuận, Kiên Giang",
  "Tân Thuận, Vĩnh Thuận, Kiên Giang",
  "Phong Đông, Vĩnh Thuận, Kiên Giang",
  "Vĩnh Phong, Vĩnh Thuận, Kiên Giang",
  "Dương Đông, Phú Quốc, Kiên Giang",
  "An Thới, Phú Quốc, Kiên Giang",
  "Cửa Cạn, Phú Quốc, Kiên Giang",
  "Gành Dầu, Phú Quốc, Kiên Giang",
  "Cửa Dương, Phú Quốc, Kiên Giang",
  "Hàm Ninh, Phú Quốc, Kiên Giang",
  "Dương Tơ, Phú Quốc, Kiên Giang",
  "Hòn Thơm, Phú Quốc, Kiên Giang",
  "Bãi Thơm, Phú Quốc, Kiên Giang",
  "Thổ Châu, Phú Quốc, Kiên Giang",
  "Hòn Tre, Kiên Hải, Kiên Giang",
  "Lại Sơn, Kiên Hải, Kiên Giang",
  "An Sơn, Kiên Hải, Kiên Giang",
  "Nam Du, Kiên Hải, Kiên Giang",
  "Thạnh Yên, U Minh Thượng, Kiên Giang",
  "Thạnh Yên A, U Minh Thượng, Kiên Giang",
  "An Minh Bắc, U Minh Thượng, Kiên Giang",
  "Vĩnh Hòa, U Minh Thượng, Kiên Giang",
  "Hoà Chánh, U Minh Thượng, Kiên Giang",
  "Minh Thuận, U Minh Thượng, Kiên Giang",
  "Vĩnh Phú, Giang Thành, Kiên Giang",
  "Vĩnh Điều, Giang Thành, Kiên Giang",
  "Tân Khánh Hòa, Giang Thành, Kiên Giang",
  "Phú Lợi, Giang Thành, Kiên Giang",
  "Phú Mỹ, Giang Thành, Kiên Giang",
  "Cái Khế, Ninh Kiều, Cần Thơ",
  "An Hòa, Ninh Kiều, Cần Thơ",
  "Thới Bình, Ninh Kiều, Cần Thơ",
  "An Nghiệp, Ninh Kiều, Cần Thơ",
  "An Cư, Ninh Kiều, Cần Thơ",
  "Tân An, Ninh Kiều, Cần Thơ",
  "An Phú, Ninh Kiều, Cần Thơ",
  "Xuân Khánh, Ninh Kiều, Cần Thơ",
  "Hưng Lợi, Ninh Kiều, Cần Thơ",
  "An Khánh, Ninh Kiều, Cần Thơ",
  "An Bình, Ninh Kiều, Cần Thơ",
  "Châu Văn Liêm, Ô Môn, Cần Thơ",
  "Thới Hòa, Ô Môn, Cần Thơ",
  "Thới Long, Ô Môn, Cần Thơ",
  "Long Hưng, Ô Môn, Cần Thơ",
  "Thới An, Ô Môn, Cần Thơ",
  "Phước Thới, Ô Môn, Cần Thơ",
  "Trường Lạc, Ô Môn, Cần Thơ",
  "Bình Thủy, Bình Thuỷ, Cần Thơ",
  "Trà An, Bình Thuỷ, Cần Thơ",
  "Trà Nóc, Bình Thuỷ, Cần Thơ",
  "Thới An Đông, Bình Thuỷ, Cần Thơ",
  "An Thới, Bình Thuỷ, Cần Thơ",
  "Bùi Hữu Nghĩa, Bình Thuỷ, Cần Thơ",
  "Long Hòa, Bình Thuỷ, Cần Thơ",
  "Long Tuyền, Bình Thuỷ, Cần Thơ",
  "Lê Bình, Cái Răng, Cần Thơ",
  "Hưng Phú, Cái Răng, Cần Thơ",
  "Hưng Thạnh, Cái Răng, Cần Thơ",
  "Ba Láng, Cái Răng, Cần Thơ",
  "Thường Thạnh, Cái Răng, Cần Thơ",
  "Phú Thứ, Cái Răng, Cần Thơ",
  "Tân Phú, Cái Răng, Cần Thơ",
  "Thốt Nốt, Thốt Nốt, Cần Thơ",
  "Thới Thuận, Thốt Nốt, Cần Thơ",
  "Thuận An, Thốt Nốt, Cần Thơ",
  "Tân Lộc, Thốt Nốt, Cần Thơ",
  "Trung Nhứt, Thốt Nốt, Cần Thơ",
  "Thạnh Hoà, Thốt Nốt, Cần Thơ",
  "Trung Kiên, Thốt Nốt, Cần Thơ",
  "Tân Hưng, Thốt Nốt, Cần Thơ",
  "Thuận Hưng, Thốt Nốt, Cần Thơ",
  "Vĩnh Bình, Vĩnh Thạnh, Cần Thơ",
  "Thanh An, Vĩnh Thạnh, Cần Thơ",
  "Vĩnh Thạnh, Vĩnh Thạnh, Cần Thơ",
  "Thạnh Mỹ, Vĩnh Thạnh, Cần Thơ",
  "Vĩnh Trinh, Vĩnh Thạnh, Cần Thơ",
  "Thạnh An, Vĩnh Thạnh, Cần Thơ",
  "Thạnh Tiến, Vĩnh Thạnh, Cần Thơ",
  "Thạnh Thắng, Vĩnh Thạnh, Cần Thơ",
  "Thạnh Lợi, Vĩnh Thạnh, Cần Thơ",
  "Thạnh Qưới, Vĩnh Thạnh, Cần Thơ",
  "Thạnh Lộc, Vĩnh Thạnh, Cần Thơ",
  "Trung An, Cờ Đỏ, Cần Thơ",
  "Trung Thạnh, Cờ Đỏ, Cần Thơ",
  "Thạnh Phú, Cờ Đỏ, Cần Thơ",
  "Trung Hưng, Cờ Đỏ, Cần Thơ",
  "Cờ Đỏ, Cờ Đỏ, Cần Thơ",
  "Thới Hưng, Cờ Đỏ, Cần Thơ",
  "Đông Hiệp, Cờ Đỏ, Cần Thơ",
  "Đông Thắng, Cờ Đỏ, Cần Thơ",
  "Thới Đông, Cờ Đỏ, Cần Thơ",
  "Thới Xuân, Cờ Đỏ, Cần Thơ",
  "Phong Điền, Phong Điền, Cần Thơ",
  "Nhơn Ái, Phong Điền, Cần Thơ",
  "Giai Xuân, Phong Điền, Cần Thơ",
  "Tân Thới, Phong Điền, Cần Thơ",
  "Trường Long, Phong Điền, Cần Thơ",
  "Mỹ Khánh, Phong Điền, Cần Thơ",
  "Nhơn Nghĩa, Phong Điền, Cần Thơ",
  "Thới Lai, Thới Lai, Cần Thơ",
  "Thới Thạnh, Thới Lai, Cần Thơ",
  "Tân Thạnh, Thới Lai, Cần Thơ",
  "Xuân Thắng, Thới Lai, Cần Thơ",
  "Đông Bình, Thới Lai, Cần Thơ",
  "Đông Thuận, Thới Lai, Cần Thơ",
  "Thới Tân, Thới Lai, Cần Thơ",
  "Trường Thắng, Thới Lai, Cần Thơ",
  "Định Môn, Thới Lai, Cần Thơ",
  "Trường Thành, Thới Lai, Cần Thơ",
  "Trường Xuân, Thới Lai, Cần Thơ",
  "Trường Xuân A, Thới Lai, Cần Thơ",
  "Trường Xuân B, Thới Lai, Cần Thơ",
  "I, Vị Thanh, Hậu Giang",
  "III, Vị Thanh, Hậu Giang",
  "IV, Vị Thanh, Hậu Giang",
  "V, Vị Thanh, Hậu Giang",
  "VII, Vị Thanh, Hậu Giang",
  "Vị Tân, Vị Thanh, Hậu Giang",
  "Hoả Lựu, Vị Thanh, Hậu Giang",
  "Tân Tiến, Vị Thanh, Hậu Giang",
  "Hoả Tiến, Vị Thanh, Hậu Giang",
  "Ngã Bảy, Ngã Bảy, Hậu Giang",
  "Lái Hiếu, Ngã Bảy, Hậu Giang",
  "Hiệp Thành, Ngã Bảy, Hậu Giang",
  "Hiệp Lợi, Ngã Bảy, Hậu Giang",
  "Đại Thành, Ngã Bảy, Hậu Giang",
  "Tân Thành, Ngã Bảy, Hậu Giang",
  "Một Ngàn, Châu Thành A, Hậu Giang",
  "Tân Hoà, Châu Thành A, Hậu Giang",
  "Bảy Ngàn, Châu Thành A, Hậu Giang",
  "Trường Long Tây, Châu Thành A, Hậu Giang",
  "Trường Long A, Châu Thành A, Hậu Giang",
  "Nhơn Nghĩa A, Châu Thành A, Hậu Giang",
  "Rạch Gòi, Châu Thành A, Hậu Giang",
  "Thạnh Xuân, Châu Thành A, Hậu Giang",
  "Cái Tắc, Châu Thành A, Hậu Giang",
  "Tân Phú Thạnh, Châu Thành A, Hậu Giang",
  "Ngã Sáu, Châu Thành, Hậu Giang",
  "Đông Thạnh, Châu Thành, Hậu Giang",
  "Đông Phú, Châu Thành, Hậu Giang",
  "Phú Hữu, Châu Thành, Hậu Giang",
  "Phú Tân, Châu Thành, Hậu Giang",
  "Mái Dầm, Châu Thành, Hậu Giang",
  "Đông Phước, Châu Thành, Hậu Giang",
  "Đông Phước A, Châu Thành, Hậu Giang",
  "Kinh Cùng, Phụng Hiệp, Hậu Giang",
  "Cây Dương, Phụng Hiệp, Hậu Giang",
  "Tân Bình, Phụng Hiệp, Hậu Giang",
  "Bình Thành, Phụng Hiệp, Hậu Giang",
  "Thạnh Hòa, Phụng Hiệp, Hậu Giang",
  "Long Thạnh, Phụng Hiệp, Hậu Giang",
  "Phụng Hiệp, Phụng Hiệp, Hậu Giang",
  "Hòa Mỹ, Phụng Hiệp, Hậu Giang",
  "Hòa An, Phụng Hiệp, Hậu Giang",
  "Phương Bình, Phụng Hiệp, Hậu Giang",
  "Hiệp Hưng, Phụng Hiệp, Hậu Giang",
  "Tân Phước Hưng, Phụng Hiệp, Hậu Giang",
  "Búng Tàu, Phụng Hiệp, Hậu Giang",
  "Phương Phú, Phụng Hiệp, Hậu Giang",
  "Tân Long, Phụng Hiệp, Hậu Giang",
  "Nàng Mau, Vị Thuỷ, Hậu Giang",
  "Vị Trung, Vị Thuỷ, Hậu Giang",
  "Vị Thuỷ, Vị Thuỷ, Hậu Giang",
  "Vị Thắng, Vị Thuỷ, Hậu Giang",
  "Vĩnh Thuận Tây, Vị Thuỷ, Hậu Giang",
  "Vĩnh Trung, Vị Thuỷ, Hậu Giang",
  "Vĩnh Tường, Vị Thuỷ, Hậu Giang",
  "Vị Đông, Vị Thuỷ, Hậu Giang",
  "Vị Thanh, Vị Thuỷ, Hậu Giang",
  "Vị Bình, Vị Thuỷ, Hậu Giang",
  "Thuận Hưng, Long Mỹ, Hậu Giang",
  "Thuận Hòa, Long Mỹ, Hậu Giang",
  "Vĩnh Thuận Đông, Long Mỹ, Hậu Giang",
  "Vĩnh Viễn, Long Mỹ, Hậu Giang",
  "Vĩnh Viễn A, Long Mỹ, Hậu Giang",
  "Lương Tâm, Long Mỹ, Hậu Giang",
  "Lương Nghĩa, Long Mỹ, Hậu Giang",
  "Xà Phiên, Long Mỹ, Hậu Giang",
  "Thuận An, Long Mỹ, Hậu Giang",
  "Trà Lồng, Long Mỹ, Hậu Giang",
  "Bình Thạnh, Long Mỹ, Hậu Giang",
  "Long Bình, Long Mỹ, Hậu Giang",
  "Vĩnh Tường, Long Mỹ, Hậu Giang",
  "Long Trị, Long Mỹ, Hậu Giang",
  "Long Trị A, Long Mỹ, Hậu Giang",
  "Long Phú, Long Mỹ, Hậu Giang",
  "Tân Phú, Long Mỹ, Hậu Giang",
  "Phường 5, Sóc Trăng, Sóc Trăng",
  "Phường 7, Sóc Trăng, Sóc Trăng",
  "Phường 8, Sóc Trăng, Sóc Trăng",
  "Phường 6, Sóc Trăng, Sóc Trăng",
  "Phường 2, Sóc Trăng, Sóc Trăng",
  "Phường 1, Sóc Trăng, Sóc Trăng",
  "Phường 4, Sóc Trăng, Sóc Trăng",
  "Phường 3, Sóc Trăng, Sóc Trăng",
  "Phường 9, Sóc Trăng, Sóc Trăng",
  "Phường 10, Sóc Trăng, Sóc Trăng",
  "Châu Thành, Châu Thành, Sóc Trăng",
  "Hồ Đắc Kiện, Châu Thành, Sóc Trăng",
  "Phú Tâm, Châu Thành, Sóc Trăng",
  "Thuận Hòa, Châu Thành, Sóc Trăng",
  "Phú Tân, Châu Thành, Sóc Trăng",
  "Thiện Mỹ, Châu Thành, Sóc Trăng",
  "An Hiệp, Châu Thành, Sóc Trăng",
  "An Ninh, Châu Thành, Sóc Trăng",
  "Kế Sách, Kế Sách, Sóc Trăng",
  "An Lạc Thôn, Kế Sách, Sóc Trăng",
  "Xuân Hòa, Kế Sách, Sóc Trăng",
  "Phong Nẫm, Kế Sách, Sóc Trăng",
  "An Lạc Tây, Kế Sách, Sóc Trăng",
  "Trinh Phú, Kế Sách, Sóc Trăng",
  "Ba Trinh, Kế Sách, Sóc Trăng",
  "Thới An Hội, Kế Sách, Sóc Trăng",
  "Nhơn Mỹ, Kế Sách, Sóc Trăng",
  "Kế Thành, Kế Sách, Sóc Trăng",
  "Kế An, Kế Sách, Sóc Trăng",
  "Đại Hải, Kế Sách, Sóc Trăng",
  "An Mỹ, Kế Sách, Sóc Trăng",
  "Huỳnh Hữu Nghĩa, Mỹ Tú, Sóc Trăng",
  "Long Hưng, Mỹ Tú, Sóc Trăng",
  "Hưng Phú, Mỹ Tú, Sóc Trăng",
  "Mỹ Hương, Mỹ Tú, Sóc Trăng",
  "Mỹ Tú, Mỹ Tú, Sóc Trăng",
  "Mỹ Phước, Mỹ Tú, Sóc Trăng",
  "Thuận Hưng, Mỹ Tú, Sóc Trăng",
  "Mỹ Thuận, Mỹ Tú, Sóc Trăng",
  "Phú Mỹ, Mỹ Tú, Sóc Trăng",
  "Cù Lao Dung, Cù Lao Dung, Sóc Trăng",
  "An Thạnh 1, Cù Lao Dung, Sóc Trăng",
  "An Thạnh Tây, Cù Lao Dung, Sóc Trăng",
  "An Thạnh Đông, Cù Lao Dung, Sóc Trăng",
  "Đại Ân 1, Cù Lao Dung, Sóc Trăng",
  "An Thạnh 2, Cù Lao Dung, Sóc Trăng",
  "An Thạnh 3, Cù Lao Dung, Sóc Trăng",
  "An Thạnh Nam, Cù Lao Dung, Sóc Trăng",
  "Long Phú, Long Phú, Sóc Trăng",
  "Song Phụng, Long Phú, Sóc Trăng",
  "Đại Ngãi, Long Phú, Sóc Trăng",
  "Hậu Thạnh, Long Phú, Sóc Trăng",
  "Long Đức, Long Phú, Sóc Trăng",
  "Trường Khánh, Long Phú, Sóc Trăng",
  "Phú Hữu, Long Phú, Sóc Trăng",
  "Tân Hưng, Long Phú, Sóc Trăng",
  "Châu Khánh, Long Phú, Sóc Trăng",
  "Tân Thạnh, Long Phú, Sóc Trăng",
  "Long Phú, Long Phú, Sóc Trăng",
  "Mỹ Xuyên, Mỹ Xuyên, Sóc Trăng",
  "Đại Tâm, Mỹ Xuyên, Sóc Trăng",
  "Tham Đôn, Mỹ Xuyên, Sóc Trăng",
  "Thạnh Phú, Mỹ Xuyên, Sóc Trăng",
  "Ngọc Đông, Mỹ Xuyên, Sóc Trăng",
  "Thạnh Quới, Mỹ Xuyên, Sóc Trăng",
  "Hòa Tú 1, Mỹ Xuyên, Sóc Trăng",
  "Gia Hòa 1, Mỹ Xuyên, Sóc Trăng",
  "Ngọc Tố, Mỹ Xuyên, Sóc Trăng",
  "Gia Hòa 2, Mỹ Xuyên, Sóc Trăng",
  "Hòa Tú II, Mỹ Xuyên, Sóc Trăng",
  "Phường 1, Ngã Năm, Sóc Trăng",
  "Phường 2, Ngã Năm, Sóc Trăng",
  "Vĩnh Quới, Ngã Năm, Sóc Trăng",
  "Tân Long, Ngã Năm, Sóc Trăng",
  "Long Bình, Ngã Năm, Sóc Trăng",
  "Phường 3, Ngã Năm, Sóc Trăng",
  "Mỹ Bình, Ngã Năm, Sóc Trăng",
  "Mỹ Quới, Ngã Năm, Sóc Trăng",
  "Phú Lộc, Thạnh Trị, Sóc Trăng",
  "Hưng Lợi, Thạnh Trị, Sóc Trăng",
  "Lâm Tân, Thạnh Trị, Sóc Trăng",
  "Thạnh Tân, Thạnh Trị, Sóc Trăng",
  "Lâm Kiết, Thạnh Trị, Sóc Trăng",
  "Tuân Tức, Thạnh Trị, Sóc Trăng",
  "Vĩnh Thành, Thạnh Trị, Sóc Trăng",
  "Thạnh Trị, Thạnh Trị, Sóc Trăng",
  "Vĩnh Lợi, Thạnh Trị, Sóc Trăng",
  "Châu Hưng, Thạnh Trị, Sóc Trăng",
  "Phường 1, Vĩnh Châu, Sóc Trăng",
  "Hòa Đông, Vĩnh Châu, Sóc Trăng",
  "Khánh Hòa, Vĩnh Châu, Sóc Trăng",
  "Vĩnh Hiệp, Vĩnh Châu, Sóc Trăng",
  "Vĩnh Hải, Vĩnh Châu, Sóc Trăng",
  "Lạc Hòa, Vĩnh Châu, Sóc Trăng",
  "Phường 2, Vĩnh Châu, Sóc Trăng",
  "Vĩnh Phước, Vĩnh Châu, Sóc Trăng",
  "Vĩnh Tân, Vĩnh Châu, Sóc Trăng",
  "Lai Hòa, Vĩnh Châu, Sóc Trăng",
  "Đại Ân  2, Trần Đề, Sóc Trăng",
  "Trần Đề, Trần Đề, Sóc Trăng",
  "Liêu Tú, Trần Đề, Sóc Trăng",
  "Lịch Hội Thượng, Trần Đề, Sóc Trăng",
  "Lịch Hội Thượng, Trần Đề, Sóc Trăng",
  "Trung Bình, Trần Đề, Sóc Trăng",
  "Tài Văn, Trần Đề, Sóc Trăng",
  "Viên An, Trần Đề, Sóc Trăng",
  "Thạnh Thới An, Trần Đề, Sóc Trăng",
  "Thạnh Thới Thuận, Trần Đề, Sóc Trăng",
  "Viên Bình, Trần Đề, Sóc Trăng",
  "Phường 2, Bạc Liêu, Bạc Liêu",
  "Phường 3, Bạc Liêu, Bạc Liêu",
  "Phường 5, Bạc Liêu, Bạc Liêu",
  "Phường 7, Bạc Liêu, Bạc Liêu",
  "Phường 1, Bạc Liêu, Bạc Liêu",
  "Phường 8, Bạc Liêu, Bạc Liêu",
  "Nhà Mát, Bạc Liêu, Bạc Liêu",
  "Vĩnh Trạch, Bạc Liêu, Bạc Liêu",
  "Vĩnh Trạch Đông, Bạc Liêu, Bạc Liêu",
  "Hiệp Thành, Bạc Liêu, Bạc Liêu",
  "Ngan Dừa, Hồng Dân, Bạc Liêu",
  "Ninh Quới, Hồng Dân, Bạc Liêu",
  "Ninh Quới A, Hồng Dân, Bạc Liêu",
  "Ninh Hòa, Hồng Dân, Bạc Liêu",
  "Lộc Ninh, Hồng Dân, Bạc Liêu",
  "Vĩnh Lộc, Hồng Dân, Bạc Liêu",
  "Vĩnh Lộc A, Hồng Dân, Bạc Liêu",
  "Ninh Thạnh Lợi A, Hồng Dân, Bạc Liêu",
  "Ninh Thạnh Lợi, Hồng Dân, Bạc Liêu",
  "Phước Long, Phước Long, Bạc Liêu",
  "Vĩnh Phú Đông, Phước Long, Bạc Liêu",
  "Vĩnh Phú Tây, Phước Long, Bạc Liêu",
  "Phước Long, Phước Long, Bạc Liêu",
  "Hưng Phú, Phước Long, Bạc Liêu",
  "Vĩnh Thanh, Phước Long, Bạc Liêu",
  "Phong Thạnh Tây A, Phước Long, Bạc Liêu",
  "Phong Thạnh Tây B, Phước Long, Bạc Liêu",
  "Vĩnh Hưng, Vĩnh Lợi, Bạc Liêu",
  "Vĩnh Hưng A, Vĩnh Lợi, Bạc Liêu",
  "Châu Hưng, Vĩnh Lợi, Bạc Liêu",
  "Châu Hưng A, Vĩnh Lợi, Bạc Liêu",
  "Hưng Thành, Vĩnh Lợi, Bạc Liêu",
  "Hưng Hội, Vĩnh Lợi, Bạc Liêu",
  "Châu Thới, Vĩnh Lợi, Bạc Liêu",
  "Long Thạnh, Vĩnh Lợi, Bạc Liêu",
  "Phường 1, Giá Rai, Bạc Liêu",
  "Hộ Phòng, Giá Rai, Bạc Liêu",
  "Phong Thạnh Đông, Giá Rai, Bạc Liêu",
  "Láng Tròn, Giá Rai, Bạc Liêu",
  "Phong Tân, Giá Rai, Bạc Liêu",
  "Tân Phong, Giá Rai, Bạc Liêu",
  "Phong Thạnh, Giá Rai, Bạc Liêu",
  "Phong Thạnh A, Giá Rai, Bạc Liêu",
  "Phong Thạnh Tây, Giá Rai, Bạc Liêu",
  "Tân Thạnh, Giá Rai, Bạc Liêu",
  "Gành Hào, Đông Hải, Bạc Liêu",
  "Long Điền Đông, Đông Hải, Bạc Liêu",
  "Long Điền Đông A, Đông Hải, Bạc Liêu",
  "Long Điền, Đông Hải, Bạc Liêu",
  "Long Điền Tây, Đông Hải, Bạc Liêu",
  "Điền Hải, Đông Hải, Bạc Liêu",
  "An Trạch, Đông Hải, Bạc Liêu",
  "An Trạch A, Đông Hải, Bạc Liêu",
  "An Phúc, Đông Hải, Bạc Liêu",
  "Định Thành, Đông Hải, Bạc Liêu",
  "Định Thành A, Đông Hải, Bạc Liêu",
  "Hòa Bình, Hoà Bình, Bạc Liêu",
  "Minh Diệu, Hoà Bình, Bạc Liêu",
  "Vĩnh Bình, Hoà Bình, Bạc Liêu",
  "Vĩnh Mỹ B, Hoà Bình, Bạc Liêu",
  "Vĩnh Hậu, Hoà Bình, Bạc Liêu",
  "Vĩnh Hậu A, Hoà Bình, Bạc Liêu",
  "Vĩnh Mỹ A, Hoà Bình, Bạc Liêu",
  "Vĩnh Thịnh, Hoà Bình, Bạc Liêu",
  "Phường 9, Cà Mau, Cà Mau",
  "Phường 4, Cà Mau, Cà Mau",
  "Phường 1, Cà Mau, Cà Mau",
  "Phường 5, Cà Mau, Cà Mau",
  "Phường 2, Cà Mau, Cà Mau",
  "Phường 8, Cà Mau, Cà Mau",
  "Phường 6, Cà Mau, Cà Mau",
  "Phường 7, Cà Mau, Cà Mau",
  "Tân Xuyên, Cà Mau, Cà Mau",
  "An Xuyên, Cà Mau, Cà Mau",
  "Tân Thành, Cà Mau, Cà Mau",
  "Tân Thành, Cà Mau, Cà Mau",
  "Tắc Vân, Cà Mau, Cà Mau",
  "Lý Văn Lâm, Cà Mau, Cà Mau",
  "Định Bình, Cà Mau, Cà Mau",
  "Hòa Thành, Cà Mau, Cà Mau",
  "Hòa Tân, Cà Mau, Cà Mau",
  "U Minh, U Minh, Cà Mau",
  "Khánh Hòa, U Minh, Cà Mau",
  "Khánh Thuận, U Minh, Cà Mau",
  "Khánh Tiến, U Minh, Cà Mau",
  "Nguyễn Phích, U Minh, Cà Mau",
  "Khánh Lâm, U Minh, Cà Mau",
  "Khánh An, U Minh, Cà Mau",
  "Khánh Hội, U Minh, Cà Mau",
  "Thới Bình, Thới Bình, Cà Mau",
  "Biển Bạch, Thới Bình, Cà Mau",
  "Tân Bằng, Thới Bình, Cà Mau",
  "Trí Phải, Thới Bình, Cà Mau",
  "Trí Lực, Thới Bình, Cà Mau",
  "Biển Bạch Đông, Thới Bình, Cà Mau",
  "Thới Bình, Thới Bình, Cà Mau",
  "Tân Phú, Thới Bình, Cà Mau",
  "Tân Lộc Bắc, Thới Bình, Cà Mau",
  "Tân Lộc, Thới Bình, Cà Mau",
  "Tân Lộc Đông, Thới Bình, Cà Mau",
  "Hồ Thị Kỷ, Thới Bình, Cà Mau",
  "Trần Văn Thời, Trần Văn Thời, Cà Mau",
  "Sông Đốc, Trần Văn Thời, Cà Mau",
  "Khánh Bình Tây Bắc, Trần Văn Thời, Cà Mau",
  "Khánh Bình Tây, Trần Văn Thời, Cà Mau",
  "Trần Hợi, Trần Văn Thời, Cà Mau",
  "Khánh Lộc, Trần Văn Thời, Cà Mau",
  "Khánh Bình, Trần Văn Thời, Cà Mau",
  "Khánh Hưng, Trần Văn Thời, Cà Mau",
  "Khánh Bình Đông, Trần Văn Thời, Cà Mau",
  "Khánh Hải, Trần Văn Thời, Cà Mau",
  "Lợi An, Trần Văn Thời, Cà Mau",
  "Phong Điền, Trần Văn Thời, Cà Mau",
  "Phong Lạc, Trần Văn Thời, Cà Mau",
  "Cái Nước, Cái Nước, Cà Mau",
  "Thạnh Phú, Cái Nước, Cà Mau",
  "Lương Thế Trân, Cái Nước, Cà Mau",
  "Phú Hưng, Cái Nước, Cà Mau",
  "Tân Hưng, Cái Nước, Cà Mau",
  "Hưng Mỹ, Cái Nước, Cà Mau",
  "Hoà Mỹ, Cái Nước, Cà Mau",
  "Đông Hưng, Cái Nước, Cà Mau",
  "Đông Thới, Cái Nước, Cà Mau",
  "Tân Hưng Đông, Cái Nước, Cà Mau",
  "Trần Thới, Cái Nước, Cà Mau",
  "Đầm Dơi, Đầm Dơi, Cà Mau",
  "Tạ An Khương, Đầm Dơi, Cà Mau",
  "Tạ An Khương  Đông, Đầm Dơi, Cà Mau",
  "Trần Phán, Đầm Dơi, Cà Mau",
  "Tân Trung, Đầm Dơi, Cà Mau",
  "Tân Đức, Đầm Dơi, Cà Mau",
  "Tân Thuận, Đầm Dơi, Cà Mau",
  "Tạ An Khương  Nam, Đầm Dơi, Cà Mau",
  "Tân Duyệt, Đầm Dơi, Cà Mau",
  "Tân Dân, Đầm Dơi, Cà Mau",
  "Tân Tiến, Đầm Dơi, Cà Mau",
  "Quách Phẩm Bắc, Đầm Dơi, Cà Mau",
  "Quách Phẩm, Đầm Dơi, Cà Mau",
  "Thanh Tùng, Đầm Dơi, Cà Mau",
  "Ngọc Chánh, Đầm Dơi, Cà Mau",
  "Nguyễn Huân, Đầm Dơi, Cà Mau",
  "Năm Căn, Năm Căn, Cà Mau",
  "Hàm Rồng, Năm Căn, Cà Mau",
  "Hiệp Tùng, Năm Căn, Cà Mau",
  "Đất Mới, Năm Căn, Cà Mau",
  "Lâm Hải, Năm Căn, Cà Mau",
  "Hàng Vịnh, Năm Căn, Cà Mau",
  "Tam Giang, Năm Căn, Cà Mau",
  "Tam Giang Đông, Năm Căn, Cà Mau",
  "Cái Đôi Vàm, Phú Tân, Cà Mau",
  "Phú Thuận, Phú Tân, Cà Mau",
  "Phú Mỹ, Phú Tân, Cà Mau",
  "Phú Tân, Phú Tân, Cà Mau",
  "Tân Hải, Phú Tân, Cà Mau",
  "Việt Thắng, Phú Tân, Cà Mau",
  "Tân Hưng Tây, Phú Tân, Cà Mau",
  "Rạch Chèo, Phú Tân, Cà Mau",
  "Nguyễn Việt Khái, Phú Tân, Cà Mau",
  "Tam Giang Tây, Ngọc Hiển, Cà Mau",
  "Tân Ân Tây, Ngọc Hiển, Cà Mau",
  "Viên An Đông, Ngọc Hiển, Cà Mau",
  "Viên An, Ngọc Hiển, Cà Mau",
  "Rạch Gốc, Ngọc Hiển, Cà Mau",
  "Tân Ân, Ngọc Hiển, Cà Mau",
  "Đất Mũi, Ngọc Hiển, Cà Mau"
]
