FULL_ADDRRESS_ERROR_DICT = {
  "Gào, Pleiku, Gia Lai": [
    "gào, pleiku, gia lai",
    "gafo, pleiku, gia lai"
  ],
  "KBang, KBang, Gia Lai": [
    "kbang, kbang, gia lai",
    "kbang, kbang, gia lai"
  ],
  "KRong, KBang, Gia Lai": [
    "krong, kbang, gia lai",
    "krong, kbang, gia lai"
  ],
  "Dun, Chư Sê, Gia Lai": [
    "dun, chư sê, gia lai",
    "dun, chuw see, gia lai"
  ],
  "Ia O, Ia Grai, Gia Lai": [
    "ia o, ia grai, gia lai",
    "ia o, ia grai, gia lai"
  ],
  "Ia Tul, Ia Pa, Gia Lai": [
    "ia tul, ia pa, gia lai",
    "ia tul, ia pa, gia lai"
  ],
  "Lơ Ku, KBang, Gia Lai": [
    "lơ ku, kbang, gia lai",
    "low ku, kbang, gia lai"
  ],
  "Sa Pa, Sa Pa, Lào Cai": [
    "sa pa, sa pa, lào cai",
    "sa pa, sa pa, lafo cai"
  ],
  "Đông, KBang, Gia Lai": [
    "đông, kbang, gia lai",
    "ddoong, kbang, gia lai"
  ],
  "AYun, Chư Sê, Gia Lai": [
    "ayun, chư sê, gia lai",
    "ayun, chuw see, gia lai"
  ],
  "Hra, Mang Yang, Gia Lai": [
    "hra, mang yang, gia lai",
    "hra, mang yang, gia lai"
  ],
  "Ia Trok, Ia Pa, Gia Lai": [
    "ia trok, ia pa, gia lai",
    "ia trok, ia pa, gia lai"
  ],
  "Kon Pne, KBang, Gia Lai": [
    "kon pne, kbang, gia lai",
    "kon pne, kbang, gia lai"
  ],
  "Sơ Pai, KBang, Gia Lai": [
    "sơ pai, kbang, gia lai",
    "sow pai, kbang, gia lai"
  ],
  "U Minh, U Minh, Cà Mau": [
    "u minh, u minh, cà mau",
    "u minh, u minh, caf mau"
  ],
  "Uar, Krông Pa, Gia Lai": [
    "uar, krông pa, gia lai",
    "uar, kroong pa, gia lai"
  ],
  ", Hoàng Sa, Đà Nẵng": [
    ", hoàng sa, đà nẵng",
    ", hoafng sa, ddaf nawxng"
  ],
  "An Phú, Pleiku, Gia Lai": [
    "an phú, pleiku, gia lai",
    "an phus, pleiku, gia lai"
  ],
  "Ayun, Mang Yang, Gia Lai": [
    "ayun, mang yang, gia lai",
    "ayun, mang yang, gia lai"
  ],
  "Bo, Kim Bôi, Hoà Bình": [
    "bo, kim bôi, hoà bình",
    "bo, kim booi, hoaf bifnh"
  ],
  "Chư Á, Pleiku, Gia Lai": [
    "chư á, pleiku, gia lai",
    "chuw as, pleiku, gia lai"
  ],
  "Hoa Lư, Pleiku, Gia Lai": [
    "hoa lư, pleiku, gia lai",
    "hoa luw, pleiku, gia lai"
  ],
  "Hua La, Sơn La, Sơn La": [
    "hua la, sơn la, sơn la",
    "hua la, sown la, sown la"
  ],
  "Ia Bă, Ia Grai, Gia Lai": [
    "ia bă, ia grai, gia lai",
    "ia baw, ia grai, gia lai"
  ],
  "Ia KDăm, Ia Pa, Gia Lai": [
    "ia kdăm, ia pa, gia lai",
    "ia kdawm, ia pa, gia lai"
  ],
  "Ia Kha, Ia Grai, Gia Lai": [
    "ia kha, ia grai, gia lai",
    "ia kha, ia grai, gia lai"
  ],
  "Ia Ko, Chư Sê, Gia Lai": [
    "ia ko, chư sê, gia lai",
    "ia ko, chuw see, gia lai"
  ],
  "Ia Sao, Ayun Pa, Gia Lai": [
    "ia sao, ayun pa, gia lai",
    "ia sao, ayun pa, gia lai"
  ],
  "Ia Sao, Ia Grai, Gia Lai": [
    "ia sao, ia grai, gia lai",
    "ia sao, ia grai, gia lai"
  ],
  "Ia Tô, Ia Grai, Gia Lai": [
    "ia tô, ia grai, gia lai",
    "ia too, ia grai, gia lai"
  ],
  "Ia Yok, Ia Grai, Gia Lai": [
    "ia yok, ia grai, gia lai",
    "ia yok, ia grai, gia lai"
  ],
  "Kim Tân, Ia Pa, Gia Lai": [
    "kim tân, ia pa, gia lai",
    "kim taan, ia pa, gia lai"
  ],
  "Kroong, Kon Tum, Kon Tum": [
    "kroong, kon tum, kon tum",
    "kroong, kon tum, kon tum"
  ],
  "Lê Mao, Vinh, Nghệ An": [
    "lê mao, vinh, nghệ an",
    "lee mao, vinh, ngheej an"
  ],
  "Pờ Tó, Ia Pa, Gia Lai": [
    "pờ tó, ia pa, gia lai",
    "powf tos, ia pa, gia lai"
  ],
  "Sa Pả, Sa Pa, Lào Cai": [
    "sa pả, sa pa, lào cai",
    "sa par, sa pa, lafo cai"
  ],
  "Tú An, An Khê, Gia Lai": [
    "tú an, an khê, gia lai",
    "tus an, an khee, gia lai"
  ],
  "Tơ Tung, KBang, Gia Lai": [
    "tơ tung, kbang, gia lai",
    "tow tung, kbang, gia lai"
  ],
  ", Lý Sơn, Quảng Ngãi": [
    ", lý sơn, quảng ngãi",
    ", lys sown, quarng ngaxi"
  ],
  "AL Bá, Chư Sê, Gia Lai": [
    "al bá, chư sê, gia lai",
    "al bas, chuw see, gia lai"
  ],
  "An Cư, Tuy An, Phú Yên": [
    "an cư, tuy an, phú yên",
    "an cuw, tuy an, phus yeen"
  ],
  "An Phú, An Khê, Gia Lai": [
    "an phú, an khê, gia lai",
    "an phus, an khee, gia lai"
  ],
  "An Tân, An Khê, Gia Lai": [
    "an tân, an khê, gia lai",
    "an taan, an khee, gia lai"
  ],
  "Ba Tri, Ba Tri, Bến Tre": [
    "ba tri, ba tri, bến tre",
    "ba tri, ba tri, beesn tre"
  ],
  "Ba Vì, Ba Vì, Hà Nội": [
    "ba vì, ba vì, hà nội",
    "ba vif, ba vif, haf nooji"
  ],
  "Chư Mố, Ia Pa, Gia Lai": [
    "chư mố, ia pa, gia lai",
    "chuw moos, ia pa, gia lai"
  ],
  "Glar, Đăk Đoa, Gia Lai": [
    "glar, đăk đoa, gia lai",
    "glar, ddawk ddoa, gia lai"
  ],
  "HNol, Đăk Đoa, Gia Lai": [
    "hnol, đăk đoa, gia lai",
    "hnol, ddawk ddoa, gia lai"
  ],
  "Ia Broăi, Ia Pa, Gia Lai": [
    "ia broăi, ia pa, gia lai",
    "ia broawi, ia pa, gia lai"
  ],
  "Ia Chia, Ia Grai, Gia Lai": [
    "ia chia, ia grai, gia lai",
    "ia chia, ia grai, gia lai"
  ],
  "Ia Chim, Kon Tum, Kon Tum": [
    "ia chim, kon tum, kon tum",
    "ia chim, kon tum, kon tum"
  ],
  "Ia Dêr, Ia Grai, Gia Lai": [
    "ia dêr, ia grai, gia lai",
    "ia deer, ia grai, gia lai"
  ],
  "Ia KRai, Ia Grai, Gia Lai": [
    "ia krai, ia grai, gia lai",
    "ia krai, ia grai, gia lai"
  ],
  "Ia Ka, Chư Păh, Gia Lai": [
    "ia ka, chư păh, gia lai",
    "ia ka, chuw pawh, gia lai"
  ],
  "Ia Khai, Ia Grai, Gia Lai": [
    "ia khai, ia grai, gia lai",
    "ia khai, ia grai, gia lai"
  ],
  "Ia Kring, Pleiku, Gia Lai": [
    "ia kring, pleiku, gia lai",
    "ia kring, pleiku, gia lai"
  ],
  "Ia Kênh, Pleiku, Gia Lai": [
    "ia kênh, pleiku, gia lai",
    "ia keenh, pleiku, gia lai"
  ],
  "Ia Le, Chư Pưh, Gia Lai": [
    "ia le, chư pưh, gia lai",
    "ia le, chuw puwh, gia lai"
  ],
  "Ia Ly, Chư Păh, Gia Lai": [
    "ia ly, chư păh, gia lai",
    "ia ly, chuw pawh, gia lai"
  ],
  "Ia Pal, Chư Sê, Gia Lai": [
    "ia pal, chư sê, gia lai",
    "ia pal, chuw see, gia lai"
  ],
  "Ia RBol, Ayun Pa, Gia Lai": [
    "ia rbol, ayun pa, gia lai",
    "ia rbol, ayun pa, gia lai"
  ],
  "Ia RTô, Ayun Pa, Gia Lai": [
    "ia rtô, ayun pa, gia lai",
    "ia rtoo, ayun pa, gia lai"
  ],
  "Kông Pla, KBang, Gia Lai": [
    "kông pla, kbang, gia lai",
    "koong pla, kbang, gia lai"
  ],
  "Lim, Tiên Du, Bắc Ninh": [
    "lim, tiên du, bắc ninh",
    "lim, tieen du, bawsc ninh"
  ],
  "Nghi Kim, Vinh, Nghệ An": [
    "nghi kim, vinh, nghệ an",
    "nghi kim, vinh, ngheej an"
  ],
  "Nghi Ân, Vinh, Nghệ An": [
    "nghi ân, vinh, nghệ an",
    "nghi aan, vinh, ngheej an"
  ],
  "Nghĩa An, KBang, Gia Lai": [
    "nghĩa an, kbang, gia lai",
    "nghixa an, kbang, gia lai"
  ],
  "SRó, Kông Chro, Gia Lai": [
    "sró, kông chro, gia lai",
    "sros, koong chro, gia lai"
  ],
  "Song An, An Khê, Gia Lai": [
    "song an, an khê, gia lai",
    "song an, an khee, gia lai"
  ],
  "Sơn Lang, KBang, Gia Lai": [
    "sơn lang, kbang, gia lai",
    "sown lang, kbang, gia lai"
  ],
  "Trà Bá, Pleiku, Gia Lai": [
    "trà bá, pleiku, gia lai",
    "traf bas, pleiku, gia lai"
  ],
  "Trà Đa, Pleiku, Gia Lai": [
    "trà đa, pleiku, gia lai",
    "traf dda, pleiku, gia lai"
  ],
  "Tả Van, Sa Pa, Lào Cai": [
    "tả van, sa pa, lào cai",
    "tar van, sa pa, lafo cai"
  ],
  "Ya ly, Sa Thầy, Kon Tum": [
    "ya ly, sa thầy, kon tum",
    "ya ly, sa thaafy, kon tum"
  ],
  "Đak SMar, KBang, Gia Lai": [
    "đak smar, kbang, gia lai",
    "ddak smar, kbang, gia lai"
  ],
  "A Lù, Bát Xát, Lào Cai": [
    "a lù, bát xát, lào cai",
    "a luf, bast xast, lafo cai"
  ],
  "An Bình, An Khê, Gia Lai": [
    "an bình, an khê, gia lai",
    "an bifnh, an khee, gia lai"
  ],
  "An Dân, Tuy An, Phú Yên": [
    "an dân, tuy an, phú yên",
    "an daan, tuy an, phus yeen"
  ],
  "An Mỹ, Tuy An, Phú Yên": [
    "an mỹ, tuy an, phú yên",
    "an myx, tuy an, phus yeen"
  ],
  "An Phú, An Phú, An Giang": [
    "an phú, an phú, an giang",
    "an phus, an phus, an giang"
  ],
  "Cheo Reo, Ayun Pa, Gia Lai": [
    "cheo reo, ayun pa, gia lai",
    "cheo reo, ayun pa, gia lai"
  ],
  "Chi Lăng, Pleiku, Gia Lai": [
    "chi lăng, pleiku, gia lai",
    "chi lawng, pleiku, gia lai"
  ],
  "Chư Răng, Ia Pa, Gia Lai": [
    "chư răng, ia pa, gia lai",
    "chuw rawng, ia pa, gia lai"
  ],
  "Cư An, Đăk Pơ, Gia Lai": [
    "cư an, đăk pơ, gia lai",
    "cuw an, ddawk pow, gia lai"
  ],
  "Cửa Nam, Vinh, Nghệ An": [
    "cửa nam, vinh, nghệ an",
    "cuwra nam, vinh, ngheej an"
  ],
  "Cửu An, An Khê, Gia Lai": [
    "cửu an, an khê, gia lai",
    "cuwru an, an khee, gia lai"
  ],
  "Duy Tân, Kon Tum, Kon Tum": [
    "duy tân, kon tum, kon tum",
    "duy taan, kon tum, kon tum"
  ],
  "H Bông, Chư Sê, Gia Lai": [
    "h bông, chư sê, gia lai",
    "h boong, chuw see, gia lai"
  ],
  "I, Vị Thanh, Hậu Giang": [
    "i, vị thanh, hậu giang",
    "i, vij thanh, haaju giang"
  ],
  "Ia Glai, Chư Sê, Gia Lai": [
    "ia glai, chư sê, gia lai",
    "ia glai, chuw see, gia lai"
  ],
  "Ia Hla, Chư Pưh, Gia Lai": [
    "ia hla, chư pưh, gia lai",
    "ia hla, chuw puwh, gia lai"
  ],
  "Ia Hrung, Ia Grai, Gia Lai": [
    "ia hrung, ia grai, gia lai",
    "ia hrung, ia grai, gia lai"
  ],
  "Ia Ma Rơn, Ia Pa, Gia Lai": [
    "ia ma rơn, ia pa, gia lai",
    "ia ma rown, ia pa, gia lai"
  ],
  "Ia O, Chư Prông, Gia Lai": [
    "ia o, chư prông, gia lai",
    "ia o, chuw proong, gia lai"
  ],
  "Khánh An, U Minh, Cà Mau": [
    "khánh an, u minh, cà mau",
    "khasnh an, u minh, caf mau"
  ],
  "Lâm, Ý Yên, Nam Định": [
    "lâm, ý yên, nam định",
    "laam, ys yeen, nam ddijnh"
  ],
  "Lê Lợi, Vinh, Nghệ An": [
    "lê lợi, vinh, nghệ an",
    "lee lowji, vinh, ngheej an"
  ],
  "Me, Gia Viễn, Ninh Bình": [
    "me, gia viễn, ninh bình",
    "me, gia vieexn, ninh bifnh"
  ],
  "Nghi Phú, Vinh, Nghệ An": [
    "nghi phú, vinh, nghệ an",
    "nghi phus, vinh, ngheej an"
  ],
  "Nà Pó, Mai Sơn, Sơn La": [
    "nà pó, mai sơn, sơn la",
    "naf pos, mai sown, sown la"
  ],
  "Nà Ơt, Mai Sơn, Sơn La": [
    "nà ơt, mai sơn, sơn la",
    "naf owt, mai sown, sown la"
  ],
  "Quế, Kim Bảng, Hà Nam": [
    "quế, kim bảng, hà nam",
    "quees, kim barng, haf nam"
  ],
  "Trang, Đăk Đoa, Gia Lai": [
    "trang, đăk đoa, gia lai",
    "trang, ddawk ddoa, gia lai"
  ],
  "Tân Sơn, Pleiku, Gia Lai": [
    "tân sơn, pleiku, gia lai",
    "taan sown, pleiku, gia lai"
  ],
  "Tây Sơn, Pleiku, Gia Lai": [
    "tây sơn, pleiku, gia lai",
    "taay sown, pleiku, gia lai"
  ],
  "V, Vị Thanh, Hậu Giang": [
    "v, vị thanh, hậu giang",
    "v, vij thanh, haaju giang"
  ],
  "Vinh Tân, Vinh, Nghệ An": [
    "vinh tân, vinh, nghệ an",
    "vinh taan, vinh, ngheej an"
  ],
  "Xuân An, An Khê, Gia Lai": [
    "xuân an, an khê, gia lai",
    "xuaan an, an khee, gia lai"
  ],
  "Y Tý, Bát Xát, Lào Cai": [
    "y tý, bát xát, lào cai",
    "y tys, bast xast, lafo cai"
  ],
  "Ya Ma, Kông Chro, Gia Lai": [
    "ya ma, kông chro, gia lai",
    "ya ma, koong chro, gia lai"
  ],
  "Đăk HLơ, KBang, Gia Lai": [
    "đăk hlơ, kbang, gia lai",
    "ddawk hlow, kbang, gia lai"
  ],
  ", Cồn Cỏ, Quảng Trị": [
    ", cồn cỏ, quảng trị",
    ", coofn cor, quarng trij"
  ],
  "A Dơk, Đăk Đoa, Gia Lai": [
    "a dơk, đăk đoa, gia lai",
    "a dowk, ddawk ddoa, gia lai"
  ],
  "An Lĩnh, Tuy An, Phú Yên": [
    "an lĩnh, tuy an, phú yên",
    "an lixnh, tuy an, phus yeen"
  ],
  "An Thọ, Tuy An, Phú Yên": [
    "an thọ, tuy an, phú yên",
    "an thoj, tuy an, phus yeen"
  ],
  "An Xuyên, Cà Mau, Cà Mau": [
    "an xuyên, cà mau, cà mau",
    "an xuyeen, caf mau, caf mau"
  ],
  "An Xuân, Tuy An, Phú Yên": [
    "an xuân, tuy an, phú yên",
    "an xuaan, tuy an, phus yeen"
  ],
  "Ba Sao, Kim Bảng, Hà Nam": [
    "ba sao, kim bảng, hà nam",
    "ba sao, kim barng, haf nam"
  ],
  "Bản Hồ, Sa Pa, Lào Cai": [
    "bản hồ, sa pa, lào cai",
    "barn hoof, sa pa, lafo cai"
  ],
  "Chu Minh, Ba Vì, Hà Nội": [
    "chu minh, ba vì, hà nội",
    "chu minh, ba vif, haf nooji"
  ],
  "Chư Băh, Ayun Pa, Gia Lai": [
    "chư băh, ayun pa, gia lai",
    "chuw bawh, ayun pa, gia lai"
  ],
  "Chư Gu, Krông Pa, Gia Lai": [
    "chư gu, krông pa, gia lai",
    "chuw gu, kroong pa, gia lai"
  ],
  "Chư Sê, Chư Sê, Gia Lai": [
    "chư sê, chư sê, gia lai",
    "chuw see, chuw see, gia lai"
  ],
  "Cô Tô, Tri Tôn, An Giang": [
    "cô tô, tri tôn, an giang",
    "coo too, tri toon, an giang"
  ],
  "Cầu Mây, Sa Pa, Lào Cai": [
    "cầu mây, sa pa, lào cai",
    "caafu maay, sa pa, lafo cai"
  ],
  "Diên Phú, Pleiku, Gia Lai": [
    "diên phú, pleiku, gia lai",
    "dieen phus, pleiku, gia lai"
  ],
  "Ea Ô, Ea Kar, Đắk Lắk": [
    "ea ô, ea kar, đắk lắk",
    "ea oo, ea kar, ddawsk lawsk"
  ],
  "Ealy, Sông Hinh, Phú Yên": [
    "ealy, sông hinh, phú yên",
    "ealy, soong hinh, phus yeen"
  ],
  "Hiếu, Kon Plông, Kon Tum": [
    "hiếu, kon plông, kon tum",
    "hieesu, kon ploong, kon tum"
  ],
  "Hà Tam, Đăk Pơ, Gia Lai": [
    "hà tam, đăk pơ, gia lai",
    "haf tam, ddawk pow, gia lai"
  ],
  "Hòa Tân, Cà Mau, Cà Mau": [
    "hòa tân, cà mau, cà mau",
    "hofa taan, caf mau, caf mau"
  ],
  "Hưng Hòa, Vinh, Nghệ An": [
    "hưng hòa, vinh, nghệ an",
    "huwng hofa, vinh, ngheej an"
  ],
  "Hội Phú, Pleiku, Gia Lai": [
    "hội phú, pleiku, gia lai",
    "hooji phus, pleiku, gia lai"
  ],
  "IV, Vị Thanh, Hậu Giang": [
    "iv, vị thanh, hậu giang",
    "iv, vij thanh, haaju giang"
  ],
  "Ia Blang, Chư Sê, Gia Lai": [
    "ia blang, chư sê, gia lai",
    "ia blang, chuw see, gia lai"
  ],
  "Ia Din, Đức Cơ, Gia Lai": [
    "ia din, đức cơ, gia lai",
    "ia din, dduwsc cow, gia lai"
  ],
  "Ia Dom, Ia H' Drai, Kon Tum": [
    "ia dom, ia h' drai, kon tum",
    "ia dom, ia h' drai, kon tum"
  ],
  "Ia Dom, Đức Cơ, Gia Lai": [
    "ia dom, đức cơ, gia lai",
    "ia dom, dduwsc cow, gia lai"
  ],
  "Ia Ga, Chư Prông, Gia Lai": [
    "ia ga, chư prông, gia lai",
    "ia ga, chuw proong, gia lai"
  ],
  "Ia Grăng, Ia Grai, Gia Lai": [
    "ia grăng, ia grai, gia lai",
    "ia grawng, ia grai, gia lai"
  ],
  "Ia Hrú, Chư Pưh, Gia Lai": [
    "ia hrú, chư pưh, gia lai",
    "ia hrus, chuw puwh, gia lai"
  ],
  "Ia Kla, Đức Cơ, Gia Lai": [
    "ia kla, đức cơ, gia lai",
    "ia kla, dduwsc cow, gia lai"
  ],
  "Ia Me, Chư Prông, Gia Lai": [
    "ia me, chư prông, gia lai",
    "ia me, chuw proong, gia lai"
  ],
  "Ia Nan, Đức Cơ, Gia Lai": [
    "ia nan, đức cơ, gia lai",
    "ia nan, dduwsc cow, gia lai"
  ],
  "Ia Nhin, Chư Păh, Gia Lai": [
    "ia nhin, chư păh, gia lai",
    "ia nhin, chuw pawh, gia lai"
  ],
  "Ia Phí, Chư Păh, Gia Lai": [
    "ia phí, chư păh, gia lai",
    "ia phis, chuw pawh, gia lai"
  ],
  "Ia Pếch, Ia Grai, Gia Lai": [
    "ia pếch, ia grai, gia lai",
    "ia peesch, ia grai, gia lai"
  ],
  "Ia RMok, Krông Pa, Gia Lai": [
    "ia rmok, krông pa, gia lai",
    "ia rmok, kroong pa, gia lai"
  ],
  "Ia RSai, Krông Pa, Gia Lai": [
    "ia rsai, krông pa, gia lai",
    "ia rsai, kroong pa, gia lai"
  ],
  "Ia Rong, Chư Pưh, Gia Lai": [
    "ia rong, chư pưh, gia lai",
    "ia rong, chuw puwh, gia lai"
  ],
  "Ia Tiêm, Chư Sê, Gia Lai": [
    "ia tiêm, chư sê, gia lai",
    "ia tieem, chuw see, gia lai"
  ],
  "Kim Bon, Phù Yên, Sơn La": [
    "kim bon, phù yên, sơn la",
    "kim bon, phuf yeen, sown la"
  ],
  "Liên Minh, Sa Pa, Lào Cai": [
    "liên minh, sa pa, lào cai",
    "lieen minh, sa pa, lafo cai"
  ],
  "Lê Lợi, Kon Tum, Kon Tum": [
    "lê lợi, kon tum, kon tum",
    "lee lowji, kon tum, kon tum"
  ],
  "Mô Rai, Sa Thầy, Kon Tum": [
    "mô rai, sa thầy, kon tum",
    "moo rai, sa thaafy, kon tum"
  ],
  "Nam Ka, Lắk, Đắk Lắk": [
    "nam ka, lắk, đắk lắk",
    "nam ka, lawsk, ddawsk lawsk"
  ],
  "Nghi Liên, Vinh, Nghệ An": [
    "nghi liên, vinh, nghệ an",
    "nghi lieen, vinh, ngheej an"
  ],
  "Ngô Mây, An Khê, Gia Lai": [
    "ngô mây, an khê, gia lai",
    "ngoo maay, an khee, gia lai"
  ],
  "Ngô Mây, Kon Tum, Kon Tum": [
    "ngô mây, kon tum, kon tum",
    "ngoo maay, kon tum, kon tum"
  ],
  "Phú An, Đăk Pơ, Gia Lai": [
    "phú an, đăk pơ, gia lai",
    "phus an, ddawk pow, gia lai"
  ],
  "Quán Bàu, Vinh, Nghệ An": [
    "quán bàu, vinh, nghệ an",
    "quasn bafu, vinh, ngheej an"
  ],
  "Sa Sơn, Sa Thầy, Kon Tum": [
    "sa sơn, sa thầy, kon tum",
    "sa sown, sa thaafy, kon tum"
  ],
  "Thành An, An Khê, Gia Lai": [
    "thành an, an khê, gia lai",
    "thafnh an, an khee, gia lai"
  ],
  "Trung Đô, Vinh, Nghệ An": [
    "trung đô, vinh, nghệ an",
    "trung ddoo, vinh, ngheej an"
  ],
  "Tân An, Đăk Pơ, Gia Lai": [
    "tân an, đăk pơ, gia lai",
    "taan an, ddawk pow, gia lai"
  ],
  "Tây Sơn, An Khê, Gia Lai": [
    "tây sơn, an khê, gia lai",
    "taay sown, an khee, gia lai"
  ],
  "Tả Phìn, Sa Pa, Lào Cai": [
    "tả phìn, sa pa, lào cai",
    "tar phifn, sa pa, lafo cai"
  ],
  "Vĩnh An, Ba Tri, Bến Tre": [
    "vĩnh an, ba tri, bến tre",
    "vixnh an, ba tri, beesn tre"
  ],
  "Xốp, Đắk Glei, Kon Tum": [
    "xốp, đắk glei, kon tum",
    "xoosp, ddawsk glei, kon tum"
  ],
  "Yên Thế, Pleiku, Gia Lai": [
    "yên thế, pleiku, gia lai",
    "yeen thees, pleiku, gia lai"
  ],
  "Yên Đỗ, Pleiku, Gia Lai": [
    "yên đỗ, pleiku, gia lai",
    "yeen ddoox, pleiku, gia lai"
  ],
  "Ô Lâm, Tri Tôn, An Giang": [
    "ô lâm, tri tôn, an giang",
    "oo laam, tri toon, an giang"
  ],
  "Đê Ar, Mang Yang, Gia Lai": [
    "đê ar, mang yang, gia lai",
    "ddee ar, mang yang, gia lai"
  ],
  "Đăk Roong, KBang, Gia Lai": [
    "đăk roong, kbang, gia lai",
    "ddawk roong, kbang, gia lai"
  ],
  "An Chấn, Tuy An, Phú Yên": [
    "an chấn, tuy an, phú yên",
    "an chaasn, tuy an, phus yeen"
  ],
  "An Hiệp, Ba Tri, Bến Tre": [
    "an hiệp, ba tri, bến tre",
    "an hieejp, ba tri, beesn tre"
  ],
  "An Hiệp, Tuy An, Phú Yên": [
    "an hiệp, tuy an, phú yên",
    "an hieejp, tuy an, phus yeen"
  ],
  "An Phú, Tuy Hoà, Phú Yên": [
    "an phú, tuy hoà, phú yên",
    "an phus, tuy hoaf, phus yeen"
  ],
  "An Thủy, Ba Tri, Bến Tre": [
    "an thủy, ba tri, bến tre",
    "an thury, ba tri, beesn tre"
  ],
  "An Tức, Tri Tôn, An Giang": [
    "an tức, tri tôn, an giang",
    "an tuwsc, tri toon, an giang"
  ],
  "An Đức, Ba Tri, Bến Tre": [
    "an đức, ba tri, bến tre",
    "an dduwsc, ba tri, beesn tre"
  ],
  "Ba Chúc, Tri Tôn, An Giang": [
    "ba chúc, tri tôn, an giang",
    "ba chusc, tri toon, an giang"
  ],
  "Ba Trại, Ba Vì, Hà Nội": [
    "ba trại, ba vì, hà nội",
    "ba traji, ba vif, haf nooji"
  ],
  "Ba Xa, Ba Tơ, Quảng Ngãi": [
    "ba xa, ba tơ, quảng ngãi",
    "ba xa, ba tow, quarng ngaxi"
  ],
  "Bar Măih, Chư Sê, Gia Lai": [
    "bar măih, chư sê, gia lai",
    "bar mawih, chuw see, gia lai"
  ],
  "Biển Hồ, Pleiku, Gia Lai": [
    "biển hồ, pleiku, gia lai",
    "bieern hoof, pleiku, gia lai"
  ],
  "Bình Tâm, Tân An, Long An": [
    "bình tâm, tân an, long an",
    "bifnh taam, taan an, long an"
  ],
  "Bó Sinh, Sông Mã, Sơn La": [
    "bó sinh, sông mã, sơn la",
    "bos sinh, soong max, sown la"
  ],
  "Chư Don, Chư Pưh, Gia Lai": [
    "chư don, chư pưh, gia lai",
    "chuw don, chuw puwh, gia lai"
  ],
  "Chư Hreng, Kon Tum, Kon Tum": [
    "chư hreng, kon tum, kon tum",
    "chuw hreng, kon tum, kon tum"
  ],
  "Chư Ty, Đức Cơ, Gia Lai": [
    "chư ty, đức cơ, gia lai",
    "chuw ty, dduwsc cow, gia lai"
  ],
  "Cò  Nòi, Mai Sơn, Sơn La": [
    "cò  nòi, mai sơn, sơn la",
    "cof  nofi, mai sown, sown la"
  ],
  "Cư Ni, Ea Kar, Đắk Lắk": [
    "cư ni, ea kar, đắk lắk",
    "cuw ni, ea kar, ddawsk lawsk"
  ],
  "Cổ Bi, Gia Lâm, Hà Nội": [
    "cổ bi, gia lâm, hà nội",
    "coor bi, gia laam, haf nooji"
  ],
  "Cổ Đô, Ba Vì, Hà Nội": [
    "cổ đô, ba vì, hà nội",
    "coor ddoo, ba vif, haf nooji"
  ],
  "Duy Minh, Duy Tiên, Hà Nam": [
    "duy minh, duy tiên, hà nam",
    "duy minh, duy tieen, haf nam"
  ],
  "Ea Kar, Ea Kar, Đắk Lắk": [
    "ea kar, ea kar, đắk lắk",
    "ea kar, ea kar, ddawsk lawsk"
  ],
  "Ea Sar, Ea Kar, Đắk Lắk": [
    "ea sar, ea kar, đắk lắk",
    "ea sar, ea kar, ddawsk lawsk"
  ],
  "Ea Sô, Ea Kar, Đắk Lắk": [
    "ea sô, ea kar, đắk lắk",
    "ea soo, ea kar, ddawsk lawsk"
  ],
  "Ea Tih, Ea Kar, Đắk Lắk": [
    "ea tih, ea kar, đắk lắk",
    "ea tih, ea kar, ddawsk lawsk"
  ],
  "EaBar, Sông Hinh, Phú Yên": [
    "eabar, sông hinh, phú yên",
    "eabar, soong hinh, phus yeen"
  ],
  "EaBia, Sông Hinh, Phú Yên": [
    "eabia, sông hinh, phú yên",
    "eabia, soong hinh, phus yeen"
  ],
  "Gia Phù, Phù Yên, Sơn La": [
    "gia phù, phù yên, sơn la",
    "gia phuf, phuf yeen, sown la"
  ],
  "H' Neng, Đăk Đoa, Gia Lai": [
    "h' neng, đăk đoa, gia lai",
    "h' neng, ddawk ddoa, gia lai"
  ],
  "Huy Hạ, Phù Yên, Sơn La": [
    "huy hạ, phù yên, sơn la",
    "huy haj, phuf yeen, sown la"
  ],
  "Huy Tân, Phù Yên, Sơn La": [
    "huy tân, phù yên, sơn la",
    "huy taan, phuf yeen, sown la"
  ],
  "Hà Tây, Chư Păh, Gia Lai": [
    "hà tây, chư păh, gia lai",
    "haf taay, chuw pawh, gia lai"
  ],
  "Hàm Rồng, Sa Pa, Lào Cai": [
    "hàm rồng, sa pa, lào cai",
    "hafm roofng, sa pa, lafo cai"
  ],
  "Hát Lót, Mai Sơn, Sơn La": [
    "hát lót, mai sơn, sơn la",
    "hast lost, mai sown, sown la"
  ],
  "Hòa Bình, Ayun Pa, Gia Lai": [
    "hòa bình, ayun pa, gia lai",
    "hofa bifnh, ayun pa, gia lai"
  ],
  "Hòa Bình, Kon Tum, Kon Tum": [
    "hòa bình, kon tum, kon tum",
    "hofa bifnh, kon tum, kon tum"
  ],
  "Hưng Bình, Vinh, Nghệ An": [
    "hưng bình, vinh, nghệ an",
    "huwng bifnh, vinh, ngheej an"
  ],
  "Hưng Dũng, Vinh, Nghệ An": [
    "hưng dũng, vinh, nghệ an",
    "huwng duxng, vinh, ngheej an"
  ],
  "Hưng Lộc, Vinh, Nghệ An": [
    "hưng lộc, vinh, nghệ an",
    "huwng loojc, vinh, ngheej an"
  ],
  "Hưng Phúc, Vinh, Nghệ An": [
    "hưng phúc, vinh, nghệ an",
    "huwng phusc, vinh, ngheej an"
  ],
  "Hồng Sơn, Vinh, Nghệ An": [
    "hồng sơn, vinh, nghệ an",
    "hoofng sown, vinh, ngheej an"
  ],
  "III, Vị Thanh, Hậu Giang": [
    "iii, vị thanh, hậu giang",
    "iii, vij thanh, haaju giang"
  ],
  "Ia BLứ, Chư Pưh, Gia Lai": [
    "ia blứ, chư pưh, gia lai",
    "ia bluws, chuw puwh, gia lai"
  ],
  "Ia Dreng, Chư Pưh, Gia Lai": [
    "ia dreng, chư pưh, gia lai",
    "ia dreng, chuw puwh, gia lai"
  ],
  "Ia Dơk, Đức Cơ, Gia Lai": [
    "ia dơk, đức cơ, gia lai",
    "ia dowk, dduwsc cow, gia lai"
  ],
  "Ia HDreh, Krông Pa, Gia Lai": [
    "ia hdreh, krông pa, gia lai",
    "ia hdreh, kroong pa, gia lai"
  ],
  "Ia HLốp, Chư Sê, Gia Lai": [
    "ia hlốp, chư sê, gia lai",
    "ia hloosp, chuw see, gia lai"
  ],
  "Ia Kly, Chư Prông, Gia Lai": [
    "ia kly, chư prông, gia lai",
    "ia kly, chuw proong, gia lai"
  ],
  "Ia Kreng, Chư Păh, Gia Lai": [
    "ia kreng, chư păh, gia lai",
    "ia kreng, chuw pawh, gia lai"
  ],
  "Ia Lang, Đức Cơ, Gia Lai": [
    "ia lang, đức cơ, gia lai",
    "ia lang, dduwsc cow, gia lai"
  ],
  "Ia Mláh, Krông Pa, Gia Lai": [
    "ia mláh, krông pa, gia lai",
    "ia mlash, kroong pa, gia lai"
  ],
  "Ia Mơ, Chư Prông, Gia Lai": [
    "ia mơ, chư prông, gia lai",
    "ia mow, chuw proong, gia lai"
  ],
  "Ia Phang, Chư Pưh, Gia Lai": [
    "ia phang, chư pưh, gia lai",
    "ia phang, chuw puwh, gia lai"
  ],
  "Ia Pia, Chư Prông, Gia Lai": [
    "ia pia, chư prông, gia lai",
    "ia pia, chuw proong, gia lai"
  ],
  "Ia Tơi, Ia H' Drai, Kon Tum": [
    "ia tơi, ia h' drai, kon tum",
    "ia towi, ia h' drai, kon tum"
  ],
  "Ia Vê, Chư Prông, Gia Lai": [
    "ia vê, chư prông, gia lai",
    "ia vee, chuw proong, gia lai"
  ],
  "Ia Đal, Ia H' Drai, Kon Tum": [
    "ia đal, ia h' drai, kon tum",
    "ia ddal, ia h' drai, kon tum"
  ],
  "K' Dang, Đăk Đoa, Gia Lai": [
    "k' dang, đăk đoa, gia lai",
    "k' dang, ddawk ddoa, gia lai"
  ],
  "Khánh An, An Phú, An Giang": [
    "khánh an, an phú, an giang",
    "khasnh an, an phus, an giang"
  ],
  "Khánh Hòa, U Minh, Cà Mau": [
    "khánh hòa, u minh, cà mau",
    "khasnh hofa, u minh, caf mau"
  ],
  "Khánh Lâm, U Minh, Cà Mau": [
    "khánh lâm, u minh, cà mau",
    "khasnh laam, u minh, caf mau"
  ],
  "Kim An, Thanh Oai, Hà Nội": [
    "kim an, thanh oai, hà nội",
    "kim an, thanh oai, haf nooji"
  ],
  "Kim Hoa, Mê Linh, Hà Nội": [
    "kim hoa, mê linh, hà nội",
    "kim hoa, mee linh, haf nooji"
  ],
  "Kim Lan, Gia Lâm, Hà Nội": [
    "kim lan, gia lâm, hà nội",
    "kim lan, gia laam, haf nooji"
  ],
  "Kim Lư, Na Rì, Bắc Kạn": [
    "kim lư, na rì, bắc kạn",
    "kim luw, na rif, bawsc kajn"
  ],
  "Kim Tân, Lào Cai, Lào Cai": [
    "kim tân, lào cai, lào cai",
    "kim taan, lafo cai, lafo cai"
  ],
  "Lam Hạ, Phủ Lý, Hà Nam": [
    "lam hạ, phủ lý, hà nam",
    "lam haj, phur lys, haf nam"
  ],
  "Lào Cai, Lào Cai, Lào Cai": [
    "lào cai, lào cai, lào cai",
    "lafo cai, lafo cai, lafo cai"
  ],
  "Lê Trì, Tri Tôn, An Giang": [
    "lê trì, tri tôn, an giang",
    "lee trif, tri toon, an giang"
  ],
  "Lơ Pang, Mang Yang, Gia Lai": [
    "lơ pang, mang yang, gia lai",
    "low pang, mang yang, gia lai"
  ],
  "Mường Bo, Sa Pa, Lào Cai": [
    "mường bo, sa pa, lào cai",
    "muwowfng bo, sa pa, lafo cai"
  ],
  "Mỹ Hòa, Ba Tri, Bến Tre": [
    "mỹ hòa, ba tri, bến tre",
    "myx hofa, ba tri, beesn tre"
  ],
  "Na Loi, Kỳ Sơn, Nghệ An": [
    "na loi, kỳ sơn, nghệ an",
    "na loi, kyf sown, ngheej an"
  ],
  "Nga An, Nga Sơn, Thanh Hóa": [
    "nga an, nga sơn, thanh hóa",
    "nga an, nga sown, thanh hosa"
  ],
  "Nghi Đức, Vinh, Nghệ An": [
    "nghi đức, vinh, nghệ an",
    "nghi dduwsc, vinh, ngheej an"
  ],
  "Nghèn, Can Lộc, Hà Tĩnh": [
    "nghèn, can lộc, hà tĩnh",
    "nghefn, can loojc, haf tixnh"
  ],
  "Ngọk Bay, Kon Tum, Kon Tum": [
    "ngọk bay, kon tum, kon tum",
    "ngojk bay, kon tum, kon tum"
  ],
  "Ninh An, Hoa Lư, Ninh Bình": [
    "ninh an, hoa lư, ninh bình",
    "ninh an, hoa luw, ninh bifnh"
  ],
  "Núi Tô, Tri Tôn, An Giang": [
    "núi tô, tri tôn, an giang",
    "nusi too, tri toon, an giang"
  ],
  "Nậm Ty, Sông Mã, Sơn La": [
    "nậm ty, sông mã, sơn la",
    "naajm ty, soong max, sown la"
  ],
  "Pa Cheo, Bát Xát, Lào Cai": [
    "pa cheo, bát xát, lào cai",
    "pa cheo, bast xast, lafo cai"
  ],
  "Phú An, Phú Tân, An Giang": [
    "phú an, phú tân, an giang",
    "phus an, phus taan, an giang"
  ],
  "Phú Lễ, Ba Tri, Bến Tre": [
    "phú lễ, ba tri, bến tre",
    "phus leex, ba tri, beesn tre"
  ],
  "Phú Sơn, Ba Vì, Hà Nội": [
    "phú sơn, ba vì, hà nội",
    "phus sown, ba vif, haf nooji"
  ],
  "Pom Hán, Lào Cai, Lào Cai": [
    "pom hán, lào cai, lào cai",
    "pom hasn, lafo cai, lafo cai"
  ],
  "Pô Kô, Đắk Tô, Kon Tum": [
    "pô kô, đắk tô, kon tum",
    "poo koo, ddawsk too, kon tum"
  ],
  "Pờ Ê, Kon Plông, Kon Tum": [
    "pờ ê, kon plông, kon tum",
    "powf ee, kon ploong, kon tum"
  ],
  "Quang Trung, Vinh, Nghệ An": [
    "quang trung, vinh, nghệ an",
    "quang trung, vinh, ngheej an"
  ],
  "Rơ Kơi, Sa Thầy, Kon Tum": [
    "rơ kơi, sa thầy, kon tum",
    "row kowi, sa thaafy, kon tum"
  ],
  "Sa Bình, Sa Thầy, Kon Tum": [
    "sa bình, sa thầy, kon tum",
    "sa bifnh, sa thaafy, kon tum"
  ],
  "Sa Nhơn, Sa Thầy, Kon Tum": [
    "sa nhơn, sa thầy, kon tum",
    "sa nhown, sa thaafy, kon tum"
  ],
  "Song Pe, Bắc Yên, Sơn La": [
    "song pe, bắc yên, sơn la",
    "song pe, bawsc yeen, sown la"
  ],
  "Sông Bờ, Ayun Pa, Gia Lai": [
    "sông bờ, ayun pa, gia lai",
    "soong bowf, ayun pa, gia lai"
  ],
  "Sơn Đà, Ba Vì, Hà Nội": [
    "sơn đà, ba vì, hà nội",
    "sown ddaf, ba vif, haf nooji"
  ],
  "Sập Xa, Phù Yên, Sơn La": [
    "sập xa, phù yên, sơn la",
    "saajp xa, phuf yeen, sown la"
  ],
  "Thanh Bình, Sa Pa, Lào Cai": [
    "thanh bình, sa pa, lào cai",
    "thanh bifnh, sa pa, lafo cai"
  ],
  "Thụy An, Ba Vì, Hà Nội": [
    "thụy an, ba vì, hà nội",
    "thujy an, ba vif, haf nooji"
  ],
  "Tri Tôn, Tri Tôn, An Giang": [
    "tri tôn, tri tôn, an giang",
    "tri toon, tri toon, an giang"
  ],
  "Tà Hộc, Mai Sơn, Sơn La": [
    "tà hộc, mai sơn, sơn la",
    "taf hoojc, mai sown, sown la"
  ],
  "Tân An, Văn Bàn, Lào Cai": [
    "tân an, văn bàn, lào cai",
    "taan an, vawn bafn, lafo cai"
  ],
  "Tân Mỹ, Ba Tri, Bến Tre": [
    "tân mỹ, ba tri, bến tre",
    "taan myx, ba tri, beesn tre"
  ],
  "Tô Hiệu, Sơn La, Sơn La": [
    "tô hiệu, sơn la, sơn la",
    "too hieeju, sown la, sown la"
  ],
  "Tô Múa, Vân Hồ, Sơn La": [
    "tô múa, vân hồ, sơn la",
    "too musa, vaan hoof, sown la"
  ],
  "Tắc Vân, Cà Mau, Cà Mau": [
    "tắc vân, cà mau, cà mau",
    "tawsc vaan, caf mau, caf mau"
  ],
  "VII, Vị Thanh, Hậu Giang": [
    "vii, vị thanh, hậu giang",
    "vii, vij thanh, haaju giang"
  ],
  "Vinh Quang, Kon Tum, Kon Tum": [
    "vinh quang, kon tum, kon tum",
    "vinh quang, kon tum, kon tum"
  ],
  "Vân Du, Ân Thi, Hưng Yên": [
    "vân du, ân thi, hưng yên",
    "vaan du, aan thi, huwng yeen"
  ],
  "Vân Hòa, Ba Vì, Hà Nội": [
    "vân hòa, ba vì, hà nội",
    "vaan hofa, ba vif, haf nooji"
  ],
  "Võ Lao, Văn Bàn, Lào Cai": [
    "võ lao, văn bàn, lào cai",
    "vox lao, vawn bafn, lafo cai"
  ],
  "Văn Lý, Lý Nhân, Hà Nam": [
    "văn lý, lý nhân, hà nam",
    "vawn lys, lys nhaan, haf nam"
  ],
  "Ya Hội, Đăk Pơ, Gia Lai": [
    "ya hội, đăk pơ, gia lai",
    "ya hooji, ddawk pow, gia lai"
  ],
  "Ya Tăng, Sa Thầy, Kon Tum": [
    "ya tăng, sa thầy, kon tum",
    "ya tawng, sa thaafy, kon tum"
  ],
  "Ya Xiêr, Sa Thầy, Kon Tum": [
    "ya xiêr, sa thầy, kon tum",
    "ya xieer, sa thaafy, kon tum"
  ],
  "Yên Bài, Ba Vì, Hà Nội": [
    "yên bài, ba vì, hà nội",
    "yeen bafi, ba vif, haf nooji"
  ],
  "Yên Nam, Duy Tiên, Hà Nam": [
    "yên nam, duy tiên, hà nam",
    "yeen nam, duy tieen, haf nam"
  ],
  "Ân Thi, Ân Thi, Hưng Yên": [
    "ân thi, ân thi, hưng yên",
    "aan thi, aan thi, huwng yeen"
  ],
  "Đak Pơ, Đăk Pơ, Gia Lai": [
    "đak pơ, đăk pơ, gia lai",
    "ddak pow, ddawk pow, gia lai"
  ],
  "Đống Đa, Pleiku, Gia Lai": [
    "đống đa, pleiku, gia lai",
    "ddoosng dda, pleiku, gia lai"
  ],
  "Đội Cung, Vinh, Nghệ An": [
    "đội cung, vinh, nghệ an",
    "ddooji cung, vinh, ngheej an"
  ],
  "An Lão, Bình Lục, Hà Nam": [
    "an lão, bình lục, hà nam",
    "an laxo, bifnh lujc, haf nam"
  ],
  "An Ninh, Bình Lục, Hà Nam": [
    "an ninh, bình lục, hà nam",
    "an ninh, bifnh lujc, haf nam"
  ],
  "An Phước, An Khê, Gia Lai": [
    "an phước, an khê, gia lai",
    "an phuwowsc, an khee, gia lai"
  ],
  "An Thành, Đăk Pơ, Gia Lai": [
    "an thành, đăk pơ, gia lai",
    "an thafnh, ddawk pow, gia lai"
  ],
  "An Thạch, Tuy An, Phú Yên": [
    "an thạch, tuy an, phú yên",
    "an thajch, tuy an, phus yeen"
  ],
  "An Trung, Kông Chro, Gia Lai": [
    "an trung, kông chro, gia lai",
    "an trung, koong chro, gia lai"
  ],
  "An Định, Tuy An, Phú Yên": [
    "an định, tuy an, phú yên",
    "an ddijnh, tuy an, phus yeen"
  ],
  "Anh Sơn, Anh Sơn, Nghệ An": [
    "anh sơn, anh sơn, nghệ an",
    "anh sown, anh sown, ngheej an"
  ],
  "Ba Nam, Ba Tơ, Quảng Ngãi": [
    "ba nam, ba tơ, quảng ngãi",
    "ba nam, ba tow, quarng ngaxi"
  ],
  "Ba Tô, Ba Tơ, Quảng Ngãi": [
    "ba tô, ba tơ, quảng ngãi",
    "ba too, ba tow, quarng ngaxi"
  ],
  "Ba Tơ, Ba Tơ, Quảng Ngãi": [
    "ba tơ, ba tơ, quảng ngãi",
    "ba tow, ba tow, quarng ngaxi"
  ],
  "Ba Vì, Ba Tơ, Quảng Ngãi": [
    "ba vì, ba tơ, quảng ngãi",
    "ba vif, ba tow, quarng ngaxi"
  ],
  "Ba, Đông Giang, Quảng Nam": [
    "ba, đông giang, quảng nam",
    "ba, ddoong giang, quarng nam"
  ],
  "Bao La, Mai Châu, Hoà Bình": [
    "bao la, mai châu, hoà bình",
    "bao la, mai chaau, hoaf bifnh"
  ],
  "Bưởi, Tây Hồ, Hà Nội": [
    "bưởi, tây hồ, hà nội",
    "buwowri, taay hoof, haf nooji"
  ],
  "Bắc Lý, Lý Nhân, Hà Nam": [
    "bắc lý, lý nhân, hà nam",
    "bawsc lys, lys nhaan, haf nam"
  ],
  "Bến Thủy, Vinh, Nghệ An": [
    "bến thủy, vinh, nghệ an",
    "beesn thury, vinh, ngheej an"
  ],
  "Bờ Y, Ngọc Hồi, Kon Tum": [
    "bờ y, ngọc hồi, kon tum",
    "bowf y, ngojc hoofi, kon tum"
  ],
  "Cao Sơn, Anh Sơn, Nghệ An": [
    "cao sơn, anh sơn, nghệ an",
    "cao sown, anh sown, ngheej an"
  ],
  "Chiềng An, Sơn La, Sơn La": [
    "chiềng an, sơn la, sơn la",
    "chieefng an, sown la, sown la"
  ],
  "Chu Phan, Mê Linh, Hà Nội": [
    "chu phan, mê linh, hà nội",
    "chu phan, mee linh, haf nooji"
  ],
  "Chân Lý, Lý Nhân, Hà Nam": [
    "chân lý, lý nhân, hà nam",
    "chaan lys, lys nhaan, haf nam"
  ],
  "Châu Sơn, Ba Vì, Hà Nội": [
    "châu sơn, ba vì, hà nội",
    "chaau sown, ba vif, haf nooji"
  ],
  "Chư Pơng, Chư Sê, Gia Lai": [
    "chư pơng, chư sê, gia lai",
    "chuw powng, chuw see, gia lai"
  ],
  "Chờ, Yên Phong, Bắc Ninh": [
    "chờ, yên phong, bắc ninh",
    "chowf, yeen phong, bawsc ninh"
  ],
  "Công Lý, Lý Nhân, Hà Nam": [
    "công lý, lý nhân, hà nam",
    "coong lys, lys nhaan, haf nam"
  ],
  "Căn Co, Sìn Hồ, Lai Châu": [
    "căn co, sìn hồ, lai châu",
    "cawn co, sifn hoof, lai chaau"
  ],
  "Cư Lễ, Na Rì, Bắc Kạn": [
    "cư lễ, na rì, bắc kạn",
    "cuw leex, na rif, bawsc kajn"
  ],
  "Cốc Ly, Bắc Hà, Lào Cai": [
    "cốc ly, bắc hà, lào cai",
    "coosc ly, bawsc haf, lafo cai"
  ],
  "Cốc San, Lào Cai, Lào Cai": [
    "cốc san, lào cai, lào cai",
    "coosc san, lafo cai, lafo cai"
  ],
  "Dang, Tây Giang, Quảng Nam": [
    "dang, tây giang, quảng nam",
    "dang, taay giang, quarng nam"
  ],
  "Diên Hồng, Pleiku, Gia Lai": [
    "diên hồng, pleiku, gia lai",
    "dieen hoofng, pleiku, gia lai"
  ],
  "Du Già, Yên Minh, Hà Giang": [
    "du già, yên minh, hà giang",
    "du giaf, yeen minh, haf giang"
  ],
  "Duy Hải, Duy Tiên, Hà Nam": [
    "duy hải, duy tiên, hà nam",
    "duy hari, duy tieen, haf nam"
  ],
  "Dĩ An, Dĩ An, Bình Dương": [
    "dĩ an, dĩ an, bình dương",
    "dix an, dix an, bifnh duwowng"
  ],
  "Ea Bá, Sông Hinh, Phú Yên": [
    "ea bá, sông hinh, phú yên",
    "ea bas, soong hinh, phus yeen"
  ],
  "Ea Hu, Cư Kuin, Đắk Lắk": [
    "ea hu, cư kuin, đắk lắk",
    "ea hu, cuw kuin, ddawsk lawsk"
  ],
  "Ea Lê, Ea Súp, Đắk Lắk": [
    "ea lê, ea súp, đắk lắk",
    "ea lee, ea susp, ddawsk lawsk"
  ],
  "Ea Păl, Ea Kar, Đắk Lắk": [
    "ea păl, ea kar, đắk lắk",
    "ea pawl, ea kar, ddawsk lawsk"
  ],
  "Ea R'Bin, Lắk, Đắk Lắk": [
    "ea r'bin, lắk, đắk lắk",
    "ea r'bin, lawsk, ddawsk lawsk"
  ],
  "Ea Wy, Ea H'leo, Đắk Lắk": [
    "ea wy, ea h'leo, đắk lắk",
    "ea wy, ea h'leo, ddawsk lawsk"
  ],
  "Ea Đar, Ea Kar, Đắk Lắk": [
    "ea đar, ea kar, đắk lắk",
    "ea ddar, ea kar, ddawsk lawsk"
  ],
  "EaTrol, Sông Hinh, Phú Yên": [
    "eatrol, sông hinh, phú yên",
    "eatrol, soong hinh, phus yeen"
  ],
  "Gôi, Vụ Bản, Nam Định": [
    "gôi, vụ bản, nam định",
    "gooi, vuj barn, nam ddijnh"
  ],
  "Hoa Sơn, Anh Sơn, Nghệ An": [
    "hoa sơn, anh sơn, nghệ an",
    "hoa sown, anh sown, ngheej an"
  ],
  "Hoàng Liên, Sa Pa, Lào Cai": [
    "hoàng liên, sa pa, lào cai",
    "hoafng lieen, sa pa, lafo cai"
  ],
  "Huy Bắc, Phù Yên, Sơn La": [
    "huy bắc, phù yên, sơn la",
    "huy bawsc, phuf yeen, sown la"
  ],
  "Hà Mòn, Đắk Hà, Kon Tum": [
    "hà mòn, đắk hà, kon tum",
    "haf mofn, ddawsk haf, kon tum"
  ],
  "Hòa An, Phú Hoà, Phú Yên": [
    "hòa an, phú hoà, phú yên",
    "hofa an, phus hoaf, phus yeen"
  ],
  "Hòa Phú, Chư Păh, Gia Lai": [
    "hòa phú, chư păh, gia lai",
    "hofa phus, chuw pawh, gia lai"
  ],
  "Hòa Thành, Cà Mau, Cà Mau": [
    "hòa thành, cà mau, cà mau",
    "hofa thafnh, caf mau, caf mau"
  ],
  "Hơ Moong, Sa Thầy, Kon Tum": [
    "hơ moong, sa thầy, kon tum",
    "how moong, sa thaafy, kon tum"
  ],
  "Hưng Chính, Vinh, Nghệ An": [
    "hưng chính, vinh, nghệ an",
    "huwng chisnh, vinh, ngheej an"
  ],
  "Hưng Đông, Vinh, Nghệ An": [
    "hưng đông, vinh, nghệ an",
    "huwng ddoong, vinh, ngheej an"
  ],
  "Hợp Lý, Lý Nhân, Hà Nam": [
    "hợp lý, lý nhân, hà nam",
    "howjp lys, lys nhaan, haf nam"
  ],
  "Ia Ake, Phú Thiện, Gia Lai": [
    "ia ake, phú thiện, gia lai",
    "ia ake, phus thieejn, gia lai"
  ],
  "Ia Bang, Chư Prông, Gia Lai": [
    "ia bang, chư prông, gia lai",
    "ia bang, chuw proong, gia lai"
  ],
  "Ia Băng, Đăk Đoa, Gia Lai": [
    "ia băng, đăk đoa, gia lai",
    "ia bawng, ddawk ddoa, gia lai"
  ],
  "Ia Krêl, Đức Cơ, Gia Lai": [
    "ia krêl, đức cơ, gia lai",
    "ia kreel, dduwsc cow, gia lai"
  ],
  "Ia Lâu, Chư Prông, Gia Lai": [
    "ia lâu, chư prông, gia lai",
    "ia laau, chuw proong, gia lai"
  ],
  "Ia Pnôn, Đức Cơ, Gia Lai": [
    "ia pnôn, đức cơ, gia lai",
    "ia pnoon, dduwsc cow, gia lai"
  ],
  "Ia Pết, Đăk Đoa, Gia Lai": [
    "ia pết, đăk đoa, gia lai",
    "ia peest, ddawk ddoa, gia lai"
  ],
  "Ia Sol, Phú Thiện, Gia Lai": [
    "ia sol, phú thiện, gia lai",
    "ia sol, phus thieejn, gia lai"
  ],
  "Ia Tôr, Chư Prông, Gia Lai": [
    "ia tôr, chư prông, gia lai",
    "ia toor, chuw proong, gia lai"
  ],
  "Khánh Hội, U Minh, Cà Mau": [
    "khánh hội, u minh, cà mau",
    "khasnh hooji, u minh, caf mau"
  ],
  "Kim Bình, Phủ Lý, Hà Nam": [
    "kim bình, phủ lý, hà nam",
    "kim bifnh, phur lys, haf nam"
  ],
  "Kim Hỷ, Na Rì, Bắc Kạn": [
    "kim hỷ, na rì, bắc kạn",
    "kim hyr, na rif, bawsc kajn"
  ],
  "Kim Lũ, Sóc Sơn, Hà Nội": [
    "kim lũ, sóc sơn, hà nội",
    "kim lux, sosc sown, haf nooji"
  ],
  "Kim Mã, Ba Đình, Hà Nội": [
    "kim mã, ba đình, hà nội",
    "kim max, ba ddifnh, haf nooji"
  ],
  "Kim Sơn, Gia Lâm, Hà Nội": [
    "kim sơn, gia lâm, hà nội",
    "kim sown, gia laam, haf nooji"
  ],
  "Kim Sơn, Trà Cú, Trà Vinh": [
    "kim sơn, trà cú, trà vinh",
    "kim sown, traf cus, traf vinh"
  ],
  "Kon Dơng, Mang Yang, Gia Lai": [
    "kon dơng, mang yang, gia lai",
    "kon downg, mang yang, gia lai"
  ],
  "Kon Gang, Đăk Đoa, Gia Lai": [
    "kon gang, đăk đoa, gia lai",
    "kon gang, ddawk ddoa, gia lai"
  ],
  "Kông HTok, Chư Sê, Gia Lai": [
    "kông htok, chư sê, gia lai",
    "koong htok, chuw see, gia lai"
  ],
  "Kỳ Hoa, Kỳ Anh, Hà Tĩnh": [
    "kỳ hoa, kỳ anh, hà tĩnh",
    "kyf hoa, kyf anh, haf tixnh"
  ],
  "Kỳ Hà, Kỳ Anh, Hà Tĩnh": [
    "kỳ hà, kỳ anh, hà tĩnh",
    "kyf haf, kyf anh, haf tixnh"
  ],
  "Kỳ Nam, Kỳ Anh, Hà Tĩnh": [
    "kỳ nam, kỳ anh, hà tĩnh",
    "kyf nam, kyf anh, haf tixnh"
  ],
  "La Sơn, Bình Lục, Hà Nam": [
    "la sơn, bình lục, hà nam",
    "la sown, bifnh lujc, haf nam"
  ],
  "Long An, Tân Châu, An Giang": [
    "long an, tân châu, an giang",
    "long an, taan chaau, an giang"
  ],
  "Long Bình, An Phú, An Giang": [
    "long bình, an phú, an giang",
    "long bifnh, an phus, an giang"
  ],
  "Lê Hồ, Kim Bảng, Hà Nam": [
    "lê hồ, kim bảng, hà nam",
    "lee hoof, kim barng, haf nam"
  ],
  "Lệ Chi, Gia Lâm, Hà Nội": [
    "lệ chi, gia lâm, hà nội",
    "leej chi, gia laam, haf nooji"
  ],
  "Ma Quai, Sìn Hồ, Lai Châu": [
    "ma quai, sìn hồ, lai châu",
    "ma quai, sifn hoof, lai chaau"
  ],
  "Mi Hòa, Kim Bôi, Hoà Bình": [
    "mi hòa, kim bôi, hoà bình",
    "mi hofa, kim booi, hoaf bifnh"
  ],
  "Minh Châu, Ba Vì, Hà Nội": [
    "minh châu, ba vì, hà nội",
    "minh chaau, ba vif, haf nooji"
  ],
  "Minh Khai, Phủ Lý, Hà Nam": [
    "minh khai, phủ lý, hà nam",
    "minh khai, phur lys, haf nam"
  ],
  "Minh Quang, Ba Vì, Hà Nội": [
    "minh quang, ba vì, hà nội",
    "minh quang, ba vif, haf nooji"
  ],
  "Mê Linh, Mê Linh, Hà Nội": [
    "mê linh, mê linh, hà nội",
    "mee linh, mee linh, haf nooji"
  ],
  "Mường Hoa, Sa Pa, Lào Cai": [
    "mường hoa, sa pa, lào cai",
    "muwowfng hoa, sa pa, lafo cai"
  ],
  "Mậu A, Văn Yên, Yên Bái": [
    "mậu a, văn yên, yên bái",
    "maaju a, vawn yeen, yeen basi"
  ],
  "Mộc Nam, Duy Tiên, Hà Nam": [
    "mộc nam, duy tiên, hà nam",
    "moojc nam, duy tieen, haf nam"
  ],
  "Mỹ Nhơn, Ba Tri, Bến Tre": [
    "mỹ nhơn, ba tri, bến tre",
    "myx nhown, ba tri, beesn tre"
  ],
  "Na Hối, Bắc Hà, Lào Cai": [
    "na hối, bắc hà, lào cai",
    "na hoosi, bawsc haf, lafo cai"
  ],
  "Na Khê, Yên Minh, Hà Giang": [
    "na khê, yên minh, hà giang",
    "na khee, yeen minh, haf giang"
  ],
  "Na Ngoi, Kỳ Sơn, Nghệ An": [
    "na ngoi, kỳ sơn, nghệ an",
    "na ngoi, kyf sown, ngheej an"
  ],
  "Nam Anh, Nam Đàn, Nghệ An": [
    "nam anh, nam đàn, nghệ an",
    "nam anh, nam ddafn, ngheej an"
  ],
  "Nam Hà, Hà Tĩnh, Hà Tĩnh": [
    "nam hà, hà tĩnh, hà tĩnh",
    "nam haf, haf tixnh, haf tixnh"
  ],
  "Nam Kim, Nam Đàn, Nghệ An": [
    "nam kim, nam đàn, nghệ an",
    "nam kim, nam ddafn, ngheej an"
  ],
  "Nam Phong, Phù Yên, Sơn La": [
    "nam phong, phù yên, sơn la",
    "nam phong, phuf yeen, sown la"
  ],
  "Nam Yang, Đăk Đoa, Gia Lai": [
    "nam yang, đăk đoa, gia lai",
    "nam yang, ddawk ddoa, gia lai"
  ],
  "Ngam La, Yên Minh, Hà Giang": [
    "ngam la, yên minh, hà giang",
    "ngam la, yeen minh, haf giang"
  ],
  "Ngok Tem, Kon Plông, Kon Tum": [
    "ngok tem, kon plông, kon tum",
    "ngok tem, kon ploong, kon tum"
  ],
  "Ngòi A, Văn Yên, Yên Bái": [
    "ngòi a, văn yên, yên bái",
    "ngofi a, vawn yeen, yeen basi"
  ],
  "Năm Căn, Năm Căn, Cà Mau": [
    "năm căn, năm căn, cà mau",
    "nawm cawn, nawm cawn, caf mau"
  ],
  "Pha Mu, Than Uyên, Lai Châu": [
    "pha mu, than uyên, lai châu",
    "pha mu, than uyeen, lai chaau"
  ],
  "Phong Vân, Ba Vì, Hà Nội": [
    "phong vân, ba vì, hà nội",
    "phong vaan, ba vif, haf nooji"
  ],
  "Phù Vân, Phủ Lý, Hà Nam": [
    "phù vân, phủ lý, hà nam",
    "phuf vaan, phur lys, haf nam"
  ],
  "Phù Yên, Phù Yên, Sơn La": [
    "phù yên, phù yên, sơn la",
    "phuf yeen, phuf yeen, sown la"
  ],
  "Phù Đổng, Pleiku, Gia Lai": [
    "phù đổng, pleiku, gia lai",
    "phuf ddoorng, pleiku, gia lai"
  ],
  "Phú Châu, Ba Vì, Hà Nội": [
    "phú châu, ba vì, hà nội",
    "phus chaau, ba vif, haf nooji"
  ],
  "Phú Hòa, Chư Păh, Gia Lai": [
    "phú hòa, chư păh, gia lai",
    "phus hofa, chuw pawh, gia lai"
  ],
  "Phú Hội, An Phú, An Giang": [
    "phú hội, an phú, an giang",
    "phus hooji, an phus, an giang"
  ],
  "Phú Hữu, An Phú, An Giang": [
    "phú hữu, an phú, an giang",
    "phus huwxu, an phus, an giang"
  ],
  "Phú Mỹ, Phú Tân, Cà Mau": [
    "phú mỹ, phú tân, cà mau",
    "phus myx, phus taan, caf mau"
  ],
  "Phú Tân, Phú Tân, Cà Mau": [
    "phú tân, phú tân, cà mau",
    "phus taan, phus taan, caf mau"
  ],
  "Phú Túc, Krông Pa, Gia Lai": [
    "phú túc, krông pa, gia lai",
    "phus tusc, kroong pa, gia lai"
  ],
  "Phường 1, Cà Mau, Cà Mau": [
    "phường 1, cà mau, cà mau",
    "phuwowfng 1, caf mau, caf mau"
  ],
  "Phường 1, Tân An, Long An": [
    "phường 1, tân an, long an",
    "phuwowfng 1, taan an, long an"
  ],
  "Phường 2, Cà Mau, Cà Mau": [
    "phường 2, cà mau, cà mau",
    "phuwowfng 2, caf mau, caf mau"
  ],
  "Phường 2, Tân An, Long An": [
    "phường 2, tân an, long an",
    "phuwowfng 2, taan an, long an"
  ],
  "Phường 3, Tân An, Long An": [
    "phường 3, tân an, long an",
    "phuwowfng 3, taan an, long an"
  ],
  "Phường 4, Cà Mau, Cà Mau": [
    "phường 4, cà mau, cà mau",
    "phuwowfng 4, caf mau, caf mau"
  ],
  "Phường 4, Tân An, Long An": [
    "phường 4, tân an, long an",
    "phuwowfng 4, taan an, long an"
  ],
  "Phường 5, Cà Mau, Cà Mau": [
    "phường 5, cà mau, cà mau",
    "phuwowfng 5, caf mau, caf mau"
  ],
  "Phường 5, Tân An, Long An": [
    "phường 5, tân an, long an",
    "phuwowfng 5, taan an, long an"
  ],
  "Phường 6, Cà Mau, Cà Mau": [
    "phường 6, cà mau, cà mau",
    "phuwowfng 6, caf mau, caf mau"
  ],
  "Phường 6, Tân An, Long An": [
    "phường 6, tân an, long an",
    "phuwowfng 6, taan an, long an"
  ],
  "Phường 7, Cà Mau, Cà Mau": [
    "phường 7, cà mau, cà mau",
    "phuwowfng 7, caf mau, caf mau"
  ],
  "Phường 7, Tân An, Long An": [
    "phường 7, tân an, long an",
    "phuwowfng 7, taan an, long an"
  ],
  "Phường 8, Cà Mau, Cà Mau": [
    "phường 8, cà mau, cà mau",
    "phuwowfng 8, caf mau, caf mau"
  ],
  "Phường 9, Cà Mau, Cà Mau": [
    "phường 9, cà mau, cà mau",
    "phuwowfng 9, caf mau, caf mau"
  ],
  "Pú Pẩu, Sông Mã, Sơn La": [
    "pú pẩu, sông mã, sơn la",
    "pus paaru, soong max, sown la"
  ],
  "Quang Huy, Phù Yên, Sơn La": [
    "quang huy, phù yên, sơn la",
    "quang huy, phuf yeen, sown la"
  ],
  "Quang Trung, Kon Tum, Kon Tum": [
    "quang trung, kon tum, kon tum",
    "quang trung, kon tum, kon tum"
  ],
  "Sa Nghĩa, Sa Thầy, Kon Tum": [
    "sa nghĩa, sa thầy, kon tum",
    "sa nghixa, sa thaafy, kon tum"
  ],
  "Sa Thầy, Sa Thầy, Kon Tum": [
    "sa thầy, sa thầy, kon tum",
    "sa thaafy, sa thaafy, kon tum"
  ],
  "Sam Kha, Sốp Cộp, Sơn La": [
    "sam kha, sốp cộp, sơn la",
    "sam kha, soosp coojp, sown la"
  ],
  "Sông Mã, Sông Mã, Sơn La": [
    "sông mã, sông mã, sơn la",
    "soong max, soong max, sown la"
  ],
  "Tam Giang, Năm Căn, Cà Mau": [
    "tam giang, năm căn, cà mau",
    "tam giang, nawm cawn, caf mau"
  ],
  "Tam Sơn, Anh Sơn, Nghệ An": [
    "tam sơn, anh sơn, nghệ an",
    "tam sown, anh sown, ngheej an"
  ],
  "Thi Sơn, Kim Bảng, Hà Nam": [
    "thi sơn, kim bảng, hà nam",
    "thi sown, kim barng, haf nam"
  ],
  "Thái Hòa, Ba Vì, Hà Nội": [
    "thái hòa, ba vì, hà nội",
    "thasi hofa, ba vif, haf nooji"
  ],
  "Trung Chải, Sa Pa, Lào Cai": [
    "trung chải, sa pa, lào cai",
    "trung chari, sa pa, lafo cai"
  ],
  "Trà Cú, Trà Cú, Trà Vinh": [
    "trà cú, trà cú, trà vinh",
    "traf cus, traf cus, traf vinh"
  ],
  "Tà Lai, Mộc Châu, Sơn La": [
    "tà lai, mộc châu, sơn la",
    "taf lai, moojc chaau, sown la"
  ],
  "Tà Xùa, Bắc Yên, Sơn La": [
    "tà xùa, bắc yên, sơn la",
    "taf xufa, bawsc yeen, sown la"
  ],
  "Tân An, La Gi, Bình Thuận": [
    "tân an, la gi, bình thuận",
    "taan an, la gi, bifnh thuaajn"
  ],
  "Tân An, Tân Châu, An Giang": [
    "tân an, tân châu, an giang",
    "taan an, taan chaau, an giang"
  ],
  "Tân An, Tân Kỳ, Nghệ An": [
    "tân an, tân kỳ, nghệ an",
    "taan an, taan kyf, ngheej an"
  ],
  "Tân Hưng, Ba Tri, Bến Tre": [
    "tân hưng, ba tri, bến tre",
    "taan huwng, ba tri, beesn tre"
  ],
  "Tân Khánh, Tân An, Long An": [
    "tân khánh, tân an, long an",
    "taan khasnh, taan an, long an"
  ],
  "Tân Lang, Phù Yên, Sơn La": [
    "tân lang, phù yên, sơn la",
    "taan lang, phuf yeen, sown la"
  ],
  "Tân Thành, Cà Mau, Cà Mau": [
    "tân thành, cà mau, cà mau",
    "taan thafnh, caf mau, caf mau"
  ],
  "Tân Xuyên, Cà Mau, Cà Mau": [
    "tân xuyên, cà mau, cà mau",
    "taan xuyeen, caf mau, caf mau"
  ],
  "Tân Xuân, Ba Tri, Bến Tre": [
    "tân xuân, ba tri, bến tre",
    "taan xuaan, ba tri, beesn tre"
  ],
  "Tú Nang, Yên Châu, Sơn La": [
    "tú nang, yên châu, sơn la",
    "tus nang, yeen chaau, sown la"
  ],
  "Vân Hồ, Vân Hồ, Sơn La": [
    "vân hồ, vân hồ, sơn la",
    "vaan hoof, vaan hoof, sown la"
  ],
  "Võ Lao, Thanh Ba, Phú Thọ": [
    "võ lao, thanh ba, phú thọ",
    "vox lao, thanh ba, phus thoj"
  ],
  "Văn Lem, Đắk Tô, Kon Tum": [
    "văn lem, đắk tô, kon tum",
    "vawn lem, ddawsk too, kon tum"
  ],
  "Văn Vũ, Na Rì, Bắc Kạn": [
    "văn vũ, na rì, bắc kạn",
    "vawn vux, na rif, bawsc kajn"
  ],
  "Văn Xá, Kim Bảng, Hà Nam": [
    "văn xá, kim bảng, hà nam",
    "vawn xas, kim barng, haf nam"
  ],
  "Vĩnh Gia, Tri Tôn, An Giang": [
    "vĩnh gia, tri tôn, an giang",
    "vixnh gia, tri toon, an giang"
  ],
  "Vĩnh Hòa, Ba Tri, Bến Tre": [
    "vĩnh hòa, ba tri, bến tre",
    "vixnh hofa, ba tri, beesn tre"
  ],
  "Xuân Nha, Vân Hồ, Sơn La": [
    "xuân nha, vân hồ, sơn la",
    "xuaan nha, vaan hoof, sown la"
  ],
  "Y Can, Trấn Yên, Yên Bái": [
    "y can, trấn yên, yên bái",
    "y can, traasn yeen, yeen basi"
  ],
  "Yang Nam, Kông Chro, Gia Lai": [
    "yang nam, kông chro, gia lai",
    "yang nam, koong chro, gia lai"
  ],
  "Yang Tao, Lắk, Đắk Lắk": [
    "yang tao, lắk, đắk lắk",
    "yang tao, lawsk, ddawsk lawsk"
  ],
  "Ít Ong, Mường La, Sơn La": [
    "ít ong, mường la, sơn la",
    "ist ong, muwowfng la, sown la"
  ],
  "Ô Quý Hồ, Sa Pa, Lào Cai": [
    "ô quý hồ, sa pa, lào cai",
    "oo quys hoof, sa pa, lafo cai"
  ],
  "Đinh Xá, Phủ Lý, Hà Nam": [
    "đinh xá, phủ lý, hà nam",
    "ddinh xas, phur lys, haf nam"
  ],
  "Đông Vĩnh, Vinh, Nghệ An": [
    "đông vĩnh, vinh, nghệ an",
    "ddoong vixnh, vinh, ngheej an"
  ],
  "Đăk Năng, Kon Tum, Kon Tum": [
    "đăk năng, kon tum, kon tum",
    "ddawk nawng, kon tum, kon tum"
  ],
  "Đăk Yă, Mang Yang, Gia Lai": [
    "đăk yă, mang yang, gia lai",
    "ddawk yaw, mang yang, gia lai"
  ],
  "Đắk Blà, Kon Tum, Kon Tum": [
    "đắk blà, kon tum, kon tum",
    "ddawsk blaf, kon tum, kon tum"
  ],
  "A Xan, Tây Giang, Quảng Nam": [
    "a xan, tây giang, quảng nam",
    "a xan, taay giang, quarng nam"
  ],
  "An Bình, Văn Yên, Yên Bái": [
    "an bình, văn yên, yên bái",
    "an bifnh, vawn yeen, yeen basi"
  ],
  "An Cư, Cái Bè, Tiền Giang": [
    "an cư, cái bè, tiền giang",
    "an cuw, casi bef, tieefn giang"
  ],
  "An Cư, Tịnh Biên, An Giang": [
    "an cư, tịnh biên, an giang",
    "an cuw, tijnh bieen, an giang"
  ],
  "An Hội, Bến Tre, Bến Tre": [
    "an hội, bến tre, bến tre",
    "an hooji, beesn tre, beesn tre"
  ],
  "An Lão, An Lão, Hải Phòng": [
    "an lão, an lão, hải phòng",
    "an laxo, an laxo, hari phofng"
  ],
  "An Mỹ, Tam Kỳ, Quảng Nam": [
    "an mỹ, tam kỳ, quảng nam",
    "an myx, tam kyf, quarng nam"
  ],
  "An Nghiệp, Tuy An, Phú Yên": [
    "an nghiệp, tuy an, phú yên",
    "an nghieejp, tuy an, phus yeen"
  ],
  "An Nội, Bình Lục, Hà Nam": [
    "an nội, bình lục, hà nam",
    "an nooji, bifnh lujc, haf nam"
  ],
  "An Phú, Lục Yên, Yên Bái": [
    "an phú, lục yên, yên bái",
    "an phus, lujc yeen, yeen basi"
  ],
  "An Phú, Tam Kỳ, Quảng Nam": [
    "an phú, tam kỳ, quảng nam",
    "an phus, tam kyf, quarng nam"
  ],
  "An Sơn, Tam Kỳ, Quảng Nam": [
    "an sơn, tam kỳ, quảng nam",
    "an sown, tam kyf, quarng nam"
  ],
  "An Đổ, Bình Lục, Hà Nam": [
    "an đổ, bình lục, hà nam",
    "an ddoor, bifnh lujc, haf nam"
  ],
  "Ba Cung, Ba Tơ, Quảng Ngãi": [
    "ba cung, ba tơ, quảng ngãi",
    "ba cung, ba tow, quarng ngaxi"
  ],
  "Ba Dinh, Ba Tơ, Quảng Ngãi": [
    "ba dinh, ba tơ, quảng ngãi",
    "ba dinh, ba tow, quarng ngaxi"
  ],
  "Ba Lế, Ba Tơ, Quảng Ngãi": [
    "ba lế, ba tơ, quảng ngãi",
    "ba lees, ba tow, quarng ngaxi"
  ],
  "Ba Vinh, Ba Tơ, Quảng Ngãi": [
    "ba vinh, ba tơ, quảng ngãi",
    "ba vinh, ba tow, quarng ngaxi"
  ],
  "Bát Xát, Bát Xát, Lào Cai": [
    "bát xát, bát xát, lào cai",
    "bast xast, bast xast, lafo cai"
  ],
  "Bình An, Lộc Hà, Hà Tĩnh": [
    "bình an, lộc hà, hà tĩnh",
    "bifnh an, loojc haf, haf tixnh"
  ],
  "Bình Minh, Lào Cai, Lào Cai": [
    "bình minh, lào cai, lào cai",
    "bifnh minh, lafo cai, lafo cai"
  ],
  "Bản Qua, Bát Xát, Lào Cai": [
    "bản qua, bát xát, lào cai",
    "barn qua, bast xast, lafo cai"
  ],
  "Bắc Hà, Bắc Hà, Lào Cai": [
    "bắc hà, bắc hà, lào cai",
    "bawsc haf, bawsc haf, lafo cai"
  ],
  "Bờ Ngoong, Chư Sê, Gia Lai": [
    "bờ ngoong, chư sê, gia lai",
    "bowf ngoong, chuw see, gia lai"
  ],
  "Cao Xá, Lâm Thao, Phú Thọ": [
    "cao xá, lâm thao, phú thọ",
    "cao xas, laam thao, phus thoj"
  ],
  "Chim Vàn, Bắc Yên, Sơn La": [
    "chim vàn, bắc yên, sơn la",
    "chim vafn, bawsc yeen, sown la"
  ],
  "Chiềng Ve, Mai Sơn, Sơn La": [
    "chiềng ve, mai sơn, sơn la",
    "chieefng ve, mai sown, sown la"
  ],
  "Châu Sơn, Phủ Lý, Hà Nam": [
    "châu sơn, phủ lý, hà nam",
    "chaau sown, phur lys, haf nam"
  ],
  "Chính Lý, Lý Nhân, Hà Nam": [
    "chính lý, lý nhân, hà nam",
    "chisnh lys, lys nhaan, haf nam"
  ],
  "Chơ Long, Kông Chro, Gia Lai": [
    "chơ long, kông chro, gia lai",
    "chow long, koong chro, gia lai"
  ],
  "Chư Rcăm, Krông Pa, Gia Lai": [
    "chư rcăm, krông pa, gia lai",
    "chuw rcawm, kroong pa, gia lai"
  ],
  "Cà Dy, Nam Giang, Quảng Nam": [
    "cà dy, nam giang, quảng nam",
    "caf dy, nam giang, quarng nam"
  ],
  "Cà Lúi, Sơn Hòa, Phú Yên": [
    "cà lúi, sơn hòa, phú yên",
    "caf lusi, sown hofa, phus yeen"
  ],
  "Cô Tô, Cô Tô, Quảng Ninh": [
    "cô tô, cô tô, quảng ninh",
    "coo too, coo too, quarng ninh"
  ],
  "Côn Minh, Na Rì, Bắc Kạn": [
    "côn minh, na rì, bắc kạn",
    "coon minh, na rif, bawsc kajn"
  ],
  "Cư Huê, Ea Kar, Đắk Lắk": [
    "cư huê, ea kar, đắk lắk",
    "cuw huee, ea kar, ddawsk lawsk"
  ],
  "Cư Jang, Ea Kar, Đắk Lắk": [
    "cư jang, ea kar, đắk lắk",
    "cuw jang, ea kar, ddawsk lawsk"
  ],
  "Cẩm Lĩnh, Ba Vì, Hà Nội": [
    "cẩm lĩnh, ba vì, hà nội",
    "caarm lixnh, ba vif, haf nooji"
  ],
  "Di Linh, Di Linh, Lâm Đồng": [
    "di linh, di linh, lâm đồng",
    "di linh, di linh, laam ddoofng"
  ],
  "Ea Bung, Ea Súp, Đắk Lắk": [
    "ea bung, ea súp, đắk lắk",
    "ea bung, ea susp, ddawsk lawsk"
  ],
  "Ea Kmút, Ea Kar, Đắk Lắk": [
    "ea kmút, ea kar, đắk lắk",
    "ea kmust, ea kar, ddawsk lawsk"
  ],
  "Ea Lâm, Sông Hinh, Phú Yên": [
    "ea lâm, sông hinh, phú yên",
    "ea laam, soong hinh, phus yeen"
  ],
  "Ea Nam, Ea H'leo, Đắk Lắk": [
    "ea nam, ea h'leo, đắk lắk",
    "ea nam, ea h'leo, ddawsk lawsk"
  ],
  "Ea Pô, Cư Jút, Đắk Nông": [
    "ea pô, cư jút, đắk nông",
    "ea poo, cuw just, ddawsk noong"
  ],
  "Ea Ral, Ea H'leo, Đắk Lắk": [
    "ea ral, ea h'leo, đắk lắk",
    "ea ral, ea h'leo, ddawsk lawsk"
  ],
  "Ea Sol, Ea H'leo, Đắk Lắk": [
    "ea sol, ea h'leo, đắk lắk",
    "ea sol, ea h'leo, ddawsk lawsk"
  ],
  "Ea Súp, Ea Súp, Đắk Lắk": [
    "ea súp, ea súp, đắk lắk",
    "ea susp, ea susp, ddawsk lawsk"
  ],
  "Ea Tir, Ea H'leo, Đắk Lắk": [
    "ea tir, ea h'leo, đắk lắk",
    "ea tir, ea h'leo, ddawsk lawsk"
  ],
  "Ga Ri, Tây Giang, Quảng Nam": [
    "ga ri, tây giang, quảng nam",
    "ga ri, taay giang, quarng nam"
  ],
  "Gia Hanh, Can Lộc, Hà Tĩnh": [
    "gia hanh, can lộc, hà tĩnh",
    "gia hanh, can loojc, haf tixnh"
  ],
  "Gia Lâm, Nho Quan, Ninh Bình": [
    "gia lâm, nho quan, ninh bình",
    "gia laam, nho quan, ninh bifnh"
  ],
  "Gia Sơn, Nho Quan, Ninh Bình": [
    "gia sơn, nho quan, ninh bình",
    "gia sown, nho quan, ninh bifnh"
  ],
  "Hang Chú, Bắc Yên, Sơn La": [
    "hang chú, bắc yên, sơn la",
    "hang chus, bawsc yeen, sown la"
  ],
  "Hanh Cù, Thanh Ba, Phú Thọ": [
    "hanh cù, thanh ba, phú thọ",
    "hanh cuf, thanh ba, phus thoj"
  ],
  "Hua Nhàn, Bắc Yên, Sơn La": [
    "hua nhàn, bắc yên, sơn la",
    "hua nhafn, bawsc yeen, sown la"
  ],
  "Hua Nà, Than Uyên, Lai Châu": [
    "hua nà, than uyên, lai châu",
    "hua naf, than uyeen, lai chaau"
  ],
  "Hua Trai, Mường La, Sơn La": [
    "hua trai, mường la, sơn la",
    "hua trai, muwowfng la, sown la"
  ],
  "Hà Bầu, Đăk Đoa, Gia Lai": [
    "hà bầu, đăk đoa, gia lai",
    "haf baafu, ddawk ddoa, gia lai"
  ],
  "Hà Huy Tập, Vinh, Nghệ An": [
    "hà huy tập, vinh, nghệ an",
    "haf huy taajp, vinh, ngheej an"
  ],
  "Hà Lai, Hà Trung, Thanh Hóa": [
    "hà lai, hà trung, thanh hóa",
    "haf lai, haf trung, thanh hosa"
  ],
  "Hàm Tân, Trà Cú, Trà Vinh": [
    "hàm tân, trà cú, trà vinh",
    "hafm taan, traf cus, traf vinh"
  ],
  "Hòa An, Chợ Mới, An Giang": [
    "hòa an, chợ mới, an giang",
    "hofa an, chowj mowsi, an giang"
  ],
  "Hòa Hậu, Lý Nhân, Hà Nam": [
    "hòa hậu, lý nhân, hà nam",
    "hofa haaju, lys nhaan, haf nam"
  ],
  "Hòa Mạc, Duy Tiên, Hà Nam": [
    "hòa mạc, duy tiên, hà nam",
    "hofa majc, duy tieen, haf nam"
  ],
  "Hòa Ân, Cầu Kè, Trà Vinh": [
    "hòa ân, cầu kè, trà vinh",
    "hofa aan, caafu kef, traf vinh"
  ],
  "Hưng Hà, Tân Hưng, Long An": [
    "hưng hà, tân hưng, long an",
    "huwng haf, taan huwng, long an"
  ],
  "Hạ Lễ, Ân Thi, Hưng Yên": [
    "hạ lễ, ân thi, hưng yên",
    "haj leex, aan thi, huwng yeen"
  ],
  "Ia Băng, Chư Prông, Gia Lai": [
    "ia băng, chư prông, gia lai",
    "ia bawng, chuw proong, gia lai"
  ],
  "Ia Hiao, Phú Thiện, Gia Lai": [
    "ia hiao, phú thiện, gia lai",
    "ia hiao, phus thieejn, gia lai"
  ],
  "Ia Khươl, Chư Păh, Gia Lai": [
    "ia khươl, chư păh, gia lai",
    "ia khuwowl, chuw pawh, gia lai"
  ],
  "Ia Peng, Phú Thiện, Gia Lai": [
    "ia peng, phú thiện, gia lai",
    "ia peng, phus thieejn, gia lai"
  ],
  "Ia Phìn, Chư Prông, Gia Lai": [
    "ia phìn, chư prông, gia lai",
    "ia phifn, chuw proong, gia lai"
  ],
  "Ia Piar, Phú Thiện, Gia Lai": [
    "ia piar, phú thiện, gia lai",
    "ia piar, phus thieejn, gia lai"
  ],
  "Ia Piơr, Chư Prông, Gia Lai": [
    "ia piơr, chư prông, gia lai",
    "ia piowr, chuw proong, gia lai"
  ],
  "Ia Púch, Chư Prông, Gia Lai": [
    "ia púch, chư prông, gia lai",
    "ia pusch, chuw proong, gia lai"
  ],
  "Ia RSươm, Krông Pa, Gia Lai": [
    "ia rsươm, krông pa, gia lai",
    "ia rsuwowm, kroong pa, gia lai"
  ],
  "Ia RVê, Ea Súp, Đắk Lắk": [
    "ia rvê, ea súp, đắk lắk",
    "ia rvee, ea susp, ddawsk lawsk"
  ],
  "Ia Yeng, Phú Thiện, Gia Lai": [
    "ia yeng, phú thiện, gia lai",
    "ia yeng, phus thieejn, gia lai"
  ],
  "Keng Đu, Kỳ Sơn, Nghệ An": [
    "keng đu, kỳ sơn, nghệ an",
    "keng ddu, kyf sown, ngheej an"
  ],
  "Khai Sơn, Anh Sơn, Nghệ An": [
    "khai sơn, anh sơn, nghệ an",
    "khai sown, anh sown, ngheej an"
  ],
  "Khánh Hậu, Tân An, Long An": [
    "khánh hậu, tân an, long an",
    "khasnh haaju, taan an, long an"
  ],
  "Khánh Tiến, U Minh, Cà Mau": [
    "khánh tiến, u minh, cà mau",
    "khasnh tieesn, u minh, caf mau"
  ],
  "Kim Bài, Thanh Oai, Hà Nội": [
    "kim bài, thanh oai, hà nội",
    "kim bafi, thanh oai, haf nooji"
  ],
  "Kim Bôi, Kim Bôi, Hoà Bình": [
    "kim bôi, kim bôi, hoà bình",
    "kim booi, kim booi, hoaf bifnh"
  ],
  "Kim Mỹ, Kim Sơn, Ninh Bình": [
    "kim mỹ, kim sơn, ninh bình",
    "kim myx, kim sown, ninh bifnh"
  ],
  "Kim Sơn, Bảo Yên, Lào Cai": [
    "kim sơn, bảo yên, lào cai",
    "kim sown, baro yeen, lafo cai"
  ],
  "Kim Sơn, Sơn Tây, Hà Nội": [
    "kim sơn, sơn tây, hà nội",
    "kim sown, sown taay, haf nooji"
  ],
  "Kim Thư, Thanh Oai, Hà Nội": [
    "kim thư, thanh oai, hà nội",
    "kim thuw, thanh oai, haf nooji"
  ],
  "Kim Tân, Kim Sơn, Ninh Bình": [
    "kim tân, kim sơn, ninh bình",
    "kim taan, kim sown, ninh bifnh"
  ],
  "Kon Thụp, Mang Yang, Gia Lai": [
    "kon thụp, mang yang, gia lai",
    "kon thujp, mang yang, gia lai"
  ],
  "Kon Đào, Đắk Tô, Kon Tum": [
    "kon đào, đắk tô, kon tum",
    "kon ddafo, ddawsk too, kon tum"
  ],
  "Kỳ Long, Kỳ Anh, Hà Tĩnh": [
    "kỳ long, kỳ anh, hà tĩnh",
    "kyf long, kyf anh, haf tixnh"
  ],
  "Kỳ Ninh, Kỳ Anh, Hà Tĩnh": [
    "kỳ ninh, kỳ anh, hà tĩnh",
    "kyf ninh, kyf anh, haf tixnh"
  ],
  "Kỳ Phú, Kỳ Anh, Hà Tĩnh": [
    "kỳ phú, kỳ anh, hà tĩnh",
    "kyf phus, kyf anh, haf tixnh"
  ],
  "Kỳ Sơn, Kỳ Anh, Hà Tĩnh": [
    "kỳ sơn, kỳ anh, hà tĩnh",
    "kyf sown, kyf anh, haf tixnh"
  ],
  "Kỳ Thư, Kỳ Anh, Hà Tĩnh": [
    "kỳ thư, kỳ anh, hà tĩnh",
    "kyf thuw, kyf anh, haf tixnh"
  ],
  "Kỳ Tân, Kỳ Anh, Hà Tĩnh": [
    "kỳ tân, kỳ anh, hà tĩnh",
    "kyf taan, kyf anh, haf tixnh"
  ],
  "Kỳ Tây, Kỳ Anh, Hà Tĩnh": [
    "kỳ tây, kỳ anh, hà tĩnh",
    "kyf taay, kyf anh, haf tixnh"
  ],
  "Kỳ Văn, Kỳ Anh, Hà Tĩnh": [
    "kỳ văn, kỳ anh, hà tĩnh",
    "kyf vawn, kyf anh, haf tixnh"
  ],
  "La Khê, Hà Đông, Hà Nội": [
    "la khê, hà đông, hà nội",
    "la khee, haf ddoong, haf nooji"
  ],
  "Laêê, Nam Giang, Quảng Nam": [
    "laêê, nam giang, quảng nam",
    "laeeee, nam giang, quarng nam"
  ],
  "Liên Hoà, Vân Hồ, Sơn La": [
    "liên hoà, vân hồ, sơn la",
    "lieen hoaf, vaan hoof, sown la"
  ],
  "Long An, Long Hồ, Vĩnh Long": [
    "long an, long hồ, vĩnh long",
    "long an, long hoof, vixnh long"
  ],
  "Long Hoà, Phú Tân, An Giang": [
    "long hoà, phú tân, an giang",
    "long hoaf, phus taan, an giang"
  ],
  "Long Sơn, Anh Sơn, Nghệ An": [
    "long sơn, anh sơn, nghệ an",
    "long sown, anh sown, ngheej an"
  ],
  "Lâm Hải, Năm Căn, Cà Mau": [
    "lâm hải, năm căn, cà mau",
    "laam hari, nawm cawn, caf mau"
  ],
  "Lê Chung, Hoà An, Cao Bằng": [
    "lê chung, hoà an, cao bằng",
    "lee chung, hoaf an, cao bawfng"
  ],
  "Lăng, Tây Giang, Quảng Nam": [
    "lăng, tây giang, quảng nam",
    "lawng, taay giang, quarng nam"
  ],
  "Mai Sơn, Yên Mô, Ninh Bình": [
    "mai sơn, yên mô, ninh bình",
    "mai sown, yeen moo, ninh bifnh"
  ],
  "Minh An, Hội An, Quảng Nam": [
    "minh an, hội an, quảng nam",
    "minh an, hooji an, quarng nam"
  ],
  "Măng Buk, Kon Plông, Kon Tum": [
    "măng buk, kon plông, kon tum",
    "mawng buk, kon ploong, kon tum"
  ],
  "Mỹ An, Chợ Mới, An Giang": [
    "mỹ an, chợ mới, an giang",
    "myx an, chowj mowsi, an giang"
  ],
  "Mỹ An, Thủ Thừa, Long An": [
    "mỹ an, thủ thừa, long an",
    "myx an, thur thuwfa, long an"
  ],
  "Mỹ Chánh, Ba Tri, Bến Tre": [
    "mỹ chánh, ba tri, bến tre",
    "myx chasnh, ba tri, beesn tre"
  ],
  "Mỹ Lý, Kỳ Sơn, Nghệ An": [
    "mỹ lý, kỳ sơn, nghệ an",
    "myx lys, kyf sown, ngheej an"
  ],
  "Na Hang, Na Hang, Tuyên Quang": [
    "na hang, na hang, tuyên quang",
    "na hang, na hang, tuyeen quang"
  ],
  "Na Mèo, Quan Sơn, Thanh Hóa": [
    "na mèo, quan sơn, thanh hóa",
    "na mefo, quan sown, thanh hosa"
  ],
  "Nam Cát, Nam Đàn, Nghệ An": [
    "nam cát, nam đàn, nghệ an",
    "nam cast, nam ddafn, ngheej an"
  ],
  "Nam Sơn, Sóc Sơn, Hà Nội": [
    "nam sơn, sóc sơn, hà nội",
    "nam sown, sosc sown, haf nooji"
  ],
  "Nga Phú, Nga Sơn, Thanh Hóa": [
    "nga phú, nga sơn, thanh hóa",
    "nga phus, nga sown, thanh hosa"
  ],
  "Nga Sơn, Nga Sơn, Thanh Hóa": [
    "nga sơn, nga sơn, thanh hóa",
    "nga sown, nga sown, thanh hosa"
  ],
  "Nga Tân, Nga Sơn, Thanh Hóa": [
    "nga tân, nga sơn, thanh hóa",
    "nga taan, nga sown, thanh hosa"
  ],
  "Nga Văn, Nga Sơn, Thanh Hóa": [
    "nga văn, nga sơn, thanh hóa",
    "nga vawn, nga sown, thanh hosa"
  ],
  "Nga Yên, Nga Sơn, Thanh Hóa": [
    "nga yên, nga sơn, thanh hóa",
    "nga yeen, nga sown, thanh hosa"
  ],
  "Nghi Thu, Cửa Lò, Nghệ An": [
    "nghi thu, cửa lò, nghệ an",
    "nghi thu, cuwra lof, ngheej an"
  ],
  "Ngok Réo, Đắk Hà, Kon Tum": [
    "ngok réo, đắk hà, kon tum",
    "ngok reso, ddawsk haf, kon tum"
  ],
  "Ngok Wang, Đắk Hà, Kon Tum": [
    "ngok wang, đắk hà, kon tum",
    "ngok wang, ddawsk haf, kon tum"
  ],
  "Ngũ Lão, Hoà An, Cao Bằng": [
    "ngũ lão, hoà an, cao bằng",
    "ngux laxo, hoaf an, cao bawfng"
  ],
  "Nho Quan, Nho Quan, Ninh Bình": [
    "nho quan, nho quan, ninh bình",
    "nho quan, nho quan, ninh bifnh"
  ],
  "Nhân Mỹ, Lý Nhân, Hà Nam": [
    "nhân mỹ, lý nhân, hà nam",
    "nhaan myx, lys nhaan, haf nam"
  ],
  "Nhơn Hoà, Chư Pưh, Gia Lai": [
    "nhơn hoà, chư pưh, gia lai",
    "nhown hoaf, chuw puwh, gia lai"
  ],
  "Nhơn Hội, An Phú, An Giang": [
    "nhơn hội, an phú, an giang",
    "nhown hooji, an phus, an giang"
  ],
  "Ninh Hòa, Hoa Lư, Ninh Bình": [
    "ninh hòa, hoa lư, ninh bình",
    "ninh hofa, hoa luw, ninh bifnh"
  ],
  "Ninh Mỹ, Hoa Lư, Ninh Bình": [
    "ninh mỹ, hoa lư, ninh bình",
    "ninh myx, hoa luw, ninh bifnh"
  ],
  "Ninh Vân, Hoa Lư, Ninh Bình": [
    "ninh vân, hoa lư, ninh bình",
    "ninh vaan, hoa luw, ninh bifnh"
  ],
  "Nàn Ma, Xín Mần, Hà Giang": [
    "nàn ma, xín mần, hà giang",
    "nafn ma, xisn maafn, haf giang"
  ],
  "Nàn Sán, Si Ma Cai, Lào Cai": [
    "nàn sán, si ma cai, lào cai",
    "nafn sasn, si ma cai, lafo cai"
  ],
  "Nàn Xín, Si Ma Cai, Lào Cai": [
    "nàn xín, si ma cai, lào cai",
    "nafn xisn, si ma cai, lafo cai"
  ],
  "Nưa, Triệu Sơn, Thanh Hóa": [
    "nưa, triệu sơn, thanh hóa",
    "nuwa, trieeju sown, thanh hosa"
  ],
  "Nậm Tha, Văn Bàn, Lào Cai": [
    "nậm tha, văn bàn, lào cai",
    "naajm tha, vawn bafn, lafo cai"
  ],
  "Nậm Xé, Văn Bàn, Lào Cai": [
    "nậm xé, văn bàn, lào cai",
    "naajm xes, vawn bafn, lafo cai"
  ],
  "Pa Khoá, Sìn Hồ, Lai Châu": [
    "pa khoá, sìn hồ, lai châu",
    "pa khoas, sifn hoof, lai chaau"
  ],
  "Pa Tần, Sìn Hồ, Lai Châu": [
    "pa tần, sìn hồ, lai châu",
    "pa taafn, sifn hoof, lai chaau"
  ],
  "Phan Si Păng, Sa Pa, Lào Cai": [
    "phan si păng, sa pa, lào cai",
    "phan si pawng, sa pa, lafo cai"
  ],
  "Phú Cần, Krông Pa, Gia Lai": [
    "phú cần, krông pa, gia lai",
    "phus caafn, kroong pa, gia lai"
  ],
  "Phú La, Hà Đông, Hà Nội": [
    "phú la, hà đông, hà nội",
    "phus la, haf ddoong, haf nooji"
  ],
  "Phú Long, Phú Tân, An Giang": [
    "phú long, phú tân, an giang",
    "phus long, phus taan, an giang"
  ],
  "Phú Lâm, Phú Tân, An Giang": [
    "phú lâm, phú tân, an giang",
    "phus laam, phus taan, an giang"
  ],
  "Phú Lâm, Tuy Hoà, Phú Yên": [
    "phú lâm, tuy hoà, phú yên",
    "phus laam, tuy hoaf, phus yeen"
  ],
  "Phú Mỹ, Phú Tân, An Giang": [
    "phú mỹ, phú tân, an giang",
    "phus myx, phus taan, an giang"
  ],
  "Phú Nam, Bắc Mê, Hà Giang": [
    "phú nam, bắc mê, hà giang",
    "phus nam, bawsc mee, haf giang"
  ],
  "Phú Phúc, Lý Nhân, Hà Nam": [
    "phú phúc, lý nhân, hà nam",
    "phus phusc, lys nhaan, haf nam"
  ],
  "Phú Đông, Ba Vì, Hà Nội": [
    "phú đông, ba vì, hà nội",
    "phus ddoong, ba vif, haf nooji"
  ],
  "Pi Toong, Mường La, Sơn La": [
    "pi toong, mường la, sơn la",
    "pi toong, muwowfng la, sown la"
  ],
  "Pà Cò, Mai Châu, Hoà Bình": [
    "pà cò, mai châu, hoà bình",
    "paf cof, mai chaau, hoaf bifnh"
  ],
  "Pả Vi, Mèo Vạc, Hà Giang": [
    "pả vi, mèo vạc, hà giang",
    "par vi, mefo vajc, haf giang"
  ],
  "Quang Kim, Bát Xát, Lào Cai": [
    "quang kim, bát xát, lào cai",
    "quang kim, bast xast, lafo cai"
  ],
  "Quang Minh, Vân Hồ, Sơn La": [
    "quang minh, vân hồ, sơn la",
    "quang minh, vaan hoof, sown la"
  ],
  "Quyết Tâm, Sơn La, Sơn La": [
    "quyết tâm, sơn la, sơn la",
    "quyeest taam, sown la, sown la"
  ],
  "Si Ma Cai, Si Ma Cai, Lào Cai": [
    "si ma cai, si ma cai, lào cai",
    "si ma cai, si ma cai, lafo cai"
  ],
  "Song An, Vũ Thư, Thái Bình": [
    "song an, vũ thư, thái bình",
    "song an, vux thuw, thasi bifnh"
  ],
  "Suối Bau, Phù Yên, Sơn La": [
    "suối bau, phù yên, sơn la",
    "suoosi bau, phuf yeen, sown la"
  ],
  "Sơn A, Nghĩa Lộ, Yên Bái": [
    "sơn a, nghĩa lộ, yên bái",
    "sown a, nghixa looj, yeen basi"
  ],
  "Sơn Hà, Nho Quan, Ninh Bình": [
    "sơn hà, nho quan, ninh bình",
    "sown haf, nho quan, ninh bifnh"
  ],
  "Sơn Hà, Sơn Hòa, Phú Yên": [
    "sơn hà, sơn hòa, phú yên",
    "sown haf, sown hofa, phus yeen"
  ],
  "Sơn Lai, Nho Quan, Ninh Bình": [
    "sơn lai, nho quan, ninh bình",
    "sown lai, nho quan, ninh bifnh"
  ],
  "Sơn Vi, Lâm Thao, Phú Thọ": [
    "sơn vi, lâm thao, phú thọ",
    "sown vi, laam thao, phus thoj"
  ],
  "Tam An, Phú Ninh, Quảng Nam": [
    "tam an, phú ninh, quảng nam",
    "tam an, phus ninh, quarng nam"
  ],
  "Tam Lư, Quan Sơn, Thanh Hóa": [
    "tam lư, quan sơn, thanh hóa",
    "tam luw, quan sown, thanh hosa"
  ],
  "Tam Đa, Phù Cừ, Hưng Yên": [
    "tam đa, phù cừ, hưng yên",
    "tam dda, phuf cuwf, huwng yeen"
  ],
  "Thanh Ba, Thanh Ba, Phú Thọ": [
    "thanh ba, thanh ba, phú thọ",
    "thanh ba, thanh ba, phus thoj"
  ],
  "Thu Tà, Xín Mần, Hà Giang": [
    "thu tà, xín mần, hà giang",
    "thu taf, xisn maafn, haf giang"
  ],
  "Thắng Lợi, Pleiku, Gia Lai": [
    "thắng lợi, pleiku, gia lai",
    "thawsng lowji, pleiku, gia lai"
  ],
  "Thới An, Ô Môn, Cần Thơ": [
    "thới an, ô môn, cần thơ",
    "thowsi an, oo moon, caafn thow"
  ],
  "Tiên Phong, Ba Vì, Hà Nội": [
    "tiên phong, ba vì, hà nội",
    "tieen phong, ba vif, haf nooji"
  ],
  "Tiên Sơn, Duy Tiên, Hà Nam": [
    "tiên sơn, duy tiên, hà nam",
    "tieen sown, duy tieen, haf nam"
  ],
  "Tiên Tân, Phủ Lý, Hà Nam": [
    "tiên tân, phủ lý, hà nam",
    "tieen taan, phur lys, haf nam"
  ],
  "Tr'Hy, Tây Giang, Quảng Nam": [
    "tr'hy, tây giang, quảng nam",
    "tr'hy, taay giang, quarng nam"
  ],
  "Trà Ôn, Trà Ôn, Vĩnh Long": [
    "trà ôn, trà ôn, vĩnh long",
    "traf oon, traf oon, vixnh long"
  ],
  "Trác Văn, Duy Tiên, Hà Nam": [
    "trác văn, duy tiên, hà nam",
    "trasc vawn, duy tieen, haf nam"
  ],
  "Trường Thi, Vinh, Nghệ An": [
    "trường thi, vinh, nghệ an",
    "truwowfng thi, vinh, ngheej an"
  ],
  "Tà Cạ, Kỳ Sơn, Nghệ An": [
    "tà cạ, kỳ sơn, nghệ an",
    "taf caj, kyf sown, ngheej an"
  ],
  "Tà Gia, Than Uyên, Lai Châu": [
    "tà gia, than uyên, lai châu",
    "taf gia, than uyeen, lai chaau"
  ],
  "Tào Sơn, Anh Sơn, Nghệ An": [
    "tào sơn, anh sơn, nghệ an",
    "tafo sown, anh sown, ngheej an"
  ],
  "Tân An, Càng Long, Trà Vinh": [
    "tân an, càng long, trà vinh",
    "taan an, cafng long, traf vinh"
  ],
  "Tân An, Hội An, Quảng Nam": [
    "tân an, hội an, quảng nam",
    "taan an, hooji an, quarng nam"
  ],
  "Tân Chi, Tiên Du, Bắc Ninh": [
    "tân chi, tiên du, bắc ninh",
    "taan chi, tieen du, bawsc ninh"
  ],
  "Tân Hòa, Phú Tân, An Giang": [
    "tân hòa, phú tân, an giang",
    "taan hofa, phus taan, an giang"
  ],
  "Tân Hải, Phú Tân, Cà Mau": [
    "tân hải, phú tân, cà mau",
    "taan hari, phus taan, caf mau"
  ],
  "Tân Lập, Kon Rẫy, Kon Tum": [
    "tân lập, kon rẫy, kon tum",
    "taan laajp, kon raaxy, kon tum"
  ],
  "Tân Phong, Phù Yên, Sơn La": [
    "tân phong, phù yên, sơn la",
    "taan phong, phuf yeen, sown la"
  ],
  "Tân Sơn, Kim Bảng, Hà Nam": [
    "tân sơn, kim bảng, hà nam",
    "taan sown, kim barng, haf nam"
  ],
  "Tân Sơn, Trà Cú, Trà Vinh": [
    "tân sơn, trà cú, trà vinh",
    "taan sown, traf cus, traf vinh"
  ],
  "Tân Thủy, Ba Tri, Bến Tre": [
    "tân thủy, ba tri, bến tre",
    "taan thury, ba tri, beesn tre"
  ],
  "Tân Xuân, Vân Hồ, Sơn La": [
    "tân xuân, vân hồ, sơn la",
    "taan xuaan, vaan hoof, sown la"
  ],
  "Tòng Bạt, Ba Vì, Hà Nội": [
    "tòng bạt, ba vì, hà nội",
    "tofng bajt, ba vif, haf nooji"
  ],
  "Tú Sơn, Kim Bôi, Hoà Bình": [
    "tú sơn, kim bôi, hoà bình",
    "tus sown, kim booi, hoaf bifnh"
  ],
  "Tạ Bú, Mường La, Sơn La": [
    "tạ bú, mường la, sơn la",
    "taj bus, muwowfng la, sown la"
  ],
  "Tạ Khoa, Bắc Yên, Sơn La": [
    "tạ khoa, bắc yên, sơn la",
    "taj khoa, bawsc yeen, sown la"
  ],
  "Tản Lĩnh, Ba Vì, Hà Nội": [
    "tản lĩnh, ba vì, hà nội",
    "tarn lixnh, ba vif, haf nooji"
  ],
  "Uy Nỗ, Đông Anh, Hà Nội": [
    "uy nỗ, đông anh, hà nội",
    "uy noox, ddoong anh, haf nooji"
  ],
  "Văn Khê, Mê Linh, Hà Nội": [
    "văn khê, mê linh, hà nội",
    "vawn khee, mee linh, haf nooji"
  ],
  "Văn Lang, Na Rì, Bắc Kạn": [
    "văn lang, na rì, bắc kạn",
    "vawn lang, na rif, bawsc kajn"
  ],
  "Văn Minh, Na Rì, Bắc Kạn": [
    "văn minh, na rì, bắc kạn",
    "vawn minh, na rif, bawsc kajn"
  ],
  "Vĩnh Hậu, An Phú, An Giang": [
    "vĩnh hậu, an phú, an giang",
    "vixnh haaju, an phus, an giang"
  ],
  "Vĩnh Lộc, An Phú, An Giang": [
    "vĩnh lộc, an phú, an giang",
    "vixnh loojc, an phus, an giang"
  ],
  "Vạn Hoà, Lào Cai, Lào Cai": [
    "vạn hoà, lào cai, lào cai",
    "vajn hoaf, lafo cai, lafo cai"
  ],
  "Vật Lại, Ba Vì, Hà Nội": [
    "vật lại, ba vì, hà nội",
    "vaajt laji, ba vif, haf nooji"
  ],
  "Xuân Khê, Lý Nhân, Hà Nam": [
    "xuân khê, lý nhân, hà nam",
    "xuaan khee, lys nhaan, haf nam"
  ],
  "Xuân La, Tây Hồ, Hà Nội": [
    "xuân la, tây hồ, hà nội",
    "xuaan la, taay hoof, haf nooji"
  ],
  "Yang Bắc, Đăk Pơ, Gia Lai": [
    "yang bắc, đăk pơ, gia lai",
    "yang bawsc, ddawk pow, gia lai"
  ],
  "Yên Bắc, Duy Tiên, Hà Nam": [
    "yên bắc, duy tiên, hà nam",
    "yeen bawsc, duy tieen, haf nam"
  ],
  "Yên Hưng, Sông Mã, Sơn La": [
    "yên hưng, sông mã, sơn la",
    "yeen huwng, soong max, sown la"
  ],
  "Yên Sơn, Yên Châu, Sơn La": [
    "yên sơn, yên châu, sơn la",
    "yeen sown, yeen chaau, sown la"
  ],
  "Ân Hòa, Kim Sơn, Ninh Bình": [
    "ân hòa, kim sơn, ninh bình",
    "aan hofa, kim sown, ninh bifnh"
  ],
  "Ân Phú, Vũ Quang, Hà Tĩnh": [
    "ân phú, vũ quang, hà tĩnh",
    "aan phus, vux quang, haf tixnh"
  ],
  "Âu Lâu, Yên Bái, Yên Bái": [
    "âu lâu, yên bái, yên bái",
    "aau laau, yeen basi, yeen basi"
  ],
  "Óc Eo, Thoại Sơn, An Giang": [
    "óc eo, thoại sơn, an giang",
    "osc eo, thoaji sown, an giang"
  ],
  "Đa Lộc, Ân Thi, Hưng Yên": [
    "đa lộc, ân thi, hưng yên",
    "dda loojc, aan thi, huwng yeen"
  ],
  "Đa Tốn, Gia Lâm, Hà Nội": [
    "đa tốn, gia lâm, hà nội",
    "dda toosn, gia laam, haf nooji"
  ],
  "Đoàn Kết, Ayun Pa, Gia Lai": [
    "đoàn kết, ayun pa, gia lai",
    "ddoafn keest, ayun pa, gia lai"
  ],
  "Đoàn Kết, Kon Tum, Kon Tum": [
    "đoàn kết, kon tum, kon tum",
    "ddoafn keest, kon tum, kon tum"
  ],
  "Đá Đỏ, Phù Yên, Sơn La": [
    "đá đỏ, phù yên, sơn la",
    "ddas ddor, phuf yeen, sown la"
  ],
  "Đại An, Trà Cú, Trà Vinh": [
    "đại an, trà cú, trà vinh",
    "ddaji an, traf cus, traf vinh"
  ],
  "Đạo Lý, Lý Nhân, Hà Nam": [
    "đạo lý, lý nhân, hà nam",
    "ddajo lys, lys nhaan, haf nam"
  ],
  "Đắk Cấm, Kon Tum, Kon Tum": [
    "đắk cấm, kon tum, kon tum",
    "ddawsk caasm, kon tum, kon tum"
  ],
  "Đắk La, Đắk Hà, Kon Tum": [
    "đắk la, đắk hà, kon tum",
    "ddawsk la, ddawsk haf, kon tum"
  ],
  "Đắk Pne, Kon Rẫy, Kon Tum": [
    "đắk pne, kon rẫy, kon tum",
    "ddawsk pne, kon raaxy, kon tum"
  ],
  "Đắk Rve, Kon Rẫy, Kon Tum": [
    "đắk rve, kon rẫy, kon tum",
    "ddawsk rve, kon raaxy, kon tum"
  ],
  "Đắk Ui, Đắk Hà, Kon Tum": [
    "đắk ui, đắk hà, kon tum",
    "ddawsk ui, ddawsk haf, kon tum"
  ],
  "Đức Lý, Lý Nhân, Hà Nam": [
    "đức lý, lý nhân, hà nam",
    "dduwsc lys, lys nhaan, haf nam"
  ],
  " Tư, Đông Giang, Quảng Nam": [
    " tư, đông giang, quảng nam",
    " tuw, ddoong giang, quarng nam"
  ],
  ", Bạch Long Vĩ, Hải Phòng": [
    ", bạch long vĩ, hải phòng",
    ", bajch long vix, hari phofng"
  ],
  "A Mú Sung, Bát Xát, Lào Cai": [
    "a mú sung, bát xát, lào cai",
    "a mus sung, bast xast, lafo cai"
  ],
  "An Bình, Dĩ An, Bình Dương": [
    "an bình, dĩ an, bình dương",
    "an bifnh, dix an, bifnh duwowng"
  ],
  "An Bình, Long Hồ, Vĩnh Long": [
    "an bình, long hồ, vĩnh long",
    "an bifnh, long hoof, vixnh long"
  ],
  "An Cơ, Châu Thành, Tây Ninh": [
    "an cơ, châu thành, tây ninh",
    "an cow, chaau thafnh, taay ninh"
  ],
  "An Cư, Ninh Kiều, Cần Thơ": [
    "an cư, ninh kiều, cần thơ",
    "an cuw, ninh kieefu, caafn thow"
  ],
  "An Hòa Tây, Ba Tri, Bến Tre": [
    "an hòa tây, ba tri, bến tre",
    "an hofa taay, ba tri, beesn tre"
  ],
  "An Hòa, An Lão, Bình Định": [
    "an hòa, an lão, bình định",
    "an hofa, an laxo, bifnh ddijnh"
  ],
  "An Hòa, Châu Thành, An Giang": [
    "an hòa, châu thành, an giang",
    "an hofa, chaau thafnh, an giang"
  ],
  "An Lão, An Lão, Bình Định": [
    "an lão, an lão, bình định",
    "an laxo, an laxo, bifnh ddijnh"
  ],
  "An Lạc, Hạ Lang, Cao Bằng": [
    "an lạc, hạ lang, cao bằng",
    "an lajc, haj lang, cao bawfng"
  ],
  "An Lạc, Lục Yên, Yên Bái": [
    "an lạc, lục yên, yên bái",
    "an lajc, lujc yeen, yeen basi"
  ],
  "An Mỹ, Mỹ Đức, Hà Nội": [
    "an mỹ, mỹ đức, hà nội",
    "an myx, myx dduwsc, haf nooji"
  ],
  "An Ninh Tây, Tuy An, Phú Yên": [
    "an ninh tây, tuy an, phú yên",
    "an ninh taay, tuy an, phus yeen"
  ],
  "An Phú, Mỹ Đức, Hà Nội": [
    "an phú, mỹ đức, hà nội",
    "an phus, myx dduwsc, haf nooji"
  ],
  "An Phú, Tịnh Biên, An Giang": [
    "an phú, tịnh biên, an giang",
    "an phus, tijnh bieen, an giang"
  ],
  "An Quy, Thạnh Phú, Bến Tre": [
    "an quy, thạnh phú, bến tre",
    "an quy, thajnh phus, beesn tre"
  ],
  "An Sơn, Văn Quan, Lạng Sơn": [
    "an sơn, văn quan, lạng sơn",
    "an sown, vawn quan, lajng sown"
  ],
  "An Thái, An Lão, Hải Phòng": [
    "an thái, an lão, hải phòng",
    "an thasi, an laxo, hari phofng"
  ],
  "An Thọ, An Lão, Hải Phòng": [
    "an thọ, an lão, hải phòng",
    "an thoj, an laxo, hari phofng"
  ],
  "An Tân, An Lão, Bình Định": [
    "an tân, an lão, bình định",
    "an taan, an laxo, bifnh ddijnh"
  ],
  "An Vinh, An Lão, Bình Định": [
    "an vinh, an lão, bình định",
    "an vinh, an laxo, bifnh ddijnh"
  ],
  "An Xuân, Tam Kỳ, Quảng Nam": [
    "an xuân, tam kỳ, quảng nam",
    "an xuaan, tam kyf, quarng nam"
  ],
  "Anh Sơn, Tĩnh Gia, Thanh Hóa": [
    "anh sơn, tĩnh gia, thanh hóa",
    "anh sown, tixnh gia, thanh hosa"
  ],
  "Ba Bích, Ba Tơ, Quảng Ngãi": [
    "ba bích, ba tơ, quảng ngãi",
    "ba bisch, ba tow, quarng ngaxi"
  ],
  "Ba Giang, Ba Tơ, Quảng Ngãi": [
    "ba giang, ba tơ, quảng ngãi",
    "ba giang, ba tow, quarng ngaxi"
  ],
  "Ba Khâm, Ba Tơ, Quảng Ngãi": [
    "ba khâm, ba tơ, quảng ngãi",
    "ba khaam, ba tow, quarng ngaxi"
  ],
  "Ba Liên, Ba Tơ, Quảng Ngãi": [
    "ba liên, ba tơ, quảng ngãi",
    "ba lieen, ba tow, quarng ngaxi"
  ],
  "Ba Ngòi, Cam Ranh, Khánh Hòa": [
    "ba ngòi, cam ranh, khánh hòa",
    "ba ngofi, cam ranh, khasnh hofa"
  ],
  "Ba Tiêu, Ba Tơ, Quảng Ngãi": [
    "ba tiêu, ba tơ, quảng ngãi",
    "ba tieeu, ba tow, quarng ngaxi"
  ],
  "Ba Trang, Ba Tơ, Quảng Ngãi": [
    "ba trang, ba tơ, quảng ngãi",
    "ba trang, ba tow, quarng ngaxi"
  ],
  "Ba Đình, Nga Sơn, Thanh Hóa": [
    "ba đình, nga sơn, thanh hóa",
    "ba ddifnh, nga sown, thanh hosa"
  ],
  "Bãi Sậy, Ân Thi, Hưng Yên": [
    "bãi sậy, ân thi, hưng yên",
    "baxi saajy, aan thi, huwng yeen"
  ],
  "Bình An, Dĩ An, Bình Dương": [
    "bình an, dĩ an, bình dương",
    "bifnh an, dix an, bifnh duwowng"
  ],
  "Bình An, Thủ Thừa, Long An": [
    "bình an, thủ thừa, long an",
    "bifnh an, thur thuwfa, long an"
  ],
  "Bình Sơn, Anh Sơn, Nghệ An": [
    "bình sơn, anh sơn, nghệ an",
    "bifnh sown, anh sown, ngheej an"
  ],
  "Bản Cái, Bắc Hà, Lào Cai": [
    "bản cái, bắc hà, lào cai",
    "barn casi, bawsc haf, lafo cai"
  ],
  "Bản Mế, Si Ma Cai, Lào Cai": [
    "bản mế, si ma cai, lào cai",
    "barn mees, si ma cai, lafo cai"
  ],
  "Bản Xèo, Bát Xát, Lào Cai": [
    "bản xèo, bát xát, lào cai",
    "barn xefo, bast xast, lafo cai"
  ],
  "Bảo Hà, Bảo Yên, Lào Cai": [
    "bảo hà, bảo yên, lào cai",
    "baro haf, baro yeen, lafo cai"
  ],
  "Bảo Nam, Kỳ Sơn, Nghệ An": [
    "bảo nam, kỳ sơn, nghệ an",
    "baro nam, kyf sown, ngheej an"
  ],
  "Bảo Nhai, Bắc Hà, Lào Cai": [
    "bảo nhai, bắc hà, lào cai",
    "baro nhai, bawsc haf, lafo cai"
  ],
  "Bắc Hà, Hà Tĩnh, Hà Tĩnh": [
    "bắc hà, hà tĩnh, hà tĩnh",
    "bawsc haf, haf tixnh, haf tixnh"
  ],
  "Bắc Lý, Kỳ Sơn, Nghệ An": [
    "bắc lý, kỳ sơn, nghệ an",
    "bawsc lys, kyf sown, ngheej an"
  ],
  "Bắc Phong, Phù Yên, Sơn La": [
    "bắc phong, phù yên, sơn la",
    "bawsc phong, phuf yeen, sown la"
  ],
  "Bắc Sơn, Ân Thi, Hưng Yên": [
    "bắc sơn, ân thi, hưng yên",
    "bawsc sown, aan thi, huwng yeen"
  ],
  "Bắc Yên, Bắc Yên, Sơn La": [
    "bắc yên, bắc yên, sơn la",
    "bawsc yeen, bawsc yeen, sown la"
  ],
  "Cam Cọn, Bảo Yên, Lào Cai": [
    "cam cọn, bảo yên, lào cai",
    "cam cojn, baro yeen, lafo cai"
  ],
  "Cam Hòa, Cam Lâm, Khánh Hòa": [
    "cam hòa, cam lâm, khánh hòa",
    "cam hofa, cam laam, khasnh hofa"
  ],
  "Cam Linh, Cam Ranh, Khánh Hòa": [
    "cam linh, cam ranh, khánh hòa",
    "cam linh, cam ranh, khasnh hofa"
  ],
  "Cam Lâm, Con Cuông, Nghệ An": [
    "cam lâm, con cuông, nghệ an",
    "cam laam, con cuoong, ngheej an"
  ],
  "Cam Phú, Cam Ranh, Khánh Hòa": [
    "cam phú, cam ranh, khánh hòa",
    "cam phus, cam ranh, khasnh hofa"
  ],
  "Cam Tân, Cam Lâm, Khánh Hòa": [
    "cam tân, cam lâm, khánh hòa",
    "cam taan, cam laam, khasnh hofa"
  ],
  "Cao Viên, Thanh Oai, Hà Nội": [
    "cao viên, thanh oai, hà nội",
    "cao vieen, thanh oai, haf nooji"
  ],
  "Cao Xá, Tân Yên, Bắc Giang": [
    "cao xá, tân yên, bắc giang",
    "cao xas, taan yeen, bawsc giang"
  ],
  "Ch'ơm, Tây Giang, Quảng Nam": [
    "ch'ơm, tây giang, quảng nam",
    "ch'owm, taay giang, quarng nam"
  ],
  "Chi Khê, Con Cuông, Nghệ An": [
    "chi khê, con cuông, nghệ an",
    "chi khee, con cuoong, ngheej an"
  ],
  "Chi Đông, Mê Linh, Hà Nội": [
    "chi đông, mê linh, hà nội",
    "chi ddoong, mee linh, haf nooji"
  ],
  "Chiềng Ban, Mai Sơn, Sơn La": [
    "chiềng ban, mai sơn, sơn la",
    "chieefng ban, mai sown, sown la"
  ],
  "Chiềng Cơi, Sơn La, Sơn La": [
    "chiềng cơi, sơn la, sơn la",
    "chieefng cowi, sown la, sown la"
  ],
  "Chiềng Cọ, Sơn La, Sơn La": [
    "chiềng cọ, sơn la, sơn la",
    "chieefng coj, sown la, sown la"
  ],
  "Chiềng En, Sông Mã, Sơn La": [
    "chiềng en, sông mã, sơn la",
    "chieefng en, soong max, sown la"
  ],
  "Chiềng Lề, Sơn La, Sơn La": [
    "chiềng lề, sơn la, sơn la",
    "chieefng leef, sown la, sown la"
  ],
  "Chiềng Mai, Mai Sơn, Sơn La": [
    "chiềng mai, mai sơn, sơn la",
    "chieefng mai, mai sown, sown la"
  ],
  "Chiềng Sinh, Sơn La, Sơn La": [
    "chiềng sinh, sơn la, sơn la",
    "chieefng sinh, sown la, sown la"
  ],
  "Chiềng Xôm, Sơn La, Sơn La": [
    "chiềng xôm, sơn la, sơn la",
    "chieefng xoom, sown la, sown la"
  ],
  "Chiềng Đen, Sơn La, Sơn La": [
    "chiềng đen, sơn la, sơn la",
    "chieefng dden, sown la, sown la"
  ],
  "Châu Giang, Duy Tiên, Hà Nam": [
    "châu giang, duy tiên, hà nam",
    "chaau giang, duy tieen, haf nam"
  ],
  "Châu Lăng, Tri Tôn, An Giang": [
    "châu lăng, tri tôn, an giang",
    "chaau lawng, tri toon, an giang"
  ],
  "Chí Cà, Xín Mần, Hà Giang": [
    "chí cà, xín mần, hà giang",
    "chis caf, xisn maafn, haf giang"
  ],
  "Chí Thạnh, Tuy An, Phú Yên": [
    "chí thạnh, tuy an, phú yên",
    "chis thajnh, tuy an, phus yeen"
  ],
  "Chũ, Lục Ngạn, Bắc Giang": [
    "chũ, lục ngạn, bắc giang",
    "chux, lujc ngajn, bawsc giang"
  ],
  "Chư Drăng, Krông Pa, Gia Lai": [
    "chư drăng, krông pa, gia lai",
    "chuw drawng, kroong pa, gia lai"
  ],
  "Chư Krêy, Kông Chro, Gia Lai": [
    "chư krêy, kông chro, gia lai",
    "chuw kreey, koong chro, gia lai"
  ],
  "Chư Ngọc, Krông Pa, Gia Lai": [
    "chư ngọc, krông pa, gia lai",
    "chuw ngojc, kroong pa, gia lai"
  ],
  "Chợ Rã, Ba Bể, Bắc Kạn": [
    "chợ rã, ba bể, bắc kạn",
    "chowj rax, ba beer, bawsc kajn"
  ],
  "Chợ Vàm, Phú Tân, An Giang": [
    "chợ vàm, phú tân, an giang",
    "chowj vafm, phus taan, an giang"
  ],
  "Co Mạ, Thuận Châu, Sơn La": [
    "co mạ, thuận châu, sơn la",
    "co maj, thuaajn chaau, sown la"
  ],
  "Cun Pheo, Mai Châu, Hoà Bình": [
    "cun pheo, mai châu, hoà bình",
    "cun pheo, mai chaau, hoaf bifnh"
  ],
  "Cách Bi, Quế Võ, Bắc Ninh": [
    "cách bi, quế võ, bắc ninh",
    "casch bi, quees vox, bawsc ninh"
  ],
  "Cán Cấu, Si Ma Cai, Lào Cai": [
    "cán cấu, si ma cai, lào cai",
    "casn caasu, si ma cai, lafo cai"
  ],
  "Cát Bi, Hải An, Hải Phòng": [
    "cát bi, hải an, hải phòng",
    "cast bi, hari an, hari phofng"
  ],
  "Cô Ba, Bảo Lạc, Cao Bằng": [
    "cô ba, bảo lạc, cao bằng",
    "coo ba, baro lajc, cao bawfng"
  ],
  "Cư Bông, Ea Kar, Đắk Lắk": [
    "cư bông, ea kar, đắk lắk",
    "cuw boong, ea kar, ddawsk lawsk"
  ],
  "Cư ELang, Ea Kar, Đắk Lắk": [
    "cư elang, ea kar, đắk lắk",
    "cuw elang, ea kar, ddawsk lawsk"
  ],
  "Cầu Kè, Cầu Kè, Trà Vinh": [
    "cầu kè, cầu kè, trà vinh",
    "caafu kef, caafu kef, traf vinh"
  ],
  "Cẩm An, Hội An, Quảng Nam": [
    "cẩm an, hội an, quảng nam",
    "caarm an, hooji an, quarng nam"
  ],
  "Cẩm Ninh, Ân Thi, Hưng Yên": [
    "cẩm ninh, ân thi, hưng yên",
    "caarm ninh, aan thi, huwng yeen"
  ],
  "Cẩm Sơn, Anh Sơn, Nghệ An": [
    "cẩm sơn, anh sơn, nghệ an",
    "caarm sown, anh sown, ngheej an"
  ],
  "Cốc Lếu, Lào Cai, Lào Cai": [
    "cốc lếu, lào cai, lào cai",
    "coosc leesu, lafo cai, lafo cai"
  ],
  "Cốc Mỳ, Bát Xát, Lào Cai": [
    "cốc mỳ, bát xát, lào cai",
    "coosc myf, bast xast, lafo cai"
  ],
  "Cồn, Hải Hậu, Nam Định": [
    "cồn, hải hậu, nam định",
    "coofn, hari haaju, nam ddijnh"
  ],
  "Cổ Loa, Đông Anh, Hà Nội": [
    "cổ loa, đông anh, hà nội",
    "coor loa, ddoong anh, haf nooji"
  ],
  "Cự Khê, Thanh Oai, Hà Nội": [
    "cự khê, thanh oai, hà nội",
    "cuwj khee, thanh oai, haf nooji"
  ],
  "Dak Lua, Tân Phú, Đồng Nai": [
    "dak lua, tân phú, đồng nai",
    "dak lua, taan phus, ddoofng nai"
  ],
  "Du Tiến, Yên Minh, Hà Giang": [
    "du tiến, yên minh, hà giang",
    "du tieesn, yeen minh, haf giang"
  ],
  "Dân Chủ, Hoà An, Cao Bằng": [
    "dân chủ, hoà an, cao bằng",
    "daan chur, hoaf an, cao bawfng"
  ],
  "Dân Hòa, Thanh Oai, Hà Nội": [
    "dân hòa, thanh oai, hà nội",
    "daan hofa, thanh oai, haf nooji"
  ],
  "Ea Hiao, Ea H'leo, Đắk Lắk": [
    "ea hiao, ea h'leo, đắk lắk",
    "ea hiao, ea h'leo, ddawsk lawsk"
  ],
  "Ea Khal, Ea H'leo, Đắk Lắk": [
    "ea khal, ea h'leo, đắk lắk",
    "ea khal, ea h'leo, ddawsk lawsk"
  ],
  "Ea Knốp, Ea Kar, Đắk Lắk": [
    "ea knốp, ea kar, đắk lắk",
    "ea knoosp, ea kar, ddawsk lawsk"
  ],
  "Ea Ktur, Cư Kuin, Đắk Lắk": [
    "ea ktur, cư kuin, đắk lắk",
    "ea ktur, cuw kuin, ddawsk lawsk"
  ],
  "Ea Lai, M'Đrắk, Đắk Lắk": [
    "ea lai, m'đrắk, đắk lắk",
    "ea lai, m'ddrawsk, ddawsk lawsk"
  ],
  "Ea Ning, Cư Kuin, Đắk Lắk": [
    "ea ning, cư kuin, đắk lắk",
    "ea ning, cuw kuin, ddawsk lawsk"
  ],
  "Ea Pil, M'Đrắk, Đắk Lắk": [
    "ea pil, m'đrắk, đắk lắk",
    "ea pil, m'ddrawsk, ddawsk lawsk"
  ],
  "Ea Rốk, Ea Súp, Đắk Lắk": [
    "ea rốk, ea súp, đắk lắk",
    "ea roosk, ea susp, ddawsk lawsk"
  ],
  "Ea Tar, Cư M'gar, Đắk Lắk": [
    "ea tar, cư m'gar, đắk lắk",
    "ea tar, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Tul, Cư M'gar, Đắk Lắk": [
    "ea tul, cư m'gar, đắk lắk",
    "ea tul, cuw m'gar, ddawsk lawsk"
  ],
  "Gia Mô, Tân Lạc, Hoà Bình": [
    "gia mô, tân lạc, hoà bình",
    "gia moo, taan lajc, hoaf bifnh"
  ],
  "Gio An, Gio Linh, Quảng Trị": [
    "gio an, gio linh, quảng trị",
    "gio an, gio linh, quarng trij"
  ],
  "Gung Ré, Di Linh, Lâm Đồng": [
    "gung ré, di linh, lâm đồng",
    "gung res, di linh, laam ddoofng"
  ],
  "Gò Dầu, Gò Dầu, Tây Ninh": [
    "gò dầu, gò dầu, tây ninh",
    "gof daafu, gof daafu, taay ninh"
  ],
  "Gò Quao, Gò Quao, Kiên Giang": [
    "gò quao, gò quao, kiên giang",
    "gof quao, gof quao, kieen giang"
  ],
  "Hang Kia, Mai Châu, Hoà Bình": [
    "hang kia, mai châu, hoà bình",
    "hang kia, mai chaau, hoaf bifnh"
  ],
  "Hoa Sơn, Ứng Hòa, Hà Nội": [
    "hoa sơn, ứng hòa, hà nội",
    "hoa sown, uwsng hofa, haf nooji"
  ],
  "Hoà Lạc, Phú Tân, An Giang": [
    "hoà lạc, phú tân, an giang",
    "hoaf lajc, phus taan, an giang"
  ],
  "Hoà Mạc, Văn Bàn, Lào Cai": [
    "hoà mạc, văn bàn, lào cai",
    "hoaf majc, vawn bafn, lafo cai"
  ],
  "Hoà Tân, Cầu Kè, Trà Vinh": [
    "hoà tân, cầu kè, trà vinh",
    "hoaf taan, caafu kef, traf vinh"
  ],
  "Hoàng Kim, Mê Linh, Hà Nội": [
    "hoàng kim, mê linh, hà nội",
    "hoafng kim, mee linh, haf nooji"
  ],
  "Hua Bun, Nậm Nhùn, Lai Châu": [
    "hua bun, nậm nhùn, lai châu",
    "hua bun, naajm nhufn, lai chaau"
  ],
  "Hua Păng, Mộc Châu, Sơn La": [
    "hua păng, mộc châu, sơn la",
    "hua pawng, moojc chaau, sown la"
  ],
  "Hà Long, Hà Trung, Thanh Hóa": [
    "hà long, hà trung, thanh hóa",
    "haf long, haf trung, thanh hosa"
  ],
  "Hà Sơn, Hà Trung, Thanh Hóa": [
    "hà sơn, hà trung, thanh hóa",
    "haf sown, haf trung, thanh hosa"
  ],
  "Hà Tu, Hạ Long, Quảng Ninh": [
    "hà tu, hạ long, quảng ninh",
    "haf tu, haj long, quarng ninh"
  ],
  "Hà Tân, Hà Trung, Thanh Hóa": [
    "hà tân, hà trung, thanh hóa",
    "haf taan, haf trung, thanh hosa"
  ],
  "Hà Vinh, Hà Trung, Thanh Hóa": [
    "hà vinh, hà trung, thanh hóa",
    "haf vinh, haf trung, thanh hosa"
  ],
  "Hà Đông, Đăk Đoa, Gia Lai": [
    "hà đông, đăk đoa, gia lai",
    "haf ddoong, ddawk ddoa, gia lai"
  ],
  "Hàm Giang, Trà Cú, Trà Vinh": [
    "hàm giang, trà cú, trà vinh",
    "hafm giang, traf cus, traf vinh"
  ],
  "Hàm Rồng, Năm Căn, Cà Mau": [
    "hàm rồng, năm căn, cà mau",
    "hafm roofng, nawm cawn, caf mau"
  ],
  "Hòa Nam, Di Linh, Lâm Đồng": [
    "hòa nam, di linh, lâm đồng",
    "hofa nam, di linh, laam ddoofng"
  ],
  "Hòa Nam, Ứng Hòa, Hà Nội": [
    "hòa nam, ứng hòa, hà nội",
    "hofa nam, uwsng hofa, haf nooji"
  ],
  "Hòa Phú, Tây Hoà, Phú Yên": [
    "hòa phú, tây hoà, phú yên",
    "hofa phus, taay hoaf, phus yeen"
  ],
  "Hòa Xá, Ứng Hòa, Hà Nội": [
    "hòa xá, ứng hòa, hà nội",
    "hofa xas, uwsng hofa, haf nooji"
  ],
  "Hùng Sơn, Anh Sơn, Nghệ An": [
    "hùng sơn, anh sơn, nghệ an",
    "hufng sown, anh sown, ngheej an"
  ],
  "Hưng Trí, Kỳ Anh, Hà Tĩnh": [
    "hưng trí, kỳ anh, hà tĩnh",
    "huwng tris, kyf anh, haf tixnh"
  ],
  "Hải An, Tĩnh Gia, Thanh Hóa": [
    "hải an, tĩnh gia, thanh hóa",
    "hari an, tixnh gia, thanh hosa"
  ],
  "Hải Yang, Đăk Đoa, Gia Lai": [
    "hải yang, đăk đoa, gia lai",
    "hari yang, ddawk ddoa, gia lai"
  ],
  "Hồng Nam, Hoà An, Cao Bằng": [
    "hồng nam, hoà an, cao bằng",
    "hoofng nam, hoaf an, cao bawfng"
  ],
  "Hội An, Chợ Mới, An Giang": [
    "hội an, chợ mới, an giang",
    "hooji an, chowj mowsi, an giang"
  ],
  "Hội Sơn, Anh Sơn, Nghệ An": [
    "hội sơn, anh sơn, nghệ an",
    "hooji sown, anh sown, ngheej an"
  ],
  "Hội Thương, Pleiku, Gia Lai": [
    "hội thương, pleiku, gia lai",
    "hooji thuwowng, pleiku, gia lai"
  ],
  "Ia Boòng, Chư Prông, Gia Lai": [
    "ia boòng, chư prông, gia lai",
    "ia boofng, chuw proong, gia lai"
  ],
  "Ia Drăng, Chư Prông, Gia Lai": [
    "ia drăng, chư prông, gia lai",
    "ia drawng, chuw proong, gia lai"
  ],
  "Ia JLơi, Ea Súp, Đắk Lắk": [
    "ia jlơi, ea súp, đắk lắk",
    "ia jlowi, ea susp, ddawsk lawsk"
  ],
  "Ia Kriêng, Đức Cơ, Gia Lai": [
    "ia kriêng, đức cơ, gia lai",
    "ia krieeng, dduwsc cow, gia lai"
  ],
  "Ia Lốp, Ea Súp, Đắk Lắk": [
    "ia lốp, ea súp, đắk lắk",
    "ia loosp, ea susp, ddawsk lawsk"
  ],
  "Khoen On, Than Uyên, Lai Châu": [
    "khoen on, than uyên, lai châu",
    "khoen on, than uyeen, lai chaau"
  ],
  "Khánh Bình, An Phú, An Giang": [
    "khánh bình, an phú, an giang",
    "khasnh bifnh, an phus, an giang"
  ],
  "Khánh Thuận, U Minh, Cà Mau": [
    "khánh thuận, u minh, cà mau",
    "khasnh thuaajn, u minh, caf mau"
  ],
  "Kim Hải, Kim Sơn, Ninh Bình": [
    "kim hải, kim sơn, ninh bình",
    "kim hari, kim sown, ninh bifnh"
  ],
  "Kim Liên, Nam Đàn, Nghệ An": [
    "kim liên, nam đàn, nghệ an",
    "kim lieen, nam ddafn, ngheej an"
  ],
  "Kim Loan, Hạ Lang, Cao Bằng": [
    "kim loan, hạ lang, cao bằng",
    "kim loan, haj lang, cao bawfng"
  ],
  "Kim Lập, Kim Bôi, Hoà Bình": [
    "kim lập, kim bôi, hoà bình",
    "kim laajp, kim booi, hoaf bifnh"
  ],
  "Kim Nỗ, Đông Anh, Hà Nội": [
    "kim nỗ, đông anh, hà nội",
    "kim noox, ddoong anh, haf nooji"
  ],
  "Kim Trung, Kim Sơn, Ninh Bình": [
    "kim trung, kim sơn, ninh bình",
    "kim trung, kim sown, ninh bifnh"
  ],
  "Kiêu Kỵ, Gia Lâm, Hà Nội": [
    "kiêu kỵ, gia lâm, hà nội",
    "kieeu kyj, gia laam, haf nooji"
  ],
  "Kon Chiêng, Mang Yang, Gia Lai": [
    "kon chiêng, mang yang, gia lai",
    "kon chieeng, mang yang, gia lai"
  ],
  "Krông Nô, Lắk, Đắk Lắk": [
    "krông nô, lắk, đắk lắk",
    "kroong noo, lawsk, ddawsk lawsk"
  ],
  "Krông Pa, Sơn Hòa, Phú Yên": [
    "krông pa, sơn hòa, phú yên",
    "kroong pa, sown hofa, phus yeen"
  ],
  "Kép, Lạng Giang, Bắc Giang": [
    "kép, lạng giang, bắc giang",
    "kesp, lajng giang, bawsc giang"
  ],
  "Kông Chro, Kông Chro, Gia Lai": [
    "kông chro, kông chro, gia lai",
    "koong chro, koong chro, gia lai"
  ],
  "Kông Yang, Kông Chro, Gia Lai": [
    "kông yang, kông chro, gia lai",
    "koong yang, koong chro, gia lai"
  ],
  "Kỳ Bắc, Kỳ Anh, Hà Tĩnh": [
    "kỳ bắc, kỳ anh, hà tĩnh",
    "kyf bawsc, kyf anh, haf tixnh"
  ],
  "Kỳ Châu, Kỳ Anh, Hà Tĩnh": [
    "kỳ châu, kỳ anh, hà tĩnh",
    "kyf chaau, kyf anh, haf tixnh"
  ],
  "Kỳ Giang, Kỳ Anh, Hà Tĩnh": [
    "kỳ giang, kỳ anh, hà tĩnh",
    "kyf giang, kyf anh, haf tixnh"
  ],
  "Kỳ Hải, Kỳ Anh, Hà Tĩnh": [
    "kỳ hải, kỳ anh, hà tĩnh",
    "kyf hari, kyf anh, haf tixnh"
  ],
  "Kỳ Khang, Kỳ Anh, Hà Tĩnh": [
    "kỳ khang, kỳ anh, hà tĩnh",
    "kyf khang, kyf anh, haf tixnh"
  ],
  "Kỳ Liên, Kỳ Anh, Hà Tĩnh": [
    "kỳ liên, kỳ anh, hà tĩnh",
    "kyf lieen, kyf anh, haf tixnh"
  ],
  "Kỳ Lạc, Kỳ Anh, Hà Tĩnh": [
    "kỳ lạc, kỳ anh, hà tĩnh",
    "kyf lajc, kyf anh, haf tixnh"
  ],
  "Kỳ Lợi, Kỳ Anh, Hà Tĩnh": [
    "kỳ lợi, kỳ anh, hà tĩnh",
    "kyf lowji, kyf anh, haf tixnh"
  ],
  "Kỳ Phong, Kỳ Anh, Hà Tĩnh": [
    "kỳ phong, kỳ anh, hà tĩnh",
    "kyf phong, kyf anh, haf tixnh"
  ],
  "Kỳ Phú, Nho Quan, Ninh Bình": [
    "kỳ phú, nho quan, ninh bình",
    "kyf phus, nho quan, ninh bifnh"
  ],
  "Kỳ Sơn, Tân Kỳ, Nghệ An": [
    "kỳ sơn, tân kỳ, nghệ an",
    "kyf sown, taan kyf, ngheej an"
  ],
  "Kỳ Thọ, Kỳ Anh, Hà Tĩnh": [
    "kỳ thọ, kỳ anh, hà tĩnh",
    "kyf thoj, kyf anh, haf tixnh"
  ],
  "Kỳ Trinh, Kỳ Anh, Hà Tĩnh": [
    "kỳ trinh, kỳ anh, hà tĩnh",
    "kyf trinh, kyf anh, haf tixnh"
  ],
  "Kỳ Trung, Kỳ Anh, Hà Tĩnh": [
    "kỳ trung, kỳ anh, hà tĩnh",
    "kyf trung, kyf anh, haf tixnh"
  ],
  "Kỳ Tân, Tân Kỳ, Nghệ An": [
    "kỳ tân, tân kỳ, nghệ an",
    "kyf taan, taan kyf, ngheej an"
  ],
  "Kỳ Xuân, Kỳ Anh, Hà Tĩnh": [
    "kỳ xuân, kỳ anh, hà tĩnh",
    "kyf xuaan, kyf anh, haf tixnh"
  ],
  "Lam Sơn, Tam Nông, Phú Thọ": [
    "lam sơn, tam nông, phú thọ",
    "lam sown, tam noong, phus thoj"
  ],
  "Liêm Chung, Phủ Lý, Hà Nam": [
    "liêm chung, phủ lý, hà nam",
    "lieem chung, phur lys, haf nam"
  ],
  "Liêm Phú, Văn Bàn, Lào Cai": [
    "liêm phú, văn bàn, lào cai",
    "lieem phus, vawn bafn, lafo cai"
  ],
  "Liên Sơn, Kim Bảng, Hà Nam": [
    "liên sơn, kim bảng, hà nam",
    "lieen sown, kim barng, haf nam"
  ],
  "Liên Sơn, Lắk, Đắk Lắk": [
    "liên sơn, lắk, đắk lắk",
    "lieen sown, lawsk, ddawsk lawsk"
  ],
  "Long An, Cần Giuộc, Long An": [
    "long an, cần giuộc, long an",
    "long an, caafn giuoojc, long an"
  ],
  "Long Hưng, Ô Môn, Cần Thơ": [
    "long hưng, ô môn, cần thơ",
    "long huwng, oo moon, caafn thow"
  ],
  "Long Phú, Tân Châu, An Giang": [
    "long phú, tân châu, an giang",
    "long phus, taan chaau, an giang"
  ],
  "Long Sơn, Tân Châu, An Giang": [
    "long sơn, tân châu, an giang",
    "long sown, taan chaau, an giang"
  ],
  "Làng Mô, Sìn Hồ, Lai Châu": [
    "làng mô, sìn hồ, lai châu",
    "lafng moo, sifn hoof, lai chaau"
  ],
  "Lâm Hợp, Kỳ Anh, Hà Tĩnh": [
    "lâm hợp, kỳ anh, hà tĩnh",
    "laam howjp, kyf anh, haf tixnh"
  ],
  "Lê Lai, Thạch An, Cao Bằng": [
    "lê lai, thạch an, cao bằng",
    "lee lai, thajch an, cao bawfng"
  ],
  "Lê Lợi, Sơn Tây, Hà Nội": [
    "lê lợi, sơn tây, hà nội",
    "lee lowji, sown taay, haf nooji"
  ],
  "Lý Văn Lâm, Cà Mau, Cà Mau": [
    "lý văn lâm, cà mau, cà mau",
    "lys vawn laam, caf mau, caf mau"
  ],
  "Lĩnh Sơn, Anh Sơn, Nghệ An": [
    "lĩnh sơn, anh sơn, nghệ an",
    "lixnh sown, anh sown, ngheej an"
  ],
  "Lương Phi, Tri Tôn, An Giang": [
    "lương phi, tri tôn, an giang",
    "luwowng phi, tri toon, an giang"
  ],
  "Lộc Hà, Lộc Hà, Hà Tĩnh": [
    "lộc hà, lộc hà, hà tĩnh",
    "loojc haf, loojc haf, haf tixnh"
  ],
  "Mai Hạ, Mai Châu, Hoà Bình": [
    "mai hạ, mai châu, hoà bình",
    "mai haj, mai chaau, hoaf bifnh"
  ],
  "Mai Lâm, Tĩnh Gia, Thanh Hóa": [
    "mai lâm, tĩnh gia, thanh hóa",
    "mai laam, tixnh gia, thanh hosa"
  ],
  "Mai Lâm, Đông Anh, Hà Nội": [
    "mai lâm, đông anh, hà nội",
    "mai laam, ddoong anh, haf nooji"
  ],
  "Mai Phụ, Lộc Hà, Hà Tĩnh": [
    "mai phụ, lộc hà, hà tĩnh",
    "mai phuj, loojc haf, haf tixnh"
  ],
  "Mai Sao, Chi Lăng, Lạng Sơn": [
    "mai sao, chi lăng, lạng sơn",
    "mai sao, chi lawng, lajng sown"
  ],
  "Mai Sơn, Lục Yên, Yên Bái": [
    "mai sơn, lục yên, yên bái",
    "mai sown, lujc yeen, yeen basi"
  ],
  "Minh An, Văn Chấn, Yên Bái": [
    "minh an, văn chấn, yên bái",
    "minh an, vawn chaasn, yeen basi"
  ],
  "Minh Khai, Hà Giang, Hà Giang": [
    "minh khai, hà giang, hà giang",
    "minh khai, haf giang, haf giang"
  ],
  "Minh Phú, Sóc Sơn, Hà Nội": [
    "minh phú, sóc sơn, hà nội",
    "minh phus, sosc sown, haf nooji"
  ],
  "Minh Sơn, Bắc Mê, Hà Giang": [
    "minh sơn, bắc mê, hà giang",
    "minh sown, bawsc mee, haf giang"
  ],
  "Minh Trí, Sóc Sơn, Hà Nội": [
    "minh trí, sóc sơn, hà nội",
    "minh tris, sosc sown, haf nooji"
  ],
  "Minh Tân, Bảo Yên, Lào Cai": [
    "minh tân, bảo yên, lào cai",
    "minh taan, baro yeen, lafo cai"
  ],
  "Minh Tân, Yên Bái, Yên Bái": [
    "minh tân, yên bái, yên bái",
    "minh taan, yeen basi, yeen basi"
  ],
  "Mã Ba, Hà Quảng, Cao Bằng": [
    "mã ba, hà quảng, cao bằng",
    "max ba, haf quarng, cao bawfng"
  ],
  "Măng Ri, Tu Mơ Rông, Kon Tum": [
    "măng ri, tu mơ rông, kon tum",
    "mawng ri, tu mow roong, kon tum"
  ],
  "Măng Đen, Kon Plông, Kon Tum": [
    "măng đen, kon plông, kon tum",
    "mawng dden, kon ploong, kon tum"
  ],
  "Mường Bon, Mai Sơn, Sơn La": [
    "mường bon, mai sơn, sơn la",
    "muwowfng bon, mai sown, sown la"
  ],
  "Mường Do, Phù Yên, Sơn La": [
    "mường do, phù yên, sơn la",
    "muwowfng do, phuf yeen, sown la"
  ],
  "Mộ Lao, Hà Đông, Hà Nội": [
    "mộ lao, hà đông, hà nội",
    "mooj lao, haf ddoong, haf nooji"
  ],
  "Mộc Bắc, Duy Tiên, Hà Nam": [
    "mộc bắc, duy tiên, hà nam",
    "moojc bawsc, duy tieen, haf nam"
  ],
  "Mỹ An, Mang Thít, Vĩnh Long": [
    "mỹ an, mang thít, vĩnh long",
    "myx an, mang thist, vixnh long"
  ],
  "Mỹ Gia, Yên Bình, Yên Bái": [
    "mỹ gia, yên bình, yên bái",
    "myx gia, yeen bifnh, yeen basi"
  ],
  "Mỹ Phú, Châu Phú, An Giang": [
    "mỹ phú, châu phú, an giang",
    "myx phus, chaau phus, an giang"
  ],
  "Mỹ Thạnh, Ba Tri, Bến Tre": [
    "mỹ thạnh, ba tri, bến tre",
    "myx thajnh, ba tri, beesn tre"
  ],
  "Mỹ Tú, Mỹ Tú, Sóc Trăng": [
    "mỹ tú, mỹ tú, sóc trăng",
    "myx tus, myx tus, sosc trawng"
  ],
  "Mỹ Yên, Bến Lức, Long An": [
    "mỹ yên, bến lức, long an",
    "myx yeen, beesn luwsc, long an"
  ],
  "Nam Ban, Lâm Hà, Lâm Đồng": [
    "nam ban, lâm hà, lâm đồng",
    "nam ban, laam haf, laam ddoofng"
  ],
  "Nam Cao, Bảo Lâm, Cao Bằng": [
    "nam cao, bảo lâm, cao bằng",
    "nam cao, baro laam, cao bawfng"
  ],
  "Nam Giang, Nam Đàn, Nghệ An": [
    "nam giang, nam đàn, nghệ an",
    "nam giang, nam ddafn, ngheej an"
  ],
  "Nam Hà, Lâm Hà, Lâm Đồng": [
    "nam hà, lâm hà, lâm đồng",
    "nam haf, laam haf, laam ddoofng"
  ],
  "Nam Hưng, Nam Đàn, Nghệ An": [
    "nam hưng, nam đàn, nghệ an",
    "nam huwng, nam ddafn, ngheej an"
  ],
  "Nam Lĩnh, Nam Đàn, Nghệ An": [
    "nam lĩnh, nam đàn, nghệ an",
    "nam lixnh, nam ddafn, ngheej an"
  ],
  "Nam Mẫu, Ba Bể, Bắc Kạn": [
    "nam mẫu, ba bể, bắc kạn",
    "nam maaxu, ba beer, bawsc kajn"
  ],
  "Nam Thanh, Nam Đàn, Nghệ An": [
    "nam thanh, nam đàn, nghệ an",
    "nam thanh, nam ddafn, ngheej an"
  ],
  "Nam Thái, Nam Đàn, Nghệ An": [
    "nam thái, nam đàn, nghệ an",
    "nam thasi, nam ddafn, ngheej an"
  ],
  "Nam Tuấn, Hoà An, Cao Bằng": [
    "nam tuấn, hoà an, cao bằng",
    "nam tuaasn, hoaf an, cao bawfng"
  ],
  "Nam Xuân, Nam Đàn, Nghệ An": [
    "nam xuân, nam đàn, nghệ an",
    "nam xuaan, nam ddafn, ngheej an"
  ],
  "Nam Yên, An Biên, Kiên Giang": [
    "nam yên, an biên, kiên giang",
    "nam yeen, an bieen, kieen giang"
  ],
  "Nam Đàn, Nam Đàn, Nghệ An": [
    "nam đàn, nam đàn, nghệ an",
    "nam ddafn, nam ddafn, ngheej an"
  ],
  "Nga Giáp, Nga Sơn, Thanh Hóa": [
    "nga giáp, nga sơn, thanh hóa",
    "nga giasp, nga sown, thanh hosa"
  ],
  "Nga Hải, Nga Sơn, Thanh Hóa": [
    "nga hải, nga sơn, thanh hóa",
    "nga hari, nga sown, thanh hosa"
  ],
  "Nga Liên, Nga Sơn, Thanh Hóa": [
    "nga liên, nga sơn, thanh hóa",
    "nga lieen, nga sown, thanh hosa"
  ],
  "Nga Thanh, Nga Sơn, Thanh Hóa": [
    "nga thanh, nga sơn, thanh hóa",
    "nga thanh, nga sown, thanh hosa"
  ],
  "Nga Thái, Nga Sơn, Thanh Hóa": [
    "nga thái, nga sơn, thanh hóa",
    "nga thasi, nga sown, thanh hosa"
  ],
  "Nga Trung, Nga Sơn, Thanh Hóa": [
    "nga trung, nga sơn, thanh hóa",
    "nga trung, nga sown, thanh hosa"
  ],
  "Nghi Hoa, Nghi Lộc, Nghệ An": [
    "nghi hoa, nghi lộc, nghệ an",
    "nghi hoa, nghi loojc, ngheej an"
  ],
  "Nghi Hòa, Cửa Lò, Nghệ An": [
    "nghi hòa, cửa lò, nghệ an",
    "nghi hofa, cuwra lof, ngheej an"
  ],
  "Nghi Tân, Cửa Lò, Nghệ An": [
    "nghi tân, cửa lò, nghệ an",
    "nghi taan, cuwra lof, ngheej an"
  ],
  "Nghi Xá, Nghi Lộc, Nghệ An": [
    "nghi xá, nghi lộc, nghệ an",
    "nghi xas, nghi loojc, ngheej an"
  ],
  "Nghĩa Hòa, Chư Păh, Gia Lai": [
    "nghĩa hòa, chư păh, gia lai",
    "nghixa hofa, chuw pawh, gia lai"
  ],
  "Nguyên Lý, Lý Nhân, Hà Nam": [
    "nguyên lý, lý nhân, hà nam",
    "nguyeen lys, lys nhaan, haf nam"
  ],
  "Nhân Bình, Lý Nhân, Hà Nam": [
    "nhân bình, lý nhân, hà nam",
    "nhaan bifnh, lys nhaan, haf nam"
  ],
  "Nhân Khang, Lý Nhân, Hà Nam": [
    "nhân khang, lý nhân, hà nam",
    "nhaan khang, lys nhaan, haf nam"
  ],
  "Như Hòa, Kim Sơn, Ninh Bình": [
    "như hòa, kim sơn, ninh bình",
    "nhuw hofa, kim sown, ninh bifnh"
  ],
  "Ninh An, Ninh Hòa, Khánh Hòa": [
    "ninh an, ninh hòa, khánh hòa",
    "ninh an, ninh hofa, khasnh hofa"
  ],
  "Ninh Dân, Thanh Ba, Phú Thọ": [
    "ninh dân, thanh ba, phú thọ",
    "ninh daan, thanh ba, phus thoj"
  ],
  "Ninh Giang, Hoa Lư, Ninh Bình": [
    "ninh giang, hoa lư, ninh bình",
    "ninh giang, hoa luw, ninh bifnh"
  ],
  "Ninh Hải, Hoa Lư, Ninh Bình": [
    "ninh hải, hoa lư, ninh bình",
    "ninh hari, hoa luw, ninh bifnh"
  ],
  "Ninh Khang, Hoa Lư, Ninh Bình": [
    "ninh khang, hoa lư, ninh bình",
    "ninh khang, hoa luw, ninh bifnh"
  ],
  "Ninh Sơn, Tây Ninh, Tây Ninh": [
    "ninh sơn, tây ninh, tây ninh",
    "ninh sown, taay ninh, taay ninh"
  ],
  "Ninh Xuân, Hoa Lư, Ninh Bình": [
    "ninh xuân, hoa lư, ninh bình",
    "ninh xuaan, hoa luw, ninh bifnh"
  ],
  "Nà Chì, Xín Mần, Hà Giang": [
    "nà chì, xín mần, hà giang",
    "naf chif, xisn maafn, haf giang"
  ],
  "Nà Hẩu, Văn Yên, Yên Bái": [
    "nà hẩu, văn yên, yên bái",
    "naf haaru, vawn yeen, yeen basi"
  ],
  "Nà Nghịu, Sông Mã, Sơn La": [
    "nà nghịu, sông mã, sơn la",
    "naf nghiju, soong max, sown la"
  ],
  "Nậm Cha, Sìn Hồ, Lai Châu": [
    "nậm cha, sìn hồ, lai châu",
    "naajm cha, sifn hoof, lai chaau"
  ],
  "Nậm Lúc, Bắc Hà, Lào Cai": [
    "nậm lúc, bắc hà, lào cai",
    "naajm lusc, bawsc haf, lafo cai"
  ],
  "Nậm Mòn, Bắc Hà, Lào Cai": [
    "nậm mòn, bắc hà, lào cai",
    "naajm mofn, bawsc haf, lafo cai"
  ],
  "Nậm Mả, Văn Bàn, Lào Cai": [
    "nậm mả, văn bàn, lào cai",
    "naajm mar, vawn bafn, lafo cai"
  ],
  "Nậm Mằn, Sông Mã, Sơn La": [
    "nậm mằn, sông mã, sơn la",
    "naajm mawfn, soong max, sown la"
  ],
  "Nậm Pung, Bát Xát, Lào Cai": [
    "nậm pung, bát xát, lào cai",
    "naajm pung, bast xast, lafo cai"
  ],
  "Nậm Xây, Văn Bàn, Lào Cai": [
    "nậm xây, văn bàn, lào cai",
    "naajm xaay, vawn bafn, lafo cai"
  ],
  "Pa ủ, Mường Tè, Lai Châu": [
    "pa ủ, mường tè, lai châu",
    "pa ur, muwowfng tef, lai chaau"
  ],
  "Phi Tô, Lâm Hà, Lâm Đồng": [
    "phi tô, lâm hà, lâm đồng",
    "phi too, laam haf, laam ddoofng"
  ],
  "Phìn Ngan, Bát Xát, Lào Cai": [
    "phìn ngan, bát xát, lào cai",
    "phifn ngan, bast xast, lafo cai"
  ],
  "Phù Linh, Sóc Sơn, Hà Nội": [
    "phù linh, sóc sơn, hà nội",
    "phuf linh, sosc sown, haf nooji"
  ],
  "Phù Lưu, Lộc Hà, Hà Tĩnh": [
    "phù lưu, lộc hà, hà tĩnh",
    "phuf luwu, loojc haf, haf tixnh"
  ],
  "Phù Lỗ, Sóc Sơn, Hà Nội": [
    "phù lỗ, sóc sơn, hà nội",
    "phuf loox, sosc sown, haf nooji"
  ],
  "Phù Ủng, Ân Thi, Hưng Yên": [
    "phù ủng, ân thi, hưng yên",
    "phuf urng, aan thi, huwng yeen"
  ],
  "Phú An, Tân Phú, Đồng Nai": [
    "phú an, tân phú, đồng nai",
    "phus an, taan phus, ddoofng nai"
  ],
  "Phú Bình, Phú Tân, An Giang": [
    "phú bình, phú tân, an giang",
    "phus bifnh, phus taan, an giang"
  ],
  "Phú Hoà, Phú Hoà, Phú Yên": [
    "phú hoà, phú hoà, phú yên",
    "phus hoaf, phus hoaf, phus yeen"
  ],
  "Phú Hưng, Phú Tân, An Giang": [
    "phú hưng, phú tân, an giang",
    "phus huwng, phus taan, an giang"
  ],
  "Phú Long, Nho Quan, Ninh Bình": [
    "phú long, nho quan, ninh bình",
    "phus long, nho quan, ninh bifnh"
  ],
  "Phú Lâm, Tiên Du, Bắc Ninh": [
    "phú lâm, tiên du, bắc ninh",
    "phus laam, tieen du, bawsc ninh"
  ],
  "Phú Minh, Sóc Sơn, Hà Nội": [
    "phú minh, sóc sơn, hà nội",
    "phus minh, sosc sown, haf nooji"
  ],
  "Phú Sơn, Nho Quan, Ninh Bình": [
    "phú sơn, nho quan, ninh bình",
    "phus sown, nho quan, ninh bifnh"
  ],
  "Phú Sơn, Tân Kỳ, Nghệ An": [
    "phú sơn, tân kỳ, nghệ an",
    "phus sown, taan kyf, ngheej an"
  ],
  "Phú Thị, Gia Lâm, Hà Nội": [
    "phú thị, gia lâm, hà nội",
    "phus thij, gia laam, haf nooji"
  ],
  "Phú Thọ, Phú Tân, An Giang": [
    "phú thọ, phú tân, an giang",
    "phus thoj, phus taan, an giang"
  ],
  "Phú Tân, Bến Tre, Bến Tre": [
    "phú tân, bến tre, bến tre",
    "phus taan, beesn tre, beesn tre"
  ],
  "Phú Xuân, Phú Tân, An Giang": [
    "phú xuân, phú tân, an giang",
    "phus xuaan, phus taan, an giang"
  ],
  "Phúc An, Yên Bình, Yên Bái": [
    "phúc an, yên bình, yên bái",
    "phusc an, yeen bifnh, yeen basi"
  ],
  "Phúc La, Hà Đông, Hà Nội": [
    "phúc la, hà đông, hà nội",
    "phusc la, haf ddoong, haf nooji"
  ],
  "Phúc Sơn, Anh Sơn, Nghệ An": [
    "phúc sơn, anh sơn, nghệ an",
    "phusc sown, anh sown, ngheej an"
  ],
  "Phúc Xá, Ba Đình, Hà Nội": [
    "phúc xá, ba đình, hà nội",
    "phusc xas, ba ddifnh, haf nooji"
  ],
  "Pá Hu, Trạm Tấu, Yên Bái": [
    "pá hu, trạm tấu, yên bái",
    "pas hu, trajm taasu, yeen basi"
  ],
  "Pắc Ngà, Bắc Yên, Sơn La": [
    "pắc ngà, bắc yên, sơn la",
    "pawsc ngaf, bawsc yeen, sown la"
  ],
  "Pắc Ta, Tân Uyên, Lai Châu": [
    "pắc ta, tân uyên, lai châu",
    "pawsc ta, taan uyeen, lai chaau"
  ],
  "Quang Minh, Mê Linh, Hà Nội": [
    "quang minh, mê linh, hà nội",
    "quang minh, mee linh, haf nooji"
  ],
  "Quang Trung, Phủ Lý, Hà Nam": [
    "quang trung, phủ lý, hà nam",
    "quang trung, phur lys, haf nam"
  ],
  "Quang Vinh, Ân Thi, Hưng Yên": [
    "quang vinh, ân thi, hưng yên",
    "quang vinh, aan thi, huwng yeen"
  ],
  "Quốc Thái, An Phú, An Giang": [
    "quốc thái, an phú, an giang",
    "quoosc thasi, an phus, an giang"
  ],
  "Sa Loong, Ngọc Hồi, Kon Tum": [
    "sa loong, ngọc hồi, kon tum",
    "sa loong, ngojc hoofi, kon tum"
  ],
  "Song Khủa, Vân Hồ, Sơn La": [
    "song khủa, vân hồ, sơn la",
    "song khura, vaan hoof, sown la"
  ],
  "Suối Tọ, Phù Yên, Sơn La": [
    "suối tọ, phù yên, sơn la",
    "suoosi toj, phuf yeen, sown la"
  ],
  "Sào Báy, Kim Bôi, Hoà Bình": [
    "sào báy, kim bôi, hoà bình",
    "safo basy, kim booi, hoaf bifnh"
  ],
  "Sìn Hồ, Sìn Hồ, Lai Châu": [
    "sìn hồ, sìn hồ, lai châu",
    "sifn hoof, sifn hoof, lai chaau"
  ],
  "Sóc Sơn, Sóc Sơn, Hà Nội": [
    "sóc sơn, sóc sơn, hà nội",
    "sosc sown, sosc sown, haf nooji"
  ],
  "Sơn Hà, Quan Sơn, Thanh Hóa": [
    "sơn hà, quan sơn, thanh hóa",
    "sown haf, quan sown, thanh hosa"
  ],
  "Sơn Long, Sơn Hòa, Phú Yên": [
    "sơn long, sơn hòa, phú yên",
    "sown long, sown hofa, phus yeen"
  ],
  "Sơn Lư, Quan Sơn, Thanh Hóa": [
    "sơn lư, quan sơn, thanh hóa",
    "sown luw, quan sown, thanh hosa"
  ],
  "Sơn Vĩ, Mèo Vạc, Hà Giang": [
    "sơn vĩ, mèo vạc, hà giang",
    "sown vix, mefo vajc, haf giang"
  ],
  "Tam Bố, Di Linh, Lâm Đồng": [
    "tam bố, di linh, lâm đồng",
    "tam boos, di linh, laam ddoofng"
  ],
  "Tam Hưng, Thanh Oai, Hà Nội": [
    "tam hưng, thanh oai, hà nội",
    "tam huwng, thanh oai, haf nooji"
  ],
  "Tam Ngãi, Cầu Kè, Trà Vinh": [
    "tam ngãi, cầu kè, trà vinh",
    "tam ngaxi, caafu kef, traf vinh"
  ],
  "Tam Phú, Tam Kỳ, Quảng Nam": [
    "tam phú, tam kỳ, quảng nam",
    "tam phus, tam kyf, quarng nam"
  ],
  "Tam Sơn, Từ Sơn, Bắc Ninh": [
    "tam sơn, từ sơn, bắc ninh",
    "tam sown, tuwf sown, bawsc ninh"
  ],
  "Tam Đa, Yên Phong, Bắc Ninh": [
    "tam đa, yên phong, bắc ninh",
    "tam dda, yeen phong, bawsc ninh"
  ],
  "Thanh Cao, Thanh Oai, Hà Nội": [
    "thanh cao, thanh oai, hà nội",
    "thanh cao, thanh oai, haf nooji"
  ],
  "Thanh Châu, Phủ Lý, Hà Nam": [
    "thanh châu, phủ lý, hà nam",
    "thanh chaau, phur lys, haf nam"
  ],
  "Thanh Hà, Thanh Ba, Phú Thọ": [
    "thanh hà, thanh ba, phú thọ",
    "thanh haf, thanh ba, phus thoj"
  ],
  "Thanh Hà, Thanh Liêm, Hà Nam": [
    "thanh hà, thanh liêm, hà nam",
    "thanh haf, thanh lieem, haf nam"
  ],
  "Thanh Lâm, Mê Linh, Hà Nội": [
    "thanh lâm, mê linh, hà nội",
    "thanh laam, mee linh, haf nooji"
  ],
  "Thanh Mai, Thanh Oai, Hà Nội": [
    "thanh mai, thanh oai, hà nội",
    "thanh mai, thanh oai, haf nooji"
  ],
  "Thanh Sơn, Kim Bảng, Hà Nam": [
    "thanh sơn, kim bảng, hà nam",
    "thanh sown, kim barng, haf nam"
  ],
  "Thanh Sơn, Trà Cú, Trà Vinh": [
    "thanh sơn, trà cú, trà vinh",
    "thanh sown, traf cus, traf vinh"
  ],
  "Thu Cúc, Tân Sơn, Phú Thọ": [
    "thu cúc, tân sơn, phú thọ",
    "thu cusc, taan sown, phus thoj"
  ],
  "Thuần Mỹ, Ba Vì, Hà Nội": [
    "thuần mỹ, ba vì, hà nội",
    "thuaafn myx, ba vif, haf nooji"
  ],
  "Thắng Lợi, Kon Tum, Kon Tum": [
    "thắng lợi, kon tum, kon tum",
    "thawsng lowji, kon tum, kon tum"
  ],
  "Thọ Sơn, Anh Sơn, Nghệ An": [
    "thọ sơn, anh sơn, nghệ an",
    "thoj sown, anh sown, ngheej an"
  ],
  "Thống Nhất, Pleiku, Gia Lai": [
    "thống nhất, pleiku, gia lai",
    "thoosng nhaast, pleiku, gia lai"
  ],
  "Thứ Ba, An Biên, Kiên Giang": [
    "thứ ba, an biên, kiên giang",
    "thuws ba, an bieen, kieen giang"
  ],
  "Tiên Du, Phù Ninh, Phú Thọ": [
    "tiên du, phù ninh, phú thọ",
    "tieen du, phuf ninh, phus thoj"
  ],
  "Tiên Hải, Phủ Lý, Hà Nam": [
    "tiên hải, phủ lý, hà nam",
    "tieen hari, phur lys, haf nam"
  ],
  "Tiên Nội, Duy Tiên, Hà Nam": [
    "tiên nội, duy tiên, hà nam",
    "tieen nooji, duy tieen, haf nam"
  ],
  "Trung An, Vũ Thư, Thái Bình": [
    "trung an, vũ thư, thái bình",
    "trung an, vux thuw, thasi bifnh"
  ],
  "Trà Côn, Trà Ôn, Vĩnh Long": [
    "trà côn, trà ôn, vĩnh long",
    "traf coon, traf oon, vixnh long"
  ],
  "Tràng An, Bình Lục, Hà Nam": [
    "tràng an, bình lục, hà nam",
    "trafng an, bifnh lujc, haf nam"
  ],
  "Trịnh Xá, Phủ Lý, Hà Nam": [
    "trịnh xá, phủ lý, hà nam",
    "trijnh xas, phur lys, haf nam"
  ],
  "Tuy Lai, Mỹ Đức, Hà Nội": [
    "tuy lai, mỹ đức, hà nội",
    "tuy lai, myx dduwsc, haf nooji"
  ],
  "Tuy Lộc, Yên Bái, Yên Bái": [
    "tuy lộc, yên bái, yên bái",
    "tuy loojc, yeen basi, yeen basi"
  ],
  "Tà Chải, Bắc Hà, Lào Cai": [
    "tà chải, bắc hà, lào cai",
    "taf chari, bawsc haf, lafo cai"
  ],
  "Tà Mung, Than Uyên, Lai Châu": [
    "tà mung, than uyên, lai châu",
    "taf mung, than uyeen, lai chaau"
  ],
  "Tà Mít, Tân Uyên, Lai Châu": [
    "tà mít, tân uyên, lai châu",
    "taf mist, taan uyeen, lai chaau"
  ],
  "Tà Đảnh, Tri Tôn, An Giang": [
    "tà đảnh, tri tôn, an giang",
    "taf ddarnh, tri toon, an giang"
  ],
  "Tàm Xá, Đông Anh, Hà Nội": [
    "tàm xá, đông anh, hà nội",
    "tafm xas, ddoong anh, haf nooji"
  ],
  "Tân An, Nghĩa Lộ, Yên Bái": [
    "tân an, nghĩa lộ, yên bái",
    "taan an, nghixa looj, yeen basi"
  ],
  "Tân Bình, Tân Trụ, Long An": [
    "tân bình, tân trụ, long an",
    "taan bifnh, taan truj, long an"
  ],
  "Tân Bình, Đăk Đoa, Gia Lai": [
    "tân bình, đăk đoa, gia lai",
    "taan bifnh, ddawk ddoa, gia lai"
  ],
  "Tân Dân, Sóc Sơn, Hà Nội": [
    "tân dân, sóc sơn, hà nội",
    "taan daan, sosc sown, haf nooji"
  ],
  "Tân Dân, Đầm Dơi, Cà Mau": [
    "tân dân, đầm dơi, cà mau",
    "taan daan, ddaafm dowi, caf mau"
  ],
  "Tân Hà, Tân Châu, Tây Ninh": [
    "tân hà, tân châu, tây ninh",
    "taan haf, taan chaau, taay ninh"
  ],
  "Tân Hòa, Bến Lức, Long An": [
    "tân hòa, bến lức, long an",
    "taan hofa, beesn luwsc, long an"
  ],
  "Tân Hưng, Tân Hưng, Long An": [
    "tân hưng, tân hưng, long an",
    "taan huwng, taan huwng, long an"
  ],
  "Tân Kỳ, Tân Kỳ, Nghệ An": [
    "tân kỳ, tân kỳ, nghệ an",
    "taan kyf, taan kyf, ngheej an"
  ],
  "Tân Long, Tân Kỳ, Nghệ An": [
    "tân long, tân kỳ, nghệ an",
    "taan long, taan kyf, ngheej an"
  ],
  "Tân Lập, Mộc Hóa, Long An": [
    "tân lập, mộc hóa, long an",
    "taan laajp, moojc hosa, long an"
  ],
  "Tân Mai, Hoàng Mai, Hà Nội": [
    "tân mai, hoàng mai, hà nội",
    "taan mai, hoafng mai, haf nooji"
  ],
  "Tân Minh, Sóc Sơn, Hà Nội": [
    "tân minh, sóc sơn, hà nội",
    "taan minh, sosc sown, haf nooji"
  ],
  "Tân Mỹ, Trà Ôn, Vĩnh Long": [
    "tân mỹ, trà ôn, vĩnh long",
    "taan myx, traf oon, vixnh long"
  ],
  "Tân Mỹ, Đức Hòa, Long An": [
    "tân mỹ, đức hòa, long an",
    "taan myx, dduwsc hofa, long an"
  ],
  "Tân Phú, Tân Kỳ, Nghệ An": [
    "tân phú, tân kỳ, nghệ an",
    "taan phus, taan kyf, ngheej an"
  ],
  "Tân Phú, Đức Hòa, Long An": [
    "tân phú, đức hòa, long an",
    "taan phus, dduwsc hofa, long an"
  ],
  "Tân Phúc, Ân Thi, Hưng Yên": [
    "tân phúc, ân thi, hưng yên",
    "taan phusc, aan thi, huwng yeen"
  ],
  "Tân Trung, Phú Tân, An Giang": [
    "tân trung, phú tân, an giang",
    "taan trung, phus taan, an giang"
  ],
  "Tân Trụ, Tân Trụ, Long An": [
    "tân trụ, tân trụ, long an",
    "taan truj, taan truj, long an"
  ],
  "Tây Sơn, Kỳ Sơn, Nghệ An": [
    "tây sơn, kỳ sơn, nghệ an",
    "taay sown, kyf sown, ngheej an"
  ],
  "Tây Đằng, Ba Vì, Hà Nội": [
    "tây đằng, ba vì, hà nội",
    "taay ddawfng, ba vif, haf nooji"
  ],
  "Tú Lý, Đà Bắc, Hoà Bình": [
    "tú lý, đà bắc, hoà bình",
    "tus lys, ddaf bawsc, hoaf bifnh"
  ],
  "Tả Phời, Lào Cai, Lào Cai": [
    "tả phời, lào cai, lào cai",
    "tar phowfi, lafo cai, lafo cai"
  ],
  "Tản Hồng, Ba Vì, Hà Nội": [
    "tản hồng, ba vì, hà nội",
    "tarn hoofng, ba vif, haf nooji"
  ],
  "Tầm Vu, Châu Thành, Long An": [
    "tầm vu, châu thành, long an",
    "taafm vu, chaau thafnh, long an"
  ],
  "Tập Sơn, Trà Cú, Trà Vinh": [
    "tập sơn, trà cú, trà vinh",
    "taajp sown, traf cus, traf vinh"
  ],
  "Tứ Xã, Lâm Thao, Phú Thọ": [
    "tứ xã, lâm thao, phú thọ",
    "tuws xax, laam thao, phus thoj"
  ],
  "Tự Do, Lạc Sơn, Hoà Bình": [
    "tự do, lạc sơn, hoà bình",
    "tuwj do, lajc sown, hoaf bifnh"
  ],
  "Tự Lập, Mê Linh, Hà Nội": [
    "tự lập, mê linh, hà nội",
    "tuwj laajp, mee linh, haf nooji"
  ],
  "Viên An, Ứng Hòa, Hà Nội": [
    "viên an, ứng hòa, hà nội",
    "vieen an, uwsng hofa, haf nooji"
  ],
  "Vân An, Chi Lăng, Lạng Sơn": [
    "vân an, chi lăng, lạng sơn",
    "vaan an, chi lawng, lajng sown"
  ],
  "Vân Hà, Đông Anh, Hà Nội": [
    "vân hà, đông anh, hà nội",
    "vaan haf, ddoong anh, haf nooji"
  ],
  "Vôi, Lạng Giang, Bắc Giang": [
    "vôi, lạng giang, bắc giang",
    "vooi, lajng giang, bawsc giang"
  ],
  "Võng La, Đông Anh, Hà Nội": [
    "võng la, đông anh, hà nội",
    "voxng la, ddoong anh, haf nooji"
  ],
  "Văn Phú, Nho Quan, Ninh Bình": [
    "văn phú, nho quan, ninh bình",
    "vawn phus, nho quan, ninh bifnh"
  ],
  "Văn Phú, Yên Bái, Yên Bái": [
    "văn phú, yên bái, yên bái",
    "vawn phus, yeen basi, yeen basi"
  ],
  "Văn Yên, Hà Tĩnh, Hà Tĩnh": [
    "văn yên, hà tĩnh, hà tĩnh",
    "vawn yeen, haf tixnh, haf tixnh"
  ],
  "Vĩnh Sơn, Anh Sơn, Nghệ An": [
    "vĩnh sơn, anh sơn, nghệ an",
    "vixnh sown, anh sown, ngheej an"
  ],
  "Vĩnh Trụ, Lý Nhân, Hà Nam": [
    "vĩnh trụ, lý nhân, hà nam",
    "vixnh truj, lys nhaan, haf nam"
  ],
  "Vũ Bản, Bình Lục, Hà Nam": [
    "vũ bản, bình lục, hà nam",
    "vux barn, bifnh lujc, haf nam"
  ],
  "Vũ Linh, Yên Bình, Yên Bái": [
    "vũ linh, yên bình, yên bái",
    "vux linh, yeen bifnh, yeen basi"
  ],
  "Vũ Quang, Vũ Quang, Hà Tĩnh": [
    "vũ quang, vũ quang, hà tĩnh",
    "vux quang, vux quang, haf tixnh"
  ],
  "Vũ Thư, Vũ Thư, Thái Bình": [
    "vũ thư, vũ thư, thái bình",
    "vux thuw, vux thuw, thasi bifnh"
  ],
  "Vũ Vinh, Vũ Thư, Thái Bình": [
    "vũ vinh, vũ thư, thái bình",
    "vux vinh, vux thuw, thasi bifnh"
  ],
  "Vũ Vân, Vũ Thư, Thái Bình": [
    "vũ vân, vũ thư, thái bình",
    "vux vaan, vux thuw, thasi bifnh"
  ],
  "Vũ Xá, Lục Nam, Bắc Giang": [
    "vũ xá, lục nam, bắc giang",
    "vux xas, lujc nam, bawsc giang"
  ],
  "Vương, Tiên Lữ, Hưng Yên": [
    "vương, tiên lữ, hưng yên",
    "vuwowng, tieen luwx, huwng yeen"
  ],
  "Vạn Yên, Mê Linh, Hà Nội": [
    "vạn yên, mê linh, hà nội",
    "vajn yeen, mee linh, haf nooji"
  ],
  "Vệ An, Bắc Ninh, Bắc Ninh": [
    "vệ an, bắc ninh, bắc ninh",
    "veej an, bawsc ninh, bawsc ninh"
  ],
  "Xuy Xá, Mỹ Đức, Hà Nội": [
    "xuy xá, mỹ đức, hà nội",
    "xuy xas, myx dduwsc, haf nooji"
  ],
  "Xuân An, Nghi Xuân, Hà Tĩnh": [
    "xuân an, nghi xuân, hà tĩnh",
    "xuaan an, nghi xuaan, haf tixnh"
  ],
  "Xuân Thu, Sóc Sơn, Hà Nội": [
    "xuân thu, sóc sơn, hà nội",
    "xuaan thu, sosc sown, haf nooji"
  ],
  "Xuân Tăng, Lào Cai, Lào Cai": [
    "xuân tăng, lào cai, lào cai",
    "xuaan tawng, lafo cai, lafo cai"
  ],
  "Xuân Ái, Văn Yên, Yên Bái": [
    "xuân ái, văn yên, yên bái",
    "xuaan asi, vawn yeen, yeen basi"
  ],
  "Xím Vàng, Bắc Yên, Sơn La": [
    "xím vàng, bắc yên, sơn la",
    "xism vafng, bawsc yeen, sown la"
  ],
  "Yang Trung, Kông Chro, Gia Lai": [
    "yang trung, kông chro, gia lai",
    "yang trung, koong chro, gia lai"
  ],
  "Yên Châu, Yên Châu, Sơn La": [
    "yên châu, yên châu, sơn la",
    "yeen chaau, yeen chaau, sown la"
  ],
  "Yên Hoa, Na Hang, Tuyên Quang": [
    "yên hoa, na hang, tuyên quang",
    "yeen hoa, na hang, tuyeen quang"
  ],
  "Yên Hòa, Yên Mô, Ninh Bình": [
    "yên hòa, yên mô, ninh bình",
    "yeen hofa, yeen moo, ninh bifnh"
  ],
  "Yên Lâm, Yên Mô, Ninh Bình": [
    "yên lâm, yên mô, ninh bình",
    "yeen laam, yeen moo, ninh bifnh"
  ],
  "Yên Minh, Yên Minh, Hà Giang": [
    "yên minh, yên minh, hà giang",
    "yeen minh, yeen minh, haf giang"
  ],
  "Yên Minh, Ý Yên, Nam Định": [
    "yên minh, ý yên, nam định",
    "yeen minh, ys yeen, nam ddijnh"
  ],
  "Yên Mỹ, Yên Mô, Ninh Bình": [
    "yên mỹ, yên mô, ninh bình",
    "yeen myx, yeen moo, ninh bifnh"
  ],
  "Yên Mỹ, Ý Yên, Nam Định": [
    "yên mỹ, ý yên, nam định",
    "yeen myx, ys yeen, nam ddijnh"
  ],
  "Yên Ninh, Yên Bái, Yên Bái": [
    "yên ninh, yên bái, yên bái",
    "yeen ninh, yeen basi, yeen basi"
  ],
  "Yên Ninh, Ý Yên, Nam Định": [
    "yên ninh, ý yên, nam định",
    "yeen ninh, ys yeen, nam ddijnh"
  ],
  "Yên Phú, Bắc Mê, Hà Giang": [
    "yên phú, bắc mê, hà giang",
    "yeen phus, bawsc mee, haf giang"
  ],
  "Yên Phú, Văn Yên, Yên Bái": [
    "yên phú, văn yên, yên bái",
    "yeen phus, vawn yeen, yeen basi"
  ],
  "Yên Phú, Ý Yên, Nam Định": [
    "yên phú, ý yên, nam định",
    "yeen phus, ys yeen, nam ddijnh"
  ],
  "Yên Sơn, Bảo Yên, Lào Cai": [
    "yên sơn, bảo yên, lào cai",
    "yeen sown, baro yeen, lafo cai"
  ],
  "Yên Tân, Ý Yên, Nam Định": [
    "yên tân, ý yên, nam định",
    "yeen taan, ys yeen, nam ddijnh"
  ],
  "Yên Từ, Yên Mô, Ninh Bình": [
    "yên từ, yên mô, ninh bình",
    "yeen tuwf, yeen moo, ninh bifnh"
  ],
  "Yên Viên, Gia Lâm, Hà Nội": [
    "yên viên, gia lâm, hà nội",
    "yeen vieen, gia laam, haf nooji"
  ],
  "Zuôich, Nam Giang, Quảng Nam": [
    "zuôich, nam giang, quảng nam",
    "zuooich, nam giang, quarng nam"
  ],
  "Âu Cơ, Phú Thọ, Phú Thọ": [
    "âu cơ, phú thọ, phú thọ",
    "aau cow, phus thoj, phus thoj"
  ],
  "Đa Phước, An Phú, An Giang": [
    "đa phước, an phú, an giang",
    "dda phuwowsc, an phus, an giang"
  ],
  "Đak Jơ Ta, Mang Yang, Gia Lai": [
    "đak jơ ta, mang yang, gia lai",
    "ddak jow ta, mang yang, gia lai"
  ],
  "Đak Ta Ley, Mang Yang, Gia Lai": [
    "đak ta ley, mang yang, gia lai",
    "ddak ta ley, mang yang, gia lai"
  ],
  "Đông An, Văn Yên, Yên Bái": [
    "đông an, văn yên, yên bái",
    "ddoong an, vawn yeen, yeen basi"
  ],
  "Đông Dư, Gia Lâm, Hà Nội": [
    "đông dư, gia lâm, hà nội",
    "ddoong duw, gia laam, haf nooji"
  ],
  "Đông Quang, Ba Vì, Hà Nội": [
    "đông quang, ba vì, hà nội",
    "ddoong quang, ba vif, haf nooji"
  ],
  "Đăk Long, Đắk Hà, Kon Tum": [
    "đăk long, đắk hà, kon tum",
    "ddawk long, ddawsk haf, kon tum"
  ],
  "Đăk Song, Kông Chro, Gia Lai": [
    "đăk song, kông chro, gia lai",
    "ddawk song, koong chro, gia lai"
  ],
  "Đăk Trôi, Mang Yang, Gia Lai": [
    "đăk trôi, mang yang, gia lai",
    "ddawk trooi, mang yang, gia lai"
  ],
  "Đăk Đoa, Đăk Đoa, Gia Lai": [
    "đăk đoa, đăk đoa, gia lai",
    "ddawk ddoa, ddawk ddoa, gia lai"
  ],
  "Đại An, Thanh Ba, Phú Thọ": [
    "đại an, thanh ba, phú thọ",
    "ddaji an, thanh ba, phus thoj"
  ],
  "Đắk Hà, Đắk Hà, Kon Tum": [
    "đắk hà, đắk hà, kon tum",
    "ddawsk haf, ddawsk haf, kon tum"
  ],
  "Đắk Kôi, Kon Rẫy, Kon Tum": [
    "đắk kôi, kon rẫy, kon tum",
    "ddawsk kooi, kon raaxy, kon tum"
  ],
  "Đắk Mar, Đắk Hà, Kon Tum": [
    "đắk mar, đắk hà, kon tum",
    "ddawsk mar, ddawsk haf, kon tum"
  ],
  "Đắk PXi, Đắk Hà, Kon Tum": [
    "đắk pxi, đắk hà, kon tum",
    "ddawsk pxi, ddawsk haf, kon tum"
  ],
  "Đắk Rơ Wa, Kon Tum, Kon Tum": [
    "đắk rơ wa, kon tum, kon tum",
    "ddawsk row wa, kon tum, kon tum"
  ],
  "Đắk Tô, Đắk Tô, Kon Tum": [
    "đắk tô, đắk tô, kon tum",
    "ddawsk too, ddawsk too, kon tum"
  ],
  "Định An, Trà Cú, Trà Vinh": [
    "định an, trà cú, trà vinh",
    "ddijnh an, traf cus, traf vinh"
  ],
  "Định Bình, Cà Mau, Cà Mau": [
    "định bình, cà mau, cà mau",
    "ddijnh bifnh, caf mau, caf mau"
  ],
  "Đứa Mòn, Sông Mã, Sơn La": [
    "đứa mòn, sông mã, sơn la",
    "dduwsa mofn, soong max, sown la"
  ],
  "A Ngo, Đa Krông, Quảng Trị": [
    "a ngo, đa krông, quảng trị",
    "a ngo, dda kroong, quarng trij"
  ],
  "A Nông, Tây Giang, Quảng Nam": [
    "a nông, tây giang, quảng nam",
    "a noong, taay giang, quarng nam"
  ],
  "A Vao, Đa Krông, Quảng Trị": [
    "a vao, đa krông, quảng trị",
    "a vao, dda kroong, quarng trij"
  ],
  "An Bình Tây, Ba Tri, Bến Tre": [
    "an bình tây, ba tri, bến tre",
    "an bifnh taay, ba tri, beesn tre"
  ],
  "An Bình, Thoại Sơn, An Giang": [
    "an bình, thoại sơn, an giang",
    "an bifnh, thoaji sown, an giang"
  ],
  "An Châu, Châu Thành, An Giang": [
    "an châu, châu thành, an giang",
    "an chaau, chaau thafnh, an giang"
  ],
  "An Dũng, An Lão, Bình Định": [
    "an dũng, an lão, bình định",
    "an duxng, an laxo, bifnh ddijnh"
  ],
  "An Hoà, Sa Đéc, Đồng Tháp": [
    "an hoà, sa đéc, đồng tháp",
    "an hoaf, sa ddesc, ddoofng thasp"
  ],
  "An Hòa Hải, Tuy An, Phú Yên": [
    "an hòa hải, tuy an, phú yên",
    "an hofa hari, tuy an, phus yeen"
  ],
  "An Hòa, Biên Hòa, Đồng Nai": [
    "an hòa, biên hòa, đồng nai",
    "an hofa, bieen hofa, ddoofng nai"
  ],
  "An Hòa, Ninh Kiều, Cần Thơ": [
    "an hòa, ninh kiều, cần thơ",
    "an hofa, ninh kieefu, caafn thow"
  ],
  "An Hòa, Quỳnh Lưu, Nghệ An": [
    "an hòa, quỳnh lưu, nghệ an",
    "an hofa, quyfnh luwu, ngheej an"
  ],
  "An Hóa, Châu Thành, Bến Tre": [
    "an hóa, châu thành, bến tre",
    "an hosa, chaau thafnh, beesn tre"
  ],
  "An Hưng, An Lão, Bình Định": [
    "an hưng, an lão, bình định",
    "an huwng, an laxo, bifnh ddijnh"
  ],
  "An Hưng, Thanh Hóa, Thanh Hóa": [
    "an hưng, thanh hóa, thanh hóa",
    "an huwng, thanh hosa, thanh hosa"
  ],
  "An Hảo, Tịnh Biên, An Giang": [
    "an hảo, tịnh biên, an giang",
    "an haro, tijnh bieen, an giang"
  ],
  "An Hữu, Cái Bè, Tiền Giang": [
    "an hữu, cái bè, tiền giang",
    "an huwxu, casi bef, tieefn giang"
  ],
  "An Khê, Thanh Khê, Đà Nẵng": [
    "an khê, thanh khê, đà nẵng",
    "an khee, thanh khee, ddaf nawxng"
  ],
  "An Mỹ, Kế Sách, Sóc Trăng": [
    "an mỹ, kế sách, sóc trăng",
    "an myx, kees sasch, sosc trawng"
  ],
  "An Ngãi Tây, Ba Tri, Bến Tre": [
    "an ngãi tây, ba tri, bến tre",
    "an ngaxi taay, ba tri, beesn tre"
  ],
  "An Nông, Tịnh Biên, An Giang": [
    "an nông, tịnh biên, an giang",
    "an noong, tijnh bieen, an giang"
  ],
  "An Phú Trung, Ba Tri, Bến Tre": [
    "an phú trung, ba tri, bến tre",
    "an phus trung, ba tri, beesn tre"
  ],
  "An Phú, Ninh Kiều, Cần Thơ": [
    "an phú, ninh kiều, cần thơ",
    "an phus, ninh kieefu, caafn thow"
  ],
  "An Quang, An Lão, Bình Định": [
    "an quang, an lão, bình định",
    "an quang, an laxo, bifnh ddijnh"
  ],
  "An Thạnh, Bến Lức, Long An": [
    "an thạnh, bến lức, long an",
    "an thajnh, beesn luwsc, long an"
  ],
  "An Thịnh, Văn Yên, Yên Bái": [
    "an thịnh, văn yên, yên bái",
    "an thijnh, vawn yeen, yeen basi"
  ],
  "An Tiến, An Lão, Hải Phòng": [
    "an tiến, an lão, hải phòng",
    "an tieesn, an laxo, hari phofng"
  ],
  "An Toàn, An Lão, Bình Định": [
    "an toàn, an lão, bình định",
    "an toafn, an laxo, bifnh ddijnh"
  ],
  "An Trung, An Lão, Bình Định": [
    "an trung, an lão, bình định",
    "an trung, an laxo, bifnh ddijnh"
  ],
  "An Tảo, Hưng Yên, Hưng Yên": [
    "an tảo, hưng yên, hưng yên",
    "an taro, huwng yeen, huwng yeen"
  ],
  "An Viên, Tiên Lữ, Hưng Yên": [
    "an viên, tiên lữ, hưng yên",
    "an vieen, tieen luwx, huwng yeen"
  ],
  "An Vĩ, Khoái Châu, Hưng Yên": [
    "an vĩ, khoái châu, hưng yên",
    "an vix, khoasi chaau, huwng yeen"
  ],
  "An Vĩnh Ngãi, Tân An, Long An": [
    "an vĩnh ngãi, tân an, long an",
    "an vixnh ngaxi, taan an, long an"
  ],
  "An Đạo, Phù Ninh, Phú Thọ": [
    "an đạo, phù ninh, phú thọ",
    "an ddajo, phuf ninh, phus thoj"
  ],
  "Ayun Hạ, Phú Thiện, Gia Lai": [
    "ayun hạ, phú thiện, gia lai",
    "ayun haj, phus thieejn, gia lai"
  ],
  "B' Lá, Bảo Lâm, Lâm Đồng": [
    "b' lá, bảo lâm, lâm đồng",
    "b' las, baro laam, laam ddoofng"
  ],
  "B'lao, Bảo Lộc, Lâm Đồng": [
    "b'lao, bảo lộc, lâm đồng",
    "b'lao, baro loojc, laam ddoofng"
  ],
  "Ba Chẽ, Ba Chẽ, Quảng Ninh": [
    "ba chẽ, ba chẽ, quảng ninh",
    "ba chex, ba chex, quarng ninh"
  ],
  "Ba Láng, Cái Răng, Cần Thơ": [
    "ba láng, cái răng, cần thơ",
    "ba lasng, casi rawng, caafn thow"
  ],
  "Ba Ngạc, Ba Tơ, Quảng Ngãi": [
    "ba ngạc, ba tơ, quảng ngãi",
    "ba ngajc, ba tow, quarng ngaxi"
  ],
  "Ba Sao, Cao Lãnh, Đồng Tháp": [
    "ba sao, cao lãnh, đồng tháp",
    "ba sao, cao laxnh, ddoofng thasp"
  ],
  "Ba Thành, Ba Tơ, Quảng Ngãi": [
    "ba thành, ba tơ, quảng ngãi",
    "ba thafnh, ba tow, quarng ngaxi"
  ],
  "Bha Lê, Tây Giang, Quảng Nam": [
    "bha lê, tây giang, quảng nam",
    "bha lee, taay giang, quarng nam"
  ],
  "Buôn Tría, Lắk, Đắk Lắk": [
    "buôn tría, lắk, đắk lắk",
    "buoon trisa, lawsk, ddawsk lawsk"
  ],
  "Bàu Cạn, Chư Prông, Gia Lai": [
    "bàu cạn, chư prông, gia lai",
    "bafu cajn, chuw proong, gia lai"
  ],
  "Bát Tràng, Gia Lâm, Hà Nội": [
    "bát tràng, gia lâm, hà nội",
    "bast trafng, gia laam, haf nooji"
  ],
  "Bình La, Bình Gia, Lạng Sơn": [
    "bình la, bình gia, lạng sơn",
    "bifnh la, bifnh gia, lajng sown"
  ],
  "Bình Long, Châu Phú, An Giang": [
    "bình long, châu phú, an giang",
    "bifnh long, chaau phus, an giang"
  ],
  "Bình Lãng, Tân Trụ, Long An": [
    "bình lãng, tân trụ, long an",
    "bifnh laxng, taan truj, long an"
  ],
  "Bình Minh, Kim Sơn, Ninh Bình": [
    "bình minh, kim sơn, ninh bình",
    "bifnh minh, kim sown, ninh bifnh"
  ],
  "Bình Minh, Thanh Oai, Hà Nội": [
    "bình minh, thanh oai, hà nội",
    "bifnh minh, thanh oai, haf nooji"
  ],
  "Bình Minh, Tây Ninh, Tây Ninh": [
    "bình minh, tây ninh, tây ninh",
    "bifnh minh, taay ninh, taay ninh"
  ],
  "Bình Mỹ, Bình Lục, Hà Nam": [
    "bình mỹ, bình lục, hà nam",
    "bifnh myx, bifnh lujc, haf nam"
  ],
  "Bình Mỹ, Châu Phú, An Giang": [
    "bình mỹ, châu phú, an giang",
    "bifnh myx, chaau phus, an giang"
  ],
  "Bình Phú, Bến Tre, Bến Tre": [
    "bình phú, bến tre, bến tre",
    "bifnh phus, beesn tre, beesn tre"
  ],
  "Bình Phú, Châu Phú, An Giang": [
    "bình phú, châu phú, an giang",
    "bifnh phus, chaau phus, an giang"
  ],
  "Bình Sơn, Kim Bôi, Hoà Bình": [
    "bình sơn, kim bôi, hoà bình",
    "bifnh sown, kim booi, hoaf bifnh"
  ],
  "Bình Tân, La Gi, Bình Thuận": [
    "bình tân, la gi, bình thuận",
    "bifnh taan, la gi, bifnh thuaajn"
  ],
  "Bích Hòa, Thanh Oai, Hà Nội": [
    "bích hòa, thanh oai, hà nội",
    "bisch hofa, thanh oai, haf nooji"
  ],
  "Bông Krang, Lắk, Đắk Lắk": [
    "bông krang, lắk, đắk lắk",
    "boong krang, lawsk, ddawsk lawsk"
  ],
  "Bản Phố, Bắc Hà, Lào Cai": [
    "bản phố, bắc hà, lào cai",
    "barn phoos, bawsc haf, lafo cai"
  ],
  "Bảo Thuận, Ba Tri, Bến Tre": [
    "bảo thuận, ba tri, bến tre",
    "baro thuaajn, ba tri, beesn tre"
  ],
  "Bảo Thạnh, Ba Tri, Bến Tre": [
    "bảo thạnh, ba tri, bến tre",
    "baro thajnh, ba tri, beesn tre"
  ],
  "Bảo Ái, Yên Bình, Yên Bái": [
    "bảo ái, yên bình, yên bái",
    "baro asi, yeen bifnh, yeen basi"
  ],
  "Bắc Lệnh, Lào Cai, Lào Cai": [
    "bắc lệnh, lào cai, lào cai",
    "bawsc leejnh, lafo cai, lafo cai"
  ],
  "Bắc Phú, Sóc Sơn, Hà Nội": [
    "bắc phú, sóc sơn, hà nội",
    "bawsc phus, sosc sown, haf nooji"
  ],
  "Bắc Sơn, Sóc Sơn, Hà Nội": [
    "bắc sơn, sóc sơn, hà nội",
    "bawsc sown, sosc sown, haf nooji"
  ],
  "Bằng An, Quế Võ, Bắc Ninh": [
    "bằng an, quế võ, bắc ninh",
    "bawfng an, quees vox, bawsc ninh"
  ],
  "Bồ Đề, Bình Lục, Hà Nam": [
    "bồ đề, bình lục, hà nam",
    "boof ddeef, bifnh lujc, haf nam"
  ],
  "Cam Bình, Cam Ranh, Khánh Hòa": [
    "cam bình, cam ranh, khánh hòa",
    "cam bifnh, cam ranh, khasnh hofa"
  ],
  "Cam Lập, Cam Ranh, Khánh Hòa": [
    "cam lập, cam ranh, khánh hòa",
    "cam laajp, cam ranh, khasnh hofa"
  ],
  "Cam Lộc, Cam Ranh, Khánh Hòa": [
    "cam lộc, cam ranh, khánh hòa",
    "cam loojc, cam ranh, khasnh hofa"
  ],
  "Cam Lợi, Cam Ranh, Khánh Hòa": [
    "cam lợi, cam ranh, khánh hòa",
    "cam lowji, cam ranh, khasnh hofa"
  ],
  "Cam Thượng, Ba Vì, Hà Nội": [
    "cam thượng, ba vì, hà nội",
    "cam thuwowjng, ba vif, haf nooji"
  ],
  "Cao Bồ, Vị Xuyên, Hà Giang": [
    "cao bồ, vị xuyên, hà giang",
    "cao boof, vij xuyeen, haf giang"
  ],
  "Cao Lâu, Cao Lộc, Lạng Sơn": [
    "cao lâu, cao lộc, lạng sơn",
    "cao laau, cao loojc, lajng sown"
  ],
  "Cao Phong, Cao Phong, Hoà Bình": [
    "cao phong, cao phong, hoà bình",
    "cao phong, cao phong, hoaf bifnh"
  ],
  "Cao Sơn, Đà Bắc, Hoà Bình": [
    "cao sơn, đà bắc, hoà bình",
    "cao sown, ddaf bawsc, hoaf bifnh"
  ],
  "Chi Lăng, Quế Võ, Bắc Ninh": [
    "chi lăng, quế võ, bắc ninh",
    "chi lawng, quees vox, bawsc ninh"
  ],
  "Chiềng Dong, Mai Sơn, Sơn La": [
    "chiềng dong, mai sơn, sơn la",
    "chieefng dong, mai sown, sown la"
  ],
  "Chiềng Kheo, Mai Sơn, Sơn La": [
    "chiềng kheo, mai sơn, sơn la",
    "chieefng kheo, mai sown, sown la"
  ],
  "Chiềng Mung, Mai Sơn, Sơn La": [
    "chiềng mung, mai sơn, sơn la",
    "chieefng mung, mai sown, sown la"
  ],
  "Chiềng Nơi, Mai Sơn, Sơn La": [
    "chiềng nơi, mai sơn, sơn la",
    "chieefng nowi, mai sown, sown la"
  ],
  "Chiềng On, Yên Châu, Sơn La": [
    "chiềng on, yên châu, sơn la",
    "chieefng on, yeen chaau, sown la"
  ],
  "Chiềng Sung, Mai Sơn, Sơn La": [
    "chiềng sung, mai sơn, sơn la",
    "chieefng sung, mai sown, sown la"
  ],
  "Chiềng Sơ, Sông Mã, Sơn La": [
    "chiềng sơ, sông mã, sơn la",
    "chieefng sow, soong max, sown la"
  ],
  "Chí Tiên, Thanh Ba, Phú Thọ": [
    "chí tiên, thanh ba, phú thọ",
    "chis tieen, thanh ba, phus thoj"
  ],
  "Chăn Nưa, Sìn Hồ, Lai Châu": [
    "chăn nưa, sìn hồ, lai châu",
    "chawn nuwa, sifn hoof, lai chaau"
  ],
  "Chế Là, Xín Mần, Hà Giang": [
    "chế là, xín mần, hà giang",
    "chees laf, xisn maafn, haf giang"
  ],
  "Co Tòng, Thuận Châu, Sơn La": [
    "co tòng, thuận châu, sơn la",
    "co tofng, thuaajn chaau, sown la"
  ],
  "Cà Nàng, Quỳnh Nhai, Sơn La": [
    "cà nàng, quỳnh nhai, sơn la",
    "caf nafng, quyfnh nhai, sown la"
  ],
  "Các Sơn, Tĩnh Gia, Thanh Hóa": [
    "các sơn, tĩnh gia, thanh hóa",
    "casc sown, tixnh gia, thanh hosa"
  ],
  "Cái Bè, Cái Bè, Tiền Giang": [
    "cái bè, cái bè, tiền giang",
    "casi bef, casi bef, tieefn giang"
  ],
  "Cái Dầu, Châu Phú, An Giang": [
    "cái dầu, châu phú, an giang",
    "casi daafu, chaau phus, an giang"
  ],
  "Cô Ngân, Hạ Lang, Cao Bằng": [
    "cô ngân, hạ lang, cao bằng",
    "coo ngaan, haj lang, cao bawfng"
  ],
  "Côn Lôn, Na Hang, Tuyên Quang": [
    "côn lôn, na hang, tuyên quang",
    "coon loon, na hang, tuyeen quang"
  ],
  "Cư KBang, Ea Súp, Đắk Lắk": [
    "cư kbang, ea súp, đắk lắk",
    "cuw kbang, ea susp, ddawsk lawsk"
  ],
  "Cư Knia, Cư Jút, Đắk Nông": [
    "cư knia, cư jút, đắk nông",
    "cuw knia, cuw just, ddawsk noong"
  ],
  "Cư M'Lan, Ea Súp, Đắk Lắk": [
    "cư m'lan, ea súp, đắk lắk",
    "cuw m'lan, ea susp, ddawsk lawsk"
  ],
  "Cư Prông, Ea Kar, Đắk Lắk": [
    "cư prông, ea kar, đắk lắk",
    "cuw proong, ea kar, ddawsk lawsk"
  ],
  "Cư San, M'Đrắk, Đắk Lắk": [
    "cư san, m'đrắk, đắk lắk",
    "cuw san, m'ddrawsk, ddawsk lawsk"
  ],
  "Cảm Ân, Yên Bình, Yên Bái": [
    "cảm ân, yên bình, yên bái",
    "carm aan, yeen bifnh, yeen basi"
  ],
  "Cẩm Hà, Hội An, Quảng Nam": [
    "cẩm hà, hội an, quảng nam",
    "caarm haf, hooji an, quarng nam"
  ],
  "Cẩm Kim, Hội An, Quảng Nam": [
    "cẩm kim, hội an, quảng nam",
    "caarm kim, hooji an, quarng nam"
  ],
  "Cẩm Nam, Hội An, Quảng Nam": [
    "cẩm nam, hội an, quảng nam",
    "caarm nam, hooji an, quarng nam"
  ],
  "Cẩm Xá, Mỹ Hào, Hưng Yên": [
    "cẩm xá, mỹ hào, hưng yên",
    "caarm xas, myx hafo, huwng yeen"
  ],
  "Cốc Lầu, Bắc Hà, Lào Cai": [
    "cốc lầu, bắc hà, lào cai",
    "coosc laafu, bawsc haf, lafo cai"
  ],
  "Cồn Thoi, Kim Sơn, Ninh Bình": [
    "cồn thoi, kim sơn, ninh bình",
    "coofn thoi, kim sown, ninh bifnh"
  ],
  "Diên Bình, Đắk Tô, Kon Tum": [
    "diên bình, đắk tô, kon tum",
    "dieen bifnh, ddawsk too, kon tum"
  ],
  "Duy Thu, Duy Xuyên, Quảng Nam": [
    "duy thu, duy xuyên, quảng nam",
    "duy thu, duy xuyeen, quarng nam"
  ],
  "Duyên Hải, Lào Cai, Lào Cai": [
    "duyên hải, lào cai, lào cai",
    "duyeen hari, lafo cai, lafo cai"
  ],
  "Dào San, Phong Thổ, Lai Châu": [
    "dào san, phong thổ, lai châu",
    "dafo san, phong thoor, lai chaau"
  ],
  "Dương Hà, Gia Lâm, Hà Nội": [
    "dương hà, gia lâm, hà nội",
    "duwowng haf, gia laam, haf nooji"
  ],
  "Dương Xá, Gia Lâm, Hà Nội": [
    "dương xá, gia lâm, hà nội",
    "duwowng xas, gia laam, haf nooji"
  ],
  "Dền Sáng, Bát Xát, Lào Cai": [
    "dền sáng, bát xát, lào cai",
    "deefn sasng, bast xast, lafo cai"
  ],
  "Dị Sử, Mỹ Hào, Hưng Yên": [
    "dị sử, mỹ hào, hưng yên",
    "dij suwr, myx hafo, huwng yeen"
  ],
  "Dồm Cang, Sốp Cộp, Sơn La": [
    "dồm cang, sốp cộp, sơn la",
    "doofm cang, soosp coojp, sown la"
  ],
  "Dục Tú, Đông Anh, Hà Nội": [
    "dục tú, đông anh, hà nội",
    "dujc tus, ddoong anh, haf nooji"
  ],
  "Ea H'leo, Ea H'leo, Đắk Lắk": [
    "ea h'leo, ea h'leo, đắk lắk",
    "ea h'leo, ea h'leo, ddawsk lawsk"
  ],
  "Ea KPam, Cư M'gar, Đắk Lắk": [
    "ea kpam, cư m'gar, đắk lắk",
    "ea kpam, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Na, Krông A Na, Đắk Lắk": [
    "ea na, krông a na, đắk lắk",
    "ea na, kroong a na, ddawsk lawsk"
  ],
  "Ea Tiêu, Cư Kuin, Đắk Lắk": [
    "ea tiêu, cư kuin, đắk lắk",
    "ea tieeu, cuw kuin, ddawsk lawsk"
  ],
  "Gia Bình, Gia Bình, Bắc Ninh": [
    "gia bình, gia bình, bắc ninh",
    "gia bifnh, gia bifnh, bawsc ninh"
  ],
  "Gia Bắc, Di Linh, Lâm Đồng": [
    "gia bắc, di linh, lâm đồng",
    "gia bawsc, di linh, laam ddoofng"
  ],
  "Gia Cát, Cao Lộc, Lạng Sơn": [
    "gia cát, cao lộc, lạng sơn",
    "gia cast, cao loojc, lajng sown"
  ],
  "Gia Hòa, Gia Viễn, Ninh Bình": [
    "gia hòa, gia viễn, ninh bình",
    "gia hofa, gia vieexn, ninh bifnh"
  ],
  "Gia Lâm, Lâm Hà, Lâm Đồng": [
    "gia lâm, lâm hà, lâm đồng",
    "gia laam, laam haf, laam ddoofng"
  ],
  "Gia Minh, Gia Viễn, Ninh Bình": [
    "gia minh, gia viễn, ninh bình",
    "gia minh, gia vieexn, ninh bifnh"
  ],
  "Gia Phú, Gia Viễn, Ninh Bình": [
    "gia phú, gia viễn, ninh bình",
    "gia phus, gia vieexn, ninh bifnh"
  ],
  "Gia Sinh, Gia Viễn, Ninh Bình": [
    "gia sinh, gia viễn, ninh bình",
    "gia sinh, gia vieexn, ninh bifnh"
  ],
  "Gia Thanh, Phù Ninh, Phú Thọ": [
    "gia thanh, phù ninh, phú thọ",
    "gia thanh, phuf ninh, phus thoj"
  ],
  "Gia Thủy, Nho Quan, Ninh Bình": [
    "gia thủy, nho quan, ninh bình",
    "gia thury, nho quan, ninh bifnh"
  ],
  "Gia Tân, Gia Viễn, Ninh Bình": [
    "gia tân, gia viễn, ninh bình",
    "gia taan, gia vieexn, ninh bifnh"
  ],
  "Gia Vân, Gia Viễn, Ninh Bình": [
    "gia vân, gia viễn, ninh bình",
    "gia vaan, gia vieexn, ninh bifnh"
  ],
  "Giai Xuân, Tân Kỳ, Nghệ An": [
    "giai xuân, tân kỳ, nghệ an",
    "giai xuaan, taan kyf, ngheej an"
  ],
  "Giao An, Lang Chánh, Thanh Hóa": [
    "giao an, lang chánh, thanh hóa",
    "giao an, lang chasnh, thanh hosa"
  ],
  "Gio Mai, Gio Linh, Quảng Trị": [
    "gio mai, gio linh, quảng trị",
    "gio mai, gio linh, quarng trij"
  ],
  "Hiên Vân, Tiên Du, Bắc Ninh": [
    "hiên vân, tiên du, bắc ninh",
    "hieen vaan, tieen du, bawsc ninh"
  ],
  "Hiệp Tùng, Năm Căn, Cà Mau": [
    "hiệp tùng, năm căn, cà mau",
    "hieejp tufng, nawm cawn, caf mau"
  ],
  "Hoà Mỹ, Cái Nước, Cà Mau": [
    "hoà mỹ, cái nước, cà mau",
    "hoaf myx, casi nuwowsc, caf mau"
  ],
  "Hoàn Sơn, Tiên Du, Bắc Ninh": [
    "hoàn sơn, tiên du, bắc ninh",
    "hoafn sown, tieen du, bawsc ninh"
  ],
  "Hoàng Tung, Hoà An, Cao Bằng": [
    "hoàng tung, hoà an, cao bằng",
    "hoafng tung, hoaf an, cao bawfng"
  ],
  "Hoàng Tây, Kim Bảng, Hà Nam": [
    "hoàng tây, kim bảng, hà nam",
    "hoafng taay, kim barng, haf nam"
  ],
  "Huy Tường, Phù Yên, Sơn La": [
    "huy tường, phù yên, sơn la",
    "huy tuwowfng, phuf yeen, sown la"
  ],
  "Huổi Một, Sông Mã, Sơn La": [
    "huổi một, sông mã, sơn la",
    "huoori moojt, soong max, sown la"
  ],
  "Hà Bình, Hà Trung, Thanh Hóa": [
    "hà bình, hà trung, thanh hóa",
    "haf bifnh, haf trung, thanh hosa"
  ],
  "Hà Bắc, Hà Trung, Thanh Hóa": [
    "hà bắc, hà trung, thanh hóa",
    "haf bawsc, haf trung, thanh hosa"
  ],
  "Hà Châu, Hà Trung, Thanh Hóa": [
    "hà châu, hà trung, thanh hóa",
    "haf chaau, haf trung, thanh hosa"
  ],
  "Hà Cầu, Hà Đông, Hà Nội": [
    "hà cầu, hà đông, hà nội",
    "haf caafu, haf ddoong, haf nooji"
  ],
  "Hà Giang, Hà Trung, Thanh Hóa": [
    "hà giang, hà trung, thanh hóa",
    "haf giang, haf trung, thanh hosa"
  ],
  "Hà Hiệu, Ba Bể, Bắc Kạn": [
    "hà hiệu, ba bể, bắc kạn",
    "haf hieeju, ba beer, bawsc kajn"
  ],
  "Hà Hải, Hà Trung, Thanh Hóa": [
    "hà hải, hà trung, thanh hóa",
    "haf hari, haf trung, thanh hosa"
  ],
  "Hà Lĩnh, Hà Trung, Thanh Hóa": [
    "hà lĩnh, hà trung, thanh hóa",
    "haf lixnh, haf trung, thanh hosa"
  ],
  "Hà Thái, Hà Trung, Thanh Hóa": [
    "hà thái, hà trung, thanh hóa",
    "haf thasi, haf trung, thanh hosa"
  ],
  "Hà Trung, Hà Trung, Thanh Hóa": [
    "hà trung, hà trung, thanh hóa",
    "haf trung, haf trung, thanh hosa"
  ],
  "Hàng Vịnh, Năm Căn, Cà Mau": [
    "hàng vịnh, năm căn, cà mau",
    "hafng vijnh, nawm cawn, caf mau"
  ],
  "Hán Đà, Yên Bình, Yên Bái": [
    "hán đà, yên bình, yên bái",
    "hasn ddaf, yeen bifnh, yeen basi"
  ],
  "Hòa An, Cẩm Lệ, Đà Nẵng": [
    "hòa an, cẩm lệ, đà nẵng",
    "hofa an, caarm leej, ddaf nawxng"
  ],
  "Hòa Bình, Trà Ôn, Vĩnh Long": [
    "hòa bình, trà ôn, vĩnh long",
    "hofa bifnh, traf oon, vixnh long"
  ],
  "Hòa Cư, Cao Lộc, Lạng Sơn": [
    "hòa cư, cao lộc, lạng sơn",
    "hofa cuw, cao loojc, lajng sown"
  ],
  "Hòa Hội, Phú Hoà, Phú Yên": [
    "hòa hội, phú hoà, phú yên",
    "hofa hooji, phus hoaf, phus yeen"
  ],
  "Hòa Kiến, Tuy Hoà, Phú Yên": [
    "hòa kiến, tuy hoà, phú yên",
    "hofa kieesn, tuy hoaf, phus yeen"
  ],
  "Hòa Lâm, Ứng Hòa, Hà Nội": [
    "hòa lâm, ứng hòa, hà nội",
    "hofa laam, uwsng hofa, haf nooji"
  ],
  "Hòa Ninh, Di Linh, Lâm Đồng": [
    "hòa ninh, di linh, lâm đồng",
    "hofa ninh, di linh, laam ddoofng"
  ],
  "Hòa Ninh, Long Hồ, Vĩnh Long": [
    "hòa ninh, long hồ, vĩnh long",
    "hofa ninh, long hoof, vixnh long"
  ],
  "Hòa Phong, Tây Hoà, Phú Yên": [
    "hòa phong, tây hoà, phú yên",
    "hofa phong, taay hoaf, phus yeen"
  ],
  "Hòa Phú, Châu Thành, Long An": [
    "hòa phú, châu thành, long an",
    "hofa phus, chaau thafnh, long an"
  ],
  "Hòa Phú, Long Hồ, Vĩnh Long": [
    "hòa phú, long hồ, vĩnh long",
    "hofa phus, long hoof, vixnh long"
  ],
  "Hòa Phú, Ứng Hòa, Hà Nội": [
    "hòa phú, ứng hòa, hà nội",
    "hofa phus, uwsng hofa, haf nooji"
  ],
  "Hòa Trị, Phú Hoà, Phú Yên": [
    "hòa trị, phú hoà, phú yên",
    "hofa trij, phus hoaf, phus yeen"
  ],
  "Hóa An, Biên Hòa, Đồng Nai": [
    "hóa an, biên hòa, đồng nai",
    "hosa an, bieen hofa, ddoofng nai"
  ],
  "Hùng An, Bắc Quang, Hà Giang": [
    "hùng an, bắc quang, hà giang",
    "hufng an, bawsc quang, haf giang"
  ],
  "Hùng Sơn, Kim Bôi, Hoà Bình": [
    "hùng sơn, kim bôi, hoà bình",
    "hufng sown, kim booi, hoaf bifnh"
  ],
  "Hạ Hoà, Hạ Hoà, Phú Thọ": [
    "hạ hoà, hạ hoà, phú thọ",
    "haj hoaf, haj hoaf, phus thoj"
  ],
  "Hải Hà, Tĩnh Gia, Thanh Hóa": [
    "hải hà, tĩnh gia, thanh hóa",
    "hari haf, tixnh gia, thanh hosa"
  ],
  "Hố Mít, Tân Uyên, Lai Châu": [
    "hố mít, tân uyên, lai châu",
    "hoos mist, taan uyeen, lai chaau"
  ],
  "Hồ, Thuận Thành, Bắc Ninh": [
    "hồ, thuận thành, bắc ninh",
    "hoof, thuaajn thafnh, bawsc ninh"
  ],
  "Hồi Ninh, Kim Sơn, Ninh Bình": [
    "hồi ninh, kim sơn, ninh bình",
    "hoofi ninh, kim sown, ninh bifnh"
  ],
  "Hồng Hà, Yên Bái, Yên Bái": [
    "hồng hà, yên bái, yên bái",
    "hoofng haf, yeen basi, yeen basi"
  ],
  "Hồng Thu, Sìn Hồ, Lai Châu": [
    "hồng thu, sìn hồ, lai châu",
    "hoofng thu, sifn hoof, lai chaau"
  ],
  "Hồng Vân, Ân Thi, Hưng Yên": [
    "hồng vân, ân thi, hưng yên",
    "hoofng vaan, aan thi, huwng yeen"
  ],
  "Hộ Độ, Lộc Hà, Hà Tĩnh": [
    "hộ độ, lộc hà, hà tĩnh",
    "hooj ddooj, loojc haf, haf tixnh"
  ],
  "Hợp Minh, Yên Bái, Yên Bái": [
    "hợp minh, yên bái, yên bái",
    "howjp minh, yeen basi, yeen basi"
  ],
  "Hợp Thành, Lào Cai, Lào Cai": [
    "hợp thành, lào cai, lào cai",
    "howjp thafnh, lafo cai, lafo cai"
  ],
  "Hữu Vinh, Yên Minh, Hà Giang": [
    "hữu vinh, yên minh, hà giang",
    "huwxu vinh, yeen minh, haf giang"
  ],
  "Ia Mơ Nông, Chư Păh, Gia Lai": [
    "ia mơ nông, chư păh, gia lai",
    "ia mow noong, chuw pawh, gia lai"
  ],
  "Khang Ninh, Ba Bể, Bắc Kạn": [
    "khang ninh, ba bể, bắc kạn",
    "khang ninh, ba beer, bawsc kajn"
  ],
  "Khau Tinh, Na Hang, Tuyên Quang": [
    "khau tinh, na hang, tuyên quang",
    "khau tinh, na hang, tuyeen quang"
  ],
  "Khánh Yên, Văn Bàn, Lào Cai": [
    "khánh yên, văn bàn, lào cai",
    "khasnh yeen, vawn bafn, lafo cai"
  ],
  "Khâu Vai, Mèo Vạc, Hà Giang": [
    "khâu vai, mèo vạc, hà giang",
    "khaau vai, mefo vajc, haf giang"
  ],
  "Khả Phong, Kim Bảng, Hà Nam": [
    "khả phong, kim bảng, hà nam",
    "khar phong, kim barng, haf nam"
  ],
  "Kim Chung, Đông Anh, Hà Nội": [
    "kim chung, đông anh, hà nội",
    "kim chung, ddoong anh, haf nooji"
  ],
  "Kim Chính, Kim Sơn, Ninh Bình": [
    "kim chính, kim sơn, ninh bình",
    "kim chisnh, kim sown, ninh bifnh"
  ],
  "Kim Hoa, Hương Sơn, Hà Tĩnh": [
    "kim hoa, hương sơn, hà tĩnh",
    "kim hoa, huwowng sown, haf tixnh"
  ],
  "Kim Hòa, Cầu Ngang, Trà Vinh": [
    "kim hòa, cầu ngang, trà vinh",
    "kim hofa, caafu ngang, traf vinh"
  ],
  "Kim Linh, Vị Xuyên, Hà Giang": [
    "kim linh, vị xuyên, hà giang",
    "kim linh, vij xuyeen, haf giang"
  ],
  "Kim Sơn, Quế Phong, Nghệ An": [
    "kim sơn, quế phong, nghệ an",
    "kim sown, quees phong, ngheej an"
  ],
  "Kim Đông, Kim Sơn, Ninh Bình": [
    "kim đông, kim sơn, ninh bình",
    "kim ddoong, kim sown, ninh bifnh"
  ],
  "Kiến An, Chợ Mới, An Giang": [
    "kiến an, chợ mới, an giang",
    "kieesn an, chowj mowsi, an giang"
  ],
  "Krông Năng, Krông Pa, Gia Lai": [
    "krông năng, krông pa, gia lai",
    "kroong nawng, kroong pa, gia lai"
  ],
  "Kế An, Kế Sách, Sóc Trăng": [
    "kế an, kế sách, sóc trăng",
    "kees an, kees sasch, sosc trawng"
  ],
  "Kỳ Tiến, Kỳ Anh, Hà Tĩnh": [
    "kỳ tiến, kỳ anh, hà tĩnh",
    "kyf tieesn, kyf anh, haf tixnh"
  ],
  "La Dêê, Nam Giang, Quảng Nam": [
    "la dêê, nam giang, quảng nam",
    "la deeee, nam giang, quarng nam"
  ],
  "La Hai, Đồng Xuân, Phú Yên": [
    "la hai, đồng xuân, phú yên",
    "la hai, ddoofng xuaan, phus yeen"
  ],
  "La Phù, Hoài Đức, Hà Nội": [
    "la phù, hoài đức, hà nội",
    "la phuf, hoafi dduwsc, haf nooji"
  ],
  "Lai Thành, Kim Sơn, Ninh Bình": [
    "lai thành, kim sơn, ninh bình",
    "lai thafnh, kim sown, ninh bifnh"
  ],
  "Lam Sơn, Bỉm Sơn, Thanh Hóa": [
    "lam sơn, bỉm sơn, thanh hóa",
    "lam sown, birm sown, thanh hosa"
  ],
  "Lam Sơn, Hưng Yên, Hưng Yên": [
    "lam sơn, hưng yên, hưng yên",
    "lam sown, huwng yeen, huwng yeen"
  ],
  "Lam Sơn, Thanh Hóa, Thanh Hóa": [
    "lam sơn, thanh hóa, thanh hóa",
    "lam sown, thanh hosa, thanh hosa"
  ],
  "Lang Sơn, Hạ Hoà, Phú Thọ": [
    "lang sơn, hạ hoà, phú thọ",
    "lang sown, haj hoaf, phus thoj"
  ],
  "Lang Thíp, Văn Yên, Yên Bái": [
    "lang thíp, văn yên, yên bái",
    "lang thisp, vawn yeen, yeen basi"
  ],
  "Liêm Chính, Phủ Lý, Hà Nam": [
    "liêm chính, phủ lý, hà nam",
    "lieem chisnh, phur lys, haf nam"
  ],
  "Liêm Sơn, Thanh Liêm, Hà Nam": [
    "liêm sơn, thanh liêm, hà nam",
    "lieem sown, thanh lieem, haf nam"
  ],
  "Liêm Tiết, Phủ Lý, Hà Nam": [
    "liêm tiết, phủ lý, hà nam",
    "lieem tieest, phur lys, haf nam"
  ],
  "Liêm Túc, Thanh Liêm, Hà Nam": [
    "liêm túc, thanh liêm, hà nam",
    "lieem tusc, thanh lieem, haf nam"
  ],
  "Liên Bão, Tiên Du, Bắc Ninh": [
    "liên bão, tiên du, bắc ninh",
    "lieen baxo, tieen du, bawsc ninh"
  ],
  "Liên Hoa, Phù Ninh, Phú Thọ": [
    "liên hoa, phù ninh, phú thọ",
    "lieen hoa, phuf ninh, phus thoj"
  ],
  "Liên Hà, Đông Anh, Hà Nội": [
    "liên hà, đông anh, hà nội",
    "lieen haf, ddoong anh, haf nooji"
  ],
  "Liên Mạc, Mê Linh, Hà Nội": [
    "liên mạc, mê linh, hà nội",
    "lieen majc, mee linh, haf nooji"
  ],
  "Liêu Xá, Yên Mỹ, Hưng Yên": [
    "liêu xá, yên mỹ, hưng yên",
    "lieeu xas, yeen myx, huwng yeen"
  ],
  "Loan Mỹ, Tam Bình, Vĩnh Long": [
    "loan mỹ, tam bình, vĩnh long",
    "loan myx, tam bifnh, vixnh long"
  ],
  "Long Anh, Thanh Hóa, Thanh Hóa": [
    "long anh, thanh hóa, thanh hóa",
    "long anh, thanh hosa, thanh hosa"
  ],
  "Long Châu, Tân Châu, An Giang": [
    "long châu, tân châu, an giang",
    "long chaau, taan chaau, an giang"
  ],
  "Long Hiệp, Trà Cú, Trà Vinh": [
    "long hiệp, trà cú, trà vinh",
    "long hieejp, traf cus, traf vinh"
  ],
  "Long Hoa, Hòa Thành, Tây Ninh": [
    "long hoa, hòa thành, tây ninh",
    "long hoa, hofa thafnh, taay ninh"
  ],
  "Long Hưng, Tân Châu, An Giang": [
    "long hưng, tân châu, an giang",
    "long huwng, taan chaau, an giang"
  ],
  "Long Hồ, Long Hồ, Vĩnh Long": [
    "long hồ, long hồ, vĩnh long",
    "long hoof, long hoof, vixnh long"
  ],
  "Long Phú, Tam Bình, Vĩnh Long": [
    "long phú, tam bình, vĩnh long",
    "long phus, tam bifnh, vixnh long"
  ],
  "Long Sơn, Thái Hoà, Nghệ An": [
    "long sơn, thái hoà, nghệ an",
    "long sown, thasi hoaf, ngheej an"
  ],
  "Long Trì, Châu Thành, Long An": [
    "long trì, châu thành, long an",
    "long trif, chaau thafnh, long an"
  ],
  "Lâm Giang, Văn Yên, Yên Bái": [
    "lâm giang, văn yên, yên bái",
    "laam giang, vawn yeen, yeen basi"
  ],
  "Lâm Thao, Lâm Thao, Phú Thọ": [
    "lâm thao, lâm thao, phú thọ",
    "laam thao, laam thao, phus thoj"
  ],
  "Lê Chánh, Tân Châu, An Giang": [
    "lê chánh, tân châu, an giang",
    "lee chasnh, taan chaau, an giang"
  ],
  "Lóng Luông, Vân Hồ, Sơn La": [
    "lóng luông, vân hồ, sơn la",
    "losng luoong, vaan hoof, sown la"
  ],
  "Lùng Cải, Bắc Hà, Lào Cai": [
    "lùng cải, bắc hà, lào cai",
    "lufng cari, bawsc haf, lafo cai"
  ],
  "Lý Bôn, Bảo Lâm, Cao Bằng": [
    "lý bôn, bảo lâm, cao bằng",
    "lys boon, baro laam, cao bawfng"
  ],
  "Lĩnh Nam, Hoàng Mai, Hà Nội": [
    "lĩnh nam, hoàng mai, hà nội",
    "lixnh nam, hoafng mai, haf nooji"
  ],
  "Lũng Hồ, Yên Minh, Hà Giang": [
    "lũng hồ, yên minh, hà giang",
    "luxng hoof, yeen minh, haf giang"
  ],
  "Lũng Pù, Mèo Vạc, Hà Giang": [
    "lũng pù, mèo vạc, hà giang",
    "luxng puf, mefo vajc, haf giang"
  ],
  "Lạc Quới, Tri Tôn, An Giang": [
    "lạc quới, tri tôn, an giang",
    "lajc quowsi, tri toon, an giang"
  ],
  "Lạc Tấn, Tân Trụ, Long An": [
    "lạc tấn, tân trụ, long an",
    "lajc taasn, taan truj, long an"
  ],
  "Lạc Vân, Nho Quan, Ninh Bình": [
    "lạc vân, nho quan, ninh bình",
    "lajc vaan, nho quan, ninh bifnh"
  ],
  "Lạc Vệ, Tiên Du, Bắc Ninh": [
    "lạc vệ, tiên du, bắc ninh",
    "lajc veej, tieen du, bawsc ninh"
  ],
  "Lạng Sơn, Anh Sơn, Nghệ An": [
    "lạng sơn, anh sơn, nghệ an",
    "lajng sown, anh sown, ngheej an"
  ],
  "Lệ Mỹ, Phù Ninh, Phú Thọ": [
    "lệ mỹ, phù ninh, phú thọ",
    "leej myx, phuf ninh, phus thoj"
  ],
  "Lệ Xá, Tiên Lữ, Hưng Yên": [
    "lệ xá, tiên lữ, hưng yên",
    "leej xas, tieen luwx, huwng yeen"
  ],
  "Mai Châu, Mai Châu, Hoà Bình": [
    "mai châu, mai châu, hoà bình",
    "mai chaau, mai chaau, hoaf bifnh"
  ],
  "Mai Hùng, Hoàng Mai, Nghệ An": [
    "mai hùng, hoàng mai, nghệ an",
    "mai hufng, hoafng mai, ngheej an"
  ],
  "Mai Đình, Sóc Sơn, Hà Nội": [
    "mai đình, sóc sơn, hà nội",
    "mai ddifnh, sosc sown, haf nooji"
  ],
  "Minh Bảo, Yên Bái, Yên Bái": [
    "minh bảo, yên bái, yên bái",
    "minh baro, yeen basi, yeen basi"
  ],
  "Minh Côi, Hạ Hoà, Phú Thọ": [
    "minh côi, hạ hoà, phú thọ",
    "minh cooi, haj hoaf, phus thoj"
  ],
  "Minh Khai, Vũ Thư, Thái Bình": [
    "minh khai, vũ thư, thái bình",
    "minh khai, vux thuw, thasi bifnh"
  ],
  "Minh Long, Hạ Lang, Cao Bằng": [
    "minh long, hạ lang, cao bằng",
    "minh long, haj lang, cao bawfng"
  ],
  "Minh Tân, Phù Cừ, Hưng Yên": [
    "minh tân, phù cừ, hưng yên",
    "minh taan, phuf cuwf, huwng yeen"
  ],
  "Má Lé, Đồng Văn, Hà Giang": [
    "má lé, đồng văn, hà giang",
    "mas les, ddoofng vawn, haf giang"
  ],
  "Mê Linh, Lâm Hà, Lâm Đồng": [
    "mê linh, lâm hà, lâm đồng",
    "mee linh, laam haf, laam ddoofng"
  ],
  "Môn Sơn, Con Cuông, Nghệ An": [
    "môn sơn, con cuông, nghệ an",
    "moon sown, con cuoong, ngheej an"
  ],
  "Mù Sang, Phong Thổ, Lai Châu": [
    "mù sang, phong thổ, lai châu",
    "muf sang, phong thoor, lai chaau"
  ],
  "Măng Cành, Kon Plông, Kon Tum": [
    "măng cành, kon plông, kon tum",
    "mawng cafnh, kon ploong, kon tum"
  ],
  "Mương Chanh, Mai Sơn, Sơn La": [
    "mương chanh, mai sơn, sơn la",
    "muwowng chanh, mai sown, sown la"
  ],
  "Mường Cai, Sông Mã, Sơn La": [
    "mường cai, sông mã, sơn la",
    "muwowfng cai, soong max, sown la"
  ],
  "Mường Men, Vân Hồ, Sơn La": [
    "mường men, vân hồ, sơn la",
    "muwowfng men, vaan hoof, sown la"
  ],
  "Mường Sai, Sông Mã, Sơn La": [
    "mường sai, sông mã, sơn la",
    "muwowfng sai, soong max, sown la"
  ],
  "Mường Tè, Vân Hồ, Sơn La": [
    "mường tè, vân hồ, sơn la",
    "muwowfng tef, vaan hoof, sown la"
  ],
  "Mường Vi, Bát Xát, Lào Cai": [
    "mường vi, bát xát, lào cai",
    "muwowfng vi, bast xast, lafo cai"
  ],
  "Mậu Long, Yên Minh, Hà Giang": [
    "mậu long, yên minh, hà giang",
    "maaju long, yeen minh, haf giang"
  ],
  "Mỏ Vàng, Văn Yên, Yên Bái": [
    "mỏ vàng, văn yên, yên bái",
    "mor vafng, vawn yeen, yeen basi"
  ],
  "Mỹ An, Thạnh Phú, Bến Tre": [
    "mỹ an, thạnh phú, bến tre",
    "myx an, thajnh phus, beesn tre"
  ],
  "Mỹ Hòa, Long Xuyên, An Giang": [
    "mỹ hòa, long xuyên, an giang",
    "myx hofa, long xuyeen, an giang"
  ],
  "Mỹ Hưng, Thanh Oai, Hà Nội": [
    "mỹ hưng, thanh oai, hà nội",
    "myx huwng, thanh oai, haf nooji"
  ],
  "Mỹ Long, Long Xuyên, An Giang": [
    "mỹ long, long xuyên, an giang",
    "myx long, long xuyeen, an giang"
  ],
  "Mỹ Lộc, Can Lộc, Hà Tĩnh": [
    "mỹ lộc, can lộc, hà tĩnh",
    "myx loojc, can loojc, haf tixnh"
  ],
  "Mỹ Phú, Thủ Thừa, Long An": [
    "mỹ phú, thủ thừa, long an",
    "myx phus, thur thuwfa, long an"
  ],
  "Mỹ Quý, Long Xuyên, An Giang": [
    "mỹ quý, long xuyên, an giang",
    "myx quys, long xuyeen, an giang"
  ],
  "Nam Cường, Lào Cai, Lào Cai": [
    "nam cường, lào cai, lào cai",
    "nam cuwowfng, lafo cai, lafo cai"
  ],
  "Nam Dong, Cư Jút, Đắk Nông": [
    "nam dong, cư jút, đắk nông",
    "nam dong, cuw just, ddawsk noong"
  ],
  "Nam Du, Kiên Hải, Kiên Giang": [
    "nam du, kiên hải, kiên giang",
    "nam du, kieen hari, kieen giang"
  ],
  "Nam Hoa, Nam Trực, Nam Định": [
    "nam hoa, nam trực, nam định",
    "nam hoa, nam truwjc, nam ddijnh"
  ],
  "Nam Nghĩa, Nam Đàn, Nghệ An": [
    "nam nghĩa, nam đàn, nghệ an",
    "nam nghixa, nam ddafn, ngheej an"
  ],
  "Nam Phong, Cao Phong, Hoà Bình": [
    "nam phong, cao phong, hoà bình",
    "nam phong, cao phong, hoaf bifnh"
  ],
  "Nam Sơn, Ba Chẽ, Quảng Ninh": [
    "nam sơn, ba chẽ, quảng ninh",
    "nam sown, ba chex, quarng ninh"
  ],
  "Nam Sơn, Bắc Ninh, Bắc Ninh": [
    "nam sơn, bắc ninh, bắc ninh",
    "nam sown, bawsc ninh, bawsc ninh"
  ],
  "Nam Sơn, Quỳ Hợp, Nghệ An": [
    "nam sơn, quỳ hợp, nghệ an",
    "nam sown, quyf howjp, ngheej an"
  ],
  "Nam Thái, An Biên, Kiên Giang": [
    "nam thái, an biên, kiên giang",
    "nam thasi, an bieen, kieen giang"
  ],
  "Nam Xuân, Quan Hóa, Thanh Hóa": [
    "nam xuân, quan hóa, thanh hóa",
    "nam xuaan, quan hosa, thanh hosa"
  ],
  "Nga Bạch, Nga Sơn, Thanh Hóa": [
    "nga bạch, nga sơn, thanh hóa",
    "nga bajch, nga sown, thanh hosa"
  ],
  "Nga Thành, Nga Sơn, Thanh Hóa": [
    "nga thành, nga sơn, thanh hóa",
    "nga thafnh, nga sown, thanh hosa"
  ],
  "Nga Thủy, Nga Sơn, Thanh Hóa": [
    "nga thủy, nga sơn, thanh hóa",
    "nga thury, nga sown, thanh hosa"
  ],
  "Nga Tiến, Nga Sơn, Thanh Hóa": [
    "nga tiến, nga sơn, thanh hóa",
    "nga tieesn, nga sown, thanh hosa"
  ],
  "Nga Vịnh, Nga Sơn, Thanh Hóa": [
    "nga vịnh, nga sơn, thanh hóa",
    "nga vijnh, nga sown, thanh hosa"
  ],
  "Nghi Hải, Cửa Lò, Nghệ An": [
    "nghi hải, cửa lò, nghệ an",
    "nghi hari, cuwra lof, ngheej an"
  ],
  "Nghi Long, Nghi Lộc, Nghệ An": [
    "nghi long, nghi lộc, nghệ an",
    "nghi long, nghi loojc, ngheej an"
  ],
  "Nghi Lâm, Nghi Lộc, Nghệ An": [
    "nghi lâm, nghi lộc, nghệ an",
    "nghi laam, nghi loojc, ngheej an"
  ],
  "Nghi Mỹ, Nghi Lộc, Nghệ An": [
    "nghi mỹ, nghi lộc, nghệ an",
    "nghi myx, nghi loojc, ngheej an"
  ],
  "Nghi Sơn, Tĩnh Gia, Thanh Hóa": [
    "nghi sơn, tĩnh gia, thanh hóa",
    "nghi sown, tixnh gia, thanh hosa"
  ],
  "Nghi Văn, Nghi Lộc, Nghệ An": [
    "nghi văn, nghi lộc, nghệ an",
    "nghi vawn, nghi loojc, ngheej an"
  ],
  "Nghi Yên, Nghi Lộc, Nghệ An": [
    "nghi yên, nghi lộc, nghệ an",
    "nghi yeen, nghi loojc, ngheej an"
  ],
  "Nghĩa Hưng, Chư Păh, Gia Lai": [
    "nghĩa hưng, chư păh, gia lai",
    "nghixa huwng, chuw pawh, gia lai"
  ],
  "Nguyễn Phích, U Minh, Cà Mau": [
    "nguyễn phích, u minh, cà mau",
    "nguyeexn phisch, u minh, caf mau"
  ],
  "Nguyễn Trãi, Kon Tum, Kon Tum": [
    "nguyễn trãi, kon tum, kon tum",
    "nguyeexn traxi, kon tum, kon tum"
  ],
  "Ngô Xá, Cẩm Khê, Phú Thọ": [
    "ngô xá, cẩm khê, phú thọ",
    "ngoo xas, caarm khee, phus thoj"
  ],
  "Ngũ Chỉ Sơn, Sa Pa, Lào Cai": [
    "ngũ chỉ sơn, sa pa, lào cai",
    "ngux chir sown, sa pa, lafo cai"
  ],
  "Ngọc Hà, Ba Đình, Hà Nội": [
    "ngọc hà, ba đình, hà nội",
    "ngojc haf, ba ddifnh, haf nooji"
  ],
  "Ngọc Hà, Hà Giang, Hà Giang": [
    "ngọc hà, hà giang, hà giang",
    "ngojc haf, haf giang, haf giang"
  ],
  "Ngọc Lũ, Bình Lục, Hà Nam": [
    "ngọc lũ, bình lục, hà nam",
    "ngojc lux, bifnh lujc, haf nam"
  ],
  "Ngọc Sơn, Kim Bảng, Hà Nam": [
    "ngọc sơn, kim bảng, hà nam",
    "ngojc sown, kim barng, haf nam"
  ],
  "Ngọk Tụ, Đắk Tô, Kon Tum": [
    "ngọk tụ, đắk tô, kon tum",
    "ngojk tuj, ddawsk too, kon tum"
  ],
  "Nhân Chính, Lý Nhân, Hà Nam": [
    "nhân chính, lý nhân, hà nam",
    "nhaan chisnh, lys nhaan, haf nam"
  ],
  "Nhân Nghĩa, Lý Nhân, Hà Nam": [
    "nhân nghĩa, lý nhân, hà nam",
    "nhaan nghixa, lys nhaan, haf nam"
  ],
  "Nhã Nam, Tân Yên, Bắc Giang": [
    "nhã nam, tân yên, bắc giang",
    "nhax nam, taan yeen, bawsc giang"
  ],
  "Nhật Tân, Kim Bảng, Hà Nam": [
    "nhật tân, kim bảng, hà nam",
    "nhaajt taan, kim barng, haf nam"
  ],
  "Nhựt Ninh, Tân Trụ, Long An": [
    "nhựt ninh, tân trụ, long an",
    "nhuwjt ninh, taan truj, long an"
  ],
  "Ninh Hiệp, Gia Lâm, Hà Nội": [
    "ninh hiệp, gia lâm, hà nội",
    "ninh hieejp, gia laam, haf nooji"
  ],
  "Ninh Hà, Ninh Hòa, Khánh Hòa": [
    "ninh hà, ninh hòa, khánh hòa",
    "ninh haf, ninh hofa, khasnh hofa"
  ],
  "Ninh Sim, Ninh Hòa, Khánh Hòa": [
    "ninh sim, ninh hòa, khánh hòa",
    "ninh sim, ninh hofa, khasnh hofa"
  ],
  "Ninh Xá, Bắc Ninh, Bắc Ninh": [
    "ninh xá, bắc ninh, bắc ninh",
    "ninh xas, bawsc ninh, bawsc ninh"
  ],
  "Ninh Đa, Ninh Hòa, Khánh Hòa": [
    "ninh đa, ninh hòa, khánh hòa",
    "ninh dda, ninh hofa, khasnh hofa"
  ],
  "Nà Phòn, Mai Châu, Hoà Bình": [
    "nà phòn, mai châu, hoà bình",
    "naf phofn, mai chaau, hoaf bifnh"
  ],
  "Núi Sam, Châu Đốc, An Giang": [
    "núi sam, châu đốc, an giang",
    "nusi sam, chaau ddoosc, an giang"
  ],
  "Núi Voi, Tịnh Biên, An Giang": [
    "núi voi, tịnh biên, an giang",
    "nusi voi, tijnh bieen, an giang"
  ],
  "Nước Hai, Hoà An, Cao Bằng": [
    "nước hai, hoà an, cao bằng",
    "nuwowsc hai, hoaf an, cao bawfng"
  ],
  "Nậm Ban, Mèo Vạc, Hà Giang": [
    "nậm ban, mèo vạc, hà giang",
    "naajm ban, mefo vajc, haf giang"
  ],
  "Nậm Càn, Kỳ Sơn, Nghệ An": [
    "nậm càn, kỳ sơn, nghệ an",
    "naajm cafn, kyf sown, ngheej an"
  ],
  "Nậm Hăn, Sìn Hồ, Lai Châu": [
    "nậm hăn, sìn hồ, lai châu",
    "naajm hawn, sifn hoof, lai chaau"
  ],
  "Nậm Mạ, Sìn Hồ, Lai Châu": [
    "nậm mạ, sìn hồ, lai châu",
    "naajm maj, sifn hoof, lai chaau"
  ],
  "Nậm Păm, Mường La, Sơn La": [
    "nậm păm, mường la, sơn la",
    "naajm pawm, muwowfng la, sown la"
  ],
  "Nậm Tăm, Sìn Hồ, Lai Châu": [
    "nậm tăm, sìn hồ, lai châu",
    "naajm tawm, sifn hoof, lai chaau"
  ],
  "Nậm Xe, Phong Thổ, Lai Châu": [
    "nậm xe, phong thổ, lai châu",
    "naajm xe, phong thoor, lai chaau"
  ],
  "Nậm ét, Quỳnh Nhai, Sơn La": [
    "nậm ét, quỳnh nhai, sơn la",
    "naajm est, quyfnh nhai, sown la"
  ],
  "Nậm Đét, Bắc Hà, Lào Cai": [
    "nậm đét, bắc hà, lào cai",
    "naajm ddest, bawsc haf, lafo cai"
  ],
  "Nếnh, Việt Yên, Bắc Giang": [
    "nếnh, việt yên, bắc giang",
    "neesnh, vieejt yeen, bawsc giang"
  ],
  "P Rao, Đông Giang, Quảng Nam": [
    "p rao, đông giang, quảng nam",
    "p rao, ddoong giang, quarng nam"
  ],
  "Phiêng Ban, Bắc Yên, Sơn La": [
    "phiêng ban, bắc yên, sơn la",
    "phieeng ban, bawsc yeen, sown la"
  ],
  "Phiêng Cằm, Mai Sơn, Sơn La": [
    "phiêng cằm, mai sơn, sơn la",
    "phieeng cawfm, mai sown, sown la"
  ],
  "Phiêng Pằn, Mai Sơn, Sơn La": [
    "phiêng pằn, mai sơn, sơn la",
    "phieeng pawfn, mai sown, sown la"
  ],
  "Phong Phú, Cầu Kè, Trà Vinh": [
    "phong phú, cầu kè, trà vinh",
    "phong phus, caafu kef, traf vinh"
  ],
  "Phìn Hồ, Sìn Hồ, Lai Châu": [
    "phìn hồ, sìn hồ, lai châu",
    "phifn hoof, sifn hoof, lai chaau"
  ],
  "Phù Khê, Từ Sơn, Bắc Ninh": [
    "phù khê, từ sơn, bắc ninh",
    "phuf khee, tuwf sown, bawsc ninh"
  ],
  "Phù Lưu, Ứng Hòa, Hà Nội": [
    "phù lưu, ứng hòa, hà nội",
    "phuf luwu, uwsng hofa, haf nooji"
  ],
  "Phù Ninh, Phù Ninh, Phú Thọ": [
    "phù ninh, phù ninh, phú thọ",
    "phuf ninh, phuf ninh, phus thoj"
  ],
  "Phú An, Cai Lậy, Tiền Giang": [
    "phú an, cai lậy, tiền giang",
    "phus an, cai laajy, tieefn giang"
  ],
  "Phú Cát, Quốc Oai, Hà Nội": [
    "phú cát, quốc oai, hà nội",
    "phus cast, quoosc oai, haf nooji"
  ],
  "Phú Cường, Ba Vì, Hà Nội": [
    "phú cường, ba vì, hà nội",
    "phus cuwowfng, ba vif, haf nooji"
  ],
  "Phú Hiệp, Phú Tân, An Giang": [
    "phú hiệp, phú tân, an giang",
    "phus hieejp, phus taan, an giang"
  ],
  "Phú Hưng, Bến Tre, Bến Tre": [
    "phú hưng, bến tre, bến tre",
    "phus huwng, beesn tre, beesn tre"
  ],
  "Phú Lâm, Tĩnh Gia, Thanh Hóa": [
    "phú lâm, tĩnh gia, thanh hóa",
    "phus laam, tixnh gia, thanh hosa"
  ],
  "Phú Lãm, Hà Đông, Hà Nội": [
    "phú lãm, hà đông, hà nội",
    "phus laxm, haf ddoong, haf nooji"
  ],
  "Phú Lũng, Yên Minh, Hà Giang": [
    "phú lũng, yên minh, hà giang",
    "phus luxng, yeen minh, haf giang"
  ],
  "Phú Lệ, Quan Hóa, Thanh Hóa": [
    "phú lệ, quan hóa, thanh hóa",
    "phus leej, quan hosa, thanh hosa"
  ],
  "Phú Lộc, Can Lộc, Hà Tĩnh": [
    "phú lộc, can lộc, hà tĩnh",
    "phus loojc, can loojc, haf tixnh"
  ],
  "Phú Lộc, Nho Quan, Ninh Bình": [
    "phú lộc, nho quan, ninh bình",
    "phus loojc, nho quan, ninh bifnh"
  ],
  "Phú Lộc, Tân Châu, An Giang": [
    "phú lộc, tân châu, an giang",
    "phus loojc, taan chaau, an giang"
  ],
  "Phú Mãn, Quốc Oai, Hà Nội": [
    "phú mãn, quốc oai, hà nội",
    "phus maxn, quoosc oai, haf nooji"
  ],
  "Phú Mỹ, Mỹ Tú, Sóc Trăng": [
    "phú mỹ, mỹ tú, sóc trăng",
    "phus myx, myx tus, sosc trawng"
  ],
  "Phú Mỹ, Phù Ninh, Phú Thọ": [
    "phú mỹ, phù ninh, phú thọ",
    "phus myx, phuf ninh, phus thoj"
  ],
  "Phú Nham, Phù Ninh, Phú Thọ": [
    "phú nham, phù ninh, phú thọ",
    "phus nham, phuf ninh, phus thoj"
  ],
  "Phú Phương, Ba Vì, Hà Nội": [
    "phú phương, ba vì, hà nội",
    "phus phuwowng, ba vif, haf nooji"
  ],
  "Phú Sơn, Quan Hóa, Thanh Hóa": [
    "phú sơn, quan hóa, thanh hóa",
    "phus sown, quan hosa, thanh hosa"
  ],
  "Phú Sơn, Tĩnh Gia, Thanh Hóa": [
    "phú sơn, tĩnh gia, thanh hóa",
    "phus sown, tixnh gia, thanh hosa"
  ],
  "Phú Thuận, Phú Tân, Cà Mau": [
    "phú thuận, phú tân, cà mau",
    "phus thuaajn, phus taan, caf mau"
  ],
  "Phú Thành, Phú Tân, An Giang": [
    "phú thành, phú tân, an giang",
    "phus thafnh, phus taan, an giang"
  ],
  "Phú Thứ, Tây Hoà, Phú Yên": [
    "phú thứ, tây hoà, phú yên",
    "phus thuws, taay hoaf, phus yeen"
  ],
  "Phú Vĩnh, Tân Châu, An Giang": [
    "phú vĩnh, tân châu, an giang",
    "phus vixnh, taan chaau, an giang"
  ],
  "Phú Xá, Cao Lộc, Lạng Sơn": [
    "phú xá, cao lộc, lạng sơn",
    "phus xas, cao loojc, lajng sown"
  ],
  "Phú Đông, Tuy Hoà, Phú Yên": [
    "phú đông, tuy hoà, phú yên",
    "phus ddoong, tuy hoaf, phus yeen"
  ],
  "Phường 1, Tuy Hoà, Phú Yên": [
    "phường 1, tuy hoà, phú yên",
    "phuwowfng 1, tuy hoaf, phus yeen"
  ],
  "Phường 2, Tuy Hoà, Phú Yên": [
    "phường 2, tuy hoà, phú yên",
    "phuwowfng 2, tuy hoaf, phus yeen"
  ],
  "Phường 3, Tuy Hoà, Phú Yên": [
    "phường 3, tuy hoà, phú yên",
    "phuwowfng 3, tuy hoaf, phus yeen"
  ],
  "Phường 4, Tuy Hoà, Phú Yên": [
    "phường 4, tuy hoà, phú yên",
    "phuwowfng 4, tuy hoaf, phus yeen"
  ],
  "Phường 5, Tuy Hoà, Phú Yên": [
    "phường 5, tuy hoà, phú yên",
    "phuwowfng 5, tuy hoaf, phus yeen"
  ],
  "Phường 6, Tuy Hoà, Phú Yên": [
    "phường 6, tuy hoà, phú yên",
    "phuwowfng 6, tuy hoaf, phus yeen"
  ],
  "Phường 7, Tuy Hoà, Phú Yên": [
    "phường 7, tuy hoà, phú yên",
    "phuwowfng 7, tuy hoaf, phus yeen"
  ],
  "Phường 8, Tuy Hoà, Phú Yên": [
    "phường 8, tuy hoà, phú yên",
    "phuwowfng 8, tuy hoaf, phus yeen"
  ],
  "Phường 9, Tuy Hoà, Phú Yên": [
    "phường 9, tuy hoà, phú yên",
    "phuwowfng 9, tuy hoaf, phus yeen"
  ],
  "Pá Lau, Trạm Tấu, Yên Bái": [
    "pá lau, trạm tấu, yên bái",
    "pas lau, trajm taasu, yeen basi"
  ],
  "Pú Đao, Nậm Nhùn, Lai Châu": [
    "pú đao, nậm nhùn, lai châu",
    "pus ddao, naajm nhufn, lai chaau"
  ],
  "Quang Minh, Văn Yên, Yên Bái": [
    "quang minh, văn yên, yên bái",
    "quang minh, vawn yeen, yeen basi"
  ],
  "Quang Phong, Na Rì, Bắc Kạn": [
    "quang phong, na rì, bắc kạn",
    "quang phong, na rif, bawsc kajn"
  ],
  "Quang Trung, Hoà An, Cao Bằng": [
    "quang trung, hoà an, cao bằng",
    "quang trung, hoaf an, cao bawfng"
  ],
  "Quảng An, Tây Hồ, Hà Nội": [
    "quảng an, tây hồ, hà nội",
    "quarng an, taay hoof, haf nooji"
  ],
  "Rạch Chèo, Phú Tân, Cà Mau": [
    "rạch chèo, phú tân, cà mau",
    "rajch chefo, phus taan, caf mau"
  ],
  "San Thàng, Lai Châu, Lai Châu": [
    "san thàng, lai châu, lai châu",
    "san thafng, lai chaau, lai chaau"
  ],
  "Sinh Long, Na Hang, Tuyên Quang": [
    "sinh long, na hang, tuyên quang",
    "sinh long, na hang, tuyeen quang"
  ],
  "Song Phú, Tam Bình, Vĩnh Long": [
    "song phú, tam bình, vĩnh long",
    "song phus, tam bifnh, vixnh long"
  ],
  "Suối Bàng, Vân Hồ, Sơn La": [
    "suối bàng, vân hồ, sơn la",
    "suoosi bafng, vaan hoof, sown la"
  ],
  "Sài Sơn, Quốc Oai, Hà Nội": [
    "sài sơn, quốc oai, hà nội",
    "safi sown, quoosc oai, haf nooji"
  ],
  "Sán Chải, Si Ma Cai, Lào Cai": [
    "sán chải, si ma cai, lào cai",
    "sasn chari, si ma cai, lafo cai"
  ],
  "Sín Chéng, Si Ma Cai, Lào Cai": [
    "sín chéng, si ma cai, lào cai",
    "sisn chesng, si ma cai, lafo cai"
  ],
  "Sơn Ba, Sơn Hà, Quảng Ngãi": [
    "sơn ba, sơn hà, quảng ngãi",
    "sown ba, sown haf, quarng ngaxi"
  ],
  "Sơn Hà, Phú Xuyên, Hà Nội": [
    "sơn hà, phú xuyên, hà nội",
    "sown haf, phus xuyeen, haf nooji"
  ],
  "Sơn Hội, Sơn Hòa, Phú Yên": [
    "sơn hội, sơn hòa, phú yên",
    "sown hooji, sown hofa, phus yeen"
  ],
  "Sơn Lộc, Can Lộc, Hà Tĩnh": [
    "sơn lộc, can lộc, hà tĩnh",
    "sown loojc, can loojc, haf tixnh"
  ],
  "Sơn Lộc, Sơn Tây, Hà Nội": [
    "sơn lộc, sơn tây, hà nội",
    "sown loojc, sown taay, haf nooji"
  ],
  "Sơn Phú, Na Hang, Tuyên Quang": [
    "sơn phú, na hang, tuyên quang",
    "sown phus, na hang, tuyeen quang"
  ],
  "Sơn Thuỷ, Văn Bàn, Lào Cai": [
    "sơn thuỷ, văn bàn, lào cai",
    "sown thuyr, vawn bafn, lafo cai"
  ],
  "Sơn Thành, Na Rì, Bắc Kạn": [
    "sơn thành, na rì, bắc kạn",
    "sown thafnh, na rif, bawsc kajn"
  ],
  "Sơn Tân, Cam Lâm, Khánh Hòa": [
    "sơn tân, cam lâm, khánh hòa",
    "sown taan, cam laam, khasnh hofa"
  ],
  "Sơn Xuân, Sơn Hòa, Phú Yên": [
    "sơn xuân, sơn hòa, phú yên",
    "sown xuaan, sown hofa, phus yeen"
  ],
  "Sập Vạt, Yên Châu, Sơn La": [
    "sập vạt, yên châu, sơn la",
    "saajp vajt, yeen chaau, sown la"
  ],
  "Tam An, Long Thành, Đồng Nai": [
    "tam an, long thành, đồng nai",
    "tam an, long thafnh, ddoofng nai"
  ],
  "Tam Bình, Tam Bình, Vĩnh Long": [
    "tam bình, tam bình, vĩnh long",
    "tam bifnh, tam bifnh, vixnh long"
  ],
  "Tam Dân, Phú Ninh, Quảng Nam": [
    "tam dân, phú ninh, quảng nam",
    "tam daan, phus ninh, quarng nam"
  ],
  "Tam Dị, Lục Nam, Bắc Giang": [
    "tam dị, lục nam, bắc giang",
    "tam dij, lujc nam, bawsc giang"
  ],
  "Tam Quang, Vũ Thư, Thái Bình": [
    "tam quang, vũ thư, thái bình",
    "tam quang, vux thuw, thasi bifnh"
  ],
  "Tam Sơn, Cẩm Khê, Phú Thọ": [
    "tam sơn, cẩm khê, phú thọ",
    "tam sown, caarm khee, phus thoj"
  ],
  "Tam Sơn, Quản Bạ, Hà Giang": [
    "tam sơn, quản bạ, hà giang",
    "tam sown, quarn baj, haf giang"
  ],
  "Tam Sơn, Sông Lô, Vĩnh Phúc": [
    "tam sơn, sông lô, vĩnh phúc",
    "tam sown, soong loo, vixnh phusc"
  ],
  "Tam Thanh, Quan Sơn, Thanh Hóa": [
    "tam thanh, quan sơn, thanh hóa",
    "tam thanh, quan sown, thanh hosa"
  ],
  "Tam Thanh, Tam Kỳ, Quảng Nam": [
    "tam thanh, tam kỳ, quảng nam",
    "tam thanh, tam kyf, quarng nam"
  ],
  "Tam Thanh, Tân Sơn, Phú Thọ": [
    "tam thanh, tân sơn, phú thọ",
    "tam thanh, taan sown, phus thoj"
  ],
  "Tam Vinh, Phú Ninh, Quảng Nam": [
    "tam vinh, phú ninh, quảng nam",
    "tam vinh, phus ninh, quarng nam"
  ],
  "Tam Đồng, Mê Linh, Hà Nội": [
    "tam đồng, mê linh, hà nội",
    "tam ddoofng, mee linh, haf nooji"
  ],
  "Thanh Hà, Hội An, Quảng Nam": [
    "thanh hà, hội an, quảng nam",
    "thanh haf, hooji an, quarng nam"
  ],
  "Thanh Mỹ, Sơn Tây, Hà Nội": [
    "thanh mỹ, sơn tây, hà nội",
    "thanh myx, sown taay, haf nooji"
  ],
  "Thanh Phú, Bến Lức, Long An": [
    "thanh phú, bến lức, long an",
    "thanh phus, beesn luwsc, long an"
  ],
  "Thanh Tâm, Thanh Liêm, Hà Nam": [
    "thanh tâm, thanh liêm, hà nam",
    "thanh taam, thanh lieem, haf nam"
  ],
  "Thanh Tân, Thanh Liêm, Hà Nam": [
    "thanh tân, thanh liêm, hà nam",
    "thanh taan, thanh lieem, haf nam"
  ],
  "Thanh Văn, Thanh Oai, Hà Nội": [
    "thanh văn, thanh oai, hà nội",
    "thanh vawn, thanh oai, haf nooji"
  ],
  "Thiên Tôn, Hoa Lư, Ninh Bình": [
    "thiên tôn, hoa lư, ninh bình",
    "thieen toon, hoa luw, ninh bifnh"
  ],
  "Thu Phong, Cao Phong, Hoà Bình": [
    "thu phong, cao phong, hoà bình",
    "thu phong, cao phong, hoaf bifnh"
  ],
  "Thu Thuỷ, Cửa Lò, Nghệ An": [
    "thu thuỷ, cửa lò, nghệ an",
    "thu thuyr, cuwra lof, ngheej an"
  ],
  "Thung Nai, Cao Phong, Hoà Bình": [
    "thung nai, cao phong, hoà bình",
    "thung nai, cao phong, hoaf bifnh"
  ],
  "Thành Sơn, Anh Sơn, Nghệ An": [
    "thành sơn, anh sơn, nghệ an",
    "thafnh sown, anh sown, ngheej an"
  ],
  "Thác Bà, Yên Bình, Yên Bái": [
    "thác bà, yên bình, yên bái",
    "thasc baf, yeen bifnh, yeen basi"
  ],
  "Thái An, Quản Bạ, Hà Giang": [
    "thái an, quản bạ, hà giang",
    "thasi an, quarn baj, haf giang"
  ],
  "Thị Hoa, Hạ Lang, Cao Bằng": [
    "thị hoa, hạ lang, cao bằng",
    "thij hoa, haj lang, cao bawfng"
  ],
  "Thống Nhất, Kon Tum, Kon Tum": [
    "thống nhất, kon tum, kon tum",
    "thoosng nhaast, kon tum, kon tum"
  ],
  "Thới Hòa, Ô Môn, Cần Thơ": [
    "thới hòa, ô môn, cần thơ",
    "thowsi hofa, oo moon, caafn thow"
  ],
  "Thới Long, Ô Môn, Cần Thơ": [
    "thới long, ô môn, cần thơ",
    "thowsi long, oo moon, caafn thow"
  ],
  "Thụy Lôi, Kim Bảng, Hà Nam": [
    "thụy lôi, kim bảng, hà nam",
    "thujy looi, kim barng, haf nam"
  ],
  "Thứa, Lương Tài, Bắc Ninh": [
    "thứa, lương tài, bắc ninh",
    "thuwsa, luwowng tafi, bawsc ninh"
  ],
  "Tiên Hiệp, Phủ Lý, Hà Nam": [
    "tiên hiệp, phủ lý, hà nam",
    "tieen hieejp, phur lys, haf nam"
  ],
  "Tiên Kỳ, Tân Kỳ, Nghệ An": [
    "tiên kỳ, tân kỳ, nghệ an",
    "tieen kyf, taan kyf, ngheej an"
  ],
  "Tri Lễ, Quế Phong, Nghệ An": [
    "tri lễ, quế phong, nghệ an",
    "tri leex, quees phong, ngheej an"
  ],
  "Tri Lễ, Văn Quan, Lạng Sơn": [
    "tri lễ, văn quan, lạng sơn",
    "tri leex, vawn quan, lajng sown"
  ],
  "Trung An, Cờ Đỏ, Cần Thơ": [
    "trung an, cờ đỏ, cần thơ",
    "trung an, cowf ddor, caafn thow"
  ],
  "Trung An, Mỹ Tho, Tiền Giang": [
    "trung an, mỹ tho, tiền giang",
    "trung an, myx tho, tieefn giang"
  ],
  "Trung Giã, Sóc Sơn, Hà Nội": [
    "trung giã, sóc sơn, hà nội",
    "trung giax, sosc sown, haf nooji"
  ],
  "Trung Mầu, Gia Lâm, Hà Nội": [
    "trung mầu, gia lâm, hà nội",
    "trung maafu, gia laam, haf nooji"
  ],
  "Trung Tú, Ứng Hòa, Hà Nội": [
    "trung tú, ứng hòa, hà nội",
    "trung tus, uwsng hofa, haf nooji"
  ],
  "Trà Vong, Tân Biên, Tây Ninh": [
    "trà vong, tân biên, tây ninh",
    "traf vong, taan bieen, taay ninh"
  ],
  "Trâu Quỳ, Gia Lâm, Hà Nội": [
    "trâu quỳ, gia lâm, hà nội",
    "traau quyf, gia laam, haf nooji"
  ],
  "Trần Phú, Na Rì, Bắc Kạn": [
    "trần phú, na rì, bắc kạn",
    "traafn phus, na rif, bawsc kajn"
  ],
  "Tu Vũ, Thanh Thuỷ, Phú Thọ": [
    "tu vũ, thanh thuỷ, phú thọ",
    "tu vux, thanh thuyr, phus thoj"
  ],
  "Tà Hừa, Than Uyên, Lai Châu": [
    "tà hừa, than uyên, lai châu",
    "taf huwfa, than uyeen, lai chaau"
  ],
  "Tà Lài, Tân Phú, Đồng Nai": [
    "tà lài, tân phú, đồng nai",
    "taf lafi, taan phus, ddoofng nai"
  ],
  "Tát Ngà, Mèo Vạc, Hà Giang": [
    "tát ngà, mèo vạc, hà giang",
    "tast ngaf, mefo vajc, haf giang"
  ],
  "Tân An, Ninh Kiều, Cần Thơ": [
    "tân an, ninh kiều, cần thơ",
    "taan an, ninh kieefu, caafn thow"
  ],
  "Tân An, Yên Dũng, Bắc Giang": [
    "tân an, yên dũng, bắc giang",
    "taan an, yeen duxng, bawsc giang"
  ],
  "Tân Bình, La Gi, Bình Thuận": [
    "tân bình, la gi, bình thuận",
    "taan bifnh, la gi, bifnh thuaajn"
  ],
  "Tân Bình, Tây Ninh, Tây Ninh": [
    "tân bình, tây ninh, tây ninh",
    "taan bifnh, taay ninh, taay ninh"
  ],
  "Tân Bửu, Bến Lức, Long An": [
    "tân bửu, bến lức, long an",
    "taan buwru, beesn luwsc, long an"
  ],
  "Tân Cảnh, Đắk Tô, Kon Tum": [
    "tân cảnh, đắk tô, kon tum",
    "taan carnh, ddawsk too, kon tum"
  ],
  "Tân Dân, An Lão, Hải Phòng": [
    "tân dân, an lão, hải phòng",
    "taan daan, an laxo, hari phofng"
  ],
  "Tân Dân, Tĩnh Gia, Thanh Hóa": [
    "tân dân, tĩnh gia, thanh hóa",
    "taan daan, tixnh gia, thanh hosa"
  ],
  "Tân Giang, Hà Tĩnh, Hà Tĩnh": [
    "tân giang, hà tĩnh, hà tĩnh",
    "taan giang, haf tixnh, haf tixnh"
  ],
  "Tân Hiệp, Trà Cú, Trà Vinh": [
    "tân hiệp, trà cú, trà vinh",
    "taan hieejp, traf cus, traf vinh"
  ],
  "Tân Hà, Lâm Hà, Lâm Đồng": [
    "tân hà, lâm hà, lâm đồng",
    "taan haf, laam haf, laam ddoofng"
  ],
  "Tân Hòa, Quốc Oai, Hà Nội": [
    "tân hòa, quốc oai, hà nội",
    "taan hofa, quoosc oai, haf nooji"
  ],
  "Tân Hòa, Tân Châu, Tây Ninh": [
    "tân hòa, tân châu, tây ninh",
    "taan hofa, taan chaau, taay ninh"
  ],
  "Tân Hòa, Tân Thạnh, Long An": [
    "tân hòa, tân thạnh, long an",
    "taan hofa, taan thajnh, long an"
  ],
  "Tân Hòa, Vũ Thư, Thái Bình": [
    "tân hòa, vũ thư, thái bình",
    "taan hofa, vux thuw, thasi bifnh"
  ],
  "Tân Hưng, Sóc Sơn, Hà Nội": [
    "tân hưng, sóc sơn, hà nội",
    "taan huwng, sosc sown, haf nooji"
  ],
  "Tân Hải, La Gi, Bình Thuận": [
    "tân hải, la gi, bình thuận",
    "taan hari, la gi, bifnh thuaajn"
  ],
  "Tân Hợp, Mộc Châu, Sơn La": [
    "tân hợp, mộc châu, sơn la",
    "taan howjp, moojc chaau, sown la"
  ],
  "Tân Hợp, Tân Kỳ, Nghệ An": [
    "tân hợp, tân kỳ, nghệ an",
    "taan howjp, taan kyf, ngheej an"
  ],
  "Tân Hợp, Văn Yên, Yên Bái": [
    "tân hợp, văn yên, yên bái",
    "taan howjp, vawn yeen, yeen basi"
  ],
  "Tân Long, Thủ Thừa, Long An": [
    "tân long, thủ thừa, long an",
    "taan long, thur thuwfa, long an"
  ],
  "Tân Lâm, Di Linh, Lâm Đồng": [
    "tân lâm, di linh, lâm đồng",
    "taan laam, di linh, laam ddoofng"
  ],
  "Tân Lập, Mộc Châu, Sơn La": [
    "tân lập, mộc châu, sơn la",
    "taan laajp, moojc chaau, sown la"
  ],
  "Tân Lộc, Lộc Hà, Hà Tĩnh": [
    "tân lộc, lộc hà, hà tĩnh",
    "taan loojc, loojc haf, haf tixnh"
  ],
  "Tân Nam, Quang Bình, Hà Giang": [
    "tân nam, quang bình, hà giang",
    "taan nam, quang bifnh, haf giang"
  ],
  "Tân Ninh, Tân Thạnh, Long An": [
    "tân ninh, tân thạnh, long an",
    "taan ninh, taan thajnh, long an"
  ],
  "Tân Phong, Lai Châu, Lai Châu": [
    "tân phong, lai châu, lai châu",
    "taan phong, lai chaau, lai chaau"
  ],
  "Tân Phú, Quốc Oai, Hà Nội": [
    "tân phú, quốc oai, hà nội",
    "taan phus, quoosc oai, haf nooji"
  ],
  "Tân Phú, Tam Bình, Vĩnh Long": [
    "tân phú, tam bình, vĩnh long",
    "taan phus, tam bifnh, vixnh long"
  ],
  "Tân Phú, Thới Bình, Cà Mau": [
    "tân phú, thới bình, cà mau",
    "taan phus, thowsi bifnh, caf mau"
  ],
  "Tân Phú, Tân Châu, Tây Ninh": [
    "tân phú, tân châu, tây ninh",
    "taan phus, taan chaau, taay ninh"
  ],
  "Tân Phú, Tân Sơn, Phú Thọ": [
    "tân phú, tân sơn, phú thọ",
    "taan phus, taan sown, phus thoj"
  ],
  "Tân Sơn, Tân Sơn, Phú Thọ": [
    "tân sơn, tân sơn, phú thọ",
    "taan sown, taan sown, phus thoj"
  ],
  "Tân Thanh, Thanh Liêm, Hà Nam": [
    "tân thanh, thanh liêm, hà nam",
    "taan thanh, thanh lieem, haf nam"
  ],
  "Tân Thành, Mộc Hóa, Long An": [
    "tân thành, mộc hóa, long an",
    "taan thafnh, moojc hosa, long an"
  ],
  "Tân Trung, Đầm Dơi, Cà Mau": [
    "tân trung, đầm dơi, cà mau",
    "taan trung, ddaafm dowi, caf mau"
  ],
  "Tân Tuyến, Tri Tôn, An Giang": [
    "tân tuyến, tri tôn, an giang",
    "taan tuyeesn, tri toon, an giang"
  ],
  "Tân Tây, Thạnh Hóa, Long An": [
    "tân tây, thạnh hóa, long an",
    "taan taay, thajnh hosa, long an"
  ],
  "Tân Xuân, Tân Kỳ, Nghệ An": [
    "tân xuân, tân kỳ, nghệ an",
    "taan xuaan, taan kyf, ngheej an"
  ],
  "Tân Ân, Ngọc Hiển, Cà Mau": [
    "tân ân, ngọc hiển, cà mau",
    "taan aan, ngojc hieern, caf mau"
  ],
  "Tây Yên, An Biên, Kiên Giang": [
    "tây yên, an biên, kiên giang",
    "taay yeen, an bieen, kieen giang"
  ],
  "Tê Xăng, Tu Mơ Rông, Kon Tum": [
    "tê xăng, tu mơ rông, kon tum",
    "tee xawng, tu mow roong, kon tum"
  ],
  "Tòng Sành, Bát Xát, Lào Cai": [
    "tòng sành, bát xát, lào cai",
    "tofng safnh, bast xast, lafo cai"
  ],
  "Tô Mậu, Lục Yên, Yên Bái": [
    "tô mậu, lục yên, yên bái",
    "too maaju, lujc yeen, yeen basi"
  ],
  "Tú Lệ, Văn Chấn, Yên Bái": [
    "tú lệ, văn chấn, yên bái",
    "tus leej, vawn chaasn, yeen basi"
  ],
  "Tĩnh Gia, Tĩnh Gia, Thanh Hóa": [
    "tĩnh gia, tĩnh gia, thanh hóa",
    "tixnh gia, tixnh gia, thanh hosa"
  ],
  "Tạ Xá, Cẩm Khê, Phú Thọ": [
    "tạ xá, cẩm khê, phú thọ",
    "taj xas, caarm khee, phus thoj"
  ],
  "Tả Phìn, Sìn Hồ, Lai Châu": [
    "tả phìn, sìn hồ, lai châu",
    "tar phifn, sifn hoof, lai chaau"
  ],
  "Tề Lễ, Tam Nông, Phú Thọ": [
    "tề lễ, tam nông, phú thọ",
    "teef leex, tam noong, phus thoj"
  ],
  "Tứ Liên, Tây Hồ, Hà Nội": [
    "tứ liên, tây hồ, hà nội",
    "tuws lieen, taay hoof, haf nooji"
  ],
  "Tử Nê, Tân Lạc, Hoà Bình": [
    "tử nê, tân lạc, hoà bình",
    "tuwr nee, taan lajc, hoaf bifnh"
  ],
  "Tự Tân, Vũ Thư, Thái Bình": [
    "tự tân, vũ thư, thái bình",
    "tuwj taan, vux thuw, thasi bifnh"
  ],
  "Vinh Quý, Hạ Lang, Cao Bằng": [
    "vinh quý, hạ lang, cao bằng",
    "vinh quys, haj lang, cao bawfng"
  ],
  "Viên An, Ngọc Hiển, Cà Mau": [
    "viên an, ngọc hiển, cà mau",
    "vieen an, ngojc hieern, caf mau"
  ],
  "Viên Sơn, Sơn Tây, Hà Nội": [
    "viên sơn, sơn tây, hà nội",
    "vieen sown, sown taay, haf nooji"
  ],
  "Viêng Lán, Yên Châu, Sơn La": [
    "viêng lán, yên châu, sơn la",
    "vieeng lasn, yeen chaau, sown la"
  ],
  "Vân Du, Đoan Hùng, Phú Thọ": [
    "vân du, đoan hùng, phú thọ",
    "vaan du, ddoan hufng, phus thoj"
  ],
  "Vân Hà, Phúc Thọ, Hà Nội": [
    "vân hà, phúc thọ, hà nội",
    "vaan haf, phusc thoj, haf nooji"
  ],
  "Vân Lĩnh, Thanh Ba, Phú Thọ": [
    "vân lĩnh, thanh ba, phú thọ",
    "vaan lixnh, thanh ba, phus thoj"
  ],
  "Vân Nam, Phúc Thọ, Hà Nội": [
    "vân nam, phúc thọ, hà nội",
    "vaan nam, phusc thoj, haf nooji"
  ],
  "Vô Tranh, Hạ Hoà, Phú Thọ": [
    "vô tranh, hạ hoà, phú thọ",
    "voo tranh, haj hoaf, phus thoj"
  ],
  "Văn Hải, Kim Sơn, Ninh Bình": [
    "văn hải, kim sơn, ninh bình",
    "vawn hari, kim sown, ninh bifnh"
  ],
  "Văn Lang, Hạ Hoà, Phú Thọ": [
    "văn lang, hạ hoà, phú thọ",
    "vawn lang, haj hoaf, phus thoj"
  ],
  "Văn Nhuệ, Ân Thi, Hưng Yên": [
    "văn nhuệ, ân thi, hưng yên",
    "vawn nhueej, aan thi, huwng yeen"
  ],
  "Văn Phong, Nho Quan, Ninh Bình": [
    "văn phong, nho quan, ninh bình",
    "vawn phong, nho quan, ninh bifnh"
  ],
  "Văn Đức, Gia Lâm, Hà Nội": [
    "văn đức, gia lâm, hà nội",
    "vawn dduwsc, gia laam, haf nooji"
  ],
  "Vĩnh An, Châu Thành, An Giang": [
    "vĩnh an, châu thành, an giang",
    "vixnh an, chaau thafnh, an giang"
  ],
  "Vĩnh Bửu, Tân Hưng, Long An": [
    "vĩnh bửu, tân hưng, long an",
    "vixnh buwru, taan huwng, long an"
  ],
  "Vĩnh Hòa, Tân Châu, An Giang": [
    "vĩnh hòa, tân châu, an giang",
    "vixnh hofa, taan chaau, an giang"
  ],
  "Vĩnh Lợi, Tân Hưng, Long An": [
    "vĩnh lợi, tân hưng, long an",
    "vixnh lowji, taan huwng, long an"
  ],
  "Vĩnh Tuy, Gò Quao, Kiên Giang": [
    "vĩnh tuy, gò quao, kiên giang",
    "vixnh tuy, gof quao, kieen giang"
  ],
  "Vĩnh Yên, Bảo Yên, Lào Cai": [
    "vĩnh yên, bảo yên, lào cai",
    "vixnh yeen, baro yeen, lafo cai"
  ],
  "Vũ Hội, Vũ Thư, Thái Bình": [
    "vũ hội, vũ thư, thái bình",
    "vux hooji, vux thuw, thasi bifnh"
  ],
  "Vũ Ninh, Bắc Ninh, Bắc Ninh": [
    "vũ ninh, bắc ninh, bắc ninh",
    "vux ninh, bawsc ninh, bawsc ninh"
  ],
  "Vũ Oai, Hạ Long, Quảng Ninh": [
    "vũ oai, hạ long, quảng ninh",
    "vux oai, haj long, quarng ninh"
  ],
  "Vũ Xá, Kim Động, Hưng Yên": [
    "vũ xá, kim động, hưng yên",
    "vux xas, kim ddoojng, huwng yeen"
  ],
  "Vạn An, Bắc Ninh, Bắc Ninh": [
    "vạn an, bắc ninh, bắc ninh",
    "vajn an, bawsc ninh, bawsc ninh"
  ],
  "Vạn Mai, Mai Châu, Hoà Bình": [
    "vạn mai, mai châu, hoà bình",
    "vajn mai, mai chaau, hoaf bifnh"
  ],
  "Vạn Thắng, Ba Vì, Hà Nội": [
    "vạn thắng, ba vì, hà nội",
    "vajn thawsng, ba vif, haf nooji"
  ],
  "Xuân An, Yên Lập, Phú Thọ": [
    "xuân an, yên lập, phú thọ",
    "xuaan an, yeen laajp, phus thoj"
  ],
  "Xuân Du, Như Thanh, Thanh Hóa": [
    "xuân du, như thanh, thanh hóa",
    "xuaan du, nhuw thanh, thanh hosa"
  ],
  "Xuân Hoà, Bảo Yên, Lào Cai": [
    "xuân hoà, bảo yên, lào cai",
    "xuaan hoaf, baro yeen, lafo cai"
  ],
  "Xuân Huy, Lâm Thao, Phú Thọ": [
    "xuân huy, lâm thao, phú thọ",
    "xuaan huy, laam thao, phus thoj"
  ],
  "Xuân Hòa, Nam Đàn, Nghệ An": [
    "xuân hòa, nam đàn, nghệ an",
    "xuaan hofa, nam ddafn, ngheej an"
  ],
  "Xuân Lai, Gia Bình, Bắc Ninh": [
    "xuân lai, gia bình, bắc ninh",
    "xuaan lai, gia bifnh, bawsc ninh"
  ],
  "Xuân Lai, Yên Bình, Yên Bái": [
    "xuân lai, yên bình, yên bái",
    "xuaan lai, yeen bifnh, yeen basi"
  ],
  "Xuân Lam, Nghi Xuân, Hà Tĩnh": [
    "xuân lam, nghi xuân, hà tĩnh",
    "xuaan lam, nghi xuaan, haf tixnh"
  ],
  "Xuân Lâm, Nam Đàn, Nghệ An": [
    "xuân lâm, nam đàn, nghệ an",
    "xuaan laam, nam ddafn, ngheej an"
  ],
  "Xuân Phú, Ea Kar, Đắk Lắk": [
    "xuân phú, ea kar, đắk lắk",
    "xuaan phus, ea kar, ddawsk lawsk"
  ],
  "Xuân Sơn, Sơn Tây, Hà Nội": [
    "xuân sơn, sơn tây, hà nội",
    "xuaan sown, sown taay, haf nooji"
  ],
  "Xuân Trúc, Ân Thi, Hưng Yên": [
    "xuân trúc, ân thi, hưng yên",
    "xuaan trusc, aan thi, huwng yeen"
  ],
  "Xy, Hướng Hóa, Quảng Trị": [
    "xy, hướng hóa, quảng trị",
    "xy, huwowsng hosa, quarng trij"
  ],
  "Xín Cái, Mèo Vạc, Hà Giang": [
    "xín cái, mèo vạc, hà giang",
    "xisn casi, mefo vajc, haf giang"
  ],
  "Y Tịch, Chi Lăng, Lạng Sơn": [
    "y tịch, chi lăng, lạng sơn",
    "y tijch, chi lawng, lajng sown"
  ],
  "Yên Bình, Ý Yên, Nam Định": [
    "yên bình, ý yên, nam định",
    "yeen bifnh, ys yeen, nam ddijnh"
  ],
  "Yên Hà, Quang Bình, Hà Giang": [
    "yên hà, quang bình, hà giang",
    "yeen haf, quang bifnh, haf giang"
  ],
  "Yên Hòa, Yên Mỹ, Hưng Yên": [
    "yên hòa, yên mỹ, hưng yên",
    "yeen hofa, yeen myx, huwng yeen"
  ],
  "Yên Hưng, Yên Mô, Ninh Bình": [
    "yên hưng, yên mô, ninh bình",
    "yeen huwng, yeen moo, ninh bifnh"
  ],
  "Yên Hưng, Ý Yên, Nam Định": [
    "yên hưng, ý yên, nam định",
    "yeen huwng, ys yeen, nam ddijnh"
  ],
  "Yên Hợp, Văn Yên, Yên Bái": [
    "yên hợp, văn yên, yên bái",
    "yeen howjp, vawn yeen, yeen basi"
  ],
  "Yên Khang, Ý Yên, Nam Định": [
    "yên khang, ý yên, nam định",
    "yeen khang, ys yeen, nam ddijnh"
  ],
  "Yên Khê, Con Cuông, Nghệ An": [
    "yên khê, con cuông, nghệ an",
    "yeen khee, con cuoong, ngheej an"
  ],
  "Yên Kỳ, Hạ Hoà, Phú Thọ": [
    "yên kỳ, hạ hoà, phú thọ",
    "yeen kyf, haj hoaf, phus thoj"
  ],
  "Yên Lộc, Kim Sơn, Ninh Bình": [
    "yên lộc, kim sơn, ninh bình",
    "yeen loojc, kim sown, ninh bifnh"
  ],
  "Yên Lộc, Ý Yên, Nam Định": [
    "yên lộc, ý yên, nam định",
    "yeen loojc, ys yeen, nam ddijnh"
  ],
  "Yên Lợi, Ý Yên, Nam Định": [
    "yên lợi, ý yên, nam định",
    "yeen lowji, ys yeen, nam ddijnh"
  ],
  "Yên Mạc, Yên Mô, Ninh Bình": [
    "yên mạc, yên mô, ninh bình",
    "yeen majc, yeen moo, ninh bifnh"
  ],
  "Yên Mỹ, Thanh Trì, Hà Nội": [
    "yên mỹ, thanh trì, hà nội",
    "yeen myx, thanh trif, haf nooji"
  ],
  "Yên Mỹ, Yên Mỹ, Hưng Yên": [
    "yên mỹ, yên mỹ, hưng yên",
    "yeen myx, yeen myx, huwng yeen"
  ],
  "Yên Nhân, Yên Mô, Ninh Bình": [
    "yên nhân, yên mô, ninh bình",
    "yeen nhaan, yeen moo, ninh bifnh"
  ],
  "Yên Nhân, Ý Yên, Nam Định": [
    "yên nhân, ý yên, nam định",
    "yeen nhaan, ys yeen, nam ddijnh"
  ],
  "Yên Phong, Bắc Mê, Hà Giang": [
    "yên phong, bắc mê, hà giang",
    "yeen phong, bawsc mee, haf giang"
  ],
  "Yên Phong, Yên Mô, Ninh Bình": [
    "yên phong, yên mô, ninh bình",
    "yeen phong, yeen moo, ninh bifnh"
  ],
  "Yên Phong, Ý Yên, Nam Định": [
    "yên phong, ý yên, nam định",
    "yeen phong, ys yeen, nam ddijnh"
  ],
  "Yên Phú, Yên Mỹ, Hưng Yên": [
    "yên phú, yên mỹ, hưng yên",
    "yeen phus, yeen myx, huwng yeen"
  ],
  "Yên Phúc, Ý Yên, Nam Định": [
    "yên phúc, ý yên, nam định",
    "yeen phusc, ys yeen, nam ddijnh"
  ],
  "Yên Phụ, Tây Hồ, Hà Nội": [
    "yên phụ, tây hồ, hà nội",
    "yeen phuj, taay hoof, haf nooji"
  ],
  "Yên Quang, Nho Quan, Ninh Bình": [
    "yên quang, nho quan, ninh bình",
    "yeen quang, nho quan, ninh bifnh"
  ],
  "Yên Quang, Ý Yên, Nam Định": [
    "yên quang, ý yên, nam định",
    "yeen quang, ys yeen, nam ddijnh"
  ],
  "Yên Sơn, Quốc Oai, Hà Nội": [
    "yên sơn, quốc oai, hà nội",
    "yeen sown, quoosc oai, haf nooji"
  ],
  "Yên Sở, Hoàng Mai, Hà Nội": [
    "yên sở, hoàng mai, hà nội",
    "yeen sowr, hoafng mai, haf nooji"
  ],
  "Yên Thái, Văn Yên, Yên Bái": [
    "yên thái, văn yên, yên bái",
    "yeen thasi, vawn yeen, yeen basi"
  ],
  "Yên Thái, Yên Mô, Ninh Bình": [
    "yên thái, yên mô, ninh bình",
    "yeen thasi, yeen moo, ninh bifnh"
  ],
  "Yên Thọ, Ý Yên, Nam Định": [
    "yên thọ, ý yên, nam định",
    "yeen thoj, ys yeen, nam ddijnh"
  ],
  "Yên Trung, Ý Yên, Nam Định": [
    "yên trung, ý yên, nam định",
    "yeen trung, ys yeen, nam ddijnh"
  ],
  "Yên Trị, Ý Yên, Nam Định": [
    "yên trị, ý yên, nam định",
    "yeen trij, ys yeen, nam ddijnh"
  ],
  "Yến Lạc, Na Rì, Bắc Kạn": [
    "yến lạc, na rì, bắc kạn",
    "yeesn lajc, na rif, bawsc kajn"
  ],
  "Ích Hậu, Lộc Hà, Hà Tĩnh": [
    "ích hậu, lộc hà, hà tĩnh",
    "isch haaju, loojc haf, haf tixnh"
  ],
  "é Tòng, Thuận Châu, Sơn La": [
    "é tòng, thuận châu, sơn la",
    "es tofng, thuaajn chaau, sown la"
  ],
  "Đu, Phú Lương, Thái Nguyên": [
    "đu, phú lương, thái nguyên",
    "ddu, phus luwowng, thasi nguyeen"
  ],
  "Đà Vị, Na Hang, Tuyên Quang": [
    "đà vị, na hang, tuyên quang",
    "ddaf vij, na hang, tuyeen quang"
  ],
  "Đú Sáng, Kim Bôi, Hoà Bình": [
    "đú sáng, kim bôi, hoà bình",
    "ddus sasng, kim booi, hoaf bifnh"
  ],
  "Đăk Krong, Đăk Đoa, Gia Lai": [
    "đăk krong, đăk đoa, gia lai",
    "ddawk krong, ddawk ddoa, gia lai"
  ],
  "Đăk Pling, Kông Chro, Gia Lai": [
    "đăk pling, kông chro, gia lai",
    "ddawk pling, koong chro, gia lai"
  ],
  "Đất Mới, Năm Căn, Cà Mau": [
    "đất mới, năm căn, cà mau",
    "ddaast mowsi, nawm cawn, caf mau"
  ],
  "Đắk Man, Đắk Glei, Kon Tum": [
    "đắk man, đắk glei, kon tum",
    "ddawsk man, ddawsk glei, kon tum"
  ],
  "Đắk Na, Tu Mơ Rông, Kon Tum": [
    "đắk na, tu mơ rông, kon tum",
    "ddawsk na, tu mow roong, kon tum"
  ],
  "Đắk Nuê, Lắk, Đắk Lắk": [
    "đắk nuê, lắk, đắk lắk",
    "ddawsk nuee, lawsk, ddawsk lawsk"
  ],
  "Đắk Nên, Kon Plông, Kon Tum": [
    "đắk nên, kon plông, kon tum",
    "ddawsk neen, kon ploong, kon tum"
  ],
  "Đắk Ring, Kon Plông, Kon Tum": [
    "đắk ring, kon plông, kon tum",
    "ddawsk ring, kon ploong, kon tum"
  ],
  "Đặng Xá, Gia Lâm, Hà Nội": [
    "đặng xá, gia lâm, hà nội",
    "ddawjng xas, gia laam, haf nooji"
  ],
  "Đồn Xá, Bình Lục, Hà Nam": [
    "đồn xá, bình lục, hà nam",
    "ddoofn xas, bifnh lujc, haf nam"
  ],
  "Đồng Du, Bình Lục, Hà Nam": [
    "đồng du, bình lục, hà nam",
    "ddoofng du, bifnh lujc, haf nam"
  ],
  "Đồng Thái, Ba Vì, Hà Nội": [
    "đồng thái, ba vì, hà nội",
    "ddoofng thasi, ba vif, haf nooji"
  ],
  "Đồng Văn, Duy Tiên, Hà Nam": [
    "đồng văn, duy tiên, hà nam",
    "ddoofng vawn, duy tieen, haf nam"
  ],
  "Đổng Xá, Na Rì, Bắc Kạn": [
    "đổng xá, na rì, bắc kạn",
    "ddoorng xas, na rif, bawsc kajn"
  ],
  "Đỗ Sơn, Thanh Ba, Phú Thọ": [
    "đỗ sơn, thanh ba, phú thọ",
    "ddoox sown, thanh ba, phus thoj"
  ],
  "Đức Long, Hoà An, Cao Bằng": [
    "đức long, hoà an, cao bằng",
    "dduwsc long, hoaf an, cao bawfng"
  ],
  "Đức Sơn, Anh Sơn, Nghệ An": [
    "đức sơn, anh sơn, nghệ an",
    "dduwsc sown, anh sown, ngheej an"
  ],
  "Đức Tân, Tân Trụ, Long An": [
    "đức tân, tân trụ, long an",
    "dduwsc taan, taan truj, long an"
  ],
  "Ấm Hạ, Hạ Hoà, Phú Thọ": [
    "ấm hạ, hạ hoà, phú thọ",
    "aasm haj, haj hoaf, phus thoj"
  ],
  "A Bung, Đa Krông, Quảng Trị": [
    "a bung, đa krông, quảng trị",
    "a bung, dda kroong, quarng trij"
  ],
  "A Rooi, Đông Giang, Quảng Nam": [
    "a rooi, đông giang, quảng nam",
    "a rooi, ddoong giang, quarng nam"
  ],
  "A Ting, Đông Giang, Quảng Nam": [
    "a ting, đông giang, quảng nam",
    "a ting, ddoong giang, quarng nam"
  ],
  "A Tiêng, Tây Giang, Quảng Nam": [
    "a tiêng, tây giang, quảng nam",
    "a tieeng, taay giang, quarng nam"
  ],
  "An Biên, Lê Chân, Hải Phòng": [
    "an biên, lê chân, hải phòng",
    "an bieen, lee chaan, hari phofng"
  ],
  "An Bá, Sơn Động, Bắc Giang": [
    "an bá, sơn động, bắc giang",
    "an bas, sown ddoojng, bawsc giang"
  ],
  "An Bình, Biên Hòa, Đồng Nai": [
    "an bình, biên hòa, đồng nai",
    "an bifnh, bieen hofa, ddoofng nai"
  ],
  "An Bình, Châu Thành, Tây Ninh": [
    "an bình, châu thành, tây ninh",
    "an bifnh, chaau thafnh, taay ninh"
  ],
  "An Bình, Ninh Kiều, Cần Thơ": [
    "an bình, ninh kiều, cần thơ",
    "an bifnh, ninh kieefu, caafn thow"
  ],
  "An Dũng, Đức Thọ, Hà Tĩnh": [
    "an dũng, đức thọ, hà tĩnh",
    "an duxng, dduwsc thoj, haf tixnh"
  ],
  "An Hoà, An Dương, Hải Phòng": [
    "an hoà, an dương, hải phòng",
    "an hoaf, an duwowng, hari phofng"
  ],
  "An Hà, Lạng Giang, Bắc Giang": [
    "an hà, lạng giang, bắc giang",
    "an haf, lajng giang, bawsc giang"
  ],
  "An Hòa, Rạch Giá, Kiên Giang": [
    "an hòa, rạch giá, kiên giang",
    "an hofa, rajch gias, kieen giang"
  ],
  "An Hòa, Tam Dương, Vĩnh Phúc": [
    "an hòa, tam dương, vĩnh phúc",
    "an hofa, tam duwowng, vixnh phusc"
  ],
  "An Hòa, Tam Nông, Đồng Tháp": [
    "an hòa, tam nông, đồng tháp",
    "an hofa, tam noong, ddoofng thasp"
  ],
  "An Hòa, Trảng Bàng, Tây Ninh": [
    "an hòa, trảng bàng, tây ninh",
    "an hofa, trarng bafng, taay ninh"
  ],
  "An Long, Tam Nông, Đồng Tháp": [
    "an long, tam nông, đồng tháp",
    "an long, tam noong, ddoofng thasp"
  ],
  "An Lâm, Nam Sách, Hải Dương": [
    "an lâm, nam sách, hải dương",
    "an laam, nam sasch, hari duwowng"
  ],
  "An Lưu, Kinh Môn, Hải Dương": [
    "an lưu, kinh môn, hải dương",
    "an luwu, kinh moon, hari duwowng"
  ],
  "An Nghĩa, An Lão, Bình Định": [
    "an nghĩa, an lão, bình định",
    "an nghixa, an laxo, bifnh ddijnh"
  ],
  "An Ngãi Trung, Ba Tri, Bến Tre": [
    "an ngãi trung, ba tri, bến tre",
    "an ngaxi trung, ba tri, beesn tre"
  ],
  "An Nhơn, Thạnh Phú, Bến Tre": [
    "an nhơn, thạnh phú, bến tre",
    "an nhown, thajnh phus, beesn tre"
  ],
  "An Ninh Đông, Tuy An, Phú Yên": [
    "an ninh đông, tuy an, phú yên",
    "an ninh ddoong, tuy an, phus yeen"
  ],
  "An Phú, Củ Chi, Hồ Chí Minh": [
    "an phú, củ chi, hồ chí minh",
    "an phus, cur chi, hoof chis minh"
  ],
  "An Phú, Quận 2, Hồ Chí Minh": [
    "an phú, quận 2, hồ chí minh",
    "an phus, quaajn 2, hoof chis minh"
  ],
  "An Sinh, Kinh Môn, Hải Dương": [
    "an sinh, kinh môn, hải dương",
    "an sinh, kinh moon, hari duwowng"
  ],
  "An Sơn, Kiên Hải, Kiên Giang": [
    "an sơn, kiên hải, kiên giang",
    "an sown, kieen hari, kieen giang"
  ],
  "An Sơn, Nam Sách, Hải Dương": [
    "an sơn, nam sách, hải dương",
    "an sown, nam sasch, hari duwowng"
  ],
  "An Thắng, An Lão, Hải Phòng": [
    "an thắng, an lão, hải phòng",
    "an thawsng, an laxo, hari phofng"
  ],
  "An Tiến, Mỹ Đức, Hà Nội": [
    "an tiến, mỹ đức, hà nội",
    "an tieesn, myx dduwsc, haf nooji"
  ],
  "Ba Trinh, Kế Sách, Sóc Trăng": [
    "ba trinh, kế sách, sóc trăng",
    "ba trinh, kees sasch, sosc trawng"
  ],
  "Ba Điền, Ba Tơ, Quảng Ngãi": [
    "ba điền, ba tơ, quảng ngãi",
    "ba ddieefn, ba tow, quarng ngaxi"
  ],
  "Ba Đình, Bỉm Sơn, Thanh Hóa": [
    "ba đình, bỉm sơn, thanh hóa",
    "ba ddifnh, birm sown, thanh hosa"
  ],
  "Ba Đình, Thanh Hóa, Thanh Hóa": [
    "ba đình, thanh hóa, thanh hóa",
    "ba ddifnh, thanh hosa, thanh hosa"
  ],
  "Ba Động, Ba Tơ, Quảng Ngãi": [
    "ba động, ba tơ, quảng ngãi",
    "ba ddoojng, ba tow, quarng ngaxi"
  ],
  "Bum Nưa, Mường Tè, Lai Châu": [
    "bum nưa, mường tè, lai châu",
    "bum nuwa, muwowfng tef, lai chaau"
  ],
  "Bum Tở, Mường Tè, Lai Châu": [
    "bum tở, mường tè, lai châu",
    "bum towr, muwowfng tef, lai chaau"
  ],
  "Bàu Đồn, Gò Dầu, Tây Ninh": [
    "bàu đồn, gò dầu, tây ninh",
    "bafu ddoofn, gof daafu, taay ninh"
  ],
  "Bát Trang, An Lão, Hải Phòng": [
    "bát trang, an lão, hải phòng",
    "bast trang, an laxo, hari phofng"
  ],
  "Bình Gia, Bình Gia, Lạng Sơn": [
    "bình gia, bình gia, lạng sơn",
    "bifnh gia, bifnh gia, lajng sown"
  ],
  "Bình Giáo, Chư Prông, Gia Lai": [
    "bình giáo, chư prông, gia lai",
    "bifnh giaso, chuw proong, gia lai"
  ],
  "Bình Kiến, Tuy Hoà, Phú Yên": [
    "bình kiến, tuy hoà, phú yên",
    "bifnh kieesn, tuy hoaf, phus yeen"
  ],
  "Bình Minh, Tĩnh Gia, Thanh Hóa": [
    "bình minh, tĩnh gia, thanh hóa",
    "bifnh minh, tixnh gia, thanh hosa"
  ],
  "Bình Ngọc, Tuy Hoà, Phú Yên": [
    "bình ngọc, tuy hoà, phú yên",
    "bifnh ngojc, tuy hoaf, phus yeen"
  ],
  "Bình Ninh, Tam Bình, Vĩnh Long": [
    "bình ninh, tam bình, vĩnh long",
    "bifnh ninh, tam bifnh, vixnh long"
  ],
  "Bình Phú, Càng Long, Trà Vinh": [
    "bình phú, càng long, trà vinh",
    "bifnh phus, cafng long, traf vinh"
  ],
  "Bình Phú, Phù Ninh, Phú Thọ": [
    "bình phú, phù ninh, phú thọ",
    "bifnh phus, phuf ninh, phus thoj"
  ],
  "Bình San, Hà Tiên, Kiên Giang": [
    "bình san, hà tiên, kiên giang",
    "bifnh san, haf tieen, kieen giang"
  ],
  "Bình Tịnh, Tân Trụ, Long An": [
    "bình tịnh, tân trụ, long an",
    "bifnh tijnh, taan truj, long an"
  ],
  "Bình Xa, Hàm Yên, Tuyên Quang": [
    "bình xa, hàm yên, tuyên quang",
    "bifnh xa, hafm yeen, tuyeen quang"
  ],
  "Bạch Hà, Yên Bình, Yên Bái": [
    "bạch hà, yên bình, yên bái",
    "bajch haf, yeen bifnh, yeen basi"
  ],
  "Bạch Sam, Mỹ Hào, Hưng Yên": [
    "bạch sam, mỹ hào, hưng yên",
    "bajch sam, myx hafo, huwng yeen"
  ],
  "Bản Díu, Xín Mần, Hà Giang": [
    "bản díu, xín mần, hà giang",
    "barn disu, xisn maafn, haf giang"
  ],
  "Bản Liền, Bắc Hà, Lào Cai": [
    "bản liền, bắc hà, lào cai",
    "barn lieefn, bawsc haf, lafo cai"
  ],
  "Bản Ngò, Xín Mần, Hà Giang": [
    "bản ngò, xín mần, hà giang",
    "barn ngof, xisn maafn, haf giang"
  ],
  "Bắc Hòa, Tân Thạnh, Long An": [
    "bắc hòa, tân thạnh, long an",
    "bawsc hofa, taan thajnh, long an"
  ],
  "Bắc La, Văn Lãng, Lạng Sơn": [
    "bắc la, văn lãng, lạng sơn",
    "bawsc la, vawn laxng, lajng sown"
  ],
  "Bắc Sơn, Tam Nông, Phú Thọ": [
    "bắc sơn, tam nông, phú thọ",
    "bawsc sown, tam noong, phus thoj"
  ],
  "Bến Lức, Bến Lức, Long An": [
    "bến lức, bến lức, long an",
    "beesn luwsc, beesn luwsc, long an"
  ],
  "Bối Cầu, Bình Lục, Hà Nam": [
    "bối cầu, bình lục, hà nam",
    "boosi caafu, bifnh lujc, haf nam"
  ],
  "Bồ Lý, Tam Đảo, Vĩnh Phúc": [
    "bồ lý, tam đảo, vĩnh phúc",
    "boof lys, tam ddaro, vixnh phusc"
  ],
  "Bồ Đề, Long Biên, Hà Nội": [
    "bồ đề, long biên, hà nội",
    "boof ddeef, long bieen, haf nooji"
  ],
  "Bồng Lai, Quế Võ, Bắc Ninh": [
    "bồng lai, quế võ, bắc ninh",
    "boofng lai, quees vox, bawsc ninh"
  ],
  "Cam An Nam, Cam Lâm, Khánh Hòa": [
    "cam an nam, cam lâm, khánh hòa",
    "cam an nam, cam laam, khasnh hofa"
  ],
  "Cam Lộ, Cam Lộ, Quảng Trị": [
    "cam lộ, cam lộ, quảng trị",
    "cam looj, cam looj, quarng trij"
  ],
  "Cam Nghĩa, Cam Ranh, Khánh Hòa": [
    "cam nghĩa, cam ranh, khánh hòa",
    "cam nghixa, cam ranh, khasnh hofa"
  ],
  "Cam Đường, Lào Cai, Lào Cai": [
    "cam đường, lào cai, lào cai",
    "cam dduwowfng, lafo cai, lafo cai"
  ],
  "Cam Đức, Cam Lâm, Khánh Hòa": [
    "cam đức, cam lâm, khánh hòa",
    "cam dduwsc, cam laam, khasnh hofa"
  ],
  "Canh Tân, Hưng Hà, Thái Bình": [
    "canh tân, hưng hà, thái bình",
    "canh taan, huwng haf, thasi bifnh"
  ],
  "Canh Tân, Thạch An, Cao Bằng": [
    "canh tân, thạch an, cao bằng",
    "canh taan, thajch an, cao bawfng"
  ],
  "Cao Dương, Thanh Oai, Hà Nội": [
    "cao dương, thanh oai, hà nội",
    "cao duwowng, thanh oai, haf nooji"
  ],
  "Cao Lộc, Cao Lộc, Lạng Sơn": [
    "cao lộc, cao lộc, lạng sơn",
    "cao loojc, cao loojc, lajng sown"
  ],
  "Cao Minh, Phúc Yên, Vĩnh Phúc": [
    "cao minh, phúc yên, vĩnh phúc",
    "cao minh, phusc yeen, vixnh phusc"
  ],
  "Cao Phong, Sông Lô, Vĩnh Phúc": [
    "cao phong, sông lô, vĩnh phúc",
    "cao phong, soong loo, vixnh phusc"
  ],
  "Cao Thành, Ứng Hòa, Hà Nội": [
    "cao thành, ứng hòa, hà nội",
    "cao thafnh, uwsng hofa, haf nooji"
  ],
  "Cao Tân, Pác Nặm, Bắc Kạn": [
    "cao tân, pác nặm, bắc kạn",
    "cao taan, pasc nawjm, bawsc kajn"
  ],
  "Cao Xanh, Hạ Long, Quảng Ninh": [
    "cao xanh, hạ long, quảng ninh",
    "cao xanh, haj long, quarng ninh"
  ],
  "Cao Đức, Gia Bình, Bắc Ninh": [
    "cao đức, gia bình, bắc ninh",
    "cao dduwsc, gia bifnh, bawsc ninh"
  ],
  "Chi Lăng, Chi Lăng, Lạng Sơn": [
    "chi lăng, chi lăng, lạng sơn",
    "chi lawng, chi lawng, lajng sown"
  ],
  "Chi Lăng, Hưng Hà, Thái Bình": [
    "chi lăng, hưng hà, thái bình",
    "chi lawng, huwng haf, thasi bifnh"
  ],
  "Chi Lăng, Tịnh Biên, An Giang": [
    "chi lăng, tịnh biên, an giang",
    "chi lawng, tijnh bieen, an giang"
  ],
  "Chi Nê, Lạc Thủy, Hoà Bình": [
    "chi nê, lạc thủy, hoà bình",
    "chi nee, lajc thury, hoaf bifnh"
  ],
  "Chiêu Lưu, Kỳ Sơn, Nghệ An": [
    "chiêu lưu, kỳ sơn, nghệ an",
    "chieeu luwu, kyf sown, ngheej an"
  ],
  "Chiềng Cang, Sông Mã, Sơn La": [
    "chiềng cang, sông mã, sơn la",
    "chieefng cang, soong max, sown la"
  ],
  "Chiềng Chung, Mai Sơn, Sơn La": [
    "chiềng chung, mai sơn, sơn la",
    "chieefng chung, mai sown, sown la"
  ],
  "Chiềng Chăn, Mai Sơn, Sơn La": [
    "chiềng chăn, mai sơn, sơn la",
    "chieefng chawn, mai sown, sown la"
  ],
  "Chiềng Ken, Văn Bàn, Lào Cai": [
    "chiềng ken, văn bàn, lào cai",
    "chieefng ken, vawn bafn, lafo cai"
  ],
  "Chiềng Khoa, Vân Hồ, Sơn La": [
    "chiềng khoa, vân hồ, sơn la",
    "chieefng khoa, vaan hoof, sown la"
  ],
  "Chiềng Ngần, Sơn La, Sơn La": [
    "chiềng ngần, sơn la, sơn la",
    "chieefng ngaafn, sown la, sown la"
  ],
  "Chiềng Yên, Vân Hồ, Sơn La": [
    "chiềng yên, vân hồ, sơn la",
    "chieefng yeen, vaan hoof, sown la"
  ],
  "Chu Hóa, Việt Trì, Phú Thọ": [
    "chu hóa, việt trì, phú thọ",
    "chu hosa, vieejt trif, phus thoj"
  ],
  "Chu Hương, Ba Bể, Bắc Kạn": [
    "chu hương, ba bể, bắc kạn",
    "chu huwowng, ba beer, bawsc kajn"
  ],
  "Chu Trinh, Cao Bằng, Cao Bằng": [
    "chu trinh, cao bằng, cao bằng",
    "chu trinh, cao bawfng, cao bawfng"
  ],
  "Chà Vàl, Nam Giang, Quảng Nam": [
    "chà vàl, nam giang, quảng nam",
    "chaf vafl, nam giang, quarng nam"
  ],
  "Chánh An, Mang Thít, Vĩnh Long": [
    "chánh an, mang thít, vĩnh long",
    "chasnh an, mang thist, vixnh long"
  ],
  "Châu Can, Phú Xuyên, Hà Nội": [
    "châu can, phú xuyên, hà nội",
    "chaau can, phus xuyeen, haf nooji"
  ],
  "Châu Khê, Con Cuông, Nghệ An": [
    "châu khê, con cuông, nghệ an",
    "chaau khee, con cuoong, ngheej an"
  ],
  "Châu Khê, Từ Sơn, Bắc Ninh": [
    "châu khê, từ sơn, bắc ninh",
    "chaau khee, tuwf sown, bawsc ninh"
  ],
  "Châu Kim, Quế Phong, Nghệ An": [
    "châu kim, quế phong, nghệ an",
    "chaau kim, quees phong, ngheej an"
  ],
  "Châu Lý, Quỳ Hợp, Nghệ An": [
    "châu lý, quỳ hợp, nghệ an",
    "chaau lys, quyf howjp, ngheej an"
  ],
  "Châu Nga, Quỳ Châu, Nghệ An": [
    "châu nga, quỳ châu, nghệ an",
    "chaau nga, quyf chaau, ngheej an"
  ],
  "Châu Phong, Tân Châu, An Giang": [
    "châu phong, tân châu, an giang",
    "chaau phong, taan chaau, an giang"
  ],
  "Chí Hòa, Hưng Hà, Thái Bình": [
    "chí hòa, hưng hà, thái bình",
    "chis hofa, huwng haf, thasi bifnh"
  ],
  "Chơ Chun, Nam Giang, Quảng Nam": [
    "chơ chun, nam giang, quảng nam",
    "chow chun, nam giang, quarng nam"
  ],
  "Chư Prông, Chư Prông, Gia Lai": [
    "chư prông, chư prông, gia lai",
    "chuw proong, chuw proong, gia lai"
  ],
  "Con Cuông, Con Cuông, Nghệ An": [
    "con cuông, con cuông, nghệ an",
    "con cuoong, con cuoong, ngheej an"
  ],
  "Cuối Hạ, Kim Bôi, Hoà Bình": [
    "cuối hạ, kim bôi, hoà bình",
    "cuoosi haj, kim booi, hoaf bifnh"
  ],
  "Càng Long, Càng Long, Trà Vinh": [
    "càng long, càng long, trà vinh",
    "cafng long, cafng long, traf vinh"
  ],
  "Cái Nhum, Mang Thít, Vĩnh Long": [
    "cái nhum, mang thít, vĩnh long",
    "casi nhum, mang thist, vixnh long"
  ],
  "Cán Khê, Như Thanh, Thanh Hóa": [
    "cán khê, như thanh, thanh hóa",
    "casn khee, nhuw thanh, thanh hosa"
  ],
  "Cán Tỷ, Quản Bạ, Hà Giang": [
    "cán tỷ, quản bạ, hà giang",
    "casn tyr, quarn baj, haf giang"
  ],
  "Cát Linh, Đống Đa, Hà Nội": [
    "cát linh, đống đa, hà nội",
    "cast linh, ddoosng dda, haf nooji"
  ],
  "Cát Tân, Như Xuân, Thanh Hóa": [
    "cát tân, như xuân, thanh hóa",
    "cast taan, nhuw xuaan, thanh hosa"
  ],
  "Cát Vân, Như Xuân, Thanh Hóa": [
    "cát vân, như xuân, thanh hóa",
    "cast vaan, nhuw xuaan, thanh hosa"
  ],
  "Cư Bao, Buôn Hồ, Đắk Lắk": [
    "cư bao, buôn hồ, đắk lắk",
    "cuw bao, buoon hoof, ddawsk lawsk"
  ],
  "Cư M'ta, M'Đrắk, Đắk Lắk": [
    "cư m'ta, m'đrắk, đắk lắk",
    "cuw m'ta, m'ddrawsk, ddawsk lawsk"
  ],
  "Cư Mốt, Ea H'leo, Đắk Lắk": [
    "cư mốt, ea h'leo, đắk lắk",
    "cuw moost, ea h'leo, ddawsk lawsk"
  ],
  "Cư Prao, M'Đrắk, Đắk Lắk": [
    "cư prao, m'đrắk, đắk lắk",
    "cuw prao, m'ddrawsk, ddawsk lawsk"
  ],
  "Cư Suê, Cư M'gar, Đắk Lắk": [
    "cư suê, cư m'gar, đắk lắk",
    "cuw suee, cuw m'gar, ddawsk lawsk"
  ],
  "Cư Ê Wi, Cư Kuin, Đắk Lắk": [
    "cư ê wi, cư kuin, đắk lắk",
    "cuw ee wi, cuw kuin, ddawsk lawsk"
  ],
  "Cẩm Giang, Gò Dầu, Tây Ninh": [
    "cẩm giang, gò dầu, tây ninh",
    "caarm giang, gof daafu, taay ninh"
  ],
  "Cẩm Lý, Lục Nam, Bắc Giang": [
    "cẩm lý, lục nam, bắc giang",
    "caarm lys, lujc nam, bawsc giang"
  ],
  "Cẩm Phô, Hội An, Quảng Nam": [
    "cẩm phô, hội an, quảng nam",
    "caarm phoo, hooji an, quarng nam"
  ],
  "Cốc Pài, Xín Mần, Hà Giang": [
    "cốc pài, xín mần, hà giang",
    "coosc pafi, xisn maafn, haf giang"
  ],
  "Cốc Rế, Xín Mần, Hà Giang": [
    "cốc rế, xín mần, hà giang",
    "coosc rees, xisn maafn, haf giang"
  ],
  "Cống Vị, Ba Đình, Hà Nội": [
    "cống vị, ba đình, hà nội",
    "coosng vij, ba ddifnh, haf nooji"
  ],
  "Cổ Đông, Sơn Tây, Hà Nội": [
    "cổ đông, sơn tây, hà nội",
    "coor ddoong, sown taay, haf nooji"
  ],
  "Củng Sơn, Sơn Hòa, Phú Yên": [
    "củng sơn, sơn hòa, phú yên",
    "curng sown, sown hofa, phus yeen"
  ],
  "Cửu Cao, Văn Giang, Hưng Yên": [
    "cửu cao, văn giang, hưng yên",
    "cuwru cao, vawn giang, huwng yeen"
  ],
  "Di Lăng, Sơn Hà, Quảng Ngãi": [
    "di lăng, sơn hà, quảng ngãi",
    "di lawng, sown haf, quarng ngaxi"
  ],
  "Duy Hòa, Duy Xuyên, Quảng Nam": [
    "duy hòa, duy xuyên, quảng nam",
    "duy hofa, duy xuyeen, quarng nam"
  ],
  "Duy Nhất, Vũ Thư, Thái Bình": [
    "duy nhất, vũ thư, thái bình",
    "duy nhaast, vux thuw, thasi bifnh"
  ],
  "Duy Phú, Duy Xuyên, Quảng Nam": [
    "duy phú, duy xuyên, quảng nam",
    "duy phus, duy xuyeen, quarng nam"
  ],
  "Duy Sơn, Duy Xuyên, Quảng Nam": [
    "duy sơn, duy xuyên, quảng nam",
    "duy sown, duy xuyeen, quarng nam"
  ],
  "Duy Tân, Duy Xuyên, Quảng Nam": [
    "duy tân, duy xuyên, quảng nam",
    "duy taan, duy xuyeen, quarng nam"
  ],
  "Duy Vinh, Duy Xuyên, Quảng Nam": [
    "duy vinh, duy xuyên, quảng nam",
    "duy vinh, duy xuyeen, quarng nam"
  ],
  "Duyên Hà, Thanh Trì, Hà Nội": [
    "duyên hà, thanh trì, hà nội",
    "duyeen haf, thanh trif, haf nooji"
  ],
  "Dương Sơn, Na Rì, Bắc Kạn": [
    "dương sơn, na rì, bắc kạn",
    "duwowng sown, na rif, bawsc kajn"
  ],
  "Dần Thàng, Văn Bàn, Lào Cai": [
    "dần thàng, văn bàn, lào cai",
    "daafn thafng, vawn bafn, lafo cai"
  ],
  "Dền Thàng, Bát Xát, Lào Cai": [
    "dền thàng, bát xát, lào cai",
    "deefn thafng, bast xast, lafo cai"
  ],
  "Dị Nậu, Tam Nông, Phú Thọ": [
    "dị nậu, tam nông, phú thọ",
    "dij naaju, tam noong, phus thoj"
  ],
  "Ea BHốk, Cư Kuin, Đắk Lắk": [
    "ea bhốk, cư kuin, đắk lắk",
    "ea bhoosk, cuw kuin, ddawsk lawsk"
  ],
  "Ea Bar, Buôn Đôn, Đắk Lắk": [
    "ea bar, buôn đôn, đắk lắk",
    "ea bar, buoon ddoon, ddawsk lawsk"
  ],
  "Ea Drăng, Ea H'leo, Đắk Lắk": [
    "ea drăng, ea h'leo, đắk lắk",
    "ea drawng, ea h'leo, ddawsk lawsk"
  ],
  "Ea Kuêh, Cư M'gar, Đắk Lắk": [
    "ea kuêh, cư m'gar, đắk lắk",
    "ea kueeh, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Pốk, Cư M'gar, Đắk Lắk": [
    "ea pốk, cư m'gar, đắk lắk",
    "ea poosk, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Sin, Krông Búk, Đắk Lắk": [
    "ea sin, krông búk, đắk lắk",
    "ea sin, kroong busk, ddawsk lawsk"
  ],
  "Ea T'Ling, Cư Jút, Đắk Nông": [
    "ea t'ling, cư jút, đắk nông",
    "ea t'ling, cuw just, ddawsk noong"
  ],
  "Ea Trang, M'Đrắk, Đắk Lắk": [
    "ea trang, m'đrắk, đắk lắk",
    "ea trang, m'ddrawsk, ddawsk lawsk"
  ],
  "Ea Uy, Krông Pắc, Đắk Lắk": [
    "ea uy, krông pắc, đắk lắk",
    "ea uy, kroong pawsc, ddawsk lawsk"
  ],
  "Ea Wer, Buôn Đôn, Đắk Lắk": [
    "ea wer, buôn đôn, đắk lắk",
    "ea wer, buoon ddoon, ddawsk lawsk"
  ],
  "Eachà Rang, Sơn Hòa, Phú Yên": [
    "eachà rang, sơn hòa, phú yên",
    "eachaf rang, sown hofa, phus yeen"
  ],
  "Gia An, Tánh Linh, Bình Thuận": [
    "gia an, tánh linh, bình thuận",
    "gia an, tasnh linh, bifnh thuaajn"
  ],
  "Gia Hiệp, Di Linh, Lâm Đồng": [
    "gia hiệp, di linh, lâm đồng",
    "gia hieejp, di linh, laam ddoofng"
  ],
  "Gia Hưng, Gia Viễn, Ninh Bình": [
    "gia hưng, gia viễn, ninh bình",
    "gia huwng, gia vieexn, ninh bifnh"
  ],
  "Gia Hội, Văn Chấn, Yên Bái": [
    "gia hội, văn chấn, yên bái",
    "gia hooji, vawn chaasn, yeen basi"
  ],
  "Gia Lạc, Gia Viễn, Ninh Bình": [
    "gia lạc, gia viễn, ninh bình",
    "gia lajc, gia vieexn, ninh bifnh"
  ],
  "Gia Lập, Gia Viễn, Ninh Bình": [
    "gia lập, gia viễn, ninh bình",
    "gia laajp, gia vieexn, ninh bifnh"
  ],
  "Gia Lộc, Chi Lăng, Lạng Sơn": [
    "gia lộc, chi lăng, lạng sơn",
    "gia loojc, chi lawng, lajng sown"
  ],
  "Gia Phong, Gia Viễn, Ninh Bình": [
    "gia phong, gia viễn, ninh bình",
    "gia phong, gia vieexn, ninh bifnh"
  ],
  "Gia Phú, Bảo Thắng, Lào Cai": [
    "gia phú, bảo thắng, lào cai",
    "gia phus, baro thawsng, lafo cai"
  ],
  "Gia Ray, Xuân Lộc, Đồng Nai": [
    "gia ray, xuân lộc, đồng nai",
    "gia ray, xuaan loojc, ddoofng nai"
  ],
  "Gia Thanh, Gia Viễn, Ninh Bình": [
    "gia thanh, gia viễn, ninh bình",
    "gia thanh, gia vieexn, ninh bifnh"
  ],
  "Gia Thụy, Long Biên, Hà Nội": [
    "gia thụy, long biên, hà nội",
    "gia thujy, long bieen, haf nooji"
  ],
  "Gia Trung, Gia Viễn, Ninh Bình": [
    "gia trung, gia viễn, ninh bình",
    "gia trung, gia vieexn, ninh bifnh"
  ],
  "Gia Xuân, Gia Viễn, Ninh Bình": [
    "gia xuân, gia viễn, ninh bình",
    "gia xuaan, gia vieexn, ninh bifnh"
  ],
  "Giang Sơn, Gia Bình, Bắc Ninh": [
    "giang sơn, gia bình, bắc ninh",
    "giang sown, gia bifnh, bawsc ninh"
  ],
  "Giao An, Giao Thủy, Nam Định": [
    "giao an, giao thủy, nam định",
    "giao an, giao thury, nam ddijnh"
  ],
  "Gio Linh, Gio Linh, Quảng Trị": [
    "gio linh, gio linh, quảng trị",
    "gio linh, gio linh, quarng trij"
  ],
  "Gio Mỹ, Gio Linh, Quảng Trị": [
    "gio mỹ, gio linh, quảng trị",
    "gio myx, gio linh, quarng trij"
  ],
  "Gio Sơn, Gio Linh, Quảng Trị": [
    "gio sơn, gio linh, quảng trị",
    "gio sown, gio linh, quarng trij"
  ],
  "Giáp Bát, Hoàng Mai, Hà Nội": [
    "giáp bát, hoàng mai, hà nội",
    "giasp bast, hoafng mai, haf nooji"
  ],
  "Giáp Lai, Thanh Sơn, Phú Thọ": [
    "giáp lai, thanh sơn, phú thọ",
    "giasp lai, thanh sown, phus thoj"
  ],
  "Giáp Trung, Bắc Mê, Hà Giang": [
    "giáp trung, bắc mê, hà giang",
    "giasp trung, bawsc mee, haf giang"
  ],
  "Giảng Võ, Ba Đình, Hà Nội": [
    "giảng võ, ba đình, hà nội",
    "giarng vox, ba ddifnh, haf nooji"
  ],
  "Hai Riêng, Sông Hinh, Phú Yên": [
    "hai riêng, sông hinh, phú yên",
    "hai rieeng, soong hinh, phus yeen"
  ],
  "Hiền Ninh, Sóc Sơn, Hà Nội": [
    "hiền ninh, sóc sơn, hà nội",
    "hieefn ninh, sosc sown, haf nooji"
  ],
  "Hiệp Hòa, Đức Hòa, Long An": [
    "hiệp hòa, đức hòa, long an",
    "hieejp hofa, dduwsc hofa, long an"
  ],
  "Hiệp Ninh, Tây Ninh, Tây Ninh": [
    "hiệp ninh, tây ninh, tây ninh",
    "hieejp ninh, taay ninh, taay ninh"
  ],
  "Hoa Thám, Bình Gia, Lạng Sơn": [
    "hoa thám, bình gia, lạng sơn",
    "hoa thasm, bifnh gia, lajng sown"
  ],
  "Hoà Lộc, Tam Bình, Vĩnh Long": [
    "hoà lộc, tam bình, vĩnh long",
    "hoaf loojc, tam bifnh, vixnh long"
  ],
  "Hoà Vinh, Đông Hòa, Phú Yên": [
    "hoà vinh, đông hòa, phú yên",
    "hoaf vinh, ddoong hofa, phus yeen"
  ],
  "Hoàn Long, Yên Mỹ, Hưng Yên": [
    "hoàn long, yên mỹ, hưng yên",
    "hoafn long, yeen myx, huwng yeen"
  ],
  "Hoàng Trĩ, Ba Bể, Bắc Kạn": [
    "hoàng trĩ, ba bể, bắc kạn",
    "hoafng trix, ba beer, bawsc kajn"
  ],
  "Hoàng Đông, Duy Tiên, Hà Nam": [
    "hoàng đông, duy tiên, hà nam",
    "hoafng ddoong, duy tieen, haf nam"
  ],
  "Huy Thượng, Phù Yên, Sơn La": [
    "huy thượng, phù yên, sơn la",
    "huy thuwowjng, phuf yeen, sown la"
  ],
  "Huồi Tụ, Kỳ Sơn, Nghệ An": [
    "huồi tụ, kỳ sơn, nghệ an",
    "huoofi tuj, kyf sown, ngheej an"
  ],
  "Hà Linh, Hương Khê, Hà Tĩnh": [
    "hà linh, hương khê, hà tĩnh",
    "haf linh, huwowng khee, haf tixnh"
  ],
  "Hà Lộc, Phú Thọ, Phú Thọ": [
    "hà lộc, phú thọ, phú thọ",
    "haf loojc, phus thoj, phus thoj"
  ],
  "Hà Ngọc, Hà Trung, Thanh Hóa": [
    "hà ngọc, hà trung, thanh hóa",
    "haf ngojc, haf trung, thanh hosa"
  ],
  "Hà Tiến, Hà Trung, Thanh Hóa": [
    "hà tiến, hà trung, thanh hóa",
    "haf tieesn, haf trung, thanh hosa"
  ],
  "Hà Đông, Hà Trung, Thanh Hóa": [
    "hà đông, hà trung, thanh hóa",
    "haf ddoong, haf trung, thanh hosa"
  ],
  "Hát Môn, Phúc Thọ, Hà Nội": [
    "hát môn, phúc thọ, hà nội",
    "hast moon, phusc thoj, haf nooji"
  ],
  "Hòa An, Cao Lãnh, Đồng Tháp": [
    "hòa an, cao lãnh, đồng tháp",
    "hofa an, cao laxnh, ddoofng thasp"
  ],
  "Hòa Bình, Chợ Mới, An Giang": [
    "hòa bình, chợ mới, an giang",
    "hofa bifnh, chowj mowsi, an giang"
  ],
  "Hòa Bình, Vũ Thư, Thái Bình": [
    "hòa bình, vũ thư, thái bình",
    "hofa bifnh, vux thuw, thasi bifnh"
  ],
  "Hòa Bắc, Di Linh, Lâm Đồng": [
    "hòa bắc, di linh, lâm đồng",
    "hofa bawsc, di linh, laam ddoofng"
  ],
  "Hòa Long, Bắc Ninh, Bắc Ninh": [
    "hòa long, bắc ninh, bắc ninh",
    "hofa long, bawsc ninh, bawsc ninh"
  ],
  "Hòa Ninh, Hòa Vang, Đà Nẵng": [
    "hòa ninh, hòa vang, đà nẵng",
    "hofa ninh, hofa vang, ddaf nawxng"
  ],
  "Hòa Phong, Mỹ Hào, Hưng Yên": [
    "hòa phong, mỹ hào, hưng yên",
    "hofa phong, myx hafo, huwng yeen"
  ],
  "Hòa Phú, Hòa Vang, Đà Nẵng": [
    "hòa phú, hòa vang, đà nẵng",
    "hofa phus, hofa vang, ddaf nawxng"
  ],
  "Hòa Sơn, Hòa Vang, Đà Nẵng": [
    "hòa sơn, hòa vang, đà nẵng",
    "hofa sown, hofa vang, ddaf nawxng"
  ],
  "Hòa Trung, Di Linh, Lâm Đồng": [
    "hòa trung, di linh, lâm đồng",
    "hofa trung, di linh, laam ddoofng"
  ],
  "Hòa Tâm, Đông Hòa, Phú Yên": [
    "hòa tâm, đông hòa, phú yên",
    "hofa taam, ddoong hofa, phus yeen"
  ],
  "Hùng An, Kim Động, Hưng Yên": [
    "hùng an, kim động, hưng yên",
    "hufng an, kim ddoojng, huwng yeen"
  ],
  "Hùng Sơn, Lâm Thao, Phú Thọ": [
    "hùng sơn, lâm thao, phú thọ",
    "hufng sown, laam thao, phus thoj"
  ],
  "Hưng Công, Bình Lục, Hà Nam": [
    "hưng công, bình lục, hà nam",
    "huwng coong, bifnh lujc, haf nam"
  ],
  "Hưng Hoá, Tam Nông, Phú Thọ": [
    "hưng hoá, tam nông, phú thọ",
    "huwng hoas, tam noong, phus thoj"
  ],
  "Hưng Hà, Hưng Hà, Thái Bình": [
    "hưng hà, hưng hà, thái bình",
    "huwng haf, huwng haf, thasi bifnh"
  ],
  "Hưng Long, Mỹ Hào, Hưng Yên": [
    "hưng long, mỹ hào, hưng yên",
    "huwng long, myx hafo, huwng yeen"
  ],
  "Hưng Mỹ, Cái Nước, Cà Mau": [
    "hưng mỹ, cái nước, cà mau",
    "huwng myx, casi nuwowsc, caf mau"
  ],
  "Hưng Phú, Mỹ Tú, Sóc Trăng": [
    "hưng phú, mỹ tú, sóc trăng",
    "huwng phus, myx tus, sosc trawng"
  ],
  "Hưng Yên, An Biên, Kiên Giang": [
    "hưng yên, an biên, kiên giang",
    "huwng yeen, an bieen, kieen giang"
  ],
  "Hạ Giáp, Phù Ninh, Phú Thọ": [
    "hạ giáp, phù ninh, phú thọ",
    "haj giasp, phuf ninh, phus thoj"
  ],
  "Hạ Sơn, Quỳ Hợp, Nghệ An": [
    "hạ sơn, quỳ hợp, nghệ an",
    "haj sown, quyf howjp, ngheej an"
  ],
  "Hải Ninh, Tĩnh Gia, Thanh Hóa": [
    "hải ninh, tĩnh gia, thanh hóa",
    "hari ninh, tixnh gia, thanh hosa"
  ],
  "Hố Nai, Biên Hòa, Đồng Nai": [
    "hố nai, biên hòa, đồng nai",
    "hoos nai, bieen hofa, ddoofng nai"
  ],
  "Hồ Nam, Lê Chân, Hải Phòng": [
    "hồ nam, lê chân, hải phòng",
    "hoof nam, lee chaan, hari phofng"
  ],
  "Hồng An, Hưng Hà, Thái Bình": [
    "hồng an, hưng hà, thái bình",
    "hoofng an, huwng haf, thasi bifnh"
  ],
  "Hồng Ca, Trấn Yên, Yên Bái": [
    "hồng ca, trấn yên, yên bái",
    "hoofng ca, traasn yeen, yeen basi"
  ],
  "Hồng Kỳ, Sóc Sơn, Hà Nội": [
    "hồng kỳ, sóc sơn, hà nội",
    "hoofng kyf, sosc sown, haf nooji"
  ],
  "Hồng Long, Nam Đàn, Nghệ An": [
    "hồng long, nam đàn, nghệ an",
    "hoofng long, nam ddafn, ngheej an"
  ],
  "Hồng Lý, Vũ Thư, Thái Bình": [
    "hồng lý, vũ thư, thái bình",
    "hoofng lys, vux thuw, thasi bifnh"
  ],
  "Hồng Ngài, Bắc Yên, Sơn La": [
    "hồng ngài, bắc yên, sơn la",
    "hoofng ngafi, bawsc yeen, sown la"
  ],
  "Hồng Quang, Ân Thi, Hưng Yên": [
    "hồng quang, ân thi, hưng yên",
    "hoofng quang, aan thi, huwng yeen"
  ],
  "Hữu Hoà, Thanh Trì, Hà Nội": [
    "hữu hoà, thanh trì, hà nội",
    "huwxu hoaf, thanh trif, haf nooji"
  ],
  "Hữu Lập, Kỳ Sơn, Nghệ An": [
    "hữu lập, kỳ sơn, nghệ an",
    "huwxu laajp, kyf sown, ngheej an"
  ],
  "Ka Long, Móng Cái, Quảng Ninh": [
    "ka long, móng cái, quảng ninh",
    "ka long, mosng casi, quarng ninh"
  ],
  "Ka Lăng, Mường Tè, Lai Châu": [
    "ka lăng, mường tè, lai châu",
    "ka lawng, muwowfng tef, lai chaau"
  ],
  "Kan Hồ, Mường Tè, Lai Châu": [
    "kan hồ, mường tè, lai châu",
    "kan hoof, muwowfng tef, lai chaau"
  ],
  "Khai Trung, Lục Yên, Yên Bái": [
    "khai trung, lục yên, yên bái",
    "khai trung, lujc yeen, yeen basi"
  ],
  "Khánh Hòa, Châu Phú, An Giang": [
    "khánh hòa, châu phú, an giang",
    "khasnh hofa, chaau phus, an giang"
  ],
  "Khánh Sơn, Nam Đàn, Nghệ An": [
    "khánh sơn, nam đàn, nghệ an",
    "khasnh sown, nam ddafn, ngheej an"
  ],
  "Kim Chung, Hưng Hà, Thái Bình": [
    "kim chung, hưng hà, thái bình",
    "kim chung, huwng haf, thasi bifnh"
  ],
  "Kim Chân, Bắc Ninh, Bắc Ninh": [
    "kim chân, bắc ninh, bắc ninh",
    "kim chaan, bawsc ninh, bawsc ninh"
  ],
  "Kim Cúc, Bảo Lạc, Cao Bằng": [
    "kim cúc, bảo lạc, cao bằng",
    "kim cusc, baro lajc, cao bawfng"
  ],
  "Kim Giang, Thanh Xuân, Hà Nội": [
    "kim giang, thanh xuân, hà nội",
    "kim giang, thanh xuaan, haf nooji"
  ],
  "Kim Liên, Đống Đa, Hà Nội": [
    "kim liên, đống đa, hà nội",
    "kim lieen, ddoosng dda, haf nooji"
  ],
  "Kim Quan, Yên Sơn, Tuyên Quang": [
    "kim quan, yên sơn, tuyên quang",
    "kim quan, yeen sown, tuyeen quang"
  ],
  "Kim Định, Kim Sơn, Ninh Bình": [
    "kim định, kim sơn, ninh bình",
    "kim ddijnh, kim sown, ninh bifnh"
  ],
  "Kiện Khê, Thanh Liêm, Hà Nam": [
    "kiện khê, thanh liêm, hà nam",
    "kieejn khee, thanh lieem, haf nam"
  ],
  "Kỳ Sơn, Hòa Bình, Hoà Bình": [
    "kỳ sơn, hòa bình, hoà bình",
    "kyf sown, hofa bifnh, hoaf bifnh"
  ],
  "Kỳ Thịnh, Kỳ Anh, Hà Tĩnh": [
    "kỳ thịnh, kỳ anh, hà tĩnh",
    "kyf thijnh, kyf anh, haf tixnh"
  ],
  "Kỳ Đồng, Kỳ Anh, Hà Tĩnh": [
    "kỳ đồng, kỳ anh, hà tĩnh",
    "kyf ddoofng, kyf anh, haf tixnh"
  ],
  "La Hiên, Võ Nhai, Thái Nguyên": [
    "la hiên, võ nhai, thái nguyên",
    "la hieen, vox nhai, thasi nguyeen"
  ],
  "La Hà, Tư Nghĩa, Quảng Ngãi": [
    "la hà, tư nghĩa, quảng ngãi",
    "la haf, tuw nghixa, quarng ngaxi"
  ],
  "Lai Vu, Kim Thành, Hải Dương": [
    "lai vu, kim thành, hải dương",
    "lai vu, kim thafnh, hari duwowng"
  ],
  "Lai Vung, Lai Vung, Đồng Tháp": [
    "lai vung, lai vung, đồng tháp",
    "lai vung, lai vung, ddoofng thasp"
  ],
  "Lam Cốt, Tân Yên, Bắc Giang": [
    "lam cốt, tân yên, bắc giang",
    "lam coost, taan yeen, bawsc giang"
  ],
  "Lam Sơn, Lê Chân, Hải Phòng": [
    "lam sơn, lê chân, hải phòng",
    "lam sown, lee chaan, hari phofng"
  ],
  "Lam Sơn, Thọ Xuân, Thanh Hóa": [
    "lam sơn, thọ xuân, thanh hóa",
    "lam sown, thoj xuaan, thanh hosa"
  ],
  "Lam Sơn, Đô Lương, Nghệ An": [
    "lam sơn, đô lương, nghệ an",
    "lam sown, ddoo luwowng, ngheej an"
  ],
  "Lan Mẫu, Lục Nam, Bắc Giang": [
    "lan mẫu, lục nam, bắc giang",
    "lan maaxu, lujc nam, bawsc giang"
  ],
  "Linh Hồ, Vị Xuyên, Hà Giang": [
    "linh hồ, vị xuyên, hà giang",
    "linh hoof, vij xuyeen, haf giang"
  ],
  "Liêm Cần, Thanh Liêm, Hà Nam": [
    "liêm cần, thanh liêm, hà nam",
    "lieem caafn, thanh lieem, haf nam"
  ],
  "Liêm Phong, Thanh Liêm, Hà Nam": [
    "liêm phong, thanh liêm, hà nam",
    "lieem phong, thanh lieem, haf nam"
  ],
  "Liêm Thuỷ, Na Rì, Bắc Kạn": [
    "liêm thuỷ, na rì, bắc kạn",
    "lieem thuyr, na rif, bawsc kajn"
  ],
  "Liêm Tuyền, Phủ Lý, Hà Nam": [
    "liêm tuyền, phủ lý, hà nam",
    "lieem tuyeefn, phur lys, haf nam"
  ],
  "Liên Châu, Thanh Oai, Hà Nội": [
    "liên châu, thanh oai, hà nội",
    "lieen chaau, thanh oai, haf nooji"
  ],
  "Liên Hà, Lâm Hà, Lâm Đồng": [
    "liên hà, lâm hà, lâm đồng",
    "lieen haf, laam haf, laam ddoofng"
  ],
  "Liên Ninh, Thanh Trì, Hà Nội": [
    "liên ninh, thanh trì, hà nội",
    "lieen ninh, thanh trif, haf nooji"
  ],
  "Liễu Giai, Ba Đình, Hà Nội": [
    "liễu giai, ba đình, hà nội",
    "lieexu giai, ba ddifnh, haf nooji"
  ],
  "Long An, Long Thành, Đồng Nai": [
    "long an, long thành, đồng nai",
    "long an, long thafnh, ddoofng nai"
  ],
  "Long Biên, Long Biên, Hà Nội": [
    "long biên, long biên, hà nội",
    "long bieen, long bieen, haf nooji"
  ],
  "Long Cốc, Tân Sơn, Phú Thọ": [
    "long cốc, tân sơn, phú thọ",
    "long coosc, taan sown, phus thoj"
  ],
  "Long Giang, Chợ Mới, An Giang": [
    "long giang, chợ mới, an giang",
    "long giang, chowj mowsi, an giang"
  ],
  "Long Hiệp, Bến Lức, Long An": [
    "long hiệp, bến lức, long an",
    "long hieejp, beesn luwsc, long an"
  ],
  "Long Hưng, Mỹ Tú, Sóc Trăng": [
    "long hưng, mỹ tú, sóc trăng",
    "long huwng, myx tus, sosc trawng"
  ],
  "Long Hẹ, Thuận Châu, Sơn La": [
    "long hẹ, thuận châu, sơn la",
    "long hej, thuaajn chaau, sown la"
  ],
  "Long Mỹ, Mang Thít, Vĩnh Long": [
    "long mỹ, mang thít, vĩnh long",
    "long myx, mang thist, vixnh long"
  ],
  "Long Phú, Long Mỹ, Hậu Giang": [
    "long phú, long mỹ, hậu giang",
    "long phus, long myx, haaju giang"
  ],
  "Long Phú, Long Phú, Sóc Trăng": [
    "long phú, long phú, sóc trăng",
    "long phus, long phus, sosc trawng"
  ],
  "Long Sơn, Cầu Ngang, Trà Vinh": [
    "long sơn, cầu ngang, trà vinh",
    "long sown, caafu ngang, traf vinh"
  ],
  "Long Đức, Trà Vinh, Trà Vinh": [
    "long đức, trà vinh, trà vinh",
    "long dduwsc, traf vinh, traf vinh"
  ],
  "Làng Chếu, Bắc Yên, Sơn La": [
    "làng chếu, bắc yên, sơn la",
    "lafng cheesu, bawsc yeen, sown la"
  ],
  "Làng Giàng, Văn Bàn, Lào Cai": [
    "làng giàng, văn bàn, lào cai",
    "lafng giafng, vawn bafn, lafo cai"
  ],
  "Lát, Lạc Dương, Lâm Đồng": [
    "lát, lạc dương, lâm đồng",
    "last, lajc duwowng, laam ddoofng"
  ],
  "Lâm San, Cẩm Mỹ, Đồng Nai": [
    "lâm san, cẩm mỹ, đồng nai",
    "laam san, caarm myx, ddoofng nai"
  ],
  "Lâm Sơn, Chi Lăng, Lạng Sơn": [
    "lâm sơn, chi lăng, lạng sơn",
    "laam sown, chi lawng, lajng sown"
  ],
  "Lãm Hà, Kiến An, Hải Phòng": [
    "lãm hà, kiến an, hải phòng",
    "laxm haf, kieesn an, hari phofng"
  ],
  "Lê Bình, Cái Răng, Cần Thơ": [
    "lê bình, cái răng, cần thơ",
    "lee bifnh, casi rawng, caafn thow"
  ],
  "Lê Lợi, Hưng Yên, Hưng Yên": [
    "lê lợi, hưng yên, hưng yên",
    "lee lowji, huwng yeen, huwng yeen"
  ],
  "Lê Lợi, Nậm Nhùn, Lai Châu": [
    "lê lợi, nậm nhùn, lai châu",
    "lee lowji, naajm nhufn, lai chaau"
  ],
  "Lê Lợi, Thạch An, Cao Bằng": [
    "lê lợi, thạch an, cao bằng",
    "lee lowji, thajch an, cao bawfng"
  ],
  "Lê Thanh, Mỹ Đức, Hà Nội": [
    "lê thanh, mỹ đức, hà nội",
    "lee thanh, myx dduwsc, haf nooji"
  ],
  "Lóng Sập, Mộc Châu, Sơn La": [
    "lóng sập, mộc châu, sơn la",
    "losng saajp, moojc chaau, sown la"
  ],
  "Lùng Phình, Bắc Hà, Lào Cai": [
    "lùng phình, bắc hà, lào cai",
    "lufng phifnh, bawsc haf, lafo cai"
  ],
  "Lùng Thẩn, Si Ma Cai, Lào Cai": [
    "lùng thẩn, si ma cai, lào cai",
    "lufng thaarn, si ma cai, lafo cai"
  ],
  "Lý Quốc, Hạ Lang, Cao Bằng": [
    "lý quốc, hạ lang, cao bằng",
    "lys quoosc, haj lang, cao bawfng"
  ],
  "Lạc Nông, Bắc Mê, Hà Giang": [
    "lạc nông, bắc mê, hà giang",
    "lajc noong, bawsc mee, haf giang"
  ],
  "Lỗ Sơn, Tân Lạc, Hoà Bình": [
    "lỗ sơn, tân lạc, hoà bình",
    "loox sown, taan lajc, hoaf bifnh"
  ],
  "Lộc Giang, Đức Hòa, Long An": [
    "lộc giang, đức hòa, long an",
    "loojc giang, dduwsc hofa, long an"
  ],
  "Lộc Hòa, Long Hồ, Vĩnh Long": [
    "lộc hòa, long hồ, vĩnh long",
    "loojc hofa, long hoof, vixnh long"
  ],
  "Lục Dạ, Con Cuông, Nghệ An": [
    "lục dạ, con cuông, nghệ an",
    "lujc daj, con cuoong, ngheej an"
  ],
  "Ma Ly Pho, Phong Thổ, Lai Châu": [
    "ma ly pho, phong thổ, lai châu",
    "ma ly pho, phong thoor, lai chaau"
  ],
  "Ma Nới, Ninh Sơn, Ninh Thuận": [
    "ma nới, ninh sơn, ninh thuận",
    "ma nowsi, ninh sown, ninh thuaajn"
  ],
  "Mai Hịch, Mai Châu, Hoà Bình": [
    "mai hịch, mai châu, hoà bình",
    "mai hijch, mai chaau, hoaf bifnh"
  ],
  "Mai Pha, Lạng Sơn, Lạng Sơn": [
    "mai pha, lạng sơn, lạng sơn",
    "mai pha, lajng sown, lajng sown"
  ],
  "Minh Châu, Yên Mỹ, Hưng Yên": [
    "minh châu, yên mỹ, hưng yên",
    "minh chaau, yeen myx, huwng yeen"
  ],
  "Minh Hòa, Hưng Hà, Thái Bình": [
    "minh hòa, hưng hà, thái bình",
    "minh hofa, huwng haf, thasi bifnh"
  ],
  "Minh Hòa, Yên Lập, Phú Thọ": [
    "minh hòa, yên lập, phú thọ",
    "minh hofa, yeen laajp, phus thoj"
  ],
  "Minh Hạc, Hạ Hoà, Phú Thọ": [
    "minh hạc, hạ hoà, phú thọ",
    "minh hajc, haj hoaf, phus thoj"
  ],
  "Minh Hải, Văn Lâm, Hưng Yên": [
    "minh hải, văn lâm, hưng yên",
    "minh hari, vawn laam, huwng yeen"
  ],
  "Minh Khai, Bình Gia, Lạng Sơn": [
    "minh khai, bình gia, lạng sơn",
    "minh khai, bifnh gia, lajng sown"
  ],
  "Minh Khai, Hưng Hà, Thái Bình": [
    "minh khai, hưng hà, thái bình",
    "minh khai, huwng haf, thasi bifnh"
  ],
  "Minh Khai, Hưng Yên, Hưng Yên": [
    "minh khai, hưng yên, hưng yên",
    "minh khai, huwng yeen, huwng yeen"
  ],
  "Minh Khai, Thạch An, Cao Bằng": [
    "minh khai, thạch an, cao bằng",
    "minh khai, thajch an, cao bawfng"
  ],
  "Minh Lãng, Vũ Thư, Thái Bình": [
    "minh lãng, vũ thư, thái bình",
    "minh laxng, vux thuw, thasi bifnh"
  ],
  "Minh Lương, Văn Bàn, Lào Cai": [
    "minh lương, văn bàn, lào cai",
    "minh luwowng, vawn bafn, lafo cai"
  ],
  "Minh Ngọc, Bắc Mê, Hà Giang": [
    "minh ngọc, bắc mê, hà giang",
    "minh ngojc, bawsc mee, haf giang"
  ],
  "Minh Quang, Vũ Thư, Thái Bình": [
    "minh quang, vũ thư, thái bình",
    "minh quang, vux thuw, thasi bifnh"
  ],
  "Minh Tân, Cẩm Khê, Phú Thọ": [
    "minh tân, cẩm khê, phú thọ",
    "minh taan, caarm khee, phus thoj"
  ],
  "Minh Tân, Hưng Hà, Thái Bình": [
    "minh tân, hưng hà, thái bình",
    "minh taan, huwng haf, thasi bifnh"
  ],
  "Minh Tân, Phú Xuyên, Hà Nội": [
    "minh tân, phú xuyên, hà nội",
    "minh taan, phus xuyeen, haf nooji"
  ],
  "Minh Tân, Vị Xuyên, Hà Giang": [
    "minh tân, vị xuyên, hà giang",
    "minh taan, vij xuyeen, haf giang"
  ],
  "Minh Xuân, Lục Yên, Yên Bái": [
    "minh xuân, lục yên, yên bái",
    "minh xuaan, lujc yeen, yeen basi"
  ],
  "Minh Đài, Tân Sơn, Phú Thọ": [
    "minh đài, tân sơn, phú thọ",
    "minh ddafi, taan sown, phus thoj"
  ],
  "Minh Đạo, Tiên Du, Bắc Ninh": [
    "minh đạo, tiên du, bắc ninh",
    "minh ddajo, tieen du, bawsc ninh"
  ],
  "Mèo Vạc, Mèo Vạc, Hà Giang": [
    "mèo vạc, mèo vạc, hà giang",
    "mefo vajc, mefo vajc, haf giang"
  ],
  "Mò Ó, Đa Krông, Quảng Trị": [
    "mò ó, đa krông, quảng trị",
    "mof os, dda kroong, quarng trij"
  ],
  "Mông Sơn, Yên Bình, Yên Bái": [
    "mông sơn, yên bình, yên bái",
    "moong sown, yeen bifnh, yeen basi"
  ],
  "Mông Ân, Bình Gia, Lạng Sơn": [
    "mông ân, bình gia, lạng sơn",
    "moong aan, bifnh gia, lajng sown"
  ],
  "Mông Ân, Bảo Lâm, Cao Bằng": [
    "mông ân, bảo lâm, cao bằng",
    "moong aan, baro laam, cao bawfng"
  ],
  "Mù Cả, Mường Tè, Lai Châu": [
    "mù cả, mường tè, lai châu",
    "muf car, muwowfng tef, lai chaau"
  ],
  "Mường Bang, Phù Yên, Sơn La": [
    "mường bang, phù yên, sơn la",
    "muwowfng bang, phuf yeen, sown la"
  ],
  "Mường Cơi, Phù Yên, Sơn La": [
    "mường cơi, phù yên, sơn la",
    "muwowfng cowi, phuf yeen, sown la"
  ],
  "Mường Hum, Bát Xát, Lào Cai": [
    "mường hum, bát xát, lào cai",
    "muwowfng hum, bast xast, lafo cai"
  ],
  "Mường Hung, Sông Mã, Sơn La": [
    "mường hung, sông mã, sơn la",
    "muwowfng hung, soong max, sown la"
  ],
  "Mường Lang, Phù Yên, Sơn La": [
    "mường lang, phù yên, sơn la",
    "muwowfng lang, phuf yeen, sown la"
  ],
  "Mạn Lạn, Thanh Ba, Phú Thọ": [
    "mạn lạn, thanh ba, phú thọ",
    "majn lajn, thanh ba, phus thoj"
  ],
  "Mậu Duệ, Yên Minh, Hà Giang": [
    "mậu duệ, yên minh, hà giang",
    "maaju dueej, yeen minh, haf giang"
  ],
  "Mễ Sở, Văn Giang, Hưng Yên": [
    "mễ sở, văn giang, hưng yên",
    "meex sowr, vawn giang, huwng yeen"
  ],
  "Mỏ Công, Tân Biên, Tây Ninh": [
    "mỏ công, tân biên, tây ninh",
    "mor coong, taan bieen, taay ninh"
  ],
  "Mộc Châu, Mộc Châu, Sơn La": [
    "mộc châu, mộc châu, sơn la",
    "moojc chaau, moojc chaau, sown la"
  ],
  "Mỹ An, Phù Mỹ, Bình Định": [
    "mỹ an, phù mỹ, bình định",
    "myx an, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Bình, Long Xuyên, An Giang": [
    "mỹ bình, long xuyên, an giang",
    "myx bifnh, long xuyeen, an giang"
  ],
  "Mỹ Bình, Đức Huệ, Long An": [
    "mỹ bình, đức huệ, long an",
    "myx bifnh, dduwsc hueej, long an"
  ],
  "Mỹ Cẩm, Càng Long, Trà Vinh": [
    "mỹ cẩm, càng long, trà vinh",
    "myx caarm, cafng long, traf vinh"
  ],
  "Mỹ Hà, Mỹ Lộc, Nam Định": [
    "mỹ hà, mỹ lộc, nam định",
    "myx haf, myx loojc, nam ddijnh"
  ],
  "Mỹ Hòa, Bình Minh, Vĩnh Long": [
    "mỹ hòa, bình minh, vĩnh long",
    "myx hofa, bifnh minh, vixnh long"
  ],
  "Mỹ Hòa, Cầu Ngang, Trà Vinh": [
    "mỹ hòa, cầu ngang, trà vinh",
    "myx hofa, caafu ngang, traf vinh"
  ],
  "Mỹ Hòa, Tân Lạc, Hoà Bình": [
    "mỹ hòa, tân lạc, hoà bình",
    "myx hofa, taan lajc, hoaf bifnh"
  ],
  "Mỹ Long, Cầu Ngang, Trà Vinh": [
    "mỹ long, cầu ngang, trà vinh",
    "myx long, caafu ngang, traf vinh"
  ],
  "Mỹ Lung, Yên Lập, Phú Thọ": [
    "mỹ lung, yên lập, phú thọ",
    "myx lung, yeen laajp, phus thoj"
  ],
  "Mỹ Lạc, Thủ Thừa, Long An": [
    "mỹ lạc, thủ thừa, long an",
    "myx lajc, thur thuwfa, long an"
  ],
  "Mỹ Lộc, Tam Bình, Vĩnh Long": [
    "mỹ lộc, tam bình, vĩnh long",
    "myx loojc, tam bifnh, vixnh long"
  ],
  "Mỹ Tân, Cái Bè, Tiền Giang": [
    "mỹ tân, cái bè, tiền giang",
    "myx taan, casi bef, tieefn giang"
  ],
  "Mỹ Đức, Châu Phú, An Giang": [
    "mỹ đức, châu phú, an giang",
    "myx dduwsc, chaau phus, an giang"
  ],
  "Na Sầm, Văn Lãng, Lạng Sơn": [
    "na sầm, văn lãng, lạng sơn",
    "na saafm, vawn laxng, lajng sown"
  ],
  "Nam Bình, Ninh Bình, Ninh Bình": [
    "nam bình, ninh bình, ninh bình",
    "nam bifnh, ninh bifnh, ninh bifnh"
  ],
  "Nam Hải, Hải An, Hải Phòng": [
    "nam hải, hải an, hải phòng",
    "nam hari, hari an, hari phofng"
  ],
  "Nam Hồng, Đông Anh, Hà Nội": [
    "nam hồng, đông anh, hà nội",
    "nam hoofng, ddoong anh, haf nooji"
  ],
  "Nam Khê, Uông Bí, Quảng Ninh": [
    "nam khê, uông bí, quảng ninh",
    "nam khee, uoong bis, quarng ninh"
  ],
  "Nam Mỹ, Nam Trực, Nam Định": [
    "nam mỹ, nam trực, nam định",
    "nam myx, nam truwjc, nam ddijnh"
  ],
  "Nam Phong, Phú Xuyên, Hà Nội": [
    "nam phong, phú xuyên, hà nội",
    "nam phong, phus xuyeen, haf nooji"
  ],
  "Nam Quang, Bảo Lâm, Cao Bằng": [
    "nam quang, bảo lâm, cao bằng",
    "nam quang, baro laam, cao bawfng"
  ],
  "Nam Sơn, Kiến An, Hải Phòng": [
    "nam sơn, kiến an, hải phòng",
    "nam sown, kieesn an, hari phofng"
  ],
  "Nam Sơn, Tam Điệp, Ninh Bình": [
    "nam sơn, tam điệp, ninh bình",
    "nam sown, tam ddieejp, ninh bifnh"
  ],
  "Nam Sơn, Đô Lương, Nghệ An": [
    "nam sơn, đô lương, nghệ an",
    "nam sown, ddoo luwowng, ngheej an"
  ],
  "Nam Tiến, Quan Hóa, Thanh Hóa": [
    "nam tiến, quan hóa, thanh hóa",
    "nam tieesn, quan hosa, thanh hosa"
  ],
  "Nga My, Phú Bình, Thái Nguyên": [
    "nga my, phú bình, thái nguyên",
    "nga my, phus bifnh, thasi nguyeen"
  ],
  "Nga Quán, Trấn Yên, Yên Bái": [
    "nga quán, trấn yên, yên bái",
    "nga quasn, traasn yeen, yeen basi"
  ],
  "Nga Thiện, Nga Sơn, Thanh Hóa": [
    "nga thiện, nga sơn, thanh hóa",
    "nga thieejn, nga sown, thanh hosa"
  ],
  "Nga Thạch, Nga Sơn, Thanh Hóa": [
    "nga thạch, nga sơn, thanh hóa",
    "nga thajch, nga sown, thanh hosa"
  ],
  "Nga Thắng, Nga Sơn, Thanh Hóa": [
    "nga thắng, nga sơn, thanh hóa",
    "nga thawsng, nga sown, thanh hosa"
  ],
  "Nga Điền, Nga Sơn, Thanh Hóa": [
    "nga điền, nga sơn, thanh hóa",
    "nga ddieefn, nga sown, thanh hosa"
  ],
  "Nghi Diên, Nghi Lộc, Nghệ An": [
    "nghi diên, nghi lộc, nghệ an",
    "nghi dieen, nghi loojc, ngheej an"
  ],
  "Nghi Hưng, Nghi Lộc, Nghệ An": [
    "nghi hưng, nghi lộc, nghệ an",
    "nghi huwng, nghi loojc, ngheej an"
  ],
  "Nghi Phong, Nghi Lộc, Nghệ An": [
    "nghi phong, nghi lộc, nghệ an",
    "nghi phong, nghi loojc, ngheej an"
  ],
  "Nghi Quang, Nghi Lộc, Nghệ An": [
    "nghi quang, nghi lộc, nghệ an",
    "nghi quang, nghi loojc, ngheej an"
  ],
  "Nghi Thuỷ, Cửa Lò, Nghệ An": [
    "nghi thuỷ, cửa lò, nghệ an",
    "nghi thuyr, cuwra lof, ngheej an"
  ],
  "Nghi Thái, Nghi Lộc, Nghệ An": [
    "nghi thái, nghi lộc, nghệ an",
    "nghi thasi, nghi loojc, ngheej an"
  ],
  "Nghi Trung, Nghi Lộc, Nghệ An": [
    "nghi trung, nghi lộc, nghệ an",
    "nghi trung, nghi loojc, ngheej an"
  ],
  "Nghi Vạn, Nghi Lộc, Nghệ An": [
    "nghi vạn, nghi lộc, nghệ an",
    "nghi vajn, nghi loojc, ngheej an"
  ],
  "Nghi Xuân, Nghi Lộc, Nghệ An": [
    "nghi xuân, nghi lộc, nghệ an",
    "nghi xuaan, nghi loojc, ngheej an"
  ],
  "Nghĩa An, Nghĩa Lộ, Yên Bái": [
    "nghĩa an, nghĩa lộ, yên bái",
    "nghixa an, nghixa looj, yeen basi"
  ],
  "Nghĩa Đô, Bảo Yên, Lào Cai": [
    "nghĩa đô, bảo yên, lào cai",
    "nghixa ddoo, baro yeen, lafo cai"
  ],
  "Nguyễn Du, Hà Tĩnh, Hà Tĩnh": [
    "nguyễn du, hà tĩnh, hà tĩnh",
    "nguyeexn du, haf tixnh, haf tixnh"
  ],
  "Nguyễn Úy, Kim Bảng, Hà Nam": [
    "nguyễn úy, kim bảng, hà nam",
    "nguyeexn usy, kim barng, haf nam"
  ],
  "Ngãi Tứ, Tam Bình, Vĩnh Long": [
    "ngãi tứ, tam bình, vĩnh long",
    "ngaxi tuws, tam bifnh, vixnh long"
  ],
  "Ngãi Xuyên, Trà Cú, Trà Vinh": [
    "ngãi xuyên, trà cú, trà vinh",
    "ngaxi xuyeen, traf cus, traf vinh"
  ],
  "Ngọc Biên, Trà Cú, Trà Vinh": [
    "ngọc biên, trà cú, trà vinh",
    "ngojc bieen, traf cus, traf vinh"
  ],
  "Ngọc Linh, Đắk Glei, Kon Tum": [
    "ngọc linh, đắk glei, kon tum",
    "ngojc linh, ddawsk glei, kon tum"
  ],
  "Ngọc Long, Yên Minh, Hà Giang": [
    "ngọc long, yên minh, hà giang",
    "ngojc long, yeen minh, haf giang"
  ],
  "Ngọc Xá, Quế Võ, Bắc Ninh": [
    "ngọc xá, quế võ, bắc ninh",
    "ngojc xas, quees vox, bawsc ninh"
  ],
  "Nhân Hòa, Mỹ Hào, Hưng Yên": [
    "nhân hòa, mỹ hào, hưng yên",
    "nhaan hofa, myx hafo, huwng yeen"
  ],
  "Nhân Hòa, Quế Võ, Bắc Ninh": [
    "nhân hòa, quế võ, bắc ninh",
    "nhaan hofa, quees vox, bawsc ninh"
  ],
  "Nhân La, Kim Động, Hưng Yên": [
    "nhân la, kim động, hưng yên",
    "nhaan la, kim ddoojng, huwng yeen"
  ],
  "Nhân Lý, Chi Lăng, Lạng Sơn": [
    "nhân lý, chi lăng, lạng sơn",
    "nhaan lys, chi lawng, lajng sown"
  ],
  "Nhân Thịnh, Lý Nhân, Hà Nam": [
    "nhân thịnh, lý nhân, hà nam",
    "nhaan thijnh, lys nhaan, haf nam"
  ],
  "Nhơn An, An Nhơn, Bình Định": [
    "nhơn an, an nhơn, bình định",
    "nhown an, an nhown, bifnh ddijnh"
  ],
  "Nhơn Bình, Trà Ôn, Vĩnh Long": [
    "nhơn bình, trà ôn, vĩnh long",
    "nhown bifnh, traf oon, vixnh long"
  ],
  "Nhơn Hoà, Tân Thạnh, Long An": [
    "nhơn hoà, tân thạnh, long an",
    "nhown hoaf, taan thajnh, long an"
  ],
  "Nhơn Mỹ, Chợ Mới, An Giang": [
    "nhơn mỹ, chợ mới, an giang",
    "nhown myx, chowj mowsi, an giang"
  ],
  "Nhơn Ninh, Tân Thạnh, Long An": [
    "nhơn ninh, tân thạnh, long an",
    "nhown ninh, taan thajnh, long an"
  ],
  "Nhật Tân, Tây Hồ, Hà Nội": [
    "nhật tân, tây hồ, hà nội",
    "nhaajt taan, taay hoof, haf nooji"
  ],
  "Nhật Tựu, Kim Bảng, Hà Nam": [
    "nhật tựu, kim bảng, hà nam",
    "nhaajt tuwju, kim barng, haf nam"
  ],
  "Nhị Long, Càng Long, Trà Vinh": [
    "nhị long, càng long, trà vinh",
    "nhij long, cafng long, traf vinh"
  ],
  "Ninh Hải, Tĩnh Gia, Thanh Hóa": [
    "ninh hải, tĩnh gia, thanh hóa",
    "ninh hari, tixnh gia, thanh hosa"
  ],
  "Ninh Phú, Ninh Hòa, Khánh Hòa": [
    "ninh phú, ninh hòa, khánh hòa",
    "ninh phus, ninh hofa, khasnh hofa"
  ],
  "Ninh Sơn, Ninh Bình, Ninh Bình": [
    "ninh sơn, ninh bình, ninh bình",
    "ninh sown, ninh bifnh, ninh bifnh"
  ],
  "Ninh Sơn, Ninh Hòa, Khánh Hòa": [
    "ninh sơn, ninh hòa, khánh hòa",
    "ninh sown, ninh hofa, khasnh hofa"
  ],
  "Ninh Thắng, Hoa Lư, Ninh Bình": [
    "ninh thắng, hoa lư, ninh bình",
    "ninh thawsng, hoa luw, ninh bifnh"
  ],
  "Ninh Thới, Cầu Kè, Trà Vinh": [
    "ninh thới, cầu kè, trà vinh",
    "ninh thowsi, caafu kef, traf vinh"
  ],
  "Ninh Tân, Ninh Hòa, Khánh Hòa": [
    "ninh tân, ninh hòa, khánh hòa",
    "ninh taan, ninh hofa, khasnh hofa"
  ],
  "Ninh Tây, Ninh Hòa, Khánh Hòa": [
    "ninh tây, ninh hòa, khánh hòa",
    "ninh taay, ninh hofa, khasnh hofa"
  ],
  "Ninh Vân, Ninh Hòa, Khánh Hòa": [
    "ninh vân, ninh hòa, khánh hòa",
    "ninh vaan, ninh hofa, khasnh hofa"
  ],
  "Ninh Ích, Ninh Hòa, Khánh Hòa": [
    "ninh ích, ninh hòa, khánh hòa",
    "ninh isch, ninh hofa, khasnh hofa"
  ],
  "Niêm Sơn, Mèo Vạc, Hà Giang": [
    "niêm sơn, mèo vạc, hà giang",
    "nieem sown, mefo vajc, haf giang"
  ],
  "Noong Hẻo, Sìn Hồ, Lai Châu": [
    "noong hẻo, sìn hồ, lai châu",
    "noong hero, sifn hoof, lai chaau"
  ],
  "Noong Lay, Thuận Châu, Sơn La": [
    "noong lay, thuận châu, sơn la",
    "noong lay, thuaajn chaau, sown la"
  ],
  "Nuông Dăm, Kim Bôi, Hoà Bình": [
    "nuông dăm, kim bôi, hoà bình",
    "nuoong dawm, kim booi, hoaf bifnh"
  ],
  "Nàn Xỉn, Xín Mần, Hà Giang": [
    "nàn xỉn, xín mần, hà giang",
    "nafn xirn, xisn maafn, haf giang"
  ],
  "Nậm Ban, Nậm Nhùn, Lai Châu": [
    "nậm ban, nậm nhùn, lai châu",
    "naajm ban, naajm nhufn, lai chaau"
  ],
  "Nậm Chạc, Bát Xát, Lào Cai": [
    "nậm chạc, bát xát, lào cai",
    "naajm chajc, bast xast, lafo cai"
  ],
  "Nậm Chầy, Văn Bàn, Lào Cai": [
    "nậm chầy, văn bàn, lào cai",
    "naajm chaafy, vawn bafn, lafo cai"
  ],
  "Nậm Cắn, Kỳ Sơn, Nghệ An": [
    "nậm cắn, kỳ sơn, nghệ an",
    "naajm cawsn, kyf sown, ngheej an"
  ],
  "Nậm Giôn, Mường La, Sơn La": [
    "nậm giôn, mường la, sơn la",
    "naajm gioon, muwowfng la, sown la"
  ],
  "Nậm Khánh, Bắc Hà, Lào Cai": [
    "nậm khánh, bắc hà, lào cai",
    "naajm khasnh, bawsc haf, lafo cai"
  ],
  "Nậm Pì, Nậm Nhùn, Lai Châu": [
    "nậm pì, nậm nhùn, lai châu",
    "naajm pif, naajm nhufn, lai chaau"
  ],
  "Nậm Rạng, Văn Bàn, Lào Cai": [
    "nậm rạng, văn bàn, lào cai",
    "naajm rajng, vawn bafn, lafo cai"
  ],
  "Nậm Sỏ, Tân Uyên, Lai Châu": [
    "nậm sỏ, tân uyên, lai châu",
    "naajm sor, taan uyeen, lai chaau"
  ],
  "Nội Duệ, Tiên Du, Bắc Ninh": [
    "nội duệ, tiên du, bắc ninh",
    "nooji dueej, tieen du, bawsc ninh"
  ],
  "Phan Thanh, Lục Yên, Yên Bái": [
    "phan thanh, lục yên, yên bái",
    "phan thanh, lujc yeen, yeen basi"
  ],
  "Phiêng Côn, Bắc Yên, Sơn La": [
    "phiêng côn, bắc yên, sơn la",
    "phieeng coon, bawsc yeen, sown la"
  ],
  "Phong Tân, Giá Rai, Bạc Liêu": [
    "phong tân, giá rai, bạc liêu",
    "phong taan, gias rai, bajc lieeu"
  ],
  "Phà Đánh, Kỳ Sơn, Nghệ An": [
    "phà đánh, kỳ sơn, nghệ an",
    "phaf ddasnh, kyf sown, ngheej an"
  ],
  "Phù Lãng, Quế Võ, Bắc Ninh": [
    "phù lãng, quế võ, bắc ninh",
    "phuf laxng, quees vox, bawsc ninh"
  ],
  "Phù Nham, Nghĩa Lộ, Yên Bái": [
    "phù nham, nghĩa lộ, yên bái",
    "phuf nham, nghixa looj, yeen basi"
  ],
  "Phù Đổng, Gia Lâm, Hà Nội": [
    "phù đổng, gia lâm, hà nội",
    "phuf ddoorng, gia laam, haf nooji"
  ],
  "Phùng, Đan Phượng, Hà Nội": [
    "phùng, đan phượng, hà nội",
    "phufng, ddan phuwowjng, haf nooji"
  ],
  "Phú Gia, Hương Khê, Hà Tĩnh": [
    "phú gia, hương khê, hà tĩnh",
    "phus gia, huwowng khee, haf tixnh"
  ],
  "Phú Hoà, Thoại Sơn, An Giang": [
    "phú hoà, thoại sơn, an giang",
    "phus hoaf, thoaji sown, an giang"
  ],
  "Phú Hưng, Cái Nước, Cà Mau": [
    "phú hưng, cái nước, cà mau",
    "phus huwng, casi nuwowsc, caf mau"
  ],
  "Phú Hộ, Phú Thọ, Phú Thọ": [
    "phú hộ, phú thọ, phú thọ",
    "phus hooj, phus thoj, phus thoj"
  ],
  "Phú Khê, Cẩm Khê, Phú Thọ": [
    "phú khê, cẩm khê, phú thọ",
    "phus khee, caarm khee, phus thoj"
  ],
  "Phú Lai, Yên Thủy, Hoà Bình": [
    "phú lai, yên thủy, hoà bình",
    "phus lai, yeen thury, hoaf bifnh"
  ],
  "Phú Linh, Vị Xuyên, Hà Giang": [
    "phú linh, vị xuyên, hà giang",
    "phus linh, vij xuyeen, haf giang"
  ],
  "Phú Lâm, Tân Phú, Đồng Nai": [
    "phú lâm, tân phú, đồng nai",
    "phus laam, taan phus, ddoofng nai"
  ],
  "Phú Lộc, Phù Ninh, Phú Thọ": [
    "phú lộc, phù ninh, phú thọ",
    "phus loojc, phuf ninh, phus thoj"
  ],
  "Phú Lộc, Tam Bình, Vĩnh Long": [
    "phú lộc, tam bình, vĩnh long",
    "phus loojc, tam bifnh, vixnh long"
  ],
  "Phú Minh, Phú Xuyên, Hà Nội": [
    "phú minh, phú xuyên, hà nội",
    "phus minh, phus xuyeen, haf nooji"
  ],
  "Phú Sơn, Bỉm Sơn, Thanh Hóa": [
    "phú sơn, bỉm sơn, thanh hóa",
    "phus sown, birm sown, thanh hosa"
  ],
  "Phú Sơn, Chợ Lách, Bến Tre": [
    "phú sơn, chợ lách, bến tre",
    "phus sown, chowj lasch, beesn tre"
  ],
  "Phú Sơn, Lâm Hà, Lâm Đồng": [
    "phú sơn, lâm hà, lâm đồng",
    "phus sown, laam haf, laam ddoofng"
  ],
  "Phú Sơn, Thanh Hóa, Thanh Hóa": [
    "phú sơn, thanh hóa, thanh hóa",
    "phus sown, thanh hosa, thanh hosa"
  ],
  "Phú Sơn, Tân Phú, Đồng Nai": [
    "phú sơn, tân phú, đồng nai",
    "phus sown, taan phus, ddoofng nai"
  ],
  "Phú Thanh, Quan Hóa, Thanh Hóa": [
    "phú thanh, quan hóa, thanh hóa",
    "phus thanh, quan hosa, thanh hosa"
  ],
  "Phú Thành, Trà Ôn, Vĩnh Long": [
    "phú thành, trà ôn, vĩnh long",
    "phus thafnh, traf oon, vixnh long"
  ],
  "Phú Thạnh, Phú Tân, An Giang": [
    "phú thạnh, phú tân, an giang",
    "phus thajnh, phus taan, an giang"
  ],
  "Phú Thạnh, Tuy Hoà, Phú Yên": [
    "phú thạnh, tuy hoà, phú yên",
    "phus thajnh, tuy hoaf, phus yeen"
  ],
  "Phú Túc, Phú Xuyên, Hà Nội": [
    "phú túc, phú xuyên, hà nội",
    "phus tusc, phus xuyeen, haf nooji"
  ],
  "Phú Vinh, Tân Lạc, Hoà Bình": [
    "phú vinh, tân lạc, hoà bình",
    "phus vinh, taan lajc, hoaf bifnh"
  ],
  "Phú Xuân, Quan Hóa, Thanh Hóa": [
    "phú xuân, quan hóa, thanh hóa",
    "phus xuaan, quan hosa, thanh hosa"
  ],
  "Phú Yên, Phú Xuyên, Hà Nội": [
    "phú yên, phú xuyên, hà nội",
    "phus yeen, phus xuyeen, haf nooji"
  ],
  "Phúc Khoa, Tân Uyên, Lai Châu": [
    "phúc khoa, tân uyên, lai châu",
    "phusc khoa, taan uyeen, lai chaau"
  ],
  "Phúc Lộc, Ba Bể, Bắc Kạn": [
    "phúc lộc, ba bể, bắc kạn",
    "phusc loojc, ba beer, bawsc kajn"
  ],
  "Phúc Ninh, Yên Bình, Yên Bái": [
    "phúc ninh, yên bình, yên bái",
    "phusc ninh, yeen bifnh, yeen basi"
  ],
  "Phúc Than, Than Uyên, Lai Châu": [
    "phúc than, than uyên, lai châu",
    "phusc than, than uyeen, lai chaau"
  ],
  "Phước Hưng, An Phú, An Giang": [
    "phước hưng, an phú, an giang",
    "phuwowsc huwng, an phus, an giang"
  ],
  "Phước Ngãi, Ba Tri, Bến Tre": [
    "phước ngãi, ba tri, bến tre",
    "phuwowsc ngaxi, ba tri, beesn tre"
  ],
  "Phường 1, Trà Vinh, Trà Vinh": [
    "phường 1, trà vinh, trà vinh",
    "phuwowfng 1, traf vinh, traf vinh"
  ],
  "Phường 1, Tây Ninh, Tây Ninh": [
    "phường 1, tây ninh, tây ninh",
    "phuwowfng 1, taay ninh, taay ninh"
  ],
  "Phường 2, Trà Vinh, Trà Vinh": [
    "phường 2, trà vinh, trà vinh",
    "phuwowfng 2, traf vinh, traf vinh"
  ],
  "Phường 2, Tây Ninh, Tây Ninh": [
    "phường 2, tây ninh, tây ninh",
    "phuwowfng 2, taay ninh, taay ninh"
  ],
  "Phường 3, Trà Vinh, Trà Vinh": [
    "phường 3, trà vinh, trà vinh",
    "phuwowfng 3, traf vinh, traf vinh"
  ],
  "Phường 3, Tây Ninh, Tây Ninh": [
    "phường 3, tây ninh, tây ninh",
    "phuwowfng 3, taay ninh, taay ninh"
  ],
  "Phường 4, Bến Tre, Bến Tre": [
    "phường 4, bến tre, bến tre",
    "phuwowfng 4, beesn tre, beesn tre"
  ],
  "Phường 4, Trà Vinh, Trà Vinh": [
    "phường 4, trà vinh, trà vinh",
    "phuwowfng 4, traf vinh, traf vinh"
  ],
  "Phường 4, Tây Ninh, Tây Ninh": [
    "phường 4, tây ninh, tây ninh",
    "phuwowfng 4, taay ninh, taay ninh"
  ],
  "Phường 5, Bến Tre, Bến Tre": [
    "phường 5, bến tre, bến tre",
    "phuwowfng 5, beesn tre, beesn tre"
  ],
  "Phường 5, Trà Vinh, Trà Vinh": [
    "phường 5, trà vinh, trà vinh",
    "phuwowfng 5, traf vinh, traf vinh"
  ],
  "Phường 6, Bến Tre, Bến Tre": [
    "phường 6, bến tre, bến tre",
    "phuwowfng 6, beesn tre, beesn tre"
  ],
  "Phường 6, Trà Vinh, Trà Vinh": [
    "phường 6, trà vinh, trà vinh",
    "phuwowfng 6, traf vinh, traf vinh"
  ],
  "Phường 7, Bến Tre, Bến Tre": [
    "phường 7, bến tre, bến tre",
    "phuwowfng 7, beesn tre, beesn tre"
  ],
  "Phường 7, Trà Vinh, Trà Vinh": [
    "phường 7, trà vinh, trà vinh",
    "phuwowfng 7, traf vinh, traf vinh"
  ],
  "Phường 8, Bến Tre, Bến Tre": [
    "phường 8, bến tre, bến tre",
    "phuwowfng 8, beesn tre, beesn tre"
  ],
  "Phường 8, Trà Vinh, Trà Vinh": [
    "phường 8, trà vinh, trà vinh",
    "phuwowfng 8, traf vinh, traf vinh"
  ],
  "Phường 9, Trà Vinh, Trà Vinh": [
    "phường 9, trà vinh, trà vinh",
    "phuwowfng 9, traf vinh, traf vinh"
  ],
  "Phố Lu, Bảo Thắng, Lào Cai": [
    "phố lu, bảo thắng, lào cai",
    "phoos lu, baro thawsng, lafo cai"
  ],
  "Phố Ràng, Bảo Yên, Lào Cai": [
    "phố ràng, bảo yên, lào cai",
    "phoos rafng, baro yeen, lafo cai"
  ],
  "Plei Kần, Ngọc Hồi, Kon Tum": [
    "plei kần, ngọc hồi, kon tum",
    "plei kaafn, ngojc hoofi, kon tum"
  ],
  "Pró, Đơn Dương, Lâm Đồng": [
    "pró, đơn dương, lâm đồng",
    "pros, ddown duwowng, laam ddoofng"
  ],
  "Pu Sam Cáp, Sìn Hồ, Lai Châu": [
    "pu sam cáp, sìn hồ, lai châu",
    "pu sam casp, sifn hoof, lai chaau"
  ],
  "Pá Lông, Thuận Châu, Sơn La": [
    "pá lông, thuận châu, sơn la",
    "pas loong, thuaajn chaau, sown la"
  ],
  "Púng Bánh, Sốp Cộp, Sơn La": [
    "púng bánh, sốp cộp, sơn la",
    "pusng basnh, soosp coojp, sown la"
  ],
  "Púng Tra, Thuận Châu, Sơn La": [
    "púng tra, thuận châu, sơn la",
    "pusng tra, thuaajn chaau, sown la"
  ],
  "Quan Hoa, Cầu Giấy, Hà Nội": [
    "quan hoa, cầu giấy, hà nội",
    "quan hoa, caafu giaasy, haf nooji"
  ],
  "Quan Sơn, Chi Lăng, Lạng Sơn": [
    "quan sơn, chi lăng, lạng sơn",
    "quan sown, chi lawng, lajng sown"
  ],
  "Quang Húc, Tam Nông, Phú Thọ": [
    "quang húc, tam nông, phú thọ",
    "quang husc, tam noong, phus thoj"
  ],
  "Quang Long, Hạ Lang, Cao Bằng": [
    "quang long, hạ lang, cao bằng",
    "quang long, haj lang, cao bawfng"
  ],
  "Quang Lộc, Can Lộc, Hà Tĩnh": [
    "quang lộc, can lộc, hà tĩnh",
    "quang loojc, can loojc, haf tixnh"
  ],
  "Quang Thọ, Vũ Quang, Hà Tĩnh": [
    "quang thọ, vũ quang, hà tĩnh",
    "quang thoj, vux quang, haf tixnh"
  ],
  "Quang Trung, Hà Giang, Hà Giang": [
    "quang trung, hà giang, hà giang",
    "quang trung, haf giang, haf giang"
  ],
  "Quang Trung, Sơn Tây, Hà Nội": [
    "quang trung, sơn tây, hà nội",
    "quang trung, sown taay, haf nooji"
  ],
  "Quy Mông, Trấn Yên, Yên Bái": [
    "quy mông, trấn yên, yên bái",
    "quy moong, traasn yeen, yeen basi"
  ],
  "Quyết Thắng, Kon Tum, Kon Tum": [
    "quyết thắng, kon tum, kon tum",
    "quyeest thawsng, kon tum, kon tum"
  ],
  "Quyết Thắng, Sơn La, Sơn La": [
    "quyết thắng, sơn la, sơn la",
    "quyeest thawsng, sown la, sown la"
  ],
  "Quý Hòa, Bình Gia, Lạng Sơn": [
    "quý hòa, bình gia, lạng sơn",
    "quys hofa, bifnh gia, lajng sown"
  ],
  "Quý Hòa, Lạc Sơn, Hoà Bình": [
    "quý hòa, lạc sơn, hoà bình",
    "quys hofa, lajc sown, hoaf bifnh"
  ],
  "Quế An, Quế Sơn, Quảng Nam": [
    "quế an, quế sơn, quảng nam",
    "quees an, quees sown, quarng nam"
  ],
  "Quế Tân, Quế Võ, Bắc Ninh": [
    "quế tân, quế võ, bắc ninh",
    "quees taan, quees vox, bawsc ninh"
  ],
  "Quốc Oai, Quốc Oai, Hà Nội": [
    "quốc oai, quốc oai, hà nội",
    "quoosc oai, quoosc oai, haf nooji"
  ],
  "Rô Men, Đam Rông, Lâm Đồng": [
    "rô men, đam rông, lâm đồng",
    "roo men, ddam roong, laam ddoofng"
  ],
  "Song Giang, Gia Bình, Bắc Ninh": [
    "song giang, gia bình, bắc ninh",
    "song giang, gia bifnh, bawsc ninh"
  ],
  "Song Lãng, Vũ Thư, Thái Bình": [
    "song lãng, vũ thư, thái bình",
    "song laxng, vux thuw, thasi bifnh"
  ],
  "Song Mai, Kim Động, Hưng Yên": [
    "song mai, kim động, hưng yên",
    "song mai, kim ddoojng, huwng yeen"
  ],
  "Song Vân, Tân Yên, Bắc Giang": [
    "song vân, tân yên, bắc giang",
    "song vaan, taan yeen, bawsc giang"
  ],
  "Suối Bu, Văn Chấn, Yên Bái": [
    "suối bu, văn chấn, yên bái",
    "suoosi bu, vawn chaasn, yeen basi"
  ],
  "Suối Trai, Sơn Hòa, Phú Yên": [
    "suối trai, sơn hòa, phú yên",
    "suoosi trai, sown hofa, phus yeen"
  ],
  "Sóc Hà, Hà Quảng, Cao Bằng": [
    "sóc hà, hà quảng, cao bằng",
    "sosc haf, haf quarng, cao bawfng"
  ],
  "Sông Hinh, Sông Hinh, Phú Yên": [
    "sông hinh, sông hinh, phú yên",
    "soong hinh, soong hinh, phus yeen"
  ],
  "Sùng Phài, Lai Châu, Lai Châu": [
    "sùng phài, lai châu, lai châu",
    "sufng phafi, lai chaau, lai chaau"
  ],
  "Săm Khóe, Mai Châu, Hoà Bình": [
    "săm khóe, mai châu, hoà bình",
    "sawm khose, mai chaau, hoaf bifnh"
  ],
  "Sơn Bao, Sơn Hà, Quảng Ngãi": [
    "sơn bao, sơn hà, quảng ngãi",
    "sown bao, sown haf, quarng ngaxi"
  ],
  "Sơn Cao, Sơn Hà, Quảng Ngãi": [
    "sơn cao, sơn hà, quảng ngãi",
    "sown cao, sown haf, quarng ngaxi"
  ],
  "Sơn Công, Ứng Hòa, Hà Nội": [
    "sơn công, ứng hòa, hà nội",
    "sown coong, uwsng hofa, haf nooji"
  ],
  "Sơn Giang, Sông Hinh, Phú Yên": [
    "sơn giang, sông hinh, phú yên",
    "sown giang, soong hinh, phus yeen"
  ],
  "Sơn Hà, Bảo Thắng, Lào Cai": [
    "sơn hà, bảo thắng, lào cai",
    "sown haf, baro thawsng, lafo cai"
  ],
  "Sơn Phong, Hội An, Quảng Nam": [
    "sơn phong, hội an, quảng nam",
    "sown phong, hooji an, quarng nam"
  ],
  "Sơn Thành, Nho Quan, Ninh Bình": [
    "sơn thành, nho quan, ninh bình",
    "sown thafnh, nho quan, ninh bifnh"
  ],
  "Sơn Đông, Bến Tre, Bến Tre": [
    "sơn đông, bến tre, bến tre",
    "sown ddoong, beesn tre, beesn tre"
  ],
  "Sơn Đông, Sơn Tây, Hà Nội": [
    "sơn đông, sơn tây, hà nội",
    "sown ddoong, sown taay, haf nooji"
  ],
  "Sốp Cộp, Sốp Cộp, Sơn La": [
    "sốp cộp, sốp cộp, sơn la",
    "soosp coojp, soosp coojp, sown la"
  ],
  "Tam Gia, Lộc Bình, Lạng Sơn": [
    "tam gia, lộc bình, lạng sơn",
    "tam gia, loojc bifnh, lajng sown"
  ],
  "Tam Giang, Yên Phong, Bắc Ninh": [
    "tam giang, yên phong, bắc ninh",
    "tam giang, yeen phong, bawsc ninh"
  ],
  "Tam Hiệp, Thanh Trì, Hà Nội": [
    "tam hiệp, thanh trì, hà nội",
    "tam hieejp, thanh trif, haf nooji"
  ],
  "Tam Hòa, Biên Hòa, Đồng Nai": [
    "tam hòa, biên hòa, đồng nai",
    "tam hofa, bieen hofa, ddoofng nai"
  ],
  "Tam Hợp, Quỳ Hợp, Nghệ An": [
    "tam hợp, quỳ hợp, nghệ an",
    "tam howjp, quyf howjp, ngheej an"
  ],
  "Tam Lãnh, Phú Ninh, Quảng Nam": [
    "tam lãnh, phú ninh, quảng nam",
    "tam laxnh, phus ninh, quarng nam"
  ],
  "Tam Lộc, Phú Ninh, Quảng Nam": [
    "tam lộc, phú ninh, quảng nam",
    "tam loojc, phus ninh, quarng nam"
  ],
  "Tam Ngọc, Tam Kỳ, Quảng Nam": [
    "tam ngọc, tam kỳ, quảng nam",
    "tam ngojc, tam kyf, quarng nam"
  ],
  "Tam Quan, Tam Đảo, Vĩnh Phúc": [
    "tam quan, tam đảo, vĩnh phúc",
    "tam quan, tam ddaro, vixnh phusc"
  ],
  "Tam Thái, Phú Ninh, Quảng Nam": [
    "tam thái, phú ninh, quảng nam",
    "tam thasi, phus ninh, quarng nam"
  ],
  "Tam Thăng, Tam Kỳ, Quảng Nam": [
    "tam thăng, tam kỳ, quảng nam",
    "tam thawng, tam kyf, quarng nam"
  ],
  "Tam Văn, Lang Chánh, Thanh Hóa": [
    "tam văn, lang chánh, thanh hóa",
    "tam vawn, lang chasnh, thanh hosa"
  ],
  "Tam Đàn, Phú Ninh, Quảng Nam": [
    "tam đàn, phú ninh, quảng nam",
    "tam ddafn, phus ninh, quarng nam"
  ],
  "Than Uyên, Than Uyên, Lai Châu": [
    "than uyên, than uyên, lai châu",
    "than uyeen, than uyeen, lai chaau"
  ],
  "Thanh An, Cam Lộ, Quảng Trị": [
    "thanh an, cam lộ, quảng trị",
    "thanh an, cam looj, quarng trij"
  ],
  "Thanh Hải, Thanh Liêm, Hà Nam": [
    "thanh hải, thanh liêm, hà nam",
    "thanh hari, thanh lieem, haf nam"
  ],
  "Thanh Long, Yên Mỹ, Hưng Yên": [
    "thanh long, yên mỹ, hưng yên",
    "thanh long, yeen myx, huwng yeen"
  ],
  "Thanh Lân, Cô Tô, Quảng Ninh": [
    "thanh lân, cô tô, quảng ninh",
    "thanh laan, coo too, quarng ninh"
  ],
  "Thanh Lạc, Nho Quan, Ninh Bình": [
    "thanh lạc, nho quan, ninh bình",
    "thanh lajc, nho quan, ninh bifnh"
  ],
  "Thanh Lộc, Can Lộc, Hà Tĩnh": [
    "thanh lộc, can lộc, hà tĩnh",
    "thanh loojc, can loojc, haf tixnh"
  ],
  "Thanh Phong, Thanh Liêm, Hà Nam": [
    "thanh phong, thanh liêm, hà nam",
    "thanh phong, thanh lieem, haf nam"
  ],
  "Thanh Sơn, Tĩnh Gia, Thanh Hóa": [
    "thanh sơn, tĩnh gia, thanh hóa",
    "thanh sown, tixnh gia, thanh hosa"
  ],
  "Thanh Thùy, Thanh Oai, Hà Nội": [
    "thanh thùy, thanh oai, hà nội",
    "thanh thufy, thanh oai, haf nooji"
  ],
  "Thanh Trì, Hoàng Mai, Hà Nội": [
    "thanh trì, hoàng mai, hà nội",
    "thanh trif, hoafng mai, haf nooji"
  ],
  "Thanh Tuyền, Phủ Lý, Hà Nam": [
    "thanh tuyền, phủ lý, hà nam",
    "thanh tuyeefn, phur lys, haf nam"
  ],
  "Thanh Tùng, Đầm Dơi, Cà Mau": [
    "thanh tùng, đầm dơi, cà mau",
    "thanh tufng, ddaafm dowi, caf mau"
  ],
  "Thanh Xuân, Sóc Sơn, Hà Nội": [
    "thanh xuân, sóc sơn, hà nội",
    "thanh xuaan, sosc sown, haf nooji"
  ],
  "Thanh Đa, Phúc Thọ, Hà Nội": [
    "thanh đa, phúc thọ, hà nội",
    "thanh dda, phusc thoj, haf nooji"
  ],
  "Thu Lũm, Mường Tè, Lai Châu": [
    "thu lũm, mường tè, lai châu",
    "thu luxm, muwowfng tef, lai chaau"
  ],
  "Thu Ngạc, Tân Sơn, Phú Thọ": [
    "thu ngạc, tân sơn, phú thọ",
    "thu ngajc, taan sown, phus thoj"
  ],
  "Thái Sơn, An Lão, Hải Phòng": [
    "thái sơn, an lão, hải phòng",
    "thasi sown, an laxo, hari phofng"
  ],
  "Thái Trị, Vĩnh Hưng, Long An": [
    "thái trị, vĩnh hưng, long an",
    "thasi trij, vixnh huwng, long an"
  ],
  "Thông Hòa, Cầu Kè, Trà Vinh": [
    "thông hòa, cầu kè, trà vinh",
    "thoong hofa, caafu kef, traf vinh"
  ],
  "Thạch Kim, Lộc Hà, Hà Tĩnh": [
    "thạch kim, lộc hà, hà tĩnh",
    "thajch kim, loojc haf, haf tixnh"
  ],
  "Thạch Sơn, Anh Sơn, Nghệ An": [
    "thạch sơn, anh sơn, nghệ an",
    "thajch sown, anh sown, ngheej an"
  ],
  "Thạch Đà, Mê Linh, Hà Nội": [
    "thạch đà, mê linh, hà nội",
    "thajch ddaf, mee linh, haf nooji"
  ],
  "Thạnh An, Thạnh Hóa, Long An": [
    "thạnh an, thạnh hóa, long an",
    "thajnh an, thajnh hosa, long an"
  ],
  "Thắng, Hiệp Hòa, Bắc Giang": [
    "thắng, hiệp hòa, bắc giang",
    "thawsng, hieejp hofa, bawsc giang"
  ],
  "Thọ Văn, Tam Nông, Phú Thọ": [
    "thọ văn, tam nông, phú thọ",
    "thoj vawn, tam noong, phus thoj"
  ],
  "Thới Hòa, Trà Ôn, Vĩnh Long": [
    "thới hòa, trà ôn, vĩnh long",
    "thowsi hofa, traf oon, vixnh long"
  ],
  "Tiên Ngoại, Duy Tiên, Hà Nam": [
    "tiên ngoại, duy tiên, hà nam",
    "tieen ngoaji, duy tieen, haf nam"
  ],
  "Tiên Nha, Lục Nam, Bắc Giang": [
    "tiên nha, lục nam, bắc giang",
    "tieen nha, lujc nam, bawsc giang"
  ],
  "Tiên Phú, Phù Ninh, Phú Thọ": [
    "tiên phú, phù ninh, phú thọ",
    "tieen phus, phuf ninh, phus thoj"
  ],
  "Tiền An, Bắc Ninh, Bắc Ninh": [
    "tiền an, bắc ninh, bắc ninh",
    "tieefn an, bawsc ninh, bawsc ninh"
  ],
  "Tiền Phong, Mê Linh, Hà Nội": [
    "tiền phong, mê linh, hà nội",
    "tieefn phong, mee linh, haf nooji"
  ],
  "Tiền Phong, Ân Thi, Hưng Yên": [
    "tiền phong, ân thi, hưng yên",
    "tieefn phong, aan thi, huwng yeen"
  ],
  "Trang Hạ, Từ Sơn, Bắc Ninh": [
    "trang hạ, từ sơn, bắc ninh",
    "trang haj, tuwf sown, bawsc ninh"
  ],
  "Tri Trung, Phú Xuyên, Hà Nội": [
    "tri trung, phú xuyên, hà nội",
    "tri trung, phus xuyeen, haf nooji"
  ],
  "Trung Hòa, Yên Mỹ, Hưng Yên": [
    "trung hòa, yên mỹ, hưng yên",
    "trung hofa, yeen myx, huwng yeen"
  ],
  "Trung Hưng, Sơn Tây, Hà Nội": [
    "trung hưng, sơn tây, hà nội",
    "trung huwng, sown taay, haf nooji"
  ],
  "Trung Hạ, Quan Sơn, Thanh Hóa": [
    "trung hạ, quan sơn, thanh hóa",
    "trung haj, quan sown, thanh hosa"
  ],
  "Trung Lộc, Can Lộc, Hà Tĩnh": [
    "trung lộc, can lộc, hà tĩnh",
    "trung loojc, can loojc, haf tixnh"
  ],
  "Trung Sơn, Quan Hóa, Thanh Hóa": [
    "trung sơn, quan hóa, thanh hóa",
    "trung sown, quan hosa, thanh hosa"
  ],
  "Trung Tâm, Lục Yên, Yên Bái": [
    "trung tâm, lục yên, yên bái",
    "trung taam, lujc yeen, yeen basi"
  ],
  "Trà An, Bình Thuỷ, Cần Thơ": [
    "trà an, bình thuỷ, cần thơ",
    "traf an, bifnh thuyr, caafn thow"
  ],
  "Trà Cổ, Tân Phú, Đồng Nai": [
    "trà cổ, tân phú, đồng nai",
    "traf coor, taan phus, ddoofng nai"
  ],
  "Trí Lực, Thới Bình, Cà Mau": [
    "trí lực, thới bình, cà mau",
    "tris luwjc, thowsi bifnh, caf mau"
  ],
  "Trúc Lâm, Tĩnh Gia, Thanh Hóa": [
    "trúc lâm, tĩnh gia, thanh hóa",
    "trusc laam, tixnh gia, thanh hosa"
  ],
  "Trúc Lâu, Lục Yên, Yên Bái": [
    "trúc lâu, lục yên, yên bái",
    "trusc laau, lujc yeen, yeen basi"
  ],
  "Trường Chinh, Kon Tum, Kon Tum": [
    "trường chinh, kon tum, kon tum",
    "truwowfng chinh, kon tum, kon tum"
  ],
  "Trần Cao, Phù Cừ, Hưng Yên": [
    "trần cao, phù cừ, hưng yên",
    "traafn cao, phuf cuwf, huwng yeen"
  ],
  "Trần Phú, Hà Giang, Hà Giang": [
    "trần phú, hà giang, hà giang",
    "traafn phus, haf giang, haf giang"
  ],
  "Trần Phú, Hà Tĩnh, Hà Tĩnh": [
    "trần phú, hà tĩnh, hà tĩnh",
    "traafn phus, haf tixnh, haf tixnh"
  ],
  "Tuy Lộc, Cẩm Khê, Phú Thọ": [
    "tuy lộc, cẩm khê, phú thọ",
    "tuy loojc, caarm khee, phus thoj"
  ],
  "Tà Bhinh, Nam Giang, Quảng Nam": [
    "tà bhinh, nam giang, quảng nam",
    "taf bhinh, nam giang, quarng nam"
  ],
  "Tà Lu, Đông Giang, Quảng Nam": [
    "tà lu, đông giang, quảng nam",
    "taf lu, ddoong giang, quarng nam"
  ],
  "Tà Pơơ, Nam Giang, Quảng Nam": [
    "tà pơơ, nam giang, quảng nam",
    "taf powow, nam giang, quarng nam"
  ],
  "Tá Bạ, Mường Tè, Lai Châu": [
    "tá bạ, mường tè, lai châu",
    "tas baj, muwowfng tef, lai chaau"
  ],
  "Tân An, Thanh Hà, Hải Dương": [
    "tân an, thanh hà, hải dương",
    "taan an, thanh haf, hari duwowng"
  ],
  "Tân An, Tân Hiệp, Kiên Giang": [
    "tân an, tân hiệp, kiên giang",
    "taan an, taan hieejp, kieen giang"
  ],
  "Tân An, Vĩnh Cửu, Đồng Nai": [
    "tân an, vĩnh cửu, đồng nai",
    "taan an, vixnh cuwru, ddoofng nai"
  ],
  "Tân Biên, Tân Biên, Tây Ninh": [
    "tân biên, tân biên, tây ninh",
    "taan bieen, taan bieen, taay ninh"
  ],
  "Tân Bình, Càng Long, Trà Vinh": [
    "tân bình, càng long, trà vinh",
    "taan bifnh, cafng long, traf vinh"
  ],
  "Tân Bình, Dĩ An, Bình Dương": [
    "tân bình, dĩ an, bình dương",
    "taan bifnh, dix an, bifnh duwowng"
  ],
  "Tân Bình, Tân Biên, Tây Ninh": [
    "tân bình, tân biên, tây ninh",
    "taan bifnh, taan bieen, taay ninh"
  ],
  "Tân Bình, Tân Thạnh, Long An": [
    "tân bình, tân thạnh, long an",
    "taan bifnh, taan thajnh, long an"
  ],
  "Tân Châu, Di Linh, Lâm Đồng": [
    "tân châu, di linh, lâm đồng",
    "taan chaau, di linh, laam ddoofng"
  ],
  "Tân Châu, Tân Châu, Tây Ninh": [
    "tân châu, tân châu, tây ninh",
    "taan chaau, taan chaau, taay ninh"
  ],
  "Tân Dân, Phú Xuyên, Hà Nội": [
    "tân dân, phú xuyên, hà nội",
    "taan daan, phus xuyeen, haf nooji"
  ],
  "Tân Hòa, Bình Gia, Lạng Sơn": [
    "tân hòa, bình gia, lạng sơn",
    "taan hofa, bifnh gia, lajng sown"
  ],
  "Tân Hòa, Hòa Bình, Hoà Bình": [
    "tân hòa, hòa bình, hoà bình",
    "taan hofa, hofa bifnh, hoaf bifnh"
  ],
  "Tân Hòa, Hưng Hà, Thái Bình": [
    "tân hòa, hưng hà, thái bình",
    "taan hofa, huwng haf, thasi bifnh"
  ],
  "Tân Hòa, Vĩnh Long, Vĩnh Long": [
    "tân hòa, vĩnh long, vĩnh long",
    "taan hofa, vixnh long, vixnh long"
  ],
  "Tân Hưng, Cái Nước, Cà Mau": [
    "tân hưng, cái nước, cà mau",
    "taan huwng, casi nuwowsc, caf mau"
  ],
  "Tân Hưng, Tân Châu, Tây Ninh": [
    "tân hưng, tân châu, tây ninh",
    "taan huwng, taan chaau, taay ninh"
  ],
  "Tân Hội, Tân Châu, Tây Ninh": [
    "tân hội, tân châu, tây ninh",
    "taan hooji, taan chaau, taay ninh"
  ],
  "Tân Long, Mang Thít, Vĩnh Long": [
    "tân long, mang thít, vĩnh long",
    "taan long, mang thist, vixnh long"
  ],
  "Tân Long, Mỹ Tho, Tiền Giang": [
    "tân long, mỹ tho, tiền giang",
    "taan long, myx tho, tieefn giang"
  ],
  "Tân Long, Ngã Năm, Sóc Trăng": [
    "tân long, ngã năm, sóc trăng",
    "taan long, ngax nawm, sosc trawng"
  ],
  "Tân Lĩnh, Lục Yên, Yên Bái": [
    "tân lĩnh, lục yên, yên bái",
    "taan lixnh, lujc yeen, yeen basi"
  ],
  "Tân Lập, Lục Yên, Yên Bái": [
    "tân lập, lục yên, yên bái",
    "taan laajp, lujc yeen, yeen basi"
  ],
  "Tân Lập, Tân Biên, Tây Ninh": [
    "tân lập, tân biên, tây ninh",
    "taan laajp, taan bieen, taay ninh"
  ],
  "Tân Lập, Tân Thạnh, Long An": [
    "tân lập, tân thạnh, long an",
    "taan laajp, taan thajnh, long an"
  ],
  "Tân Lập, Vũ Thư, Thái Bình": [
    "tân lập, vũ thư, thái bình",
    "taan laajp, vux thuw, thasi bifnh"
  ],
  "Tân Lập, Yên Mỹ, Hưng Yên": [
    "tân lập, yên mỹ, hưng yên",
    "taan laajp, yeen myx, huwng yeen"
  ],
  "Tân Lễ, Hưng Hà, Thái Bình": [
    "tân lễ, hưng hà, thái bình",
    "taan leex, huwng haf, thasi bifnh"
  ],
  "Tân Lộc, Tam Bình, Vĩnh Long": [
    "tân lộc, tam bình, vĩnh long",
    "taan loojc, tam bifnh, vixnh long"
  ],
  "Tân Lộc, Thới Bình, Cà Mau": [
    "tân lộc, thới bình, cà mau",
    "taan loojc, thowsi bifnh, caf mau"
  ],
  "Tân Mai, Biên Hòa, Đồng Nai": [
    "tân mai, biên hòa, đồng nai",
    "taan mai, bieen hofa, ddoofng nai"
  ],
  "Tân Minh, Thanh Sơn, Phú Thọ": [
    "tân minh, thanh sơn, phú thọ",
    "taan minh, thanh sown, phus thoj"
  ],
  "Tân Minh, Đà Bắc, Hoà Bình": [
    "tân minh, đà bắc, hoà bình",
    "taan minh, ddaf bawsc, hoaf bifnh"
  ],
  "Tân Mỹ, Lạc Sơn, Hoà Bình": [
    "tân mỹ, lạc sơn, hoà bình",
    "taan myx, lajc sown, hoaf bifnh"
  ],
  "Tân Pheo, Đà Bắc, Hoà Bình": [
    "tân pheo, đà bắc, hoà bình",
    "taan pheo, ddaf bawsc, hoaf bifnh"
  ],
  "Tân Phong, Giá Rai, Bạc Liêu": [
    "tân phong, giá rai, bạc liêu",
    "taan phong, gias rai, bajc lieeu"
  ],
  "Tân Phong, Tân Biên, Tây Ninh": [
    "tân phong, tân biên, tây ninh",
    "taan phong, taan bieen, taay ninh"
  ],
  "Tân Phong, Vũ Thư, Thái Bình": [
    "tân phong, vũ thư, thái bình",
    "taan phong, vux thuw, thasi bifnh"
  ],
  "Tân Phú, Châu Thành, An Giang": [
    "tân phú, châu thành, an giang",
    "taan phus, chaau thafnh, an giang"
  ],
  "Tân Phú, Cái Răng, Cần Thơ": [
    "tân phú, cái răng, cần thơ",
    "taan phus, casi rawng, caafn thow"
  ],
  "Tân Phú, Long Mỹ, Hậu Giang": [
    "tân phú, long mỹ, hậu giang",
    "taan phus, long myx, haaju giang"
  ],
  "Tân Phú, Tân Phú, Đồng Nai": [
    "tân phú, tân phú, đồng nai",
    "taan phus, taan phus, ddoofng nai"
  ],
  "Tân Quang, Văn Lâm, Hưng Yên": [
    "tân quang, văn lâm, hưng yên",
    "taan quang, vawn laam, huwng yeen"
  ],
  "Tân Sơn, Thanh Hóa, Thanh Hóa": [
    "tân sơn, thanh hóa, thanh hóa",
    "taan sown, thanh hosa, thanh hosa"
  ],
  "Tân Thành, Kim Sơn, Ninh Bình": [
    "tân thành, kim sơn, ninh bình",
    "taan thafnh, kim sown, ninh bifnh"
  ],
  "Tân Tiến, Bảo Yên, Lào Cai": [
    "tân tiến, bảo yên, lào cai",
    "taan tieesn, baro yeen, lafo cai"
  ],
  "Tân Tiến, La Gi, Bình Thuận": [
    "tân tiến, la gi, bình thuận",
    "taan tieesn, la gi, bifnh thuaajn"
  ],
  "Tân Tiến, Đầm Dơi, Cà Mau": [
    "tân tiến, đầm dơi, cà mau",
    "taan tieesn, ddaafm dowi, caf mau"
  ],
  "Tân Tri, Bắc Sơn, Lạng Sơn": [
    "tân tri, bắc sơn, lạng sơn",
    "taan tri, bawsc sown, lajng sown"
  ],
  "Tân Uyên, Tân Uyên, Lai Châu": [
    "tân uyên, tân uyên, lai châu",
    "taan uyeen, taan uyeen, lai chaau"
  ],
  "Tân Viên, An Lão, Hải Phòng": [
    "tân viên, an lão, hải phòng",
    "taan vieen, an laxo, hari phofng"
  ],
  "Tân Văn, Bình Gia, Lạng Sơn": [
    "tân văn, bình gia, lạng sơn",
    "taan vawn, bifnh gia, lajng sown"
  ],
  "Tân Văn, Lâm Hà, Lâm Đồng": [
    "tân văn, lâm hà, lâm đồng",
    "taan vawn, laam haf, laam ddoofng"
  ],
  "Tân Ân, Cần Đước, Long An": [
    "tân ân, cần đước, long an",
    "taan aan, caafn dduwowsc, long an"
  ],
  "Tân Đức, Đầm Dơi, Cà Mau": [
    "tân đức, đầm dơi, cà mau",
    "taan dduwsc, ddaafm dowi, caf mau"
  ],
  "Tân Ước, Thanh Oai, Hà Nội": [
    "tân ước, thanh oai, hà nội",
    "taan uwowsc, thanh oai, haf nooji"
  ],
  "Tây An, Tây Sơn, Bình Định": [
    "tây an, tây sơn, bình định",
    "taay an, taay sown, bifnh ddijnh"
  ],
  "Tây Phong, Cao Phong, Hoà Bình": [
    "tây phong, cao phong, hoà bình",
    "taay phong, cao phong, hoaf bifnh"
  ],
  "Tây Phú, Thoại Sơn, An Giang": [
    "tây phú, thoại sơn, an giang",
    "taay phus, thoaji sown, an giang"
  ],
  "Tây Đô, Hưng Hà, Thái Bình": [
    "tây đô, hưng hà, thái bình",
    "taay ddoo, huwng haf, thasi bifnh"
  ],
  "Tô Châu, Hà Tiên, Kiên Giang": [
    "tô châu, hà tiên, kiên giang",
    "too chaau, haf tieen, kieen giang"
  ],
  "Tùng Bá, Vị Xuyên, Hà Giang": [
    "tùng bá, vị xuyên, hà giang",
    "tufng bas, vij xuyeen, haf giang"
  ],
  "Tùng Lâm, Tĩnh Gia, Thanh Hóa": [
    "tùng lâm, tĩnh gia, thanh hóa",
    "tufng laam, tixnh gia, thanh hosa"
  ],
  "Tùng Lộc, Can Lộc, Hà Tĩnh": [
    "tùng lộc, can lộc, hà tĩnh",
    "tufng loojc, can loojc, haf tixnh"
  ],
  "Tường Hạ, Phù Yên, Sơn La": [
    "tường hạ, phù yên, sơn la",
    "tuwowfng haj, phuf yeen, sown la"
  ],
  "Tường Phù, Phù Yên, Sơn La": [
    "tường phù, phù yên, sơn la",
    "tuwowfng phuf, phuf yeen, sown la"
  ],
  "Tả Ngảo, Sìn Hồ, Lai Châu": [
    "tả ngảo, sìn hồ, lai châu",
    "tar ngaro, sifn hoof, lai chaau"
  ],
  "Tả Nhìu, Xín Mần, Hà Giang": [
    "tả nhìu, xín mần, hà giang",
    "tar nhifu, xisn maafn, haf giang"
  ],
  "Tả Ván, Quản Bạ, Hà Giang": [
    "tả ván, quản bạ, hà giang",
    "tar vasn, quarn baj, haf giang"
  ],
  "Tấn Mỹ, Chợ Mới, An Giang": [
    "tấn mỹ, chợ mới, an giang",
    "taasn myx, chowj mowsi, an giang"
  ],
  "Tứ Yên, Sông Lô, Vĩnh Phúc": [
    "tứ yên, sông lô, vĩnh phúc",
    "tuws yeen, soong loo, vixnh phusc"
  ],
  "Tự Do, Quảng Hòa, Cao Bằng": [
    "tự do, quảng hòa, cao bằng",
    "tuwj do, quarng hofa, cao bawfng"
  ],
  "Viễn Sơn, Văn Yên, Yên Bái": [
    "viễn sơn, văn yên, yên bái",
    "vieexn sown, vawn yeen, yeen basi"
  ],
  "Việt Long, Sóc Sơn, Hà Nội": [
    "việt long, sóc sơn, hà nội",
    "vieejt long, sosc sown, haf nooji"
  ],
  "Vân Cơ, Việt Trì, Phú Thọ": [
    "vân cơ, việt trì, phú thọ",
    "vaan cow, vieejt trif, phus thoj"
  ],
  "Vân Khánh, An Minh, Kiên Giang": [
    "vân khánh, an minh, kiên giang",
    "vaan khasnh, an minh, kieen giang"
  ],
  "Vân Nội, Đông Anh, Hà Nội": [
    "vân nội, đông anh, hà nội",
    "vaan nooji, ddoong anh, haf nooji"
  ],
  "Vân Sơn, Tân Lạc, Hoà Bình": [
    "vân sơn, tân lạc, hoà bình",
    "vaan sown, taan lajc, hoaf bifnh"
  ],
  "Vân Từ, Phú Xuyên, Hà Nội": [
    "vân từ, phú xuyên, hà nội",
    "vaan tuwf, phus xuyeen, haf nooji"
  ],
  "Vô Tranh, Lục Nam, Bắc Giang": [
    "vô tranh, lục nam, bắc giang",
    "voo tranh, lujc nam, bawsc giang"
  ],
  "Văn An, Chí Linh, Hải Dương": [
    "văn an, chí linh, hải dương",
    "vawn an, chis linh, hari duwowng"
  ],
  "Văn Bán, Cẩm Khê, Phú Thọ": [
    "văn bán, cẩm khê, phú thọ",
    "vawn basn, caarm khee, phus thoj"
  ],
  "Văn Lang, Hưng Hà, Thái Bình": [
    "văn lang, hưng hà, thái bình",
    "vawn lang, huwng haf, thasi bifnh"
  ],
  "Văn Lung, Phú Thọ, Phú Thọ": [
    "văn lung, phú thọ, phú thọ",
    "vawn lung, phus thoj, phus thoj"
  ],
  "Văn Môn, Yên Phong, Bắc Ninh": [
    "văn môn, yên phong, bắc ninh",
    "vawn moon, yeen phong, bawsc ninh"
  ],
  "Văn Quan, Văn Quan, Lạng Sơn": [
    "văn quan, văn quan, lạng sơn",
    "vawn quan, vawn quan, lajng sown"
  ],
  "Văn Quán, Hà Đông, Hà Nội": [
    "văn quán, hà đông, hà nội",
    "vawn quasn, haf ddoong, haf nooji"
  ],
  "Văn Sơn, Lạc Sơn, Hoà Bình": [
    "văn sơn, lạc sơn, hoà bình",
    "vawn sown, lajc sown, hoaf bifnh"
  ],
  "Văn Xuôi, Tu Mơ Rông, Kon Tum": [
    "văn xuôi, tu mơ rông, kon tum",
    "vawn xuooi, tu mow roong, kon tum"
  ],
  "Vĩnh An, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh an, vĩnh lộc, thanh hóa",
    "vixnh an, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Bình, Vĩnh Hưng, Long An": [
    "vĩnh bình, vĩnh hưng, long an",
    "vixnh bifnh, vixnh huwng, long an"
  ],
  "Vĩnh Hưng, Vĩnh Hưng, Long An": [
    "vĩnh hưng, vĩnh hưng, long an",
    "vixnh huwng, vixnh huwng, long an"
  ],
  "Vĩnh Kim, Cầu Ngang, Trà Vinh": [
    "vĩnh kim, cầu ngang, trà vinh",
    "vixnh kim, caafu ngang, traf vinh"
  ],
  "Vĩnh Phúc, Ba Đình, Hà Nội": [
    "vĩnh phúc, ba đình, hà nội",
    "vixnh phusc, ba ddifnh, haf nooji"
  ],
  "Vĩnh Trị, Vĩnh Hưng, Long An": [
    "vĩnh trị, vĩnh hưng, long an",
    "vixnh trij, vixnh huwng, long an"
  ],
  "Vĩnh Tuy, Bắc Quang, Hà Giang": [
    "vĩnh tuy, bắc quang, hà giang",
    "vixnh tuy, bawsc quang, haf giang"
  ],
  "Vĩnh Xuân, Trà Ôn, Vĩnh Long": [
    "vĩnh xuân, trà ôn, vĩnh long",
    "vixnh xuaan, traf oon, vixnh long"
  ],
  "Vĩnh Đại, Tân Hưng, Long An": [
    "vĩnh đại, tân hưng, long an",
    "vixnh ddaji, taan huwng, long an"
  ],
  "Vũ Bình, Lạc Sơn, Hoà Bình": [
    "vũ bình, lạc sơn, hoà bình",
    "vux bifnh, lajc sown, hoaf bifnh"
  ],
  "Vũ Lễ, Bắc Sơn, Lạng Sơn": [
    "vũ lễ, bắc sơn, lạng sơn",
    "vux leex, bawsc sown, lajng sown"
  ],
  "Vũ Sơn, Bắc Sơn, Lạng Sơn": [
    "vũ sơn, bắc sơn, lạng sơn",
    "vux sown, bawsc sown, lajng sown"
  ],
  "Vũ Tiến, Vũ Thư, Thái Bình": [
    "vũ tiến, vũ thư, thái bình",
    "vux tieesn, vux thuw, thasi bifnh"
  ],
  "Vũ Đoài, Vũ Thư, Thái Bình": [
    "vũ đoài, vũ thư, thái bình",
    "vux ddoafi, vux thuw, thasi bifnh"
  ],
  "Vạn Kim, Mỹ Đức, Hà Nội": [
    "vạn kim, mỹ đức, hà nội",
    "vajn kim, myx dduwsc, haf nooji"
  ],
  "Vạn Ninh, Gia Bình, Bắc Ninh": [
    "vạn ninh, gia bình, bắc ninh",
    "vajn ninh, gia bifnh, bawsc ninh"
  ],
  "Xa Lý, Lục Ngạn, Bắc Giang": [
    "xa lý, lục ngạn, bắc giang",
    "xa lys, lujc ngajn, bawsc giang"
  ],
  "Xuân Canh, Đông Anh, Hà Nội": [
    "xuân canh, đông anh, hà nội",
    "xuaan canh, ddoong anh, haf nooji"
  ],
  "Xuân Giang, Sóc Sơn, Hà Nội": [
    "xuân giang, sóc sơn, hà nội",
    "xuaan giang, sosc sown, haf nooji"
  ],
  "Xuân Hòa, Vũ Thư, Thái Bình": [
    "xuân hòa, vũ thư, thái bình",
    "xuaan hofa, vux thuw, thasi bifnh"
  ],
  "Xuân Khanh, Sơn Tây, Hà Nội": [
    "xuân khanh, sơn tây, hà nội",
    "xuaan khanh, sown taay, haf nooji"
  ],
  "Xuân La, Pác Nặm, Bắc Kạn": [
    "xuân la, pác nặm, bắc kạn",
    "xuaan la, pasc nawjm, bawsc kajn"
  ],
  "Xuân Long, Yên Bình, Yên Bái": [
    "xuân long, yên bình, yên bái",
    "xuaan long, yeen bifnh, yeen basi"
  ],
  "Xuân Lâm, Tĩnh Gia, Thanh Hóa": [
    "xuân lâm, tĩnh gia, thanh hóa",
    "xuaan laam, tixnh gia, thanh hosa"
  ],
  "Xuân Lộc, Can Lộc, Hà Tĩnh": [
    "xuân lộc, can lộc, hà tĩnh",
    "xuaan loojc, can loojc, haf tixnh"
  ],
  "Xuân Mỹ, Nghi Xuân, Hà Tĩnh": [
    "xuân mỹ, nghi xuân, hà tĩnh",
    "xuaan myx, nghi xuaan, haf tixnh"
  ],
  "Xuân Sơn, Tân Sơn, Phú Thọ": [
    "xuân sơn, tân sơn, phú thọ",
    "xuaan sown, taan sown, phus thoj"
  ],
  "Xuân Tầm, Văn Yên, Yên Bái": [
    "xuân tầm, văn yên, yên bái",
    "xuaan taafm, vawn yeen, yeen basi"
  ],
  "Xuân Yên, Nghi Xuân, Hà Tĩnh": [
    "xuân yên, nghi xuân, hà tĩnh",
    "xuaan yeen, nghi xuaan, haf tixnh"
  ],
  "Xuân Áng, Hạ Hoà, Phú Thọ": [
    "xuân áng, hạ hoà, phú thọ",
    "xuaan asng, haj hoaf, phus thoj"
  ],
  "Xà Hồ, Trạm Tấu, Yên Bái": [
    "xà hồ, trạm tấu, yên bái",
    "xaf hoof, trajm taasu, yeen basi"
  ],
  "Xích Thổ, Nho Quan, Ninh Bình": [
    "xích thổ, nho quan, ninh bình",
    "xisch thoor, nho quan, ninh bifnh"
  ],
  "Xín Mần, Xín Mần, Hà Giang": [
    "xín mần, xín mần, hà giang",
    "xisn maafn, xisn maafn, haf giang"
  ],
  "Yên Bình, Yên Bình, Yên Bái": [
    "yên bình, yên bình, yên bái",
    "yeen bifnh, yeen bifnh, yeen basi"
  ],
  "Yên Bằng, Ý Yên, Nam Định": [
    "yên bằng, ý yên, nam định",
    "yeen bawfng, ys yeen, nam ddijnh"
  ],
  "Yên Chính, Ý Yên, Nam Định": [
    "yên chính, ý yên, nam định",
    "yeen chisnh, ys yeen, nam ddijnh"
  ],
  "Yên Cát, Như Xuân, Thanh Hóa": [
    "yên cát, như xuân, thanh hóa",
    "yeen cast, nhuw xuaan, thanh hosa"
  ],
  "Yên Giả, Quế Võ, Bắc Ninh": [
    "yên giả, quế võ, bắc ninh",
    "yeen giar, quees vox, bawsc ninh"
  ],
  "Yên Hòa, Đà Bắc, Hoà Bình": [
    "yên hòa, đà bắc, hoà bình",
    "yeen hofa, ddaf bawsc, hoaf bifnh"
  ],
  "Yên Hồng, Ý Yên, Nam Định": [
    "yên hồng, ý yên, nam định",
    "yeen hoofng, ys yeen, nam ddijnh"
  ],
  "Yên Khánh, Ý Yên, Nam Định": [
    "yên khánh, ý yên, nam định",
    "yeen khasnh, ys yeen, nam ddijnh"
  ],
  "Yên Lư, Yên Dũng, Bắc Giang": [
    "yên lư, yên dũng, bắc giang",
    "yeen luw, yeen duxng, bawsc giang"
  ],
  "Yên Lỗ, Bình Gia, Lạng Sơn": [
    "yên lỗ, bình gia, lạng sơn",
    "yeen loox, bifnh gia, lajng sown"
  ],
  "Yên Nghĩa, Ý Yên, Nam Định": [
    "yên nghĩa, ý yên, nam định",
    "yeen nghixa, ys yeen, nam ddijnh"
  ],
  "Yên Phú, Lạc Sơn, Hoà Bình": [
    "yên phú, lạc sơn, hoà bình",
    "yeen phus, lajc sown, hoaf bifnh"
  ],
  "Yên Sơn, Lục Nam, Bắc Giang": [
    "yên sơn, lục nam, bắc giang",
    "yeen sown, lujc nam, bawsc giang"
  ],
  "Yên Sơn, Thanh Sơn, Phú Thọ": [
    "yên sơn, thanh sơn, phú thọ",
    "yeen sown, thanh sown, phus thoj"
  ],
  "Yên Thành, Yên Mô, Ninh Bình": [
    "yên thành, yên mô, ninh bình",
    "yeen thafnh, yeen moo, ninh bifnh"
  ],
  "Yên Thành, Ý Yên, Nam Định": [
    "yên thành, ý yên, nam định",
    "yeen thafnh, ys yeen, nam ddijnh"
  ],
  "Yên Thế, Lục Yên, Yên Bái": [
    "yên thế, lục yên, yên bái",
    "yeen thees, lujc yeen, yeen basi"
  ],
  "Yên Tiến, Ý Yên, Nam Định": [
    "yên tiến, ý yên, nam định",
    "yeen tieesn, ys yeen, nam ddijnh"
  ],
  "Yến Sơn, Hà Trung, Thanh Hóa": [
    "yến sơn, hà trung, thanh hóa",
    "yeesn sown, haf trung, thanh hosa"
  ],
  "Đa Kao, Quận 1, Hồ Chí Minh": [
    "đa kao, quận 1, hồ chí minh",
    "dda kao, quaajn 1, hoof chis minh"
  ],
  "Đa Mai, Bắc Giang, Bắc Giang": [
    "đa mai, bắc giang, bắc giang",
    "dda mai, bawsc giang, bawsc giang"
  ],
  "Đình Cao, Phù Cừ, Hưng Yên": [
    "đình cao, phù cừ, hưng yên",
    "ddifnh cao, phuf cuwf, huwng yeen"
  ],
  "Đình Dù, Văn Lâm, Hưng Yên": [
    "đình dù, văn lâm, hưng yên",
    "ddifnh duf, vawn laam, huwng yeen"
  ],
  "Đông Anh, Đông Anh, Hà Nội": [
    "đông anh, đông anh, hà nội",
    "ddoong anh, ddoong anh, haf nooji"
  ],
  "Đông Hòa, An Minh, Kiên Giang": [
    "đông hòa, an minh, kiên giang",
    "ddoong hofa, an minh, kieen giang"
  ],
  "Đông Minh, Yên Minh, Hà Giang": [
    "đông minh, yên minh, hà giang",
    "ddoong minh, yeen minh, haf giang"
  ],
  "Đông Sang, Mộc Châu, Sơn La": [
    "đông sang, mộc châu, sơn la",
    "ddoong sang, moojc chaau, sown la"
  ],
  "Đăk Djrăng, Mang Yang, Gia Lai": [
    "đăk djrăng, mang yang, gia lai",
    "ddawk djrawng, mang yang, gia lai"
  ],
  "Đăk Ngọk, Đắk Hà, Kon Tum": [
    "đăk ngọk, đắk hà, kon tum",
    "ddawk ngojk, ddawsk haf, kon tum"
  ],
  "Đăk Sơmei, Đăk Đoa, Gia Lai": [
    "đăk sơmei, đăk đoa, gia lai",
    "ddawk sowmei, ddawk ddoa, gia lai"
  ],
  "Đăk Tơ Ver, Chư Păh, Gia Lai": [
    "đăk tơ ver, chư păh, gia lai",
    "ddawk tow ver, chuw pawh, gia lai"
  ],
  "Đại Kim, Hoàng Mai, Hà Nội": [
    "đại kim, hoàng mai, hà nội",
    "ddaji kim, hoafng mai, haf nooji"
  ],
  "Đại Lai, Gia Bình, Bắc Ninh": [
    "đại lai, gia bình, bắc ninh",
    "ddaji lai, gia bifnh, bawsc ninh"
  ],
  "Đại Nài, Hà Tĩnh, Hà Tĩnh": [
    "đại nài, hà tĩnh, hà tĩnh",
    "ddaji nafi, haf tixnh, haf tixnh"
  ],
  "Đại Sơn, Văn Yên, Yên Bái": [
    "đại sơn, văn yên, yên bái",
    "ddaji sown, vawn yeen, yeen basi"
  ],
  "Đất Bằng, Krông Pa, Gia Lai": [
    "đất bằng, krông pa, gia lai",
    "ddaast bawfng, kroong pa, gia lai"
  ],
  "Đầm Dơi, Đầm Dơi, Cà Mau": [
    "đầm dơi, đầm dơi, cà mau",
    "ddaafm dowi, ddaafm dowi, caf mau"
  ],
  "Đắk Ang, Ngọc Hồi, Kon Tum": [
    "đắk ang, ngọc hồi, kon tum",
    "ddawsk ang, ngojc hoofi, kon tum"
  ],
  "Đắk Blô, Đắk Glei, Kon Tum": [
    "đắk blô, đắk glei, kon tum",
    "ddawsk bloo, ddawsk glei, kon tum"
  ],
  "Đắk Glei, Đắk Glei, Kon Tum": [
    "đắk glei, đắk glei, kon tum",
    "ddawsk glei, ddawsk glei, kon tum"
  ],
  "Đắk HRing, Đắk Hà, Kon Tum": [
    "đắk hring, đắk hà, kon tum",
    "ddawsk hring, ddawsk haf, kon tum"
  ],
  "Đắk Hà, Tu Mơ Rông, Kon Tum": [
    "đắk hà, tu mơ rông, kon tum",
    "ddawsk haf, tu mow roong, kon tum"
  ],
  "Đắk Kan, Ngọc Hồi, Kon Tum": [
    "đắk kan, ngọc hồi, kon tum",
    "ddawsk kan, ngojc hoofi, kon tum"
  ],
  "Đắk Long, Đắk Glei, Kon Tum": [
    "đắk long, đắk glei, kon tum",
    "ddawsk long, ddawsk glei, kon tum"
  ],
  "Đắk Môn, Đắk Glei, Kon Tum": [
    "đắk môn, đắk glei, kon tum",
    "ddawsk moon, ddawsk glei, kon tum"
  ],
  "Đắk Phơi, Lắk, Đắk Lắk": [
    "đắk phơi, lắk, đắk lắk",
    "ddawsk phowi, lawsk, ddawsk lawsk"
  ],
  "Đắk Pék, Đắk Glei, Kon Tum": [
    "đắk pék, đắk glei, kon tum",
    "ddawsk pesk, ddawsk glei, kon tum"
  ],
  "Đắk Sao, Tu Mơ Rông, Kon Tum": [
    "đắk sao, tu mơ rông, kon tum",
    "ddawsk sao, tu mow roong, kon tum"
  ],
  "Đắk Trăm, Đắk Tô, Kon Tum": [
    "đắk trăm, đắk tô, kon tum",
    "ddawsk trawm, ddawsk too, kon tum"
  ],
  "Đắk Tăng, Kon Plông, Kon Tum": [
    "đắk tăng, kon plông, kon tum",
    "ddawsk tawng, kon ploong, kon tum"
  ],
  "Đắk Xú, Ngọc Hồi, Kon Tum": [
    "đắk xú, ngọc hồi, kon tum",
    "ddawsk xus, ngojc hoofi, kon tum"
  ],
  "Đặng Lễ, Ân Thi, Hưng Yên": [
    "đặng lễ, ân thi, hưng yên",
    "ddawjng leex, aan thi, huwng yeen"
  ],
  "Đỉnh Sơn, Anh Sơn, Nghệ An": [
    "đỉnh sơn, anh sơn, nghệ an",
    "ddirnh sown, anh sown, ngheej an"
  ],
  "Địa Linh, Ba Bể, Bắc Kạn": [
    "địa linh, ba bể, bắc kạn",
    "ddija linh, ba beer, bawsc kajn"
  ],
  "Định An, Gò Quao, Kiên Giang": [
    "định an, gò quao, kiên giang",
    "ddijnh an, gof quao, kieen giang"
  ],
  "Đồng Hóa, Kim Bảng, Hà Nam": [
    "đồng hóa, kim bảng, hà nam",
    "ddoofng hosa, kim barng, haf nam"
  ],
  "Đức Hoà, Sóc Sơn, Hà Nội": [
    "đức hoà, sóc sơn, hà nội",
    "dduwsc hoaf, sosc sown, haf nooji"
  ],
  "Đức Hòa, Đức Hòa, Long An": [
    "đức hòa, đức hòa, long an",
    "dduwsc hofa, dduwsc hofa, long an"
  ],
  "Đức Long, Nho Quan, Ninh Bình": [
    "đức long, nho quan, ninh bình",
    "dduwsc long, nho quan, ninh bifnh"
  ],
  "A Vương, Tây Giang, Quảng Nam": [
    "a vương, tây giang, quảng nam",
    "a vuwowng, taay giang, quarng nam"
  ],
  "An Bình, Buôn Hồ, Đắk Lắk": [
    "an bình, buôn hồ, đắk lắk",
    "an bifnh, buoon hoof, ddawsk lawsk"
  ],
  "An Bình, Cao Lãnh, Đồng Tháp": [
    "an bình, cao lãnh, đồng tháp",
    "an bifnh, cao laxnh, ddoofng thasp"
  ],
  "An Bình, Lạc Thủy, Hoà Bình": [
    "an bình, lạc thủy, hoà bình",
    "an bifnh, lajc thury, hoaf bifnh"
  ],
  "An Bình, Nam Sách, Hải Dương": [
    "an bình, nam sách, hải dương",
    "an bifnh, nam sasch, hari duwowng"
  ],
  "An Bình, Rạch Giá, Kiên Giang": [
    "an bình, rạch giá, kiên giang",
    "an bifnh, rajch gias, kieen giang"
  ],
  "An Dương, Tân Yên, Bắc Giang": [
    "an dương, tân yên, bắc giang",
    "an duwowng, taan yeen, bawsc giang"
  ],
  "An Hiệp, Châu Thành, Bến Tre": [
    "an hiệp, châu thành, bến tre",
    "an hieejp, chaau thafnh, beesn tre"
  ],
  "An Hoà, Vĩnh Bảo, Hải Phòng": [
    "an hoà, vĩnh bảo, hải phòng",
    "an hoaf, vixnh baro, hari phofng"
  ],
  "An Hưng, An Dương, Hải Phòng": [
    "an hưng, an dương, hải phòng",
    "an huwng, an duwowng, hari phofng"
  ],
  "An Khánh, Châu Thành, Bến Tre": [
    "an khánh, châu thành, bến tre",
    "an khasnh, chaau thafnh, beesn tre"
  ],
  "An Khánh, Hoài Đức, Hà Nội": [
    "an khánh, hoài đức, hà nội",
    "an khasnh, hoafi dduwsc, haf nooji"
  ],
  "An Khánh, Ninh Kiều, Cần Thơ": [
    "an khánh, ninh kiều, cần thơ",
    "an khasnh, ninh kieefu, caafn thow"
  ],
  "An Linh, Phú Giáo, Bình Dương": [
    "an linh, phú giáo, bình dương",
    "an linh, phus giaso, bifnh duwowng"
  ],
  "An Long, Phú Giáo, Bình Dương": [
    "an long, phú giáo, bình dương",
    "an long, phus giaso, bifnh duwowng"
  ],
  "An Lương, Văn Chấn, Yên Bái": [
    "an lương, văn chấn, yên bái",
    "an luwowng, vawn chaasn, yeen basi"
  ],
  "An Lạc, Buôn Hồ, Đắk Lắk": [
    "an lạc, buôn hồ, đắk lắk",
    "an lajc, buoon hoof, ddawsk lawsk"
  ],
  "An Lạc, Chí Linh, Hải Dương": [
    "an lạc, chí linh, hải dương",
    "an lajc, chis linh, hari duwowng"
  ],
  "An Ninh Tây, Đức Hòa, Long An": [
    "an ninh tây, đức hòa, long an",
    "an ninh taay, dduwsc hofa, long an"
  ],
  "An Ninh, Châu Thành, Sóc Trăng": [
    "an ninh, châu thành, sóc trăng",
    "an ninh, chaau thafnh, sosc trawng"
  ],
  "An Ninh, Tiền Hải, Thái Bình": [
    "an ninh, tiền hải, thái bình",
    "an ninh, tieefn hari, thasi bifnh"
  ],
  "An Nông, Triệu Sơn, Thanh Hóa": [
    "an nông, triệu sơn, thanh hóa",
    "an noong, trieeju sown, thanh hosa"
  ],
  "An Phú Tân, Cầu Kè, Trà Vinh": [
    "an phú tân, cầu kè, trà vinh",
    "an phus taan, caafu kef, traf vinh"
  ],
  "An Phú, Thuận An, Bình Dương": [
    "an phú, thuận an, bình dương",
    "an phus, thuaajn an, bifnh duwowng"
  ],
  "An Phụ, Kinh Môn, Hải Dương": [
    "an phụ, kinh môn, hải dương",
    "an phuj, kinh moon, hari duwowng"
  ],
  "An Sơn, Thuận An, Bình Dương": [
    "an sơn, thuận an, bình dương",
    "an sown, thuaajn an, bifnh duwowng"
  ],
  "An Thanh, Tứ Kỳ, Hải Dương": [
    "an thanh, tứ kỳ, hải dương",
    "an thanh, tuws kyf, hari duwowng"
  ],
  "An Thạnh, Bến Cầu, Tây Ninh": [
    "an thạnh, bến cầu, tây ninh",
    "an thajnh, beesn caafu, taay ninh"
  ],
  "An Tân, Thái Thụy, Thái Bình": [
    "an tân, thái thụy, thái bình",
    "an taan, thasi thujy, thasi bifnh"
  ],
  "An Tây, Bến Cát, Bình Dương": [
    "an tây, bến cát, bình dương",
    "an taay, beesn cast, bifnh duwowng"
  ],
  "An Vũ, Quỳnh Phụ, Thái Bình": [
    "an vũ, quỳnh phụ, thái bình",
    "an vux, quyfnh phuj, thasi bifnh"
  ],
  "Ba Nang, Đa Krông, Quảng Trị": [
    "ba nang, đa krông, quảng trị",
    "ba nang, dda kroong, quarng trij"
  ],
  "Biên Giang, Hà Đông, Hà Nội": [
    "biên giang, hà đông, hà nội",
    "bieen giang, haf ddoong, haf nooji"
  ],
  "Bom Bo, Bù Đăng, Bình Phước": [
    "bom bo, bù đăng, bình phước",
    "bom bo, buf ddawng, bifnh phuwowsc"
  ],
  "Buôn Triết, Lắk, Đắk Lắk": [
    "buôn triết, lắk, đắk lắk",
    "buoon trieest, lawsk, ddawsk lawsk"
  ],
  "Bài Sơn, Đô Lương, Nghệ An": [
    "bài sơn, đô lương, nghệ an",
    "bafi sown, ddoo luwowng, ngheej an"
  ],
  "Bàng La, Đồ Sơn, Hải Phòng": [
    "bàng la, đồ sơn, hải phòng",
    "bafng la, ddoof sown, hari phofng"
  ],
  "Bàu Sen, Long Khánh, Đồng Nai": [
    "bàu sen, long khánh, đồng nai",
    "bafu sen, long khasnh, ddoofng nai"
  ],
  "Báo Đáp, Trấn Yên, Yên Bái": [
    "báo đáp, trấn yên, yên bái",
    "baso ddasp, traasn yeen, yeen basi"
  ],
  "Bình An, Long Thành, Đồng Nai": [
    "bình an, long thành, đồng nai",
    "bifnh an, long thafnh, ddoofng nai"
  ],
  "Bình An, Lâm Bình, Tuyên Quang": [
    "bình an, lâm bình, tuyên quang",
    "bifnh an, laam bifnh, tuyeen quang"
  ],
  "Bình An, Quận 2, Hồ Chí Minh": [
    "bình an, quận 2, hồ chí minh",
    "bifnh an, quaajn 2, hoof chis minh"
  ],
  "Bình Chánh, Châu Phú, An Giang": [
    "bình chánh, châu phú, an giang",
    "bifnh chasnh, chaau phus, an giang"
  ],
  "Bình Dương, Hoà An, Cao Bằng": [
    "bình dương, hoà an, cao bằng",
    "bifnh duwowng, hoaf an, cao bawfng"
  ],
  "Bình Hòa, Châu Thành, An Giang": [
    "bình hòa, châu thành, an giang",
    "bifnh hofa, chaau thafnh, an giang"
  ],
  "Bình Nghĩa, Bình Lục, Hà Nam": [
    "bình nghĩa, bình lục, hà nam",
    "bifnh nghixa, bifnh lujc, haf nam"
  ],
  "Bình Sơn, Lục Nam, Bắc Giang": [
    "bình sơn, lục nam, bắc giang",
    "bifnh sown, lujc nam, bawsc giang"
  ],
  "Bình Thanh, Cao Phong, Hoà Bình": [
    "bình thanh, cao phong, hoà bình",
    "bifnh thanh, cao phong, hoaf bifnh"
  ],
  "Bình Thạnh, Mộc Hóa, Long An": [
    "bình thạnh, mộc hóa, long an",
    "bifnh thajnh, moojc hosa, long an"
  ],
  "Bình Thủy, Châu Phú, An Giang": [
    "bình thủy, châu phú, an giang",
    "bifnh thury, chaau phus, an giang"
  ],
  "Bình Đa, Biên Hòa, Đồng Nai": [
    "bình đa, biên hòa, đồng nai",
    "bifnh dda, bieen hofa, ddoofng nai"
  ],
  "Bình Đức, Bến Lức, Long An": [
    "bình đức, bến lức, long an",
    "bifnh dduwsc, beesn luwsc, long an"
  ],
  "Bạch Xa, Hàm Yên, Tuyên Quang": [
    "bạch xa, hàm yên, tuyên quang",
    "bajch xa, hafm yeen, tuyeen quang"
  ],
  "Bản Bo, Tam Đường, Lai Châu": [
    "bản bo, tam đường, lai châu",
    "barn bo, tam dduwowfng, lai chaau"
  ],
  "Bản Lang, Phong Thổ, Lai Châu": [
    "bản lang, phong thổ, lai châu",
    "barn lang, phong thoor, lai chaau"
  ],
  "Bản Mù, Trạm Tấu, Yên Bái": [
    "bản mù, trạm tấu, yên bái",
    "barn muf, trajm taasu, yeen basi"
  ],
  "Bản Vược, Bát Xát, Lào Cai": [
    "bản vược, bát xát, lào cai",
    "barn vuwowjc, bast xast, lafo cai"
  ],
  "Bảo Khê, Hưng Yên, Hưng Yên": [
    "bảo khê, hưng yên, hưng yên",
    "baro khee, huwng yeen, huwng yeen"
  ],
  "Bảo Lâm, Cao Lộc, Lạng Sơn": [
    "bảo lâm, cao lộc, lạng sơn",
    "baro laam, cao loojc, lajng sown"
  ],
  "Bảo Sơn, Lục Nam, Bắc Giang": [
    "bảo sơn, lục nam, bắc giang",
    "baro sown, lujc nam, bawsc giang"
  ],
  "Bảo Thanh, Phù Ninh, Phú Thọ": [
    "bảo thanh, phù ninh, phú thọ",
    "baro thanh, phuf ninh, phus thoj"
  ],
  "Bắc An, Chí Linh, Hải Dương": [
    "bắc an, chí linh, hải dương",
    "bawsc an, chis linh, hari duwowng"
  ],
  "Bắc Cường, Lào Cai, Lào Cai": [
    "bắc cường, lào cai, lào cai",
    "bawsc cuwowfng, lafo cai, lafo cai"
  ],
  "Bắc Phong, Cao Phong, Hoà Bình": [
    "bắc phong, cao phong, hoà bình",
    "bawsc phong, cao phong, hoaf bifnh"
  ],
  "Bắc Sơn, Bỉm Sơn, Thanh Hóa": [
    "bắc sơn, bỉm sơn, thanh hóa",
    "bawsc sown, birm sown, thanh hosa"
  ],
  "Bắc Sơn, Hưng Hà, Thái Bình": [
    "bắc sơn, hưng hà, thái bình",
    "bawsc sown, huwng haf, thasi bifnh"
  ],
  "Bắc Sơn, Quỳ Hợp, Nghệ An": [
    "bắc sơn, quỳ hợp, nghệ an",
    "bawsc sown, quyf howjp, ngheej an"
  ],
  "Bắc Sơn, Sầm Sơn, Thanh Hóa": [
    "bắc sơn, sầm sơn, thanh hóa",
    "bawsc sown, saafm sown, thanh hosa"
  ],
  "Bằng Giã, Hạ Hoà, Phú Thọ": [
    "bằng giã, hạ hoà, phú thọ",
    "bawfng giax, haj hoaf, phus thoj"
  ],
  "Bến Sung, Như Thanh, Thanh Hóa": [
    "bến sung, như thanh, thanh hóa",
    "beesn sung, nhuw thanh, thanh hosa"
  ],
  "Bố Hạ, Yên Thế, Bắc Giang": [
    "bố hạ, yên thế, bắc giang",
    "boos haj, yeen thees, bawsc giang"
  ],
  "Bồng Khê, Con Cuông, Nghệ An": [
    "bồng khê, con cuông, nghệ an",
    "boofng khee, con cuoong, ngheej an"
  ],
  "Ca Đình, Đoan Hùng, Phú Thọ": [
    "ca đình, đoan hùng, phú thọ",
    "ca ddifnh, ddoan hufng, phus thoj"
  ],
  "Cai Bộ, Quảng Hòa, Cao Bằng": [
    "cai bộ, quảng hòa, cao bằng",
    "cai booj, quarng hofa, cao bawfng"
  ],
  "Cai Kinh, Hữu Lũng, Lạng Sơn": [
    "cai kinh, hữu lũng, lạng sơn",
    "cai kinh, huwxu luxng, lajng sown"
  ],
  "Cam Thuận, Cam Ranh, Khánh Hòa": [
    "cam thuận, cam ranh, khánh hòa",
    "cam thuaajn, cam ranh, khasnh hofa"
  ],
  "Cao Kỳ, Chợ Mới, Bắc Kạn": [
    "cao kỳ, chợ mới, bắc kạn",
    "cao kyf, chowj mowsi, bawsc kajn"
  ],
  "Cao Sơn, Lương Sơn, Hoà Bình": [
    "cao sơn, lương sơn, hoà bình",
    "cao sown, luwowng sown, hoaf bifnh"
  ],
  "Chiềng Hoa, Mường La, Sơn La": [
    "chiềng hoa, mường la, sơn la",
    "chieefng hoa, muwowfng la, sown la"
  ],
  "Chiềng Khoi, Yên Châu, Sơn La": [
    "chiềng khoi, yên châu, sơn la",
    "chieefng khoi, yeen chaau, sown la"
  ],
  "Chiềng Lao, Mường La, Sơn La": [
    "chiềng lao, mường la, sơn la",
    "chieefng lao, muwowfng la, sown la"
  ],
  "Chiềng Phung, Sông Mã, Sơn La": [
    "chiềng phung, sông mã, sơn la",
    "chieefng phung, soong max, sown la"
  ],
  "Chiềng San, Mường La, Sơn La": [
    "chiềng san, mường la, sơn la",
    "chieefng san, muwowfng la, sown la"
  ],
  "Chiềng Xuân, Vân Hồ, Sơn La": [
    "chiềng xuân, vân hồ, sơn la",
    "chieefng xuaan, vaan hoof, sown la"
  ],
  "Chiềng Ân, Mường La, Sơn La": [
    "chiềng ân, mường la, sơn la",
    "chieefng aan, muwowfng la, sown la"
  ],
  "Châu Phong, Quế Võ, Bắc Ninh": [
    "châu phong, quế võ, bắc ninh",
    "chaau phong, quees vox, bawsc ninh"
  ],
  "Chư A Thai, Phú Thiện, Gia Lai": [
    "chư a thai, phú thiện, gia lai",
    "chuw a thai, phus thieejn, gia lai"
  ],
  "Chư Đăng Ya, Chư Păh, Gia Lai": [
    "chư đăng ya, chư păh, gia lai",
    "chuw ddawng ya, chuw pawh, gia lai"
  ],
  "Chất Bình, Kim Sơn, Ninh Bình": [
    "chất bình, kim sơn, ninh bình",
    "chaast bifnh, kim sown, ninh bifnh"
  ],
  "Chợ Mới, Chợ Mới, An Giang": [
    "chợ mới, chợ mới, an giang",
    "chowj mowsi, chowj mowsi, an giang"
  ],
  "Cà Ná, Thuận Nam, Ninh Thuận": [
    "cà ná, thuận nam, ninh thuận",
    "caf nas, thuaajn nam, ninh thuaajn"
  ],
  "Cái Vồn, Bình Minh, Vĩnh Long": [
    "cái vồn, bình minh, vĩnh long",
    "casi voofn, bifnh minh, vixnh long"
  ],
  "Cát Bà, Cát Hải, Hải Phòng": [
    "cát bà, cát hải, hải phòng",
    "cast baf, cast hari, hari phofng"
  ],
  "Cát Dài, Lê Chân, Hải Phòng": [
    "cát dài, lê chân, hải phòng",
    "cast dafi, lee chaan, hari phofng"
  ],
  "Công Sơn, Cao Lộc, Lạng Sơn": [
    "công sơn, cao lộc, lạng sơn",
    "coong sown, cao loojc, lajng sown"
  ],
  "Công Đa, Yên Sơn, Tuyên Quang": [
    "công đa, yên sơn, tuyên quang",
    "coong dda, yeen sown, tuyeen quang"
  ],
  "Cư A Mung, Ea H'leo, Đắk Lắk": [
    "cư a mung, ea h'leo, đắk lắk",
    "cuw a mung, ea h'leo, ddawsk lawsk"
  ],
  "Cư M'gar, Cư M'gar, Đắk Lắk": [
    "cư m'gar, cư m'gar, đắk lắk",
    "cuw m'gar, cuw m'gar, ddawsk lawsk"
  ],
  "Cư Né, Krông Búk, Đắk Lắk": [
    "cư né, krông búk, đắk lắk",
    "cuw nes, kroong busk, ddawsk lawsk"
  ],
  "Cư Yên, Lương Sơn, Hoà Bình": [
    "cư yên, lương sơn, hoà bình",
    "cuw yeen, luwowng sown, hoaf bifnh"
  ],
  "Cảm Nhân, Yên Bình, Yên Bái": [
    "cảm nhân, yên bình, yên bái",
    "carm nhaan, yeen bifnh, yeen basi"
  ],
  "Cảnh Hưng, Tiên Du, Bắc Ninh": [
    "cảnh hưng, tiên du, bắc ninh",
    "carnh huwng, tieen du, bawsc ninh"
  ],
  "Cấn Hữu, Quốc Oai, Hà Nội": [
    "cấn hữu, quốc oai, hà nội",
    "caasn huwxu, quoosc oai, haf nooji"
  ],
  "Cầu Thia, Nghĩa Lộ, Yên Bái": [
    "cầu thia, nghĩa lộ, yên bái",
    "caafu thia, nghixa looj, yeen basi"
  ],
  "Cẩm Châu, Hội An, Quảng Nam": [
    "cẩm châu, hội an, quảng nam",
    "caarm chaau, hooji an, quarng nam"
  ],
  "Cẩm Hà, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm hà, cẩm xuyên, hà tĩnh",
    "caarm haf, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Khê, Cẩm Khê, Phú Thọ": [
    "cẩm khê, cẩm khê, phú thọ",
    "caarm khee, caarm khee, phus thoj"
  ],
  "Cẩm Thanh, Hội An, Quảng Nam": [
    "cẩm thanh, hội an, quảng nam",
    "caarm thanh, hooji an, quarng nam"
  ],
  "Cổ Am, Vĩnh Bảo, Hải Phòng": [
    "cổ am, vĩnh bảo, hải phòng",
    "coor am, vixnh baro, hari phofng"
  ],
  "Cổ Linh, Pác Nặm, Bắc Kạn": [
    "cổ linh, pác nặm, bắc kạn",
    "coor linh, pasc nawjm, bawsc kajn"
  ],
  "Cổ Phúc, Trấn Yên, Yên Bái": [
    "cổ phúc, trấn yên, yên bái",
    "coor phusc, traasn yeen, yeen basi"
  ],
  "Cỗ Đạm, Nghi Xuân, Hà Tĩnh": [
    "cỗ đạm, nghi xuân, hà tĩnh",
    "coox ddajm, nghi xuaan, haf tixnh"
  ],
  "Cộng Hòa, Quốc Oai, Hà Nội": [
    "cộng hòa, quốc oai, hà nội",
    "coojng hofa, quoosc oai, haf nooji"
  ],
  "Cờ Đỏ, Cờ Đỏ, Cần Thơ": [
    "cờ đỏ, cờ đỏ, cần thơ",
    "cowf ddor, cowf ddor, caafn thow"
  ],
  "Củ Chi, Củ Chi, Hồ Chí Minh": [
    "củ chi, củ chi, hồ chí minh",
    "cur chi, cur chi, hoof chis minh"
  ],
  "Cửa Nam, Hoàn Kiếm, Hà Nội": [
    "cửa nam, hoàn kiếm, hà nội",
    "cuwra nam, hoafn kieesm, haf nooji"
  ],
  "Cự Khối, Long Biên, Hà Nội": [
    "cự khối, long biên, hà nội",
    "cuwj khoosi, long bieen, haf nooji"
  ],
  "D'Ran, Đơn Dương, Lâm Đồng": [
    "d'ran, đơn dương, lâm đồng",
    "d'ran, ddown duwowng, laam ddoofng"
  ],
  "Dak Mang, Hoài Ân, Bình Định": [
    "dak mang, hoài ân, bình định",
    "dak mang, hoafi aan, bifnh ddijnh"
  ],
  "Diên Lãm, Quỳ Châu, Nghệ An": [
    "diên lãm, quỳ châu, nghệ an",
    "dieen laxm, quyf chaau, ngheej an"
  ],
  "Diễn An, Diễn Châu, Nghệ An": [
    "diễn an, diễn châu, nghệ an",
    "dieexn an, dieexn chaau, ngheej an"
  ],
  "Dliê Yang, Ea H'leo, Đắk Lắk": [
    "dliê yang, ea h'leo, đắk lắk",
    "dliee yang, ea h'leo, ddawsk lawsk"
  ],
  "Duy Châu, Duy Xuyên, Quảng Nam": [
    "duy châu, duy xuyên, quảng nam",
    "duy chaau, duy xuyeen, quarng nam"
  ],
  "Duy Hải, Duy Xuyên, Quảng Nam": [
    "duy hải, duy xuyên, quảng nam",
    "duy hari, duy xuyeen, quarng nam"
  ],
  "Duy Trinh, Duy Xuyên, Quảng Nam": [
    "duy trinh, duy xuyên, quảng nam",
    "duy trinh, duy xuyeen, quarng nam"
  ],
  "Duy Trung, Duy Xuyên, Quảng Nam": [
    "duy trung, duy xuyên, quảng nam",
    "duy trung, duy xuyeen, quarng nam"
  ],
  "Duy Tân, Kinh Môn, Hải Dương": [
    "duy tân, kinh môn, hải dương",
    "duy taan, kinh moon, hari duwowng"
  ],
  "Dân Chủ, Hòa Bình, Hoà Bình": [
    "dân chủ, hòa bình, hoà bình",
    "daan chur, hofa bifnh, hoaf bifnh"
  ],
  "Dân Chủ, Hưng Hà, Thái Bình": [
    "dân chủ, hưng hà, thái bình",
    "daan chur, huwng haf, thasi bifnh"
  ],
  "Dân Lý, Triệu Sơn, Thanh Hóa": [
    "dân lý, triệu sơn, thanh hóa",
    "daan lys, trieeju sown, thanh hosa"
  ],
  "Dũng Phong, Cao Phong, Hoà Bình": [
    "dũng phong, cao phong, hoà bình",
    "duxng phong, cao phong, hoaf bifnh"
  ],
  "Dư Hàng, Lê Chân, Hải Phòng": [
    "dư hàng, lê chân, hải phòng",
    "duw hafng, lee chaan, hari phofng"
  ],
  "Dương Quang, Gia Lâm, Hà Nội": [
    "dương quang, gia lâm, hà nội",
    "duwowng quang, gia laam, haf nooji"
  ],
  "Dương Quỳ, Văn Bàn, Lào Cai": [
    "dương quỳ, văn bàn, lào cai",
    "duwowng quyf, vawn bafn, lafo cai"
  ],
  "Dị Chế, Tiên Lữ, Hưng Yên": [
    "dị chế, tiên lữ, hưng yên",
    "dij chees, tieen luwx, huwng yeen"
  ],
  "Ea Blang, Buôn Hồ, Đắk Lắk": [
    "ea blang, buôn hồ, đắk lắk",
    "ea blang, buoon hoof, ddawsk lawsk"
  ],
  "Ea H'MLay, M'Đrắk, Đắk Lắk": [
    "ea h'mlay, m'đrắk, đắk lắk",
    "ea h'mlay, m'ddrawsk, ddawsk lawsk"
  ],
  "Ea Hiu, Krông Pắc, Đắk Lắk": [
    "ea hiu, krông pắc, đắk lắk",
    "ea hiu, kroong pawsc, ddawsk lawsk"
  ],
  "Ea Huar, Buôn Đôn, Đắk Lắk": [
    "ea huar, buôn đôn, đắk lắk",
    "ea huar, buoon ddoon, ddawsk lawsk"
  ],
  "Ea Kiết, Cư M'gar, Đắk Lắk": [
    "ea kiết, cư m'gar, đắk lắk",
    "ea kieest, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Kly, Krông Pắc, Đắk Lắk": [
    "ea kly, krông pắc, đắk lắk",
    "ea kly, kroong pawsc, ddawsk lawsk"
  ],
  "Ea M'nang, Cư M'gar, Đắk Lắk": [
    "ea m'nang, cư m'gar, đắk lắk",
    "ea m'nang, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Ngai, Krông Búk, Đắk Lắk": [
    "ea ngai, krông búk, đắk lắk",
    "ea ngai, kroong busk, ddawsk lawsk"
  ],
  "Ea Puk, Krông Năng, Đắk Lắk": [
    "ea puk, krông năng, đắk lắk",
    "ea puk, kroong nawng, ddawsk lawsk"
  ],
  "Ea Riêng, M'Đrắk, Đắk Lắk": [
    "ea riêng, m'đrắk, đắk lắk",
    "ea rieeng, m'ddrawsk, ddawsk lawsk"
  ],
  "Ea Siên, Buôn Hồ, Đắk Lắk": [
    "ea siên, buôn hồ, đắk lắk",
    "ea sieen, buoon hoof, ddawsk lawsk"
  ],
  "Ea Tam, Krông Năng, Đắk Lắk": [
    "ea tam, krông năng, đắk lắk",
    "ea tam, kroong nawng, ddawsk lawsk"
  ],
  "Gia Cẩm, Việt Trì, Phú Thọ": [
    "gia cẩm, việt trì, phú thọ",
    "gia caarm, vieejt trif, phus thoj"
  ],
  "Gia Phố, Hương Khê, Hà Tĩnh": [
    "gia phố, hương khê, hà tĩnh",
    "gia phoos, huwowng khee, haf tixnh"
  ],
  "Gia Tiến, Gia Viễn, Ninh Bình": [
    "gia tiến, gia viễn, ninh bình",
    "gia tieesn, gia vieexn, ninh bifnh"
  ],
  "Gia Trấn, Gia Viễn, Ninh Bình": [
    "gia trấn, gia viễn, ninh bình",
    "gia traasn, gia vieexn, ninh bifnh"
  ],
  "Gia Tân, Gia Lộc, Hải Dương": [
    "gia tân, gia lộc, hải dương",
    "gia taan, gia loojc, hari duwowng"
  ],
  "Gia Tường, Nho Quan, Ninh Bình": [
    "gia tường, nho quan, ninh bình",
    "gia tuwowfng, nho quan, ninh bifnh"
  ],
  "Gia Điền, Hạ Hoà, Phú Thọ": [
    "gia điền, hạ hoà, phú thọ",
    "gia ddieefn, haj hoaf, phus thoj"
  ],
  "Giai Phạm, Yên Mỹ, Hưng Yên": [
    "giai phạm, yên mỹ, hưng yên",
    "giai phajm, yeen myx, huwng yeen"
  ],
  "Giang Biên, Long Biên, Hà Nội": [
    "giang biên, long biên, hà nội",
    "giang bieen, long bieen, haf nooji"
  ],
  "Giang Ma, Tam Đường, Lai Châu": [
    "giang ma, tam đường, lai châu",
    "giang ma, tam dduwowfng, lai chaau"
  ],
  "Giao Hà, Giao Thủy, Nam Định": [
    "giao hà, giao thủy, nam định",
    "giao haf, giao thury, nam ddijnh"
  ],
  "Giao Long, Châu Thành, Bến Tre": [
    "giao long, châu thành, bến tre",
    "giao long, chaau thafnh, beesn tre"
  ],
  "Gio Châu, Gio Linh, Quảng Trị": [
    "gio châu, gio linh, quảng trị",
    "gio chaau, gio linh, quarng trij"
  ],
  "Gio Hải, Gio Linh, Quảng Trị": [
    "gio hải, gio linh, quảng trị",
    "gio hari, gio linh, quarng trij"
  ],
  "Gio Quang, Gio Linh, Quảng Trị": [
    "gio quang, gio linh, quảng trị",
    "gio quang, gio linh, quarng trij"
  ],
  "Hai Bà Trưng, Phủ Lý, Hà Nam": [
    "hai bà trưng, phủ lý, hà nam",
    "hai baf truwng, phur lys, haf nam"
  ],
  "Hiến Nam, Hưng Yên, Hưng Yên": [
    "hiến nam, hưng yên, hưng yên",
    "hieesn nam, huwng yeen, huwng yeen"
  ],
  "Hiền Quan, Tam Nông, Phú Thọ": [
    "hiền quan, tam nông, phú thọ",
    "hieefn quan, tam noong, phus thoj"
  ],
  "Hiệp Hòa, Vũ Thư, Thái Bình": [
    "hiệp hòa, vũ thư, thái bình",
    "hieejp hofa, vux thuw, thasi bifnh"
  ],
  "Hoa Lộc, Hậu Lộc, Thanh Hóa": [
    "hoa lộc, hậu lộc, thanh hóa",
    "hoa loojc, haaju loojc, thanh hosa"
  ],
  "Hoa Thành, Yên Thành, Nghệ An": [
    "hoa thành, yên thành, nghệ an",
    "hoa thafnh, yeen thafnh, ngheej an"
  ],
  "Hoà Chung, Cao Bằng, Cao Bằng": [
    "hoà chung, cao bằng, cao bằng",
    "hoaf chung, cao bawfng, cao bawfng"
  ],
  "Hoà Hiếu, Thái Hoà, Nghệ An": [
    "hoà hiếu, thái hoà, nghệ an",
    "hoaf hieesu, thasi hoaf, ngheej an"
  ],
  "Huy Giáp, Bảo Lạc, Cao Bằng": [
    "huy giáp, bảo lạc, cao bằng",
    "huy giasp, baro lajc, cao bawfng"
  ],
  "Hà An, Quảng Yên, Quảng Ninh": [
    "hà an, quảng yên, quảng ninh",
    "haf an, quarng yeen, quarng ninh"
  ],
  "Hà Kỳ, Tứ Kỳ, Hải Dương": [
    "hà kỳ, tứ kỳ, hải dương",
    "haf kyf, tuws kyf, hari duwowng"
  ],
  "Hà Lam, Thăng Bình, Quảng Nam": [
    "hà lam, thăng bình, quảng nam",
    "haf lam, thawng bifnh, quarng nam"
  ],
  "Hà Lâu, Tiên Yên, Quảng Ninh": [
    "hà lâu, tiên yên, quảng ninh",
    "haf laau, tieen yeen, quarng ninh"
  ],
  "Hà Lương, Hạ Hoà, Phú Thọ": [
    "hà lương, hạ hoà, phú thọ",
    "haf luwowng, haj hoaf, phus thoj"
  ],
  "Hà Lầm, Hạ Long, Quảng Ninh": [
    "hà lầm, hạ long, quảng ninh",
    "haf laafm, haj long, quarng ninh"
  ],
  "Hà Phong, Hạ Long, Quảng Ninh": [
    "hà phong, hạ long, quảng ninh",
    "haf phong, haj long, quarng ninh"
  ],
  "Hà Trung, Hạ Long, Quảng Ninh": [
    "hà trung, hạ long, quảng ninh",
    "haf trung, haj long, quarng ninh"
  ],
  "Hàng Gai, Hoàn Kiếm, Hà Nội": [
    "hàng gai, hoàn kiếm, hà nội",
    "hafng gai, hoafn kieesm, haf nooji"
  ],
  "Hàng Mã, Hoàn Kiếm, Hà Nội": [
    "hàng mã, hoàn kiếm, hà nội",
    "hafng max, hoafn kieesm, haf nooji"
  ],
  "Háng Đồng, Bắc Yên, Sơn La": [
    "háng đồng, bắc yên, sơn la",
    "hasng ddoofng, bawsc yeen, sown la"
  ],
  "Hát Lìu, Trạm Tấu, Yên Bái": [
    "hát lìu, trạm tấu, yên bái",
    "hast lifu, trajm taasu, yeen basi"
  ],
  "Hòa An, Chiêm Hóa, Tuyên Quang": [
    "hòa an, chiêm hóa, tuyên quang",
    "hofa an, chieem hosa, tuyeen quang"
  ],
  "Hòa An, Thái Thụy, Thái Bình": [
    "hòa an, thái thụy, thái bình",
    "hofa an, thasi thujy, thasi bifnh"
  ],
  "Hòa Bình 1, Tây Hoà, Phú Yên": [
    "hòa bình 1, tây hoà, phú yên",
    "hofa bifnh 1, taay hoaf, phus yeen"
  ],
  "Hòa Bình, Bình Gia, Lạng Sơn": [
    "hòa bình, bình gia, lạng sơn",
    "hofa bifnh, bifnh gia, lajng sown"
  ],
  "Hòa Bình, Chi Lăng, Lạng Sơn": [
    "hòa bình, chi lăng, lạng sơn",
    "hofa bifnh, chi lawng, lajng sown"
  ],
  "Hòa Bình, Hòa Bình, Hoà Bình": [
    "hòa bình, hòa bình, hoà bình",
    "hofa bifnh, hofa bifnh, hoaf bifnh"
  ],
  "Hòa Bình, Hưng Hà, Thái Bình": [
    "hòa bình, hưng hà, thái bình",
    "hofa bifnh, huwng haf, thasi bifnh"
  ],
  "Hòa Bình, Văn Quan, Lạng Sơn": [
    "hòa bình, văn quan, lạng sơn",
    "hofa bifnh, vawn quan, lajng sown"
  ],
  "Hòa Bắc, Hòa Vang, Đà Nẵng": [
    "hòa bắc, hòa vang, đà nẵng",
    "hofa bawsc, hofa vang, ddaf nawxng"
  ],
  "Hòa Châu, Hòa Vang, Đà Nẵng": [
    "hòa châu, hòa vang, đà nẵng",
    "hofa chaau, hofa vang, ddaf nawxng"
  ],
  "Hòa Hiệp, Tam Bình, Vĩnh Long": [
    "hòa hiệp, tam bình, vĩnh long",
    "hofa hieejp, tam bifnh, vixnh long"
  ],
  "Hòa Hiệp, Tân Biên, Tây Ninh": [
    "hòa hiệp, tân biên, tây ninh",
    "hofa hieejp, taan bieen, taay ninh"
  ],
  "Hòa Hưng, Cái Bè, Tiền Giang": [
    "hòa hưng, cái bè, tiền giang",
    "hofa huwng, casi bef, tieefn giang"
  ],
  "Hòa Khê, Thanh Khê, Đà Nẵng": [
    "hòa khê, thanh khê, đà nẵng",
    "hofa khee, thanh khee, ddaf nawxng"
  ],
  "Hòa Liên, Hòa Vang, Đà Nẵng": [
    "hòa liên, hòa vang, đà nẵng",
    "hofa lieen, hofa vang, ddaf nawxng"
  ],
  "Hòa Long, Lai Vung, Đồng Tháp": [
    "hòa long, lai vung, đồng tháp",
    "hofa long, lai vung, ddoofng thasp"
  ],
  "Hòa Minh, Châu Thành, Trà Vinh": [
    "hòa minh, châu thành, trà vinh",
    "hofa minh, chaau thafnh, traf vinh"
  ],
  "Hòa Nhơn, Hòa Vang, Đà Nẵng": [
    "hòa nhơn, hòa vang, đà nẵng",
    "hofa nhown, hofa vang, ddaf nawxng"
  ],
  "Hòa Phong, Hòa Vang, Đà Nẵng": [
    "hòa phong, hòa vang, đà nẵng",
    "hofa phong, hofa vang, ddaf nawxng"
  ],
  "Hòa Sơn, Ninh Sơn, Ninh Thuận": [
    "hòa sơn, ninh sơn, ninh thuận",
    "hofa sown, ninh sown, ninh thuaajn"
  ],
  "Hòa Sơn, Đô Lương, Nghệ An": [
    "hòa sơn, đô lương, nghệ an",
    "hofa sown, ddoo luwowng, ngheej an"
  ],
  "Hòa Thắng, Phú Hoà, Phú Yên": [
    "hòa thắng, phú hoà, phú yên",
    "hofa thawsng, phus hoaf, phus yeen"
  ],
  "Hòa Thịnh, Tây Hoà, Phú Yên": [
    "hòa thịnh, tây hoà, phú yên",
    "hofa thijnh, taay hoaf, phus yeen"
  ],
  "Hòa Đồng, Tây Hoà, Phú Yên": [
    "hòa đồng, tây hoà, phú yên",
    "hofa ddoofng, taay hoaf, phus yeen"
  ],
  "Hòn Tre, Kiên Hải, Kiên Giang": [
    "hòn tre, kiên hải, kiên giang",
    "hofn tre, kieen hari, kieen giang"
  ],
  "Hóa Quỳ, Như Xuân, Thanh Hóa": [
    "hóa quỳ, như xuân, thanh hóa",
    "hosa quyf, nhuw xuaan, thanh hosa"
  ],
  "Hùng Lô, Việt Trì, Phú Thọ": [
    "hùng lô, việt trì, phú thọ",
    "hufng loo, vieejt trif, phus thoj"
  ],
  "Hùng Tiến, Kim Sơn, Ninh Bình": [
    "hùng tiến, kim sơn, ninh bình",
    "hufng tieesn, kim sown, ninh bifnh"
  ],
  "Hùng Tiến, Nam Đàn, Nghệ An": [
    "hùng tiến, nam đàn, nghệ an",
    "hufng tieesn, nam ddafn, ngheej an"
  ],
  "Húc, Hướng Hóa, Quảng Trị": [
    "húc, hướng hóa, quảng trị",
    "husc, huwowsng hosa, quarng trij"
  ],
  "Hưng Long, Yên Lập, Phú Thọ": [
    "hưng long, yên lập, phú thọ",
    "huwng long, yeen laajp, phus thoj"
  ],
  "Hưng Phú, Cái Răng, Cần Thơ": [
    "hưng phú, cái răng, cần thơ",
    "huwng phus, casi rawng, caafn thow"
  ],
  "Hưng Thạnh, Tân Hưng, Long An": [
    "hưng thạnh, tân hưng, long an",
    "huwng thajnh, taan huwng, long an"
  ],
  "Hưng Vũ, Bắc Sơn, Lạng Sơn": [
    "hưng vũ, bắc sơn, lạng sơn",
    "huwng vux, bawsc sown, lajng sown"
  ],
  "Hưng Điền, Tân Hưng, Long An": [
    "hưng điền, tân hưng, long an",
    "huwng ddieefn, taan huwng, long an"
  ],
  "Hương Minh, Vũ Quang, Hà Tĩnh": [
    "hương minh, vũ quang, hà tĩnh",
    "huwowng minh, vux quang, haf tixnh"
  ],
  "Hương Sơn, Tân Kỳ, Nghệ An": [
    "hương sơn, tân kỳ, nghệ an",
    "huwowng sown, taan kyf, ngheej an"
  ],
  "Hải An, Hải Hậu, Nam Định": [
    "hải an, hải hậu, nam định",
    "hari an, hari haaju, nam ddijnh"
  ],
  "Hải Bình, Tĩnh Gia, Thanh Hóa": [
    "hải bình, tĩnh gia, thanh hóa",
    "hari bifnh, tixnh gia, thanh hosa"
  ],
  "Hải Bối, Đông Anh, Hà Nội": [
    "hải bối, đông anh, hà nội",
    "hari boosi, ddoong anh, haf nooji"
  ],
  "Hải Châu, Tĩnh Gia, Thanh Hóa": [
    "hải châu, tĩnh gia, thanh hóa",
    "hari chaau, tixnh gia, thanh hosa"
  ],
  "Hải Long, Như Thanh, Thanh Hóa": [
    "hải long, như thanh, thanh hóa",
    "hari long, nhuw thanh, thanh hosa"
  ],
  "Hải Lĩnh, Tĩnh Gia, Thanh Hóa": [
    "hải lĩnh, tĩnh gia, thanh hóa",
    "hari lixnh, tixnh gia, thanh hosa"
  ],
  "Hải Nhân, Tĩnh Gia, Thanh Hóa": [
    "hải nhân, tĩnh gia, thanh hóa",
    "hari nhaan, tixnh gia, thanh hosa"
  ],
  "Hải Thanh, Tĩnh Gia, Thanh Hóa": [
    "hải thanh, tĩnh gia, thanh hóa",
    "hari thanh, tixnh gia, thanh hosa"
  ],
  "Hải Yến, Tĩnh Gia, Thanh Hóa": [
    "hải yến, tĩnh gia, thanh hóa",
    "hari yeesn, tixnh gia, thanh hosa"
  ],
  "Hậu Lộc, Tam Bình, Vĩnh Long": [
    "hậu lộc, tam bình, vĩnh long",
    "haaju loojc, tam bifnh, vixnh long"
  ],
  "Hậu Nghĩa, Đức Hòa, Long An": [
    "hậu nghĩa, đức hòa, long an",
    "haaju nghixa, dduwsc hofa, long an"
  ],
  "Hồ Sơn, Tam Đảo, Vĩnh Phúc": [
    "hồ sơn, tam đảo, vĩnh phúc",
    "hoof sown, tam ddaro, vixnh phusc"
  ],
  "Hồi Xuân, Quan Hóa, Thanh Hóa": [
    "hồi xuân, quan hóa, thanh hóa",
    "hoofi xuaan, quan hosa, thanh hosa"
  ],
  "Hồng An, Bảo Lạc, Cao Bằng": [
    "hồng an, bảo lạc, cao bằng",
    "hoofng an, baro lajc, cao bawfng"
  ],
  "Hồng Lộc, Lộc Hà, Hà Tĩnh": [
    "hồng lộc, lộc hà, hà tĩnh",
    "hoofng loojc, loojc haf, haf tixnh"
  ],
  "Hồng Nam, Hưng Yên, Hưng Yên": [
    "hồng nam, hưng yên, hưng yên",
    "hoofng nam, huwng yeen, huwng yeen"
  ],
  "Hồng Việt, Hoà An, Cao Bằng": [
    "hồng việt, hoà an, cao bằng",
    "hoofng vieejt, hoaf an, cao bawfng"
  ],
  "Hộ Phòng, Giá Rai, Bạc Liêu": [
    "hộ phòng, giá rai, bạc liêu",
    "hooj phofng, gias rai, bajc lieeu"
  ],
  "Hợp Phong, Cao Phong, Hoà Bình": [
    "hợp phong, cao phong, hoà bình",
    "howjp phong, cao phong, hoaf bifnh"
  ],
  "Hợp Tiến, Kim Bôi, Hoà Bình": [
    "hợp tiến, kim bôi, hoà bình",
    "howjp tieesn, kim booi, hoaf bifnh"
  ],
  "Hữu Kiệm, Kỳ Sơn, Nghệ An": [
    "hữu kiệm, kỳ sơn, nghệ an",
    "huwxu kieejm, kyf sown, ngheej an"
  ],
  "Hữu Lễ, Văn Quan, Lạng Sơn": [
    "hữu lễ, văn quan, lạng sơn",
    "huwxu leex, vawn quan, lajng sown"
  ],
  "Hựu Thành, Trà Ôn, Vĩnh Long": [
    "hựu thành, trà ôn, vĩnh long",
    "huwju thafnh, traf oon, vixnh long"
  ],
  "Khai Thái, Phú Xuyên, Hà Nội": [
    "khai thái, phú xuyên, hà nội",
    "khai thasi, phus xuyeen, haf nooji"
  ],
  "Khun Há, Tam Đường, Lai Châu": [
    "khun há, tam đường, lai châu",
    "khun has, tam dduwowfng, lai chaau"
  ],
  "Khánh An, Yên Khánh, Ninh Bình": [
    "khánh an, yên khánh, ninh bình",
    "khasnh an, yeen khasnh, ninh bifnh"
  ],
  "Khánh Hoà, Lục Yên, Yên Bái": [
    "khánh hoà, lục yên, yên bái",
    "khasnh hoaf, lujc yeen, yeen basi"
  ],
  "Khánh Hưng, Vĩnh Hưng, Long An": [
    "khánh hưng, vĩnh hưng, long an",
    "khasnh huwng, vixnh huwng, long an"
  ],
  "Khải Xuân, Thanh Ba, Phú Thọ": [
    "khải xuân, thanh ba, phú thọ",
    "khari xuaan, thanh ba, phus thoj"
  ],
  "Kim Anh, Kim Thành, Hải Dương": [
    "kim anh, kim thành, hải dương",
    "kim anh, kim thafnh, hari duwowng"
  ],
  "Kim Chung, Hoài Đức, Hà Nội": [
    "kim chung, hoài đức, hà nội",
    "kim chung, hoafi dduwsc, haf nooji"
  ],
  "Kim Long, Tam Dương, Vĩnh Phúc": [
    "kim long, tam dương, vĩnh phúc",
    "kim long, tam duwowng, vixnh phusc"
  ],
  "Kim Ngọc, Bắc Quang, Hà Giang": [
    "kim ngọc, bắc quang, hà giang",
    "kim ngojc, bawsc quang, haf giang"
  ],
  "Kim Thành, Yên Thành, Nghệ An": [
    "kim thành, yên thành, nghệ an",
    "kim thafnh, yeen thafnh, ngheej an"
  ],
  "Kim Thái, Vụ Bản, Nam Định": [
    "kim thái, vụ bản, nam định",
    "kim thasi, vuj barn, nam ddijnh"
  ],
  "Kinh Bắc, Bắc Ninh, Bắc Ninh": [
    "kinh bắc, bắc ninh, bắc ninh",
    "kinh bawsc, bawsc ninh, bawsc ninh"
  ],
  "Kiệt Sơn, Tân Sơn, Phú Thọ": [
    "kiệt sơn, tân sơn, phú thọ",
    "kieejt sown, taan sown, phus thoj"
  ],
  "Krông Á, M'Đrắk, Đắk Lắk": [
    "krông á, m'đrắk, đắk lắk",
    "kroong as, m'ddrawsk, ddawsk lawsk"
  ],
  "Kông Lơng Khơng, KBang, Gia Lai": [
    "kông lơng khơng, kbang, gia lai",
    "koong lowng khowng, kbang, gia lai"
  ],
  "Kỳ Bá, Thái Bình, Thái Bình": [
    "kỳ bá, thái bình, thái bình",
    "kyf bas, thasi bifnh, thasi bifnh"
  ],
  "Kỳ Phương, Kỳ Anh, Hà Tĩnh": [
    "kỳ phương, kỳ anh, hà tĩnh",
    "kyf phuwowng, kyf anh, haf tixnh"
  ],
  "Lai Hòa, Vĩnh Châu, Sóc Trăng": [
    "lai hòa, vĩnh châu, sóc trăng",
    "lai hofa, vixnh chaau, sosc trawng"
  ],
  "Lai Hạ, Lương Tài, Bắc Ninh": [
    "lai hạ, lương tài, bắc ninh",
    "lai haj, luwowng tafi, bawsc ninh"
  ],
  "Lai Đồng, Tân Sơn, Phú Thọ": [
    "lai đồng, tân sơn, phú thọ",
    "lai ddoofng, taan sown, phus thoj"
  ],
  "Lam Sơn, Ngọc Lặc, Thanh Hóa": [
    "lam sơn, ngọc lặc, thanh hóa",
    "lam sown, ngojc lawjc, thanh hosa"
  ],
  "Lan Giới, Tân Yên, Bắc Giang": [
    "lan giới, tân yên, bắc giang",
    "lan giowsi, taan yeen, bawsc giang"
  ],
  "Lao Chải, Vị Xuyên, Hà Giang": [
    "lao chải, vị xuyên, hà giang",
    "lao chari, vij xuyeen, haf giang"
  ],
  "Liên Bạt, Ứng Hòa, Hà Nội": [
    "liên bạt, ứng hòa, hà nội",
    "lieen bajt, uwsng hofa, haf nooji"
  ],
  "Liên Sơn, Chi Lăng, Lạng Sơn": [
    "liên sơn, chi lăng, lạng sơn",
    "lieen sown, chi lawng, lajng sown"
  ],
  "Liên Sơn, Gia Viễn, Ninh Bình": [
    "liên sơn, gia viễn, ninh bình",
    "lieen sown, gia vieexn, ninh bifnh"
  ],
  "Liên Sơn, Tân Yên, Bắc Giang": [
    "liên sơn, tân yên, bắc giang",
    "lieen sown, taan yeen, bawsc giang"
  ],
  "Liễu Đô, Lục Yên, Yên Bái": [
    "liễu đô, lục yên, yên bái",
    "lieexu ddoo, lujc yeen, yeen basi"
  ],
  "Liệp Tè, Thuận Châu, Sơn La": [
    "liệp tè, thuận châu, sơn la",
    "lieejp tef, thuaajn chaau, sown la"
  ],
  "Long Bình, Long Mỹ, Hậu Giang": [
    "long bình, long mỹ, hậu giang",
    "long bifnh, long myx, haaju giang"
  ],
  "Long Bình, Ngã Năm, Sóc Trăng": [
    "long bình, ngã năm, sóc trăng",
    "long bifnh, ngax nawm, sosc trawng"
  ],
  "Long Cang, Cần Đước, Long An": [
    "long cang, cần đước, long an",
    "long cang, caafn dduwowsc, long an"
  ],
  "Long Châu, Yên Phong, Bắc Ninh": [
    "long châu, yên phong, bắc ninh",
    "long chaau, yeen phong, bawsc ninh"
  ],
  "Long Chữ, Bến Cầu, Tây Ninh": [
    "long chữ, bến cầu, tây ninh",
    "long chuwx, beesn caafu, taay ninh"
  ],
  "Long Giang, Bến Cầu, Tây Ninh": [
    "long giang, bến cầu, tây ninh",
    "long giang, beesn caafu, taay ninh"
  ],
  "Long Giao, Cẩm Mỹ, Đồng Nai": [
    "long giao, cẩm mỹ, đồng nai",
    "long giao, caarm myx, ddoofng nai"
  ],
  "Long Hòa, Bình Đại, Bến Tre": [
    "long hòa, bình đại, bến tre",
    "long hofa, bifnh ddaji, beesn tre"
  ],
  "Long Hòa, Châu Thành, Trà Vinh": [
    "long hòa, châu thành, trà vinh",
    "long hofa, chaau thafnh, traf vinh"
  ],
  "Long Hòa, Cần Đước, Long An": [
    "long hòa, cần đước, long an",
    "long hofa, caafn dduwowsc, long an"
  ],
  "Long Hòa, Gò Công, Tiền Giang": [
    "long hòa, gò công, tiền giang",
    "long hofa, gof coong, tieefn giang"
  ],
  "Long Hưng, Văn Giang, Hưng Yên": [
    "long hưng, văn giang, hưng yên",
    "long huwng, vawn giang, huwng yeen"
  ],
  "Long Hậu, Cần Giuộc, Long An": [
    "long hậu, cần giuộc, long an",
    "long haaju, caafn giuoojc, long an"
  ],
  "Long Khê, Cần Đước, Long An": [
    "long khê, cần đước, long an",
    "long khee, caafn dduwowsc, long an"
  ],
  "Long Kiến, Chợ Mới, An Giang": [
    "long kiến, chợ mới, an giang",
    "long kieesn, chowj mowsi, an giang"
  ],
  "Long Mai, Minh Long, Quảng Ngãi": [
    "long mai, minh long, quảng ngãi",
    "long mai, minh long, quarng ngaxi"
  ],
  "Long Sơn, Cần Đước, Long An": [
    "long sơn, cần đước, long an",
    "long sown, caafn dduwowsc, long an"
  ],
  "Long Thạnh, Tân Châu, An Giang": [
    "long thạnh, tân châu, an giang",
    "long thajnh, taan chaau, an giang"
  ],
  "Long Trị, Long Mỹ, Hậu Giang": [
    "long trị, long mỹ, hậu giang",
    "long trij, long myx, haaju giang"
  ],
  "Long Xá, Hưng Nguyên, Nghệ An": [
    "long xá, hưng nguyên, nghệ an",
    "long xas, huwng nguyeen, ngheej an"
  ],
  "Láng Hạ, Đống Đa, Hà Nội": [
    "láng hạ, đống đa, hà nội",
    "lasng haj, ddoosng dda, haf nooji"
  ],
  "Láng Tròn, Giá Rai, Bạc Liêu": [
    "láng tròn, giá rai, bạc liêu",
    "lasng trofn, gias rai, bajc lieeu"
  ],
  "Lâm Ca, Đình Lập, Lạng Sơn": [
    "lâm ca, đình lập, lạng sơn",
    "laam ca, ddifnh laajp, lajng sown"
  ],
  "Lâm Phú, Lang Chánh, Thanh Hóa": [
    "lâm phú, lang chánh, thanh hóa",
    "laam phus, lang chasnh, thanh hosa"
  ],
  "Lâm Sơn, Ninh Sơn, Ninh Thuận": [
    "lâm sơn, ninh sơn, ninh thuận",
    "laam sown, ninh sown, ninh thuaajn"
  ],
  "Lãng Ngâm, Gia Bình, Bắc Ninh": [
    "lãng ngâm, gia bình, bắc ninh",
    "laxng ngaam, gia bifnh, bawsc ninh"
  ],
  "Lão Hộ, Yên Dũng, Bắc Giang": [
    "lão hộ, yên dũng, bắc giang",
    "laxo hooj, yeen duxng, bawsc giang"
  ],
  "Lê Lợi, Hạ Long, Quảng Ninh": [
    "lê lợi, hạ long, quảng ninh",
    "lee lowji, haj long, quarng ninh"
  ],
  "Lê Ninh, Kinh Môn, Hải Dương": [
    "lê ninh, kinh môn, hải dương",
    "lee ninh, kinh moon, hari duwowng"
  ],
  "Lìa, Hướng Hóa, Quảng Trị": [
    "lìa, hướng hóa, quảng trị",
    "lifa, huwowsng hosa, quarng trij"
  ],
  "Lóng Phiêng, Yên Châu, Sơn La": [
    "lóng phiêng, yên châu, sơn la",
    "losng phieeng, yeen chaau, sown la"
  ],
  "Lùng Thàng, Sìn Hồ, Lai Châu": [
    "lùng thàng, sìn hồ, lai châu",
    "lufng thafng, sifn hoof, lai chaau"
  ],
  "Lùng Tám, Quản Bạ, Hà Giang": [
    "lùng tám, quản bạ, hà giang",
    "lufng tasm, quarn baj, haf giang"
  ],
  "Lý Thành, Yên Thành, Nghệ An": [
    "lý thành, yên thành, nghệ an",
    "lys thafnh, yeen thafnh, ngheej an"
  ],
  "Lũng Chinh, Mèo Vạc, Hà Giang": [
    "lũng chinh, mèo vạc, hà giang",
    "luxng chinh, mefo vajc, haf giang"
  ],
  "Lũng Cú, Đồng Văn, Hà Giang": [
    "lũng cú, đồng văn, hà giang",
    "luxng cus, ddoofng vawn, haf giang"
  ],
  "Lưu Hoàng, Ứng Hòa, Hà Nội": [
    "lưu hoàng, ứng hòa, hà nội",
    "luwu hoafng, uwsng hofa, haf nooji"
  ],
  "Lưu Sơn, Đô Lương, Nghệ An": [
    "lưu sơn, đô lương, nghệ an",
    "luwu sown, ddoo luwowng, ngheej an"
  ],
  "Lương Hòa, Bến Lức, Long An": [
    "lương hòa, bến lức, long an",
    "luwowng hofa, beesn luwsc, long an"
  ],
  "Lương Lỗ, Thanh Ba, Phú Thọ": [
    "lương lỗ, thanh ba, phú thọ",
    "luwowng loox, thanh ba, phus thoj"
  ],
  "Lương Sơn, Bảo Yên, Lào Cai": [
    "lương sơn, bảo yên, lào cai",
    "luwowng sown, baro yeen, lafo cai"
  ],
  "Lạng Khê, Con Cuông, Nghệ An": [
    "lạng khê, con cuông, nghệ an",
    "lajng khee, con cuoong, ngheej an"
  ],
  "Lạng Phong, Nho Quan, Ninh Bình": [
    "lạng phong, nho quan, ninh bình",
    "lajng phong, nho quan, ninh bifnh"
  ],
  "Lộc An, Bảo Lâm, Lâm Đồng": [
    "lộc an, bảo lâm, lâm đồng",
    "loojc an, baro laam, laam ddoofng"
  ],
  "Lộc An, Long Thành, Đồng Nai": [
    "lộc an, long thành, đồng nai",
    "loojc an, long thafnh, ddoofng nai"
  ],
  "Lộc An, Nam Định, Nam Định": [
    "lộc an, nam định, nam định",
    "loojc an, nam ddijnh, nam ddijnh"
  ],
  "Lộc Yên, Cao Lộc, Lạng Sơn": [
    "lộc yên, cao lộc, lạng sơn",
    "loojc yeen, cao loojc, lajng sown"
  ],
  "Lục Sơn, Lục Nam, Bắc Giang": [
    "lục sơn, lục nam, bắc giang",
    "lujc sown, lujc nam, bawsc giang"
  ],
  "M'Đrắk, M'Đrắk, Đắk Lắk": [
    "m'đrắk, m'đrắk, đắk lắk",
    "m'ddrawsk, m'ddrawsk, ddawsk lawsk"
  ],
  "Mai Động, Hoàng Mai, Hà Nội": [
    "mai động, hoàng mai, hà nội",
    "mai ddoojng, hoafng mai, haf nooji"
  ],
  "Minh Cầm, Ba Chẽ, Quảng Ninh": [
    "minh cầm, ba chẽ, quảng ninh",
    "minh caafm, ba chex, quarng ninh"
  ],
  "Minh Dân, Hàm Yên, Tuyên Quang": [
    "minh dân, hàm yên, tuyên quang",
    "minh daan, hafm yeen, tuyeen quang"
  ],
  "Minh Hoàng, Phù Cừ, Hưng Yên": [
    "minh hoàng, phù cừ, hưng yên",
    "minh hoafng, phuf cuwf, huwng yeen"
  ],
  "Minh Hợp, Quỳ Hợp, Nghệ An": [
    "minh hợp, quỳ hợp, nghệ an",
    "minh howjp, quyf howjp, ngheej an"
  ],
  "Minh Khai, Hoài Đức, Hà Nội": [
    "minh khai, hoài đức, hà nội",
    "minh khai, hoafi dduwsc, haf nooji"
  ],
  "Minh Phú, Đoan Hùng, Phú Thọ": [
    "minh phú, đoan hùng, phú thọ",
    "minh phus, ddoan hufng, phus thoj"
  ],
  "Minh Quán, Trấn Yên, Yên Bái": [
    "minh quán, trấn yên, yên bái",
    "minh quasn, traasn yeen, yeen basi"
  ],
  "Minh Quân, Trấn Yên, Yên Bái": [
    "minh quân, trấn yên, yên bái",
    "minh quaan, traasn yeen, yeen basi"
  ],
  "Minh Sơn, Đô Lương, Nghệ An": [
    "minh sơn, đô lương, nghệ an",
    "minh sown, ddoo luwowng, ngheej an"
  ],
  "Minh Tiến, Lục Yên, Yên Bái": [
    "minh tiến, lục yên, yên bái",
    "minh tieesn, lujc yeen, yeen basi"
  ],
  "Minh Tiến, Phù Cừ, Hưng Yên": [
    "minh tiến, phù cừ, hưng yên",
    "minh tieesn, phuf cuwf, huwng yeen"
  ],
  "Minh Tân, Vĩnh Lộc, Thanh Hóa": [
    "minh tân, vĩnh lộc, thanh hóa",
    "minh taan, vixnh loojc, thanh hosa"
  ],
  "Minh Tân, Vụ Bản, Nam Định": [
    "minh tân, vụ bản, nam định",
    "minh taan, vuj barn, nam ddijnh"
  ],
  "Minh Đức, Mỹ Hào, Hưng Yên": [
    "minh đức, mỹ hào, hưng yên",
    "minh dduwsc, myx hafo, huwng yeen"
  ],
  "Minh Đức, Ứng Hòa, Hà Nội": [
    "minh đức, ứng hòa, hà nội",
    "minh dduwsc, uwsng hofa, haf nooji"
  ],
  "Mân Thái, Sơn Trà, Đà Nẵng": [
    "mân thái, sơn trà, đà nẵng",
    "maan thasi, sown traf, ddaf nawxng"
  ],
  "Mã Thành, Yên Thành, Nghệ An": [
    "mã thành, yên thành, nghệ an",
    "max thafnh, yeen thafnh, ngheej an"
  ],
  "Mã Đà, Vĩnh Cửu, Đồng Nai": [
    "mã đà, vĩnh cửu, đồng nai",
    "max ddaf, vixnh cuwru, ddoofng nai"
  ],
  "Mê Pu, Đức Linh, Bình Thuận": [
    "mê pu, đức linh, bình thuận",
    "mee pu, dduwsc linh, bifnh thuaajn"
  ],
  "Mông Hóa, Hòa Bình, Hoà Bình": [
    "mông hóa, hòa bình, hoà bình",
    "moong hosa, hofa bifnh, hoaf bifnh"
  ],
  "Mường Bú, Mường La, Sơn La": [
    "mường bú, mường la, sơn la",
    "muwowfng bus, muwowfng la, sown la"
  ],
  "Mường Bằng, Mai Sơn, Sơn La": [
    "mường bằng, mai sơn, sơn la",
    "muwowfng bawfng, mai sown, sown la"
  ],
  "Mường Khoa, Bắc Yên, Sơn La": [
    "mường khoa, bắc yên, sơn la",
    "muwowfng khoa, bawsc yeen, sown la"
  ],
  "Mường Lầm, Sông Mã, Sơn La": [
    "mường lầm, sông mã, sơn la",
    "muwowfng laafm, soong max, sown la"
  ],
  "Mường Và, Sốp Cộp, Sơn La": [
    "mường và, sốp cộp, sơn la",
    "muwowfng vaf, soosp coojp, sown la"
  ],
  "Mẫu Sơn, Cao Lộc, Lạng Sơn": [
    "mẫu sơn, cao lộc, lạng sơn",
    "maaxu sown, cao loojc, lajng sown"
  ],
  "Mậu Lâm, Như Thanh, Thanh Hóa": [
    "mậu lâm, như thanh, thanh hóa",
    "maaju laam, nhuw thanh, thanh hosa"
  ],
  "Mậu Đông, Văn Yên, Yên Bái": [
    "mậu đông, văn yên, yên bái",
    "maaju ddoong, vawn yeen, yeen basi"
  ],
  "Mộ Đạo, Quế Võ, Bắc Ninh": [
    "mộ đạo, quế võ, bắc ninh",
    "mooj ddajo, quees vox, bawsc ninh"
  ],
  "Mỹ An, Lục Ngạn, Bắc Giang": [
    "mỹ an, lục ngạn, bắc giang",
    "myx an, lujc ngajn, bawsc giang"
  ],
  "Mỹ Bình, Ngã Năm, Sóc Trăng": [
    "mỹ bình, ngã năm, sóc trăng",
    "myx bifnh, ngax nawm, sosc trawng"
  ],
  "Mỹ Hiệp, Chợ Mới, An Giang": [
    "mỹ hiệp, chợ mới, an giang",
    "myx hieejp, chowj mowsi, an giang"
  ],
  "Mỹ Hội, Cái Bè, Tiền Giang": [
    "mỹ hội, cái bè, tiền giang",
    "myx hooji, casi bef, tieefn giang"
  ],
  "Mỹ Khánh, Long Xuyên, An Giang": [
    "mỹ khánh, long xuyên, an giang",
    "myx khasnh, long xuyeen, an giang"
  ],
  "Mỹ Long, Cai Lậy, Tiền Giang": [
    "mỹ long, cai lậy, tiền giang",
    "myx long, cai laajy, tieefn giang"
  ],
  "Mỹ Luông, Chợ Mới, An Giang": [
    "mỹ luông, chợ mới, an giang",
    "myx luoong, chowj mowsi, an giang"
  ],
  "Mỹ Lệ, Cần Đước, Long An": [
    "mỹ lệ, cần đước, long an",
    "myx leej, caafn dduwowsc, long an"
  ],
  "Mỹ Lộc, Cần Giuộc, Long An": [
    "mỹ lộc, cần giuộc, long an",
    "myx loojc, caafn giuoojc, long an"
  ],
  "Mỹ Phong, Mỹ Tho, Tiền Giang": [
    "mỹ phong, mỹ tho, tiền giang",
    "myx phong, myx tho, tieefn giang"
  ],
  "Mỹ Sơn, Ninh Sơn, Ninh Thuận": [
    "mỹ sơn, ninh sơn, ninh thuận",
    "myx sown, ninh sown, ninh thuaajn"
  ],
  "Mỹ Sơn, Đô Lương, Nghệ An": [
    "mỹ sơn, đô lương, nghệ an",
    "myx sown, ddoo luwowng, ngheej an"
  ],
  "Mỹ Thới, Long Xuyên, An Giang": [
    "mỹ thới, long xuyên, an giang",
    "myx thowsi, long xuyeen, an giang"
  ],
  "Mỹ Trung, Cái Bè, Tiền Giang": [
    "mỹ trung, cái bè, tiền giang",
    "myx trung, casi bef, tieefn giang"
  ],
  "Mỹ Tân, Mỹ Lộc, Nam Định": [
    "mỹ tân, mỹ lộc, nam định",
    "myx taan, myx loojc, nam ddijnh"
  ],
  "Mỹ Xuyên, Long Xuyên, An Giang": [
    "mỹ xuyên, long xuyên, an giang",
    "myx xuyeen, long xuyeen, an giang"
  ],
  "Mỹ Xá, Nam Định, Nam Định": [
    "mỹ xá, nam định, nam định",
    "myx xas, nam ddijnh, nam ddijnh"
  ],
  "Mỹ Đức, An Lão, Hải Phòng": [
    "mỹ đức, an lão, hải phòng",
    "myx dduwsc, an laxo, hari phofng"
  ],
  "Na Mao, Đại Từ, Thái Nguyên": [
    "na mao, đại từ, thái nguyên",
    "na mao, ddaji tuwf, thasi nguyeen"
  ],
  "Nam Cường, Yên Bái, Yên Bái": [
    "nam cường, yên bái, yên bái",
    "nam cuwowfng, yeen basi, yeen basi"
  ],
  "Nam Giang, Nam Trực, Nam Định": [
    "nam giang, nam trực, nam định",
    "nam giang, nam truwjc, nam ddijnh"
  ],
  "Nam Giang, Thọ Xuân, Thanh Hóa": [
    "nam giang, thọ xuân, thanh hóa",
    "nam giang, thoj xuaan, thanh hosa"
  ],
  "Nam Hà, Tiền Hải, Thái Bình": [
    "nam hà, tiền hải, thái bình",
    "nam haf, tieefn hari, thasi bifnh"
  ],
  "Nam Hùng, Nam Trực, Nam Định": [
    "nam hùng, nam trực, nam định",
    "nam hufng, nam truwjc, nam ddijnh"
  ],
  "Nam Hải, Nam Trực, Nam Định": [
    "nam hải, nam trực, nam định",
    "nam hari, nam truwjc, nam ddijnh"
  ],
  "Nam Lợi, Nam Trực, Nam Định": [
    "nam lợi, nam trực, nam định",
    "nam lowji, nam truwjc, nam ddijnh"
  ],
  "Nam Ngạn, Thanh Hóa, Thanh Hóa": [
    "nam ngạn, thanh hóa, thanh hóa",
    "nam ngajn, thanh hosa, thanh hosa"
  ],
  "Nam Ninh, Cát Tiên, Lâm Đồng": [
    "nam ninh, cát tiên, lâm đồng",
    "nam ninh, cast tieen, laam ddoofng"
  ],
  "Nam Quan, Lộc Bình, Lạng Sơn": [
    "nam quan, lộc bình, lạng sơn",
    "nam quan, loojc bifnh, lajng sown"
  ],
  "Nam Sơn, An Dương, Hải Phòng": [
    "nam sơn, an dương, hải phòng",
    "nam sown, an duwowng, hari phofng"
  ],
  "Nam Thanh, Nam Trực, Nam Định": [
    "nam thanh, nam trực, nam định",
    "nam thanh, nam truwjc, nam ddijnh"
  ],
  "Nam Thành, Ninh Bình, Ninh Bình": [
    "nam thành, ninh bình, ninh bình",
    "nam thafnh, ninh bifnh, ninh bifnh"
  ],
  "Nam Thành, Yên Thành, Nghệ An": [
    "nam thành, yên thành, nghệ an",
    "nam thafnh, yeen thafnh, ngheej an"
  ],
  "Nam Thái A, An Biên, Kiên Giang": [
    "nam thái a, an biên, kiên giang",
    "nam thasi a, an bieen, kieen giang"
  ],
  "Nam Thái, Nam Trực, Nam Định": [
    "nam thái, nam trực, nam định",
    "nam thasi, nam truwjc, nam ddijnh"
  ],
  "Nam Tiến, Phú Xuyên, Hà Nội": [
    "nam tiến, phú xuyên, hà nội",
    "nam tieesn, phus xuyeen, haf nooji"
  ],
  "Nam Toàn, Nam Trực, Nam Định": [
    "nam toàn, nam trực, nam định",
    "nam toafn, nam truwjc, nam ddijnh"
  ],
  "Nam Tân, Nam Sách, Hải Dương": [
    "nam tân, nam sách, hải dương",
    "nam taan, nam sasch, hari duwowng"
  ],
  "Nam Viêm, Phúc Yên, Vĩnh Phúc": [
    "nam viêm, phúc yên, vĩnh phúc",
    "nam vieem, phusc yeen, vixnh phusc"
  ],
  "Nam Vân, Nam Định, Nam Định": [
    "nam vân, nam định, nam định",
    "nam vaan, nam ddijnh, nam ddijnh"
  ],
  "Nam Đà, Krông Nô, Đắk Nông": [
    "nam đà, krông nô, đắk nông",
    "nam ddaf, kroong noo, ddawsk noong"
  ],
  "Nam Động, Quan Hóa, Thanh Hóa": [
    "nam động, quan hóa, thanh hóa",
    "nam ddoojng, quan hosa, thanh hosa"
  ],
  "Nga Hoàng, Yên Lập, Phú Thọ": [
    "nga hoàng, yên lập, phú thọ",
    "nga hoafng, yeen laajp, phus thoj"
  ],
  "Nga My, Tương Dương, Nghệ An": [
    "nga my, tương dương, nghệ an",
    "nga my, tuwowng duwowng, ngheej an"
  ],
  "Nghi Hương, Cửa Lò, Nghệ An": [
    "nghi hương, cửa lò, nghệ an",
    "nghi huwowng, cuwra lof, ngheej an"
  ],
  "Nghi Kiều, Nghi Lộc, Nghệ An": [
    "nghi kiều, nghi lộc, nghệ an",
    "nghi kieefu, nghi loojc, ngheej an"
  ],
  "Nghi Tiến, Nghi Lộc, Nghệ An": [
    "nghi tiến, nghi lộc, nghệ an",
    "nghi tieesn, nghi loojc, ngheej an"
  ],
  "Nghĩa An, Nam Trực, Nam Định": [
    "nghĩa an, nam trực, nam định",
    "nghixa an, nam truwjc, nam ddijnh"
  ],
  "Nghĩa An, Nghĩa Đàn, Nghệ An": [
    "nghĩa an, nghĩa đàn, nghệ an",
    "nghixa an, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Bình, Tân Kỳ, Nghệ An": [
    "nghĩa bình, tân kỳ, nghệ an",
    "nghixa bifnh, taan kyf, ngheej an"
  ],
  "Nghĩa Dũng, Tân Kỳ, Nghệ An": [
    "nghĩa dũng, tân kỳ, nghệ an",
    "nghixa duxng, taan kyf, ngheej an"
  ],
  "Nghĩa Hoàn, Tân Kỳ, Nghệ An": [
    "nghĩa hoàn, tân kỳ, nghệ an",
    "nghixa hoafn, taan kyf, ngheej an"
  ],
  "Nghĩa Hành, Tân Kỳ, Nghệ An": [
    "nghĩa hành, tân kỳ, nghệ an",
    "nghixa hafnh, taan kyf, ngheej an"
  ],
  "Nghĩa Hợp, Tân Kỳ, Nghệ An": [
    "nghĩa hợp, tân kỳ, nghệ an",
    "nghixa howjp, taan kyf, ngheej an"
  ],
  "Nghĩa Mỹ, Thái Hoà, Nghệ An": [
    "nghĩa mỹ, thái hoà, nghệ an",
    "nghixa myx, thasi hoaf, ngheej an"
  ],
  "Nghĩa Phúc, Tân Kỳ, Nghệ An": [
    "nghĩa phúc, tân kỳ, nghệ an",
    "nghixa phusc, taan kyf, ngheej an"
  ],
  "Nghĩa Thái, Tân Kỳ, Nghệ An": [
    "nghĩa thái, tân kỳ, nghệ an",
    "nghixa thasi, taan kyf, ngheej an"
  ],
  "Nguyên Xá, Vũ Thư, Thái Bình": [
    "nguyên xá, vũ thư, thái bình",
    "nguyeen xas, vux thuw, thasi bifnh"
  ],
  "Ngô Quyền, Sơn Tây, Hà Nội": [
    "ngô quyền, sơn tây, hà nội",
    "ngoo quyeefn, sown taay, haf nooji"
  ],
  "Ngũ Hiệp, Thanh Trì, Hà Nội": [
    "ngũ hiệp, thanh trì, hà nội",
    "ngux hieejp, thanh trif, haf nooji"
  ],
  "Ngọc Long, Yên Mỹ, Hưng Yên": [
    "ngọc long, yên mỹ, hưng yên",
    "ngojc long, yeen myx, huwng yeen"
  ],
  "Ngọc Lâm, Long Biên, Hà Nội": [
    "ngọc lâm, long biên, hà nội",
    "ngojc laam, long bieen, haf nooji"
  ],
  "Ngọc Lâm, Mỹ Hào, Hưng Yên": [
    "ngọc lâm, mỹ hào, hưng yên",
    "ngojc laam, myx hafo, huwng yeen"
  ],
  "Ngọc Lây, Tu Mơ Rông, Kon Tum": [
    "ngọc lây, tu mơ rông, kon tum",
    "ngojc laay, tu mow roong, kon tum"
  ],
  "Ngọc Lý, Tân Yên, Bắc Giang": [
    "ngọc lý, tân yên, bắc giang",
    "ngojc lys, taan yeen, bawsc giang"
  ],
  "Ngọc Mỹ, Quốc Oai, Hà Nội": [
    "ngọc mỹ, quốc oai, hà nội",
    "ngojc myx, quoosc oai, haf nooji"
  ],
  "Ngọc Yêu, Tu Mơ Rông, Kon Tum": [
    "ngọc yêu, tu mơ rông, kon tum",
    "ngojc yeeu, tu mow roong, kon tum"
  ],
  "Nhà Bàng, Tịnh Biên, An Giang": [
    "nhà bàng, tịnh biên, an giang",
    "nhaf bafng, tijnh bieen, an giang"
  ],
  "Nhà Bè, Nhà Bè, Hồ Chí Minh": [
    "nhà bè, nhà bè, hồ chí minh",
    "nhaf bef, nhaf bef, hoof chis minh"
  ],
  "Nhân Mỹ, Tân Lạc, Hoà Bình": [
    "nhân mỹ, tân lạc, hoà bình",
    "nhaan myx, taan lajc, hoaf bifnh"
  ],
  "Nhơn Phú, Mang Thít, Vĩnh Long": [
    "nhơn phú, mang thít, vĩnh long",
    "nhown phus, mang thist, vixnh long"
  ],
  "Ninh Bình, Ninh Hòa, Khánh Hòa": [
    "ninh bình, ninh hòa, khánh hòa",
    "ninh bifnh, ninh hofa, khasnh hofa"
  ],
  "Ninh Diêm, Ninh Hòa, Khánh Hòa": [
    "ninh diêm, ninh hòa, khánh hòa",
    "ninh dieem, ninh hofa, khasnh hofa"
  ],
  "Ninh Giang, Ninh Hòa, Khánh Hòa": [
    "ninh giang, ninh hòa, khánh hòa",
    "ninh giang, ninh hofa, khasnh hofa"
  ],
  "Ninh Hưng, Ninh Hòa, Khánh Hòa": [
    "ninh hưng, ninh hòa, khánh hòa",
    "ninh huwng, ninh hofa, khasnh hofa"
  ],
  "Ninh Hải, Ninh Hòa, Khánh Hòa": [
    "ninh hải, ninh hòa, khánh hòa",
    "ninh hari, ninh hofa, khasnh hofa"
  ],
  "Ninh Lộc, Ninh Hòa, Khánh Hòa": [
    "ninh lộc, ninh hòa, khánh hòa",
    "ninh loojc, ninh hofa, khasnh hofa"
  ],
  "Ninh Phong, Ninh Bình, Ninh Bình": [
    "ninh phong, ninh bình, ninh bình",
    "ninh phong, ninh bifnh, ninh bifnh"
  ],
  "Ninh Phúc, Ninh Bình, Ninh Bình": [
    "ninh phúc, ninh bình, ninh bình",
    "ninh phusc, ninh bifnh, ninh bifnh"
  ],
  "Ninh Quang, Ninh Hòa, Khánh Hòa": [
    "ninh quang, ninh hòa, khánh hòa",
    "ninh quang, ninh hofa, khasnh hofa"
  ],
  "Ninh Thân, Ninh Hòa, Khánh Hòa": [
    "ninh thân, ninh hòa, khánh hòa",
    "ninh thaan, ninh hofa, khasnh hofa"
  ],
  "Ninh Thạnh, Tây Ninh, Tây Ninh": [
    "ninh thạnh, tây ninh, tây ninh",
    "ninh thajnh, taay ninh, taay ninh"
  ],
  "Ninh Thọ, Ninh Hòa, Khánh Hòa": [
    "ninh thọ, ninh hòa, khánh hòa",
    "ninh thoj, ninh hofa, khasnh hofa"
  ],
  "Ninh Trung, Ninh Hòa, Khánh Hòa": [
    "ninh trung, ninh hòa, khánh hòa",
    "ninh trung, ninh hofa, khasnh hofa"
  ],
  "Ninh Xuân, Ninh Hòa, Khánh Hòa": [
    "ninh xuân, ninh hòa, khánh hòa",
    "ninh xuaan, ninh hofa, khasnh hofa"
  ],
  "Niêm Tòng, Mèo Vạc, Hà Giang": [
    "niêm tòng, mèo vạc, hà giang",
    "nieem tofng, mefo vajc, haf giang"
  ],
  "Nà Mường, Mộc Châu, Sơn La": [
    "nà mường, mộc châu, sơn la",
    "naf muwowfng, moojc chaau, sown la"
  ],
  "Nà Tăm, Tam Đường, Lai Châu": [
    "nà tăm, tam đường, lai châu",
    "naf tawm, tam dduwowfng, lai chaau"
  ],
  "Núi Sập, Thoại Sơn, An Giang": [
    "núi sập, thoại sơn, an giang",
    "nusi saajp, thoaji sown, an giang"
  ],
  "Năng Khả, Na Hang, Tuyên Quang": [
    "năng khả, na hang, tuyên quang",
    "nawng khar, na hang, tuyeen quang"
  ],
  "Nấm Dẩn, Xín Mần, Hà Giang": [
    "nấm dẩn, xín mần, hà giang",
    "naasm daarn, xisn maafn, haf giang"
  ],
  "Nậm Chà, Nậm Nhùn, Lai Châu": [
    "nậm chà, nậm nhùn, lai châu",
    "naajm chaf, naajm nhufn, lai chaau"
  ],
  "Nậm Cuổi, Sìn Hồ, Lai Châu": [
    "nậm cuổi, sìn hồ, lai châu",
    "naajm cuoori, sifn hoof, lai chaau"
  ],
  "Nậm Cần, Tân Uyên, Lai Châu": [
    "nậm cần, tân uyên, lai châu",
    "naajm caafn, taan uyeen, lai chaau"
  ],
  "Nậm Lạnh, Sốp Cộp, Sơn La": [
    "nậm lạnh, sốp cộp, sơn la",
    "naajm lajnh, soosp coojp, sown la"
  ],
  "Nậm Manh, Nậm Nhùn, Lai Châu": [
    "nậm manh, nậm nhùn, lai châu",
    "naajm manh, naajm nhufn, lai chaau"
  ],
  "Phong Châu, Phù Ninh, Phú Thọ": [
    "phong châu, phù ninh, phú thọ",
    "phong chaau, phuf ninh, phus thoj"
  ],
  "Phong Khê, Bắc Ninh, Bắc Ninh": [
    "phong khê, bắc ninh, bắc ninh",
    "phong khee, bawsc ninh, bawsc ninh"
  ],
  "Phong Phú, Tân Lạc, Hoà Bình": [
    "phong phú, tân lạc, hoà bình",
    "phong phus, taan lajc, hoaf bifnh"
  ],
  "Phát Diệm, Kim Sơn, Ninh Bình": [
    "phát diệm, kim sơn, ninh bình",
    "phast dieejm, kim sown, ninh bifnh"
  ],
  "Phù Chẩn, Từ Sơn, Bắc Ninh": [
    "phù chẩn, từ sơn, bắc ninh",
    "phuf chaarn, tuwf sown, bawsc ninh"
  ],
  "Phù Lưu, Hàm Yên, Tuyên Quang": [
    "phù lưu, hàm yên, tuyên quang",
    "phuf luwu, hafm yeen, tuyeen quang"
  ],
  "Phùng Xá, Mỹ Đức, Hà Nội": [
    "phùng xá, mỹ đức, hà nội",
    "phufng xas, myx dduwsc, haf nooji"
  ],
  "Phú An, Bến Cát, Bình Dương": [
    "phú an, bến cát, bình dương",
    "phus an, beesn cast, bifnh duwowng"
  ],
  "Phú Bình, Tân Phú, Đồng Nai": [
    "phú bình, tân phú, đồng nai",
    "phus bifnh, taan phus, ddoofng nai"
  ],
  "Phú Hữu, Long Phú, Sóc Trăng": [
    "phú hữu, long phú, sóc trăng",
    "phus huwxu, long phus, sosc trawng"
  ],
  "Phú Long, Bình Đại, Bến Tre": [
    "phú long, bình đại, bến tre",
    "phus long, bifnh ddaji, beesn tre"
  ],
  "Phú Lâm, Đoan Hùng, Phú Thọ": [
    "phú lâm, đoan hùng, phú thọ",
    "phus laam, ddoan hufng, phus thoj"
  ],
  "Phú Lý, Vĩnh Cửu, Đồng Nai": [
    "phú lý, vĩnh cửu, đồng nai",
    "phus lys, vixnh cuwru, ddoofng nai"
  ],
  "Phú Lạc, Cẩm Khê, Phú Thọ": [
    "phú lạc, cẩm khê, phú thọ",
    "phus lajc, caarm khee, phus thoj"
  ],
  "Phú Lập, Tân Phú, Đồng Nai": [
    "phú lập, tân phú, đồng nai",
    "phus laajp, taan phus, ddoofng nai"
  ],
  "Phú Lộc, Tân Phú, Đồng Nai": [
    "phú lộc, tân phú, đồng nai",
    "phus loojc, taan phus, ddoofng nai"
  ],
  "Phú Nhuận, Bến Tre, Bến Tre": [
    "phú nhuận, bến tre, bến tre",
    "phus nhuaajn, beesn tre, beesn tre"
  ],
  "Phú Quý, Cai Lậy, Tiền Giang": [
    "phú quý, cai lậy, tiền giang",
    "phus quys, cai laajy, tieefn giang"
  ],
  "Phú Quới, Long Hồ, Vĩnh Long": [
    "phú quới, long hồ, vĩnh long",
    "phus quowsi, long hoof, vixnh long"
  ],
  "Phú Thanh, Tân Phú, Đồng Nai": [
    "phú thanh, tân phú, đồng nai",
    "phus thanh, taan phus, ddoofng nai"
  ],
  "Phú Thịnh, Sơn Tây, Hà Nội": [
    "phú thịnh, sơn tây, hà nội",
    "phus thijnh, sown taay, haf nooji"
  ],
  "Phú Thứ, Cái Răng, Cần Thơ": [
    "phú thứ, cái răng, cần thơ",
    "phus thuws, casi rawng, caafn thow"
  ],
  "Phú Trung, Tân Phú, Đồng Nai": [
    "phú trung, tân phú, đồng nai",
    "phus trung, taan phus, ddoofng nai"
  ],
  "Phú Túc, Châu Thành, Bến Tre": [
    "phú túc, châu thành, bến tre",
    "phus tusc, chaau thafnh, beesn tre"
  ],
  "Phú Vang, Bình Đại, Bến Tre": [
    "phú vang, bình đại, bến tre",
    "phus vang, bifnh ddaji, beesn tre"
  ],
  "Phú Xuân, Tân Phú, Đồng Nai": [
    "phú xuân, tân phú, đồng nai",
    "phus xuaan, taan phus, ddoofng nai"
  ],
  "Phú Đức, Long Hồ, Vĩnh Long": [
    "phú đức, long hồ, vĩnh long",
    "phus dduwsc, long hoof, vixnh long"
  ],
  "Phúc Hòa, Phúc Thọ, Hà Nội": [
    "phúc hòa, phúc thọ, hà nội",
    "phusc hofa, phusc thoj, haf nooji"
  ],
  "Phúc Hòa, Tân Yên, Bắc Giang": [
    "phúc hòa, tân yên, bắc giang",
    "phusc hofa, taan yeen, bawsc giang"
  ],
  "Phúc Khánh, Bảo Yên, Lào Cai": [
    "phúc khánh, bảo yên, lào cai",
    "phusc khasnh, baro yeen, lafo cai"
  ],
  "Phúc Lai, Đoan Hùng, Phú Thọ": [
    "phúc lai, đoan hùng, phú thọ",
    "phusc lai, ddoan hufng, phus thoj"
  ],
  "Phúc Lâm, Mỹ Đức, Hà Nội": [
    "phúc lâm, mỹ đức, hà nội",
    "phusc laam, myx dduwsc, haf nooji"
  ],
  "Phúc Lợi, Long Biên, Hà Nội": [
    "phúc lợi, long biên, hà nội",
    "phusc lowji, long bieen, haf nooji"
  ],
  "Phúc Lợi, Lục Yên, Yên Bái": [
    "phúc lợi, lục yên, yên bái",
    "phusc lowji, lujc yeen, yeen basi"
  ],
  "Phúc Sơn, Nghĩa Lộ, Yên Bái": [
    "phúc sơn, nghĩa lộ, yên bái",
    "phusc sown, nghixa looj, yeen basi"
  ],
  "Phúc Sơn, Tân Yên, Bắc Giang": [
    "phúc sơn, tân yên, bắc giang",
    "phusc sown, taan yeen, bawsc giang"
  ],
  "Phúc Thọ, Nghi Lộc, Nghệ An": [
    "phúc thọ, nghi lộc, nghệ an",
    "phusc thoj, nghi loojc, ngheej an"
  ],
  "Phường 1, Giá Rai, Bạc Liêu": [
    "phường 1, giá rai, bạc liêu",
    "phuwowfng 1, gias rai, bajc lieeu"
  ],
  "Phật Tích, Tiên Du, Bắc Ninh": [
    "phật tích, tiên du, bắc ninh",
    "phaajt tisch, tieen du, bawsc ninh"
  ],
  "Phố Là, Đồng Văn, Hà Giang": [
    "phố là, đồng văn, hà giang",
    "phoos laf, ddoofng vawn, haf giang"
  ],
  "Phố Mới, Quế Võ, Bắc Ninh": [
    "phố mới, quế võ, bắc ninh",
    "phoos mowsi, quees vox, bawsc ninh"
  ],
  "Pù Nhi, Mường Lát, Thanh Hóa": [
    "pù nhi, mường lát, thanh hóa",
    "puf nhi, muwowfng last, thanh hosa"
  ],
  "Quang Hưng, An Lão, Hải Phòng": [
    "quang hưng, an lão, hải phòng",
    "quang huwng, an laxo, hari phofng"
  ],
  "Quang Hưng, Phù Cừ, Hưng Yên": [
    "quang hưng, phù cừ, hưng yên",
    "quang huwng, phuf cuwf, huwng yeen"
  ],
  "Quang Minh, Bắc Quang, Hà Giang": [
    "quang minh, bắc quang, hà giang",
    "quang minh, bawsc quang, haf giang"
  ],
  "Quang Phong, Thái Hoà, Nghệ An": [
    "quang phong, thái hoà, nghệ an",
    "quang phong, thasi hoaf, ngheej an"
  ],
  "Quang Tiến, Sóc Sơn, Hà Nội": [
    "quang tiến, sóc sơn, hà nội",
    "quang tieesn, sosc sown, haf nooji"
  ],
  "Quang Trung, An Lão, Hải Phòng": [
    "quang trung, an lão, hải phòng",
    "quang trung, an laxo, hari phofng"
  ],
  "Quang Trung, Hà Đông, Hà Nội": [
    "quang trung, hà đông, hà nội",
    "quang trung, haf ddoong, haf nooji"
  ],
  "Quang Yên, Sông Lô, Vĩnh Phúc": [
    "quang yên, sông lô, vĩnh phúc",
    "quang yeen, soong loo, vixnh phusc"
  ],
  "Qui Hướng, Mộc Châu, Sơn La": [
    "qui hướng, mộc châu, sơn la",
    "qui huwowsng, moojc chaau, sown la"
  ],
  "Quán Hành, Nghi Lộc, Nghệ An": [
    "quán hành, nghi lộc, nghệ an",
    "quasn hafnh, nghi loojc, ngheej an"
  ],
  "Quán Thánh, Ba Đình, Hà Nội": [
    "quán thánh, ba đình, hà nội",
    "quasn thasnh, ba ddifnh, haf nooji"
  ],
  "Quảng Khê, Ba Bể, Bắc Kạn": [
    "quảng khê, ba bể, bắc kạn",
    "quarng khee, ba beer, bawsc kajn"
  ],
  "Quảng Lãng, Ân Thi, Hưng Yên": [
    "quảng lãng, ân thi, hưng yên",
    "quarng laxng, aan thi, huwng yeen"
  ],
  "Quảng Yên, Thanh Ba, Phú Thọ": [
    "quảng yên, thanh ba, phú thọ",
    "quarng yeen, thanh ba, phus thoj"
  ],
  "Quế Nham, Tân Yên, Bắc Giang": [
    "quế nham, tân yên, bắc giang",
    "quees nham, taan yeen, bawsc giang"
  ],
  "Quỳnh Lưu, Nho Quan, Ninh Bình": [
    "quỳnh lưu, nho quan, ninh bình",
    "quyfnh luwu, nho quan, ninh bifnh"
  ],
  "Sao Vàng, Thọ Xuân, Thanh Hóa": [
    "sao vàng, thọ xuân, thanh hóa",
    "sao vafng, thoj xuaan, thanh hosa"
  ],
  "Song Mai, Bắc Giang, Bắc Giang": [
    "song mai, bắc giang, bắc giang",
    "song mai, bawsc giang, bawsc giang"
  ],
  "Suối Bạc, Sơn Hòa, Phú Yên": [
    "suối bạc, sơn hòa, phú yên",
    "suoosi bajc, sown hofa, phus yeen"
  ],
  "Suối Cát, Cam Lâm, Khánh Hòa": [
    "suối cát, cam lâm, khánh hòa",
    "suoosi cast, cam laam, khasnh hofa"
  ],
  "Suối Dây, Tân Châu, Tây Ninh": [
    "suối dây, tân châu, tây ninh",
    "suoosi daay, taan chaau, taay ninh"
  ],
  "Suối Hoa, Bắc Ninh, Bắc Ninh": [
    "suối hoa, bắc ninh, bắc ninh",
    "suoosi hoa, bawsc ninh, bawsc ninh"
  ],
  "Suối Hoa, Tân Lạc, Hoà Bình": [
    "suối hoa, tân lạc, hoà bình",
    "suoosi hoa, taan lajc, hoaf bifnh"
  ],
  "Suối Ngô, Tân Châu, Tây Ninh": [
    "suối ngô, tân châu, tây ninh",
    "suoosi ngoo, taan chaau, taay ninh"
  ],
  "Suối Tân, Cam Lâm, Khánh Hòa": [
    "suối tân, cam lâm, khánh hòa",
    "suoosi taan, cam laam, khasnh hofa"
  ],
  "Sàng Ma Sáo, Bát Xát, Lào Cai": [
    "sàng ma sáo, bát xát, lào cai",
    "safng ma saso, bast xast, lafo cai"
  ],
  "Sông Lô, Việt Trì, Phú Thọ": [
    "sông lô, việt trì, phú thọ",
    "soong loo, vieejt trif, phus thoj"
  ],
  "Sông Ray, Cẩm Mỹ, Đồng Nai": [
    "sông ray, cẩm mỹ, đồng nai",
    "soong ray, caarm myx, ddoofng nai"
  ],
  "Sùng Đô, Văn Chấn, Yên Bái": [
    "sùng đô, văn chấn, yên bái",
    "sufng ddoo, vawn chaasn, yeen basi"
  ],
  "Sơn Bua, Sơn Tây, Quảng Ngãi": [
    "sơn bua, sơn tây, quảng ngãi",
    "sown bua, sown taay, quarng ngaxi"
  ],
  "Sơn Cương, Thanh Ba, Phú Thọ": [
    "sơn cương, thanh ba, phú thọ",
    "sown cuwowng, thanh ba, phus thoj"
  ],
  "Sơn Hà, Hữu Lũng, Lạng Sơn": [
    "sơn hà, hữu lũng, lạng sơn",
    "sown haf, huwxu luxng, lajng sown"
  ],
  "Sơn Hàm, Hương Sơn, Hà Tĩnh": [
    "sơn hàm, hương sơn, hà tĩnh",
    "sown hafm, huwowng sown, haf tixnh"
  ],
  "Sơn Hòa, Châu Thành, Bến Tre": [
    "sơn hòa, châu thành, bến tre",
    "sown hofa, chaau thafnh, beesn tre"
  ],
  "Sơn Hùng, Thanh Sơn, Phú Thọ": [
    "sơn hùng, thanh sơn, phú thọ",
    "sown hufng, thanh sown, phus thoj"
  ],
  "Sơn Hạ, Sơn Hà, Quảng Ngãi": [
    "sơn hạ, sơn hà, quảng ngãi",
    "sown haj, sown haf, quarng ngaxi"
  ],
  "Sơn Kỳ, Sơn Hà, Quảng Ngãi": [
    "sơn kỳ, sơn hà, quảng ngãi",
    "sown kyf, sown haf, quarng ngaxi"
  ],
  "Sơn Linh, Sơn Hà, Quảng Ngãi": [
    "sơn linh, sơn hà, quảng ngãi",
    "sown linh, sown haf, quarng ngaxi"
  ],
  "Sơn Long, Hương Sơn, Hà Tĩnh": [
    "sơn long, hương sơn, hà tĩnh",
    "sown long, huwowng sown, haf tixnh"
  ],
  "Sơn Lâm, Hương Sơn, Hà Tĩnh": [
    "sơn lâm, hương sơn, hà tĩnh",
    "sown laam, huwowng sown, haf tixnh"
  ],
  "Sơn Lễ, Hương Sơn, Hà Tĩnh": [
    "sơn lễ, hương sơn, hà tĩnh",
    "sown leex, huwowng sown, haf tixnh"
  ],
  "Sơn Lộ, Bảo Lạc, Cao Bằng": [
    "sơn lộ, bảo lạc, cao bằng",
    "sown looj, baro lajc, cao bawfng"
  ],
  "Sơn Nguyên, Sơn Hòa, Phú Yên": [
    "sơn nguyên, sơn hòa, phú yên",
    "sown nguyeen, sown hofa, phus yeen"
  ],
  "Sơn Nham, Sơn Hà, Quảng Ngãi": [
    "sơn nham, sơn hà, quảng ngãi",
    "sown nham, sown haf, quarng ngaxi"
  ],
  "Sơn Ninh, Hương Sơn, Hà Tĩnh": [
    "sơn ninh, hương sơn, hà tĩnh",
    "sown ninh, huwowng sown, haf tixnh"
  ],
  "Sơn Phú, Hương Sơn, Hà Tĩnh": [
    "sơn phú, hương sơn, hà tĩnh",
    "sown phus, huwowng sown, haf tixnh"
  ],
  "Sơn Thủy, Mai Châu, Hoà Bình": [
    "sơn thủy, mai châu, hoà bình",
    "sown thury, mai chaau, hoaf bifnh"
  ],
  "Sơn Thủy, Quan Sơn, Thanh Hóa": [
    "sơn thủy, quan sơn, thanh hóa",
    "sown thury, quan sown, thanh hosa"
  ],
  "Sơn Trà, Hương Sơn, Hà Tĩnh": [
    "sơn trà, hương sơn, hà tĩnh",
    "sown traf, huwowng sown, haf tixnh"
  ],
  "Sơn Tây, Hương Sơn, Hà Tĩnh": [
    "sơn tây, hương sơn, hà tĩnh",
    "sown taay, huwowng sown, haf tixnh"
  ],
  "Sơn Tình, Cẩm Khê, Phú Thọ": [
    "sơn tình, cẩm khê, phú thọ",
    "sown tifnh, caarm khee, phus thoj"
  ],
  "Sơn Định, Sơn Hòa, Phú Yên": [
    "sơn định, sơn hòa, phú yên",
    "sown ddijnh, sown hofa, phus yeen"
  ],
  "Sủ Ngòi, Hòa Bình, Hoà Bình": [
    "sủ ngòi, hòa bình, hoà bình",
    "sur ngofi, hofa bifnh, hoaf bifnh"
  ],
  "Sủng Thài, Yên Minh, Hà Giang": [
    "sủng thài, yên minh, hà giang",
    "surng thafi, yeen minh, haf giang"
  ],
  "Sủng Trà, Mèo Vạc, Hà Giang": [
    "sủng trà, mèo vạc, hà giang",
    "surng traf, mefo vajc, haf giang"
  ],
  "Ta Ma, Tuần Giáo, Điện Biên": [
    "ta ma, tuần giáo, điện biên",
    "ta ma, tuaafn giaso, ddieejn bieen"
  ],
  "Tam Bình, Cai Lậy, Tiền Giang": [
    "tam bình, cai lậy, tiền giang",
    "tam bifnh, cai laajy, tieefn giang"
  ],
  "Tam Hiệp, Phúc Thọ, Hà Nội": [
    "tam hiệp, phúc thọ, hà nội",
    "tam hieejp, phusc thoj, haf nooji"
  ],
  "Tam Hòa, Núi Thành, Quảng Nam": [
    "tam hòa, núi thành, quảng nam",
    "tam hofa, nusi thafnh, quarng nam"
  ],
  "Tam Kim, Nguyên Bình, Cao Bằng": [
    "tam kim, nguyên bình, cao bằng",
    "tam kim, nguyeen bifnh, cao bawfng"
  ],
  "Tam Sơn, Núi Thành, Quảng Nam": [
    "tam sơn, núi thành, quảng nam",
    "tam sown, nusi thafnh, quarng nam"
  ],
  "Tam Thanh, Vụ Bản, Nam Định": [
    "tam thanh, vụ bản, nam định",
    "tam thanh, vuj barn, nam ddijnh"
  ],
  "Tam Thành, Phú Ninh, Quảng Nam": [
    "tam thành, phú ninh, quảng nam",
    "tam thafnh, phus ninh, quarng nam"
  ],
  "Tam Trà, Núi Thành, Quảng Nam": [
    "tam trà, núi thành, quảng nam",
    "tam traf, nusi thafnh, quarng nam"
  ],
  "Tam Đa, Vĩnh Bảo, Hải Phòng": [
    "tam đa, vĩnh bảo, hải phòng",
    "tam dda, vixnh baro, hari phofng"
  ],
  "Tam Đại, Phú Ninh, Quảng Nam": [
    "tam đại, phú ninh, quảng nam",
    "tam ddaji, phus ninh, quarng nam"
  ],
  "Thanh An, Minh Long, Quảng Ngãi": [
    "thanh an, minh long, quảng ngãi",
    "thanh an, minh long, quarng ngaxi"
  ],
  "Thanh An, Thanh Hà, Hải Dương": [
    "thanh an, thanh hà, hải dương",
    "thanh an, thanh haf, hari duwowng"
  ],
  "Thanh Hòa, Như Xuân, Thanh Hóa": [
    "thanh hòa, như xuân, thanh hóa",
    "thanh hofa, nhuw xuaan, thanh hosa"
  ],
  "Thanh Kỳ, Như Thanh, Thanh Hóa": [
    "thanh kỳ, như thanh, thanh hóa",
    "thanh kyf, nhuw thanh, thanh hosa"
  ],
  "Thanh Lâm, Ba Chẽ, Quảng Ninh": [
    "thanh lâm, ba chẽ, quảng ninh",
    "thanh laam, ba chex, quarng ninh"
  ],
  "Thanh Lâm, Lục Nam, Bắc Giang": [
    "thanh lâm, lục nam, bắc giang",
    "thanh laam, lujc nam, bawsc giang"
  ],
  "Thanh Lâm, Như Xuân, Thanh Hóa": [
    "thanh lâm, như xuân, thanh hóa",
    "thanh laam, nhuw xuaan, thanh hosa"
  ],
  "Thanh Lòa, Cao Lộc, Lạng Sơn": [
    "thanh lòa, cao lộc, lạng sơn",
    "thanh lofa, cao loojc, lajng sown"
  ],
  "Thanh Minh, Phú Thọ, Phú Thọ": [
    "thanh minh, phú thọ, phú thọ",
    "thanh minh, phus thoj, phus thoj"
  ],
  "Thanh Nghị, Thanh Liêm, Hà Nam": [
    "thanh nghị, thanh liêm, hà nam",
    "thanh nghij, thanh lieem, haf nam"
  ],
  "Thanh Sơn, Ba Chẽ, Quảng Ninh": [
    "thanh sơn, ba chẽ, quảng ninh",
    "thanh sown, ba chex, quarng ninh"
  ],
  "Thanh Sơn, Như Xuân, Thanh Hóa": [
    "thanh sơn, như xuân, thanh hóa",
    "thanh sown, nhuw xuaan, thanh hosa"
  ],
  "Thanh Sơn, Thanh Sơn, Phú Thọ": [
    "thanh sơn, thanh sơn, phú thọ",
    "thanh sown, thanh sown, phus thoj"
  ],
  "Thanh Sơn, Tân Phú, Đồng Nai": [
    "thanh sơn, tân phú, đồng nai",
    "thanh sown, taan phus, ddoofng nai"
  ],
  "Thanh Thủy, Thanh Liêm, Hà Nam": [
    "thanh thủy, thanh liêm, hà nam",
    "thanh thury, thanh lieem, haf nam"
  ],
  "Thanh Tân, Như Thanh, Thanh Hóa": [
    "thanh tân, như thanh, thanh hóa",
    "thanh taan, nhuw thanh, thanh hosa"
  ],
  "Thanh Uyên, Tam Nông, Phú Thọ": [
    "thanh uyên, tam nông, phú thọ",
    "thanh uyeen, tam noong, phus thoj"
  ],
  "Thanh Vinh, Phú Thọ, Phú Thọ": [
    "thanh vinh, phú thọ, phú thọ",
    "thanh vinh, phus thoj, phus thoj"
  ],
  "Thanh Vân, Quản Bạ, Hà Giang": [
    "thanh vân, quản bạ, hà giang",
    "thanh vaan, quarn baj, haf giang"
  ],
  "Thiên Lộc, Can Lộc, Hà Tĩnh": [
    "thiên lộc, can lộc, hà tĩnh",
    "thieen loojc, can loojc, haf tixnh"
  ],
  "Thiện Mỹ, Trà Ôn, Vĩnh Long": [
    "thiện mỹ, trà ôn, vĩnh long",
    "thieejn myx, traf oon, vixnh long"
  ],
  "Thuận An, Bình Minh, Vĩnh Long": [
    "thuận an, bình minh, vĩnh long",
    "thuaajn an, bifnh minh, vixnh long"
  ],
  "Thuận An, Long Mỹ, Hậu Giang": [
    "thuận an, long mỹ, hậu giang",
    "thuaajn an, long myx, haaju giang"
  ],
  "Thuận Hoà, An Minh, Kiên Giang": [
    "thuận hoà, an minh, kiên giang",
    "thuaajn hoaf, an minh, kieen giang"
  ],
  "Thuỵ Lâm, Đông Anh, Hà Nội": [
    "thuỵ lâm, đông anh, hà nội",
    "thuyj laam, ddoong anh, haf nooji"
  ],
  "Thành Công, Ba Đình, Hà Nội": [
    "thành công, ba đình, hà nội",
    "thafnh coong, ba ddifnh, haf nooji"
  ],
  "Thành Sơn, Mai Châu, Hoà Bình": [
    "thành sơn, mai châu, hoà bình",
    "thafnh sown, mai chaau, hoaf bifnh"
  ],
  "Thành Sơn, Quan Hóa, Thanh Hóa": [
    "thành sơn, quan hóa, thanh hóa",
    "thafnh sown, quan hosa, thanh hosa"
  ],
  "Thành Tô, Hải An, Hải Phòng": [
    "thành tô, hải an, hải phòng",
    "thafnh too, hari an, hari phofng"
  ],
  "Thái Bảo, Gia Bình, Bắc Ninh": [
    "thái bảo, gia bình, bắc ninh",
    "thasi baro, gia bifnh, bawsc ninh"
  ],
  "Thái Sơn, Bảo Lâm, Cao Bằng": [
    "thái sơn, bảo lâm, cao bằng",
    "thasi sown, baro laam, cao bawfng"
  ],
  "Thôm Mòn, Thuận Châu, Sơn La": [
    "thôm mòn, thuận châu, sơn la",
    "thoom mofn, thuaajn chaau, sown la"
  ],
  "Thăng Hưng, Chư Prông, Gia Lai": [
    "thăng hưng, chư prông, gia lai",
    "thawng huwng, chuw proong, gia lai"
  ],
  "Thạch Hạ, Hà Tĩnh, Hà Tĩnh": [
    "thạch hạ, hà tĩnh, hà tĩnh",
    "thajch haj, haf tixnh, haf tixnh"
  ],
  "Thạch Linh, Hà Tĩnh, Hà Tĩnh": [
    "thạch linh, hà tĩnh, hà tĩnh",
    "thajch linh, haf tixnh, haf tixnh"
  ],
  "Thạch Mỹ, Lộc Hà, Hà Tĩnh": [
    "thạch mỹ, lộc hà, hà tĩnh",
    "thajch myx, loojc haf, haf tixnh"
  ],
  "Thạch Quý, Hà Tĩnh, Hà Tĩnh": [
    "thạch quý, hà tĩnh, hà tĩnh",
    "thajch quys, haf tixnh, haf tixnh"
  ],
  "Thạnh Hòa, Bến Lức, Long An": [
    "thạnh hòa, bến lức, long an",
    "thajnh hofa, beesn luwsc, long an"
  ],
  "Thạnh Hưng, Tân Hưng, Long An": [
    "thạnh hưng, tân hưng, long an",
    "thajnh huwng, taan huwng, long an"
  ],
  "Thạnh Phú, Cầu Kè, Trà Vinh": [
    "thạnh phú, cầu kè, trà vinh",
    "thajnh phus, caafu kef, traf vinh"
  ],
  "Thạnh Tân, Tây Ninh, Tây Ninh": [
    "thạnh tân, tây ninh, tây ninh",
    "thajnh taan, taay ninh, taay ninh"
  ],
  "Thần Xa, Võ Nhai, Thái Nguyên": [
    "thần xa, võ nhai, thái nguyên",
    "thaafn xa, vox nhai, thasi nguyeen"
  ],
  "Thắng Mố, Yên Minh, Hà Giang": [
    "thắng mố, yên minh, hà giang",
    "thawsng moos, yeen minh, haf giang"
  ],
  "Thống Nhất, Lào Cai, Lào Cai": [
    "thống nhất, lào cai, lào cai",
    "thoosng nhaast, lafo cai, lafo cai"
  ],
  "Thổ Quan, Đống Đa, Hà Nội": [
    "thổ quan, đống đa, hà nội",
    "thoor quan, ddoosng dda, haf nooji"
  ],
  "Thới Lai, Thới Lai, Cần Thơ": [
    "thới lai, thới lai, cần thơ",
    "thowsi lai, thowsi lai, caafn thow"
  ],
  "Thụy Khuê, Tây Hồ, Hà Nội": [
    "thụy khuê, tây hồ, hà nội",
    "thujy khuee, taay hoof, haf nooji"
  ],
  "Thủ Sỹ, Tiên Lữ, Hưng Yên": [
    "thủ sỹ, tiên lữ, hưng yên",
    "thur syx, tieen luwx, huwng yeen"
  ],
  "Thủy Tây, Thạnh Hóa, Long An": [
    "thủy tây, thạnh hóa, long an",
    "thury taay, thajnh hosa, long an"
  ],
  "Tiên Kiên, Lâm Thao, Phú Thọ": [
    "tiên kiên, lâm thao, phú thọ",
    "tieen kieen, laam thao, phus thoj"
  ],
  "Tiên Yên, Quang Bình, Hà Giang": [
    "tiên yên, quang bình, hà giang",
    "tieen yeen, quang bifnh, haf giang"
  ],
  "Tiến Thắng, Lý Nhân, Hà Nam": [
    "tiến thắng, lý nhân, hà nam",
    "tieesn thawsng, lys nhaan, haf nam"
  ],
  "Toàn Sơn, Đà Bắc, Hoà Bình": [
    "toàn sơn, đà bắc, hoà bình",
    "toafn sown, ddaf bawsc, hoaf bifnh"
  ],
  "Tri Phương, Tiên Du, Bắc Ninh": [
    "tri phương, tiên du, bắc ninh",
    "tri phuwowng, tieen du, bawsc ninh"
  ],
  "Tri Thủy, Phú Xuyên, Hà Nội": [
    "tri thủy, phú xuyên, hà nội",
    "tri thury, phus xuyeen, haf nooji"
  ],
  "Trung An,  Vũng Liêm, Vĩnh Long": [
    "trung an,  vũng liêm, vĩnh long",
    "trung an,  vuxng lieem, vixnh long"
  ],
  "Trung An, Củ Chi, Hồ Chí Minh": [
    "trung an, củ chi, hồ chí minh",
    "trung an, cur chi, hoof chis minh"
  ],
  "Trung Giáp, Phù Ninh, Phú Thọ": [
    "trung giáp, phù ninh, phú thọ",
    "trung giasp, phuf ninh, phus thoj"
  ],
  "Trung Hà, Yên Lạc, Vĩnh Phúc": [
    "trung hà, yên lạc, vĩnh phúc",
    "trung haf, yeen lajc, vixnh phusc"
  ],
  "Trung Hưng, Yên Mỹ, Hưng Yên": [
    "trung hưng, yên mỹ, hưng yên",
    "trung huwng, yeen myx, huwng yeen"
  ],
  "Trung Minh, Hòa Bình, Hoà Bình": [
    "trung minh, hòa bình, hoà bình",
    "trung minh, hofa bifnh, hoaf bifnh"
  ],
  "Trung Sơn, Sầm Sơn, Thanh Hóa": [
    "trung sơn, sầm sơn, thanh hóa",
    "trung sown, saafm sown, thanh hosa"
  ],
  "Trung Sơn, Yên Lập, Phú Thọ": [
    "trung sơn, yên lập, phú thọ",
    "trung sown, yeen laajp, phus thoj"
  ],
  "Trung Tâm, Nghĩa Lộ, Yên Bái": [
    "trung tâm, nghĩa lộ, yên bái",
    "trung taam, nghixa looj, yeen basi"
  ],
  "Trung Tự, Đống Đa, Hà Nội": [
    "trung tự, đống đa, hà nội",
    "trung tuwj, ddoosng dda, haf nooji"
  ],
  "Trung Xuân, Quan Sơn, Thanh Hóa": [
    "trung xuân, quan sơn, thanh hóa",
    "trung xuaan, quan sown, thanh hosa"
  ],
  "Trà Don, Nam Trà My, Quảng Nam": [
    "trà don, nam trà my, quảng nam",
    "traf don, nam traf my, quarng nam"
  ],
  "Trà Mai, Nam Trà My, Quảng Nam": [
    "trà mai, nam trà my, quảng nam",
    "traf mai, nam traf my, quarng nam"
  ],
  "Trà Nam, Nam Trà My, Quảng Nam": [
    "trà nam, nam trà my, quảng nam",
    "traf nam, nam traf my, quarng nam"
  ],
  "Tráng Việt, Mê Linh, Hà Nội": [
    "tráng việt, mê linh, hà nội",
    "trasng vieejt, mee linh, haf nooji"
  ],
  "Trí Nang, Lang Chánh, Thanh Hóa": [
    "trí nang, lang chánh, thanh hóa",
    "tris nang, lang chasnh, thanh hosa"
  ],
  "Trí Phải, Thới Bình, Cà Mau": [
    "trí phải, thới bình, cà mau",
    "tris phari, thowsi bifnh, caf mau"
  ],
  "Trí Yên, Yên Dũng, Bắc Giang": [
    "trí yên, yên dũng, bắc giang",
    "tris yeen, yeen duxng, bawsc giang"
  ],
  "Trù Sơn, Đô Lương, Nghệ An": [
    "trù sơn, đô lương, nghệ an",
    "truf sown, ddoo luwowng, ngheej an"
  ],
  "Trúc Bạch, Ba Đình, Hà Nội": [
    "trúc bạch, ba đình, hà nội",
    "trusc bajch, ba ddifnh, haf nooji"
  ],
  "Trúc Sơn, Cư Jút, Đắk Nông": [
    "trúc sơn, cư jút, đắk nông",
    "trusc sown, cuw just, ddawsk noong"
  ],
  "Trần Phán, Đầm Dơi, Cà Mau": [
    "trần phán, đầm dơi, cà mau",
    "traafn phasn, ddaafm dowi, caf mau"
  ],
  "Trần Phú, Hoàng Mai, Hà Nội": [
    "trần phú, hoàng mai, hà nội",
    "traafn phus, hoafng mai, haf nooji"
  ],
  "Trị An, Vĩnh Cửu, Đồng Nai": [
    "trị an, vĩnh cửu, đồng nai",
    "trij an, vixnh cuwru, ddoofng nai"
  ],
  "Tuy Lộc, Hậu Lộc, Thanh Hóa": [
    "tuy lộc, hậu lộc, thanh hóa",
    "tuy loojc, haaju loojc, thanh hosa"
  ],
  "Tuyên Bình, Vĩnh Hưng, Long An": [
    "tuyên bình, vĩnh hưng, long an",
    "tuyeen bifnh, vixnh huwng, long an"
  ],
  "Tà Nung, Đà Lạt, Lâm Đồng": [
    "tà nung, đà lạt, lâm đồng",
    "taf nung, ddaf lajt, laam ddoofng"
  ],
  "Tân An, Chiêm Hóa, Tuyên Quang": [
    "tân an, chiêm hóa, tuyên quang",
    "taan an, chieem hosa, tuyeen quang"
  ],
  "Tân Bình, Bình Tân, Vĩnh Long": [
    "tân bình, bình tân, vĩnh long",
    "taan bifnh, bifnh taan, vixnh long"
  ],
  "Tân Bình, Như Xuân, Thanh Hóa": [
    "tân bình, như xuân, thanh hóa",
    "taan bifnh, nhuw xuaan, thanh hosa"
  ],
  "Tân Bắc, Quang Bình, Hà Giang": [
    "tân bắc, quang bình, hà giang",
    "taan bawsc, quang bifnh, haf giang"
  ],
  "Tân Bằng, Thới Bình, Cà Mau": [
    "tân bằng, thới bình, cà mau",
    "taan bawfng, thowsi bifnh, caf mau"
  ],
  "Tân Duyệt, Đầm Dơi, Cà Mau": [
    "tân duyệt, đầm dơi, cà mau",
    "taan duyeejt, ddaafm dowi, caf mau"
  ],
  "Tân Dân, Hạ Long, Quảng Ninh": [
    "tân dân, hạ long, quảng ninh",
    "taan daan, haj long, quarng ninh"
  ],
  "Tân Dân, Việt Trì, Phú Thọ": [
    "tân dân, việt trì, phú thọ",
    "taan daan, vieejt trif, phus thoj"
  ],
  "Tân Dân, Đức Thọ, Hà Tĩnh": [
    "tân dân, đức thọ, hà tĩnh",
    "taan daan, dduwsc thoj, haf tixnh"
  ],
  "Tân Dương, Bảo Yên, Lào Cai": [
    "tân dương, bảo yên, lào cai",
    "taan duwowng, baro yeen, lafo cai"
  ],
  "Tân Giang, Cao Bằng, Cao Bằng": [
    "tân giang, cao bằng, cao bằng",
    "taan giang, cao bawfng, cao bawfng"
  ],
  "Tân Hiệp, Hội An, Quảng Nam": [
    "tân hiệp, hội an, quảng nam",
    "taan hieejp, hooji an, quarng nam"
  ],
  "Tân Hiệp, Thạnh Hóa, Long An": [
    "tân hiệp, thạnh hóa, long an",
    "taan hieejp, thajnh hosa, long an"
  ],
  "Tân Hiệp, Tân Châu, Tây Ninh": [
    "tân hiệp, tân châu, tây ninh",
    "taan hieejp, taan chaau, taay ninh"
  ],
  "Tân Hà, Hàm Tân, Bình Thuận": [
    "tân hà, hàm tân, bình thuận",
    "taan haf, hafm taan, bifnh thuaajn"
  ],
  "Tân Hòa, Biên Hòa, Đồng Nai": [
    "tân hòa, biên hòa, đồng nai",
    "taan hofa, bieen hofa, ddoofng nai"
  ],
  "Tân Hòa, Lai Vung, Đồng Tháp": [
    "tân hòa, lai vung, đồng tháp",
    "taan hofa, lai vung, ddoofng thasp"
  ],
  "Tân Hòa, Tiểu Cần, Trà Vinh": [
    "tân hòa, tiểu cần, trà vinh",
    "taan hofa, tieeru caafn, traf vinh"
  ],
  "Tân Hưng, Bình Tân, Vĩnh Long": [
    "tân hưng, bình tân, vĩnh long",
    "taan huwng, bifnh taan, vixnh long"
  ],
  "Tân Hưng, Cái Bè, Tiền Giang": [
    "tân hưng, cái bè, tiền giang",
    "taan huwng, casi bef, tieefn giang"
  ],
  "Tân Hưng, Hưng Yên, Hưng Yên": [
    "tân hưng, hưng yên, hưng yên",
    "taan huwng, huwng yeen, huwng yeen"
  ],
  "Tân Hưng, Long Phú, Sóc Trăng": [
    "tân hưng, long phú, sóc trăng",
    "taan huwng, long phus, sosc trawng"
  ],
  "Tân Hương, Tân Kỳ, Nghệ An": [
    "tân hương, tân kỳ, nghệ an",
    "taan huwowng, taan kyf, ngheej an"
  ],
  "Tân Hạnh, Long Hồ, Vĩnh Long": [
    "tân hạnh, long hồ, vĩnh long",
    "taan hajnh, long hoof, vixnh long"
  ],
  "Tân Hồng, Từ Sơn, Bắc Ninh": [
    "tân hồng, từ sơn, bắc ninh",
    "taan hoofng, tuwf sown, bawsc ninh"
  ],
  "Tân Hội, Vĩnh Long, Vĩnh Long": [
    "tân hội, vĩnh long, vĩnh long",
    "taan hooji, vixnh long, vixnh long"
  ],
  "Tân Liên, Cao Lộc, Lạng Sơn": [
    "tân liên, cao lộc, lạng sơn",
    "taan lieen, cao loojc, lajng sown"
  ],
  "Tân Long, Yên Sơn, Tuyên Quang": [
    "tân long, yên sơn, tuyên quang",
    "taan long, yeen sown, tuyeen quang"
  ],
  "Tân Lân, Cần Đước, Long An": [
    "tân lân, cần đước, long an",
    "taan laan, caafn dduwowsc, long an"
  ],
  "Tân Lạc, Quỳ Châu, Nghệ An": [
    "tân lạc, quỳ châu, nghệ an",
    "taan lajc, quyf chaau, ngheej an"
  ],
  "Tân Lập, Bắc Quang, Hà Giang": [
    "tân lập, bắc quang, hà giang",
    "taan laajp, bawsc quang, haf giang"
  ],
  "Tân Lập, Lạc Sơn, Hoà Bình": [
    "tân lập, lạc sơn, hoà bình",
    "taan laajp, lajc sown, hoaf bifnh"
  ],
  "Tân Lập, Nha Trang, Khánh Hòa": [
    "tân lập, nha trang, khánh hòa",
    "taan laajp, nha trang, khasnh hofa"
  ],
  "Tân Lập, Sông Lô, Vĩnh Phúc": [
    "tân lập, sông lô, vĩnh phúc",
    "taan laajp, soong loo, vixnh phusc"
  ],
  "Tân Lập, Thanh Sơn, Phú Thọ": [
    "tân lập, thanh sơn, phú thọ",
    "taan laajp, thanh sown, phus thoj"
  ],
  "Tân Lập, Tịnh Biên, An Giang": [
    "tân lập, tịnh biên, an giang",
    "taan laajp, tijnh bieen, an giang"
  ],
  "Tân Lợi, Tịnh Biên, An Giang": [
    "tân lợi, tịnh biên, an giang",
    "taan lowji, tijnh bieen, an giang"
  ],
  "Tân Mỹ, Văn Lãng, Lạng Sơn": [
    "tân mỹ, văn lãng, lạng sơn",
    "taan myx, vawn laxng, lajng sown"
  ],
  "Tân Nghĩa, Di Linh, Lâm Đồng": [
    "tân nghĩa, di linh, lâm đồng",
    "taan nghixa, di linh, laam ddoofng"
  ],
  "Tân Ngãi, Vĩnh Long, Vĩnh Long": [
    "tân ngãi, vĩnh long, vĩnh long",
    "taan ngaxi, vixnh long, vixnh long"
  ],
  "Tân Phú, Cai Lậy, Tiền Giang": [
    "tân phú, cai lậy, tiền giang",
    "taan phus, cai laajy, tieefn giang"
  ],
  "Tân Phú, Châu Thành, Bến Tre": [
    "tân phú, châu thành, bến tre",
    "taan phus, chaau thafnh, beesn tre"
  ],
  "Tân Quang, Bắc Quang, Hà Giang": [
    "tân quang, bắc quang, hà giang",
    "taan quang, bawsc quang, haf giang"
  ],
  "Tân Quy, Quận 7, Hồ Chí Minh": [
    "tân quy, quận 7, hồ chí minh",
    "taan quy, quaajn 7, hoof chis minh"
  ],
  "Tân Sơn, Ninh Sơn, Ninh Thuận": [
    "tân sơn, ninh sơn, ninh thuận",
    "taan sown, ninh sown, ninh thuaajn"
  ],
  "Tân Sơn, Quỳnh Lưu, Nghệ An": [
    "tân sơn, quỳnh lưu, nghệ an",
    "taan sown, quyfnh luwu, ngheej an"
  ],
  "Tân Sơn, Đô Lương, Nghệ An": [
    "tân sơn, đô lương, nghệ an",
    "taan sown, ddoo luwowng, ngheej an"
  ],
  "Tân Thanh, Cái Bè, Tiền Giang": [
    "tân thanh, cái bè, tiền giang",
    "taan thanh, casi bef, tieefn giang"
  ],
  "Tân Thanh, Lâm Hà, Lâm Đồng": [
    "tân thanh, lâm hà, lâm đồng",
    "taan thanh, laam haf, laam ddoofng"
  ],
  "Tân Thiện, La Gi, Bình Thuận": [
    "tân thiện, la gi, bình thuận",
    "taan thieejn, la gi, bifnh thuaajn"
  ],
  "Tân Thuận, Đầm Dơi, Cà Mau": [
    "tân thuận, đầm dơi, cà mau",
    "taan thuaajn, ddaafm dowi, caf mau"
  ],
  "Tân Thành, Mai Châu, Hoà Bình": [
    "tân thành, mai châu, hoà bình",
    "taan thafnh, mai chaau, hoaf bifnh"
  ],
  "Tân Thành, Thủ Thừa, Long An": [
    "tân thành, thủ thừa, long an",
    "taan thafnh, thur thuwfa, long an"
  ],
  "Tân Thành, Tân Châu, Tây Ninh": [
    "tân thành, tân châu, tây ninh",
    "taan thafnh, taan chaau, taay ninh"
  ],
  "Tân Thành, Tân Thạnh, Long An": [
    "tân thành, tân thạnh, long an",
    "taan thafnh, taan thajnh, long an"
  ],
  "Tân Thạnh, An Minh, Kiên Giang": [
    "tân thạnh, an minh, kiên giang",
    "taan thajnh, an minh, kieen giang"
  ],
  "Tân Thạnh, Tân Châu, An Giang": [
    "tân thạnh, tân châu, an giang",
    "taan thajnh, taan chaau, an giang"
  ],
  "Tân Thịnh, Yên Bái, Yên Bái": [
    "tân thịnh, yên bái, yên bái",
    "taan thijnh, yeen basi, yeen basi"
  ],
  "Tân Trung, Tân Yên, Bắc Giang": [
    "tân trung, tân yên, bắc giang",
    "taan trung, taan yeen, bawsc giang"
  ],
  "Tân Tác, Văn Lãng, Lạng Sơn": [
    "tân tác, văn lãng, lạng sơn",
    "taan tasc, vawn laxng, lajng sown"
  ],
  "Tân Tập, Cần Giuộc, Long An": [
    "tân tập, cần giuộc, long an",
    "taan taajp, caafn giuoojc, long an"
  ],
  "Tân Việt, Yên Mỹ, Hưng Yên": [
    "tân việt, yên mỹ, hưng yên",
    "taan vieejt, yeen myx, huwng yeen"
  ],
  "Tân Yên, Hàm Yên, Tuyên Quang": [
    "tân yên, hàm yên, tuyên quang",
    "taan yeen, hafm yeen, tuyeen quang"
  ],
  "Tân Đông, Thạnh Hóa, Long An": [
    "tân đông, thạnh hóa, long an",
    "taan ddoong, thajnh hosa, long an"
  ],
  "Tân Đông, Tân Châu, Tây Ninh": [
    "tân đông, tân châu, tây ninh",
    "taan ddoong, taan chaau, taay ninh"
  ],
  "Tây Hiếu, Thái Hoà, Nghệ An": [
    "tây hiếu, thái hoà, nghệ an",
    "taay hieesu, thasi hoaf, ngheej an"
  ],
  "Tây Hồ, Thọ Xuân, Thanh Hóa": [
    "tây hồ, thọ xuân, thanh hóa",
    "taay hoof, thoj xuaan, thanh hosa"
  ],
  "Tây Sơn, Tam Điệp, Ninh Bình": [
    "tây sơn, tam điệp, ninh bình",
    "taay sown, tam ddieejp, ninh bifnh"
  ],
  "Tây Yên A, An Biên, Kiên Giang": [
    "tây yên a, an biên, kiên giang",
    "taay yeen a, an bieen, kieen giang"
  ],
  "Tông Cọ, Thuận Châu, Sơn La": [
    "tông cọ, thuận châu, sơn la",
    "toong coj, thuaajn chaau, sown la"
  ],
  "Tùng Khê, Cẩm Khê, Phú Thọ": [
    "tùng khê, cẩm khê, phú thọ",
    "tufng khee, caarm khee, phus thoj"
  ],
  "Tùng Vài, Quản Bạ, Hà Giang": [
    "tùng vài, quản bạ, hà giang",
    "tufng vafi, quarn baj, haf giang"
  ],
  "Tú Xuyên, Văn Quan, Lạng Sơn": [
    "tú xuyên, văn quan, lạng sơn",
    "tus xuyeen, vawn quan, lajng sown"
  ],
  "Tĩnh Hải, Tĩnh Gia, Thanh Hóa": [
    "tĩnh hải, tĩnh gia, thanh hóa",
    "tixnh hari, tixnh gia, thanh hosa"
  ],
  "Tư Mại, Yên Dũng, Bắc Giang": [
    "tư mại, yên dũng, bắc giang",
    "tuw maji, yeen duxng, bawsc giang"
  ],
  "Tương Mai, Hoàng Mai, Hà Nội": [
    "tương mai, hoàng mai, hà nội",
    "tuwowng mai, hoafng mai, haf nooji"
  ],
  "Tường Phong, Phù Yên, Sơn La": [
    "tường phong, phù yên, sơn la",
    "tuwowfng phong, phuf yeen, sown la"
  ],
  "Tường Sơn, Anh Sơn, Nghệ An": [
    "tường sơn, anh sơn, nghệ an",
    "tuwowfng sown, anh sown, ngheej an"
  ],
  "Tả Lủng, Mèo Vạc, Hà Giang": [
    "tả lủng, mèo vạc, hà giang",
    "tar lurng, mefo vajc, haf giang"
  ],
  "Tả Van Chư, Bắc Hà, Lào Cai": [
    "tả van chư, bắc hà, lào cai",
    "tar van chuw, bawsc haf, lafo cai"
  ],
  "Tề Lỗ, Yên Lạc, Vĩnh Phúc": [
    "tề lỗ, yên lạc, vĩnh phúc",
    "teef loox, yeen lajc, vixnh phusc"
  ],
  "Tống Phan, Phù Cừ, Hưng Yên": [
    "tống phan, phù cừ, hưng yên",
    "toosng phan, phuf cuwf, huwng yeen"
  ],
  "Tứ Hiệp, Hạ Hoà, Phú Thọ": [
    "tứ hiệp, hạ hoà, phú thọ",
    "tuws hieejp, haj hoaf, phus thoj"
  ],
  "Tứ Hiệp, Thanh Trì, Hà Nội": [
    "tứ hiệp, thanh trì, hà nội",
    "tuws hieejp, thanh trif, haf nooji"
  ],
  "Vinh Tiền, Tân Sơn, Phú Thọ": [
    "vinh tiền, tân sơn, phú thọ",
    "vinh tieefn, taan sown, phus thoj"
  ],
  "Viên Nội, Ứng Hòa, Hà Nội": [
    "viên nội, ứng hòa, hà nội",
    "vieen nooji, uwsng hofa, haf nooji"
  ],
  "Việt Thắng, Phú Tân, Cà Mau": [
    "việt thắng, phú tân, cà mau",
    "vieejt thawsng, phus taan, caf mau"
  ],
  "Vàng San, Mường Tè, Lai Châu": [
    "vàng san, mường tè, lai châu",
    "vafng san, muwowfng tef, lai chaau"
  ],
  "Vân Canh, Hoài Đức, Hà Nội": [
    "vân canh, hoài đức, hà nội",
    "vaan canh, hoafi dduwsc, haf nooji"
  ],
  "Vân Côn, Hoài Đức, Hà Nội": [
    "vân côn, hoài đức, hà nội",
    "vaan coon, hoafi dduwsc, haf nooji"
  ],
  "Vân Giang, Ninh Bình, Ninh Bình": [
    "vân giang, ninh bình, ninh bình",
    "vaan giang, ninh bifnh, ninh bifnh"
  ],
  "Vân Hà, Việt Yên, Bắc Giang": [
    "vân hà, việt yên, bắc giang",
    "vaan haf, vieejt yeen, bawsc giang"
  ],
  "Vân Hội, Trấn Yên, Yên Bái": [
    "vân hội, trấn yên, yên bái",
    "vaan hooji, traasn yeen, yeen basi"
  ],
  "Vân Phú, Việt Trì, Phú Thọ": [
    "vân phú, việt trì, phú thọ",
    "vaan phus, vieejt trif, phus thoj"
  ],
  "Vân Phúc, Phúc Thọ, Hà Nội": [
    "vân phúc, phúc thọ, hà nội",
    "vaan phusc, phusc thoj, haf nooji"
  ],
  "Vân Âm, Ngọc Lặc, Thanh Hóa": [
    "vân âm, ngọc lặc, thanh hóa",
    "vaan aam, ngojc lawjc, thanh hosa"
  ],
  "Vân Đình, Ứng Hòa, Hà Nội": [
    "vân đình, ứng hòa, hà nội",
    "vaan ddifnh, uwsng hofa, haf nooji"
  ],
  "Võ Miếu, Thanh Sơn, Phú Thọ": [
    "võ miếu, thanh sơn, phú thọ",
    "vox mieesu, thanh sown, phus thoj"
  ],
  "Võ Xu, Đức Linh, Bình Thuận": [
    "võ xu, đức linh, bình thuận",
    "vox xu, dduwsc linh, bifnh thuaajn"
  ],
  "Văn Cẩm, Hưng Hà, Thái Bình": [
    "văn cẩm, hưng hà, thái bình",
    "vawn caarm, huwng haf, thasi bifnh"
  ],
  "Văn Giang, Văn Giang, Hưng Yên": [
    "văn giang, văn giang, hưng yên",
    "vawn giang, vawn giang, huwng yeen"
  ],
  "Văn Giáo, Tịnh Biên, An Giang": [
    "văn giáo, tịnh biên, an giang",
    "vawn giaso, tijnh bieen, an giang"
  ],
  "Văn Khúc, Cẩm Khê, Phú Thọ": [
    "văn khúc, cẩm khê, phú thọ",
    "vawn khusc, caarm khee, phus thoj"
  ],
  "Văn Luông, Tân Sơn, Phú Thọ": [
    "văn luông, tân sơn, phú thọ",
    "vawn luoong, taan sown, phus thoj"
  ],
  "Văn Lợi, Quỳ Hợp, Nghệ An": [
    "văn lợi, quỳ hợp, nghệ an",
    "vawn lowji, quyf howjp, ngheej an"
  ],
  "Văn Nho, Bá Thước, Thanh Hóa": [
    "văn nho, bá thước, thanh hóa",
    "vawn nho, bas thuwowsc, thanh hosa"
  ],
  "Văn Sơn, Đô Lương, Nghệ An": [
    "văn sơn, đô lương, nghệ an",
    "vawn sown, ddoo luwowng, ngheej an"
  ],
  "Văn Võ, Chương Mỹ, Hà Nội": [
    "văn võ, chương mỹ, hà nội",
    "vawn vox, chuwowng myx, haf nooji"
  ],
  "Vĩnh An, Tây Sơn, Bình Định": [
    "vĩnh an, tây sơn, bình định",
    "vixnh an, taay sown, bifnh ddijnh"
  ],
  "Vĩnh An, Vĩnh Cửu, Đồng Nai": [
    "vĩnh an, vĩnh cửu, đồng nai",
    "vixnh an, vixnh cuwru, ddoofng nai"
  ],
  "Vĩnh Chân, Hạ Hoà, Phú Thọ": [
    "vĩnh chân, hạ hoà, phú thọ",
    "vixnh chaan, haj hoaf, phus thoj"
  ],
  "Vĩnh Châu A, Tân Hưng, Long An": [
    "vĩnh châu a, tân hưng, long an",
    "vixnh chaau a, taan huwng, long an"
  ],
  "Vĩnh Châu B, Tân Hưng, Long An": [
    "vĩnh châu b, tân hưng, long an",
    "vixnh chaau b, taan huwng, long an"
  ],
  "Vĩnh Công, Châu Thành, Long An": [
    "vĩnh công, châu thành, long an",
    "vixnh coong, chaau thafnh, long an"
  ],
  "Vĩnh Hanh, Châu Thành, An Giang": [
    "vĩnh hanh, châu thành, an giang",
    "vixnh hanh, chaau thafnh, an giang"
  ],
  "Vĩnh Hòa, Chợ Lách, Bến Tre": [
    "vĩnh hòa, chợ lách, bến tre",
    "vixnh hofa, chowj lasch, beesn tre"
  ],
  "Vĩnh Hòa, Nha Trang, Khánh Hòa": [
    "vĩnh hòa, nha trang, khánh hòa",
    "vixnh hofa, nha trang, khasnh hofa"
  ],
  "Vĩnh Hưng, Hoàng Mai, Hà Nội": [
    "vĩnh hưng, hoàng mai, hà nội",
    "vixnh huwng, hoafng mai, haf nooji"
  ],
  "Vĩnh Kiên, Yên Bình, Yên Bái": [
    "vĩnh kiên, yên bình, yên bái",
    "vixnh kieen, yeen bifnh, yeen basi"
  ],
  "Vĩnh Lạc, Lục Yên, Yên Bái": [
    "vĩnh lạc, lục yên, yên bái",
    "vixnh lajc, lujc yeen, yeen basi"
  ],
  "Vĩnh Lại, Lâm Thao, Phú Thọ": [
    "vĩnh lại, lâm thao, phú thọ",
    "vixnh laji, laam thao, phus thoj"
  ],
  "Vĩnh Mỹ, Châu Đốc, An Giang": [
    "vĩnh mỹ, châu đốc, an giang",
    "vixnh myx, chaau ddoosc, an giang"
  ],
  "Vĩnh Phú, Thoại Sơn, An Giang": [
    "vĩnh phú, thoại sơn, an giang",
    "vixnh phus, thoaji sown, an giang"
  ],
  "Vĩnh Phước, Tri Tôn, An Giang": [
    "vĩnh phước, tri tôn, an giang",
    "vixnh phuwowsc, tri toon, an giang"
  ],
  "Vĩnh Thạnh, Tân Hưng, Long An": [
    "vĩnh thạnh, tân hưng, long an",
    "vixnh thajnh, taan huwng, long an"
  ],
  "Vĩnh Tiến, Kim Bôi, Hoà Bình": [
    "vĩnh tiến, kim bôi, hoà bình",
    "vixnh tieesn, kim booi, hoaf bifnh"
  ],
  "Vĩnh Trường, An Phú, An Giang": [
    "vĩnh trường, an phú, an giang",
    "vixnh truwowfng, an phus, an giang"
  ],
  "Vĩnh Tế, Châu Đốc, An Giang": [
    "vĩnh tế, châu đốc, an giang",
    "vixnh tees, chaau ddoosc, an giang"
  ],
  "Vĩnh Xá, Kim Động, Hưng Yên": [
    "vĩnh xá, kim động, hưng yên",
    "vixnh xas, kim ddoojng, huwng yeen"
  ],
  "Vĩnh Yên, Bình Gia, Lạng Sơn": [
    "vĩnh yên, bình gia, lạng sơn",
    "vixnh yeen, bifnh gia, lajng sown"
  ],
  "Vũ Lăng, Bắc Sơn, Lạng Sơn": [
    "vũ lăng, bắc sơn, lạng sơn",
    "vux lawng, bawsc sown, lajng sown"
  ],
  "Vạn Linh, Chi Lăng, Lạng Sơn": [
    "vạn linh, chi lăng, lạng sơn",
    "vajn linh, chi lawng, lajng sown"
  ],
  "Vạn Phúc, Hà Đông, Hà Nội": [
    "vạn phúc, hà đông, hà nội",
    "vajn phusc, haf ddoong, haf nooji"
  ],
  "Vạn Phúc, Thanh Trì, Hà Nội": [
    "vạn phúc, thanh trì, hà nội",
    "vajn phusc, thanh trif, haf nooji"
  ],
  "Vạn Thái, Ứng Hòa, Hà Nội": [
    "vạn thái, ứng hòa, hà nội",
    "vajn thasi, uwsng hofa, haf nooji"
  ],
  "Vạn Xuân, Tam Nông, Phú Thọ": [
    "vạn xuân, tam nông, phú thọ",
    "vajn xuaan, tam noong, phus thoj"
  ],
  "Vầy Nưa, Đà Bắc, Hoà Bình": [
    "vầy nưa, đà bắc, hoà bình",
    "vaafy nuwa, ddaf bawsc, hoaf bifnh"
  ],
  "Vị Tân, Vị Thanh, Hậu Giang": [
    "vị tân, vị thanh, hậu giang",
    "vij taan, vij thanh, haaju giang"
  ],
  "Vụ Bản, Lạc Sơn, Hoà Bình": [
    "vụ bản, lạc sơn, hoà bình",
    "vuj barn, lajc sown, hoaf bifnh"
  ],
  "Xuân An, Long Khánh, Đồng Nai": [
    "xuân an, long khánh, đồng nai",
    "xuaan an, long khasnh, ddoofng nai"
  ],
  "Xuân Chính, Kim Sơn, Ninh Bình": [
    "xuân chính, kim sơn, ninh bình",
    "xuaan chisnh, kim sown, ninh bifnh"
  ],
  "Xuân Dương, Na Rì, Bắc Kạn": [
    "xuân dương, na rì, bắc kạn",
    "xuaan duwowng, na rif, bawsc kajn"
  ],
  "Xuân Dục, Mỹ Hào, Hưng Yên": [
    "xuân dục, mỹ hào, hưng yên",
    "xuaan dujc, myx hafo, huwng yeen"
  ],
  "Xuân Giang, Nghi Xuân, Hà Tĩnh": [
    "xuân giang, nghi xuân, hà tĩnh",
    "xuaan giang, nghi xuaan, haf tixnh"
  ],
  "Xuân Hiệp, Trà Ôn, Vĩnh Long": [
    "xuân hiệp, trà ôn, vĩnh long",
    "xuaan hieejp, traf oon, vixnh long"
  ],
  "Xuân Hà, Thanh Khê, Đà Nẵng": [
    "xuân hà, thanh khê, đà nẵng",
    "xuaan haf, thanh khee, ddaf nawxng"
  ],
  "Xuân Hòa, Như Xuân, Thanh Hóa": [
    "xuân hòa, như xuân, thanh hóa",
    "xuaan hofa, nhuw xuaan, thanh hosa"
  ],
  "Xuân Hải, Nghi Xuân, Hà Tĩnh": [
    "xuân hải, nghi xuân, hà tĩnh",
    "xuaan hari, nghi xuaan, haf tixnh"
  ],
  "Xuân Hội, Nghi Xuân, Hà Tĩnh": [
    "xuân hội, nghi xuân, hà tĩnh",
    "xuaan hooji, nghi xuaan, haf tixnh"
  ],
  "Xuân Lai, Thọ Xuân, Thanh Hóa": [
    "xuân lai, thọ xuân, thanh hóa",
    "xuaan lai, thoj xuaan, thanh hosa"
  ],
  "Xuân Liên, Nghi Xuân, Hà Tĩnh": [
    "xuân liên, nghi xuân, hà tĩnh",
    "xuaan lieen, nghi xuaan, haf tixnh"
  ],
  "Xuân Long, Cao Lộc, Lạng Sơn": [
    "xuân long, cao lộc, lạng sơn",
    "xuaan long, cao loojc, lajng sown"
  ],
  "Xuân Lâm, Sông Cầu, Phú Yên": [
    "xuân lâm, sông cầu, phú yên",
    "xuaan laam, soong caafu, phus yeen"
  ],
  "Xuân Lĩnh, Nghi Xuân, Hà Tĩnh": [
    "xuân lĩnh, nghi xuân, hà tĩnh",
    "xuaan lixnh, nghi xuaan, haf tixnh"
  ],
  "Xuân Lũng, Lâm Thao, Phú Thọ": [
    "xuân lũng, lâm thao, phú thọ",
    "xuaan luxng, laam thao, phus thoj"
  ],
  "Xuân Minh, Quang Bình, Hà Giang": [
    "xuân minh, quang bình, hà giang",
    "xuaan minh, quang bifnh, haf giang"
  ],
  "Xuân Nộn, Đông Anh, Hà Nội": [
    "xuân nộn, đông anh, hà nội",
    "xuaan noojn, ddoong anh, haf nooji"
  ],
  "Xuân Phú, Sông Cầu, Phú Yên": [
    "xuân phú, sông cầu, phú yên",
    "xuaan phus, soong caafu, phus yeen"
  ],
  "Xuân Phổ, Nghi Xuân, Hà Tĩnh": [
    "xuân phổ, nghi xuân, hà tĩnh",
    "xuaan phoor, nghi xuaan, haf tixnh"
  ],
  "Xuân Quan, Văn Giang, Hưng Yên": [
    "xuân quan, văn giang, hưng yên",
    "xuaan quan, vawn giang, huwng yeen"
  ],
  "Xuân Thủy, Kim Bôi, Hoà Bình": [
    "xuân thủy, kim bôi, hoà bình",
    "xuaan thury, kim booi, hoaf bifnh"
  ],
  "Xuân Viên, Nghi Xuân, Hà Tĩnh": [
    "xuân viên, nghi xuân, hà tĩnh",
    "xuaan vieen, nghi xuaan, haf tixnh"
  ],
  "Xuân Yên, Sông Cầu, Phú Yên": [
    "xuân yên, sông cầu, phú yên",
    "xuaan yeen, soong caafu, phus yeen"
  ],
  "Xuân Đài, Tân Sơn, Phú Thọ": [
    "xuân đài, tân sơn, phú thọ",
    "xuaan ddafi, taan sown, phus thoj"
  ],
  "Xà Phiên, Long Mỹ, Hậu Giang": [
    "xà phiên, long mỹ, hậu giang",
    "xaf phieen, long myx, haaju giang"
  ],
  "Xà Phìn, Đồng Văn, Hà Giang": [
    "xà phìn, đồng văn, hà giang",
    "xaf phifn, ddoofng vawn, haf giang"
  ],
  "Yên Bình, Quang Bình, Hà Giang": [
    "yên bình, quang bình, hà giang",
    "yeen bifnh, quang bifnh, haf giang"
  ],
  "Yên Cư, Chợ Mới, Bắc Kạn": [
    "yên cư, chợ mới, bắc kạn",
    "yeen cuw, chowj mowsi, bawsc kajn"
  ],
  "Yên Dương, Ý Yên, Nam Định": [
    "yên dương, ý yên, nam định",
    "yeen duwowng, ys yeen, nam ddijnh"
  ],
  "Yên Hoà, Cầu Giấy, Hà Nội": [
    "yên hoà, cầu giấy, hà nội",
    "yeen hoaf, caafu giaasy, haf nooji"
  ],
  "Yên Hòa, Cẩm Xuyên, Hà Tĩnh": [
    "yên hòa, cẩm xuyên, hà tĩnh",
    "yeen hofa, caarm xuyeen, haf tixnh"
  ],
  "Yên Hồ, Đức Thọ, Hà Tĩnh": [
    "yên hồ, đức thọ, hà tĩnh",
    "yeen hoof, dduwsc thoj, haf tixnh"
  ],
  "Yên Hợp, Quỳ Hợp, Nghệ An": [
    "yên hợp, quỳ hợp, nghệ an",
    "yeen howjp, quyf howjp, ngheej an"
  ],
  "Yên Luật, Hạ Hoà, Phú Thọ": [
    "yên luật, hạ hoà, phú thọ",
    "yeen luaajt, haj hoaf, phus thoj"
  ],
  "Yên Lâm, Hàm Yên, Tuyên Quang": [
    "yên lâm, hàm yên, tuyên quang",
    "yeen laam, hafm yeen, tuyeen quang"
  ],
  "Yên Lãng, Thanh Sơn, Phú Thọ": [
    "yên lãng, thanh sơn, phú thọ",
    "yeen laxng, thanh sown, phus thoj"
  ],
  "Yên Lương, Ý Yên, Nam Định": [
    "yên lương, ý yên, nam định",
    "yeen luwowng, ys yeen, nam ddijnh"
  ],
  "Yên Lạc, Như Thanh, Thanh Hóa": [
    "yên lạc, như thanh, thanh hóa",
    "yeen lajc, nhuw thanh, thanh hosa"
  ],
  "Yên Lập, Yên Lập, Phú Thọ": [
    "yên lập, yên lập, phú thọ",
    "yeen laajp, yeen laajp, phus thoj"
  ],
  "Yên Mông, Hòa Bình, Hoà Bình": [
    "yên mông, hòa bình, hoà bình",
    "yeen moong, hofa bifnh, hoaf bifnh"
  ],
  "Yên Nghĩa, Hà Đông, Hà Nội": [
    "yên nghĩa, hà đông, hà nội",
    "yeen nghixa, haf ddoong, haf nooji"
  ],
  "Yên Ninh, Yên Khánh, Ninh Bình": [
    "yên ninh, yên khánh, ninh bình",
    "yeen ninh, yeen khasnh, ninh bifnh"
  ],
  "Yên Phú, Hàm Yên, Tuyên Quang": [
    "yên phú, hàm yên, tuyên quang",
    "yeen phus, hafm yeen, tuyeen quang"
  ],
  "Yên Phúc, Văn Quan, Lạng Sơn": [
    "yên phúc, văn quan, lạng sơn",
    "yeen phusc, vawn quan, lajng sown"
  ],
  "Yên Phụ, Yên Phong, Bắc Ninh": [
    "yên phụ, yên phong, bắc ninh",
    "yeen phuj, yeen phong, bawsc ninh"
  ],
  "Yên Sơn, Hà Quảng, Cao Bằng": [
    "yên sơn, hà quảng, cao bằng",
    "yeen sown, haf quarng, cao bawfng"
  ],
  "Yên Sơn, Tam Điệp, Ninh Bình": [
    "yên sơn, tam điệp, ninh bình",
    "yeen sown, tam ddieejp, ninh bifnh"
  ],
  "Yên Sơn, Đô Lương, Nghệ An": [
    "yên sơn, đô lương, nghệ an",
    "yeen sown, ddoo luwowng, ngheej an"
  ],
  "Yên Sở, Hoài Đức, Hà Nội": [
    "yên sở, hoài đức, hà nội",
    "yeen sowr, hoafi dduwsc, haf nooji"
  ],
  "Yên Thành, Yên Bình, Yên Bái": [
    "yên thành, yên bình, yên bái",
    "yeen thafnh, yeen bifnh, yeen basi"
  ],
  "Yên Thắng, Yên Mô, Ninh Bình": [
    "yên thắng, yên mô, ninh bình",
    "yeen thawsng, yeen moo, ninh bifnh"
  ],
  "Yên Thắng, Ý Yên, Nam Định": [
    "yên thắng, ý yên, nam định",
    "yeen thawsng, ys yeen, nam ddijnh"
  ],
  "Yên Thịnh, Yên Bái, Yên Bái": [
    "yên thịnh, yên bái, yên bái",
    "yeen thijnh, yeen basi, yeen basi"
  ],
  "Yên Thịnh, Yên Mô, Ninh Bình": [
    "yên thịnh, yên mô, ninh bình",
    "yeen thijnh, yeen moo, ninh bifnh"
  ],
  "Yên Thọ, Như Thanh, Thanh Hóa": [
    "yên thọ, như thanh, thanh hóa",
    "yeen thoj, nhuw thanh, thanh hosa"
  ],
  "Yên Thổ, Bảo Lâm, Cao Bằng": [
    "yên thổ, bảo lâm, cao bằng",
    "yeen thoor, baro laam, cao bawfng"
  ],
  "Yên Trung, Yên Phong, Bắc Ninh": [
    "yên trung, yên phong, bắc ninh",
    "yeen trung, yeen phong, bawsc ninh"
  ],
  "Yên Tập, Cẩm Khê, Phú Thọ": [
    "yên tập, cẩm khê, phú thọ",
    "yeen taajp, caarm khee, phus thoj"
  ],
  "Yên Định, Bắc Mê, Hà Giang": [
    "yên định, bắc mê, hà giang",
    "yeen ddijnh, bawsc mee, haf giang"
  ],
  "Yên Đồng, Yên Mô, Ninh Bình": [
    "yên đồng, yên mô, ninh bình",
    "yeen ddoofng, yeen moo, ninh bifnh"
  ],
  "Yên Đồng, Ý Yên, Nam Định": [
    "yên đồng, ý yên, nam định",
    "yeen ddoofng, ys yeen, nam ddijnh"
  ],
  "Yết Kiêu, Hà Đông, Hà Nội": [
    "yết kiêu, hà đông, hà nội",
    "yeest kieeu, haf ddoong, haf nooji"
  ],
  "Za Hung, Đông Giang, Quảng Nam": [
    "za hung, đông giang, quảng nam",
    "za hung, ddoong giang, quarng nam"
  ],
  "Ân Mỹ, Hoài Ân, Bình Định": [
    "ân mỹ, hoài ân, bình định",
    "aan myx, hoafi aan, bifnh ddijnh"
  ],
  "Ân Nghĩa, Lạc Sơn, Hoà Bình": [
    "ân nghĩa, lạc sơn, hoà bình",
    "aan nghixa, lajc sown, hoaf bifnh"
  ],
  "Ân Sơn, Hoài Ân, Bình Định": [
    "ân sơn, hoài ân, bình định",
    "aan sown, hoafi aan, bifnh ddijnh"
  ],
  "Ân Tín, Hoài Ân, Bình Định": [
    "ân tín, hoài ân, bình định",
    "aan tisn, hoafi aan, bifnh ddijnh"
  ],
  "Ô Long Vỹ, Châu Phú, An Giang": [
    "ô long vỹ, châu phú, an giang",
    "oo long vyx, chaau phus, an giang"
  ],
  "Đa Lộc, Châu Thành, Trà Vinh": [
    "đa lộc, châu thành, trà vinh",
    "dda loojc, chaau thafnh, traf vinh"
  ],
  "Đa Lộc, Hậu Lộc, Thanh Hóa": [
    "đa lộc, hậu lộc, thanh hóa",
    "dda loojc, haaju loojc, thanh hosa"
  ],
  "Đa Phúc, Yên Thủy, Hoà Bình": [
    "đa phúc, yên thủy, hoà bình",
    "dda phusc, yeen thury, hoaf bifnh"
  ],
  "Đan Hội, Lục Nam, Bắc Giang": [
    "đan hội, lục nam, bắc giang",
    "ddan hooji, lujc nam, bawsc giang"
  ],
  "Đinh Lạc, Di Linh, Lâm Đồng": [
    "đinh lạc, di linh, lâm đồng",
    "ddinh lajc, di linh, laam ddoofng"
  ],
  "Đinh Văn, Lâm Hà, Lâm Đồng": [
    "đinh văn, lâm hà, lâm đồng",
    "ddinh vawn, laam haf, laam ddoofng"
  ],
  "Điềm He, Văn Quan, Lạng Sơn": [
    "điềm he, văn quan, lạng sơn",
    "ddieefm he, vawn quan, lajng sown"
  ],
  "Điện Quan, Bảo Yên, Lào Cai": [
    "điện quan, bảo yên, lào cai",
    "ddieejn quan, baro yeen, lafo cai"
  ],
  "Đoàn Kết, Lai Châu, Lai Châu": [
    "đoàn kết, lai châu, lai châu",
    "ddoafn keest, lai chaau, lai chaau"
  ],
  "Đà Bắc, Đà Bắc, Hoà Bình": [
    "đà bắc, đà bắc, hoà bình",
    "ddaf bawsc, ddaf bawsc, hoaf bifnh"
  ],
  "Đà Sơn, Đô Lương, Nghệ An": [
    "đà sơn, đô lương, nghệ an",
    "ddaf sown, ddoo luwowng, ngheej an"
  ],
  "Đào Dương, Ân Thi, Hưng Yên": [
    "đào dương, ân thi, hưng yên",
    "ddafo duwowng, aan thi, huwng yeen"
  ],
  "Đào Viên, Quế Võ, Bắc Ninh": [
    "đào viên, quế võ, bắc ninh",
    "ddafo vieen, quees vox, bawsc ninh"
  ],
  "Đình Xuyên, Gia Lâm, Hà Nội": [
    "đình xuyên, gia lâm, hà nội",
    "ddifnh xuyeen, gia laam, haf nooji"
  ],
  "Đông Bắc, Kim Bôi, Hoà Bình": [
    "đông bắc, kim bôi, hoà bình",
    "ddoong bawsc, kim booi, hoaf bifnh"
  ],
  "Đông Hà, Quản Bạ, Hà Giang": [
    "đông hà, quản bạ, hà giang",
    "ddoong haf, quarn baj, haf giang"
  ],
  "Đông Hòa, Dĩ An, Bình Dương": [
    "đông hòa, dĩ an, bình dương",
    "ddoong hofa, dix an, bifnh duwowng"
  ],
  "Đông Hưng, An Minh, Kiên Giang": [
    "đông hưng, an minh, kiên giang",
    "ddoong huwng, an minh, kieen giang"
  ],
  "Đông La, Hoài Đức, Hà Nội": [
    "đông la, hoài đức, hà nội",
    "ddoong la, hoafi dduwsc, haf nooji"
  ],
  "Đông Lai, Tân Lạc, Hoà Bình": [
    "đông lai, tân lạc, hoà bình",
    "ddoong lai, taan lajc, hoaf bifnh"
  ],
  "Đông Lĩnh, Thanh Ba, Phú Thọ": [
    "đông lĩnh, thanh ba, phú thọ",
    "ddoong lixnh, thanh ba, phus thoj"
  ],
  "Đông Lỗ, Ứng Hòa, Hà Nội": [
    "đông lỗ, ứng hòa, hà nội",
    "ddoong loox, uwsng hofa, haf nooji"
  ],
  "Đông Mỹ, Thanh Trì, Hà Nội": [
    "đông mỹ, thanh trì, hà nội",
    "ddoong myx, thanh trif, haf nooji"
  ],
  "Đông Phong, Lai Châu, Lai Châu": [
    "đông phong, lai châu, lai châu",
    "ddoong phong, lai chaau, lai chaau"
  ],
  "Đông Xuân, Sóc Sơn, Hà Nội": [
    "đông xuân, sóc sơn, hà nội",
    "ddoong xuaan, sosc sown, haf nooji"
  ],
  "Đông Yên, An Biên, Kiên Giang": [
    "đông yên, an biên, kiên giang",
    "ddoong yeen, an bieen, kieen giang"
  ],
  "Đông Yên, Quốc Oai, Hà Nội": [
    "đông yên, quốc oai, hà nội",
    "ddoong yeen, quoosc oai, haf nooji"
  ],
  "Đăk Pơ Pho, Kông Chro, Gia Lai": [
    "đăk pơ pho, kông chro, gia lai",
    "ddawk pow pho, koong chro, gia lai"
  ],
  "Đại An, Vụ Bản, Nam Định": [
    "đại an, vụ bản, nam định",
    "ddaji an, vuj barn, nam ddijnh"
  ],
  "Đại Bái, Gia Bình, Bắc Ninh": [
    "đại bái, gia bình, bắc ninh",
    "ddaji basi, gia bifnh, bawsc ninh"
  ],
  "Đại Minh, Yên Bình, Yên Bái": [
    "đại minh, yên bình, yên bái",
    "ddaji minh, yeen bifnh, yeen basi"
  ],
  "Đại Phác, Văn Yên, Yên Bái": [
    "đại phác, văn yên, yên bái",
    "ddaji phasc, vawn yeen, yeen basi"
  ],
  "Đại Tiến, Hoà An, Cao Bằng": [
    "đại tiến, hoà an, cao bằng",
    "ddaji tieesn, hoaf an, cao bawfng"
  ],
  "Đại áng, Thanh Trì, Hà Nội": [
    "đại áng, thanh trì, hà nội",
    "ddaji asng, thanh trif, haf nooji"
  ],
  "Đắc Pre, Nam Giang, Quảng Nam": [
    "đắc pre, nam giang, quảng nam",
    "ddawsc pre, nam giang, quarng nam"
  ],
  "Đắk Liêng, Lắk, Đắk Lắk": [
    "đắk liêng, lắk, đắk lắk",
    "ddawsk lieeng, lawsk, ddawsk lawsk"
  ],
  "Đắk Ruồng, Kon Rẫy, Kon Tum": [
    "đắk ruồng, kon rẫy, kon tum",
    "ddawsk ruoofng, kon raaxy, kon tum"
  ],
  "Đắk Tờ Re, Kon Rẫy, Kon Tum": [
    "đắk tờ re, kon rẫy, kon tum",
    "ddawsk towf re, kon raaxy, kon tum"
  ],
  "Đắk Wil, Cư Jút, Đắk Nông": [
    "đắk wil, cư jút, đắk nông",
    "ddawsk wil, cuw just, ddawsk noong"
  ],
  "Định Hóa, Kim Sơn, Ninh Bình": [
    "định hóa, kim sơn, ninh bình",
    "ddijnh hosa, kim sown, ninh bifnh"
  ],
  "Đồng Mai, Hà Đông, Hà Nội": [
    "đồng mai, hà đông, hà nội",
    "ddoofng mai, haf ddoong, haf nooji"
  ],
  "Đồng Môn, Hà Tĩnh, Hà Tĩnh": [
    "đồng môn, hà tĩnh, hà tĩnh",
    "ddoofng moon, haf tixnh, haf tixnh"
  ],
  "Đồng Tâm, Yên Bái, Yên Bái": [
    "đồng tâm, yên bái, yên bái",
    "ddoofng taam, yeen basi, yeen basi"
  ],
  "Đồng Văn, Tân Kỳ, Nghệ An": [
    "đồng văn, tân kỳ, nghệ an",
    "ddoofng vawn, taan kyf, ngheej an"
  ],
  "Đỗ Xuyên, Thanh Ba, Phú Thọ": [
    "đỗ xuyên, thanh ba, phú thọ",
    "ddoox xuyeen, thanh ba, phus thoj"
  ],
  "Đội Cấn, Ba Đình, Hà Nội": [
    "đội cấn, ba đình, hà nội",
    "ddooji caasn, ba ddifnh, haf nooji"
  ],
  "Đức Giang, Vũ Quang, Hà Tĩnh": [
    "đức giang, vũ quang, hà tĩnh",
    "dduwsc giang, vux quang, haf tixnh"
  ],
  "Đức Liên, Vũ Quang, Hà Tĩnh": [
    "đức liên, vũ quang, hà tĩnh",
    "dduwsc lieen, vux quang, haf tixnh"
  ],
  "Đức Long, Quế Võ, Bắc Ninh": [
    "đức long, quế võ, bắc ninh",
    "dduwsc long, quees vox, bawsc ninh"
  ],
  "Đức Lĩnh, Vũ Quang, Hà Tĩnh": [
    "đức lĩnh, vũ quang, hà tĩnh",
    "dduwsc lixnh, vux quang, haf tixnh"
  ],
  "Đức Mỹ, Càng Long, Trà Vinh": [
    "đức mỹ, càng long, trà vinh",
    "dduwsc myx, cafng long, traf vinh"
  ],
  "Ỷ La, Tuyên Quang, Tuyên Quang": [
    "ỷ la, tuyên quang, tuyên quang",
    "yr la, tuyeen quang, tuyeen quang"
  ],
  " Tây Sơn, Hương Sơn, Hà Tĩnh": [
    " tây sơn, hương sơn, hà tĩnh",
    " taay sown, huwowng sown, haf tixnh"
  ],
  "An Bài, Quỳnh Phụ, Thái Bình": [
    "an bài, quỳnh phụ, thái bình",
    "an bafi, quyfnh phuj, thasi bifnh"
  ],
  "An Bình, Phú Giáo, Bình Dương": [
    "an bình, phú giáo, bình dương",
    "an bifnh, phus giaso, bifnh duwowng"
  ],
  "An Châu, Sơn Động, Bắc Giang": [
    "an châu, sơn động, bắc giang",
    "an chaau, sown ddoojng, bawsc giang"
  ],
  "An Châu, Đông Hưng, Thái Bình": [
    "an châu, đông hưng, thái bình",
    "an chaau, ddoong huwng, thasi bifnh"
  ],
  "An Dương, Lê Chân, Hải Phòng": [
    "an dương, lê chân, hải phòng",
    "an duwowng, lee chaan, hari phofng"
  ],
  "An Hòa, Huế, Thừa Thiên Huế": [
    "an hòa, huế, thừa thiên huế",
    "an hofa, huees, thuwfa thieen huees"
  ],
  "An Hồng, An Dương, Hải Phòng": [
    "an hồng, an dương, hải phòng",
    "an hoofng, an duwowng, hari phofng"
  ],
  "An Khánh, Quận 2, Hồ Chí Minh": [
    "an khánh, quận 2, hồ chí minh",
    "an khasnh, quaajn 2, hoof chis minh"
  ],
  "An Khê, Quỳnh Phụ, Thái Bình": [
    "an khê, quỳnh phụ, thái bình",
    "an khee, quyfnh phuj, thasi bifnh"
  ],
  "An Lạc, Sơn Động, Bắc Giang": [
    "an lạc, sơn động, bắc giang",
    "an lajc, sown ddoojng, bawsc giang"
  ],
  "An Lễ, Quỳnh Phụ, Thái Bình": [
    "an lễ, quỳnh phụ, thái bình",
    "an leex, quyfnh phuj, thasi bifnh"
  ],
  "An Mỹ, Quỳnh Phụ, Thái Bình": [
    "an mỹ, quỳnh phụ, thái bình",
    "an myx, quyfnh phuj, thasi bifnh"
  ],
  "An Nhơn, Đạ Tẻh, Lâm Đồng": [
    "an nhơn, đạ tẻh, lâm đồng",
    "an nhown, ddaj terh, laam ddoofng"
  ],
  "An Ninh, Quỳnh Phụ, Thái Bình": [
    "an ninh, quỳnh phụ, thái bình",
    "an ninh, quyfnh phuj, thasi bifnh"
  ],
  "An Phúc, Đông Hải, Bạc Liêu": [
    "an phúc, đông hải, bạc liêu",
    "an phusc, ddoong hari, bajc lieeu"
  ],
  "An Phước, Mang Thít, Vĩnh Long": [
    "an phước, mang thít, vĩnh long",
    "an phuwowsc, mang thist, vixnh long"
  ],
  "An Quí, Quỳnh Phụ, Thái Bình": [
    "an quí, quỳnh phụ, thái bình",
    "an quis, quyfnh phuj, thasi bifnh"
  ],
  "An Thuận, Thạnh Phú, Bến Tre": [
    "an thuận, thạnh phú, bến tre",
    "an thuaajn, thajnh phus, beesn tre"
  ],
  "An Thái, Phú Giáo, Bình Dương": [
    "an thái, phú giáo, bình dương",
    "an thasi, phus giaso, bifnh duwowng"
  ],
  "An Thạnh, Thạnh Phú, Bến Tre": [
    "an thạnh, thạnh phú, bến tre",
    "an thajnh, thajnh phus, beesn tre"
  ],
  "An Thắng, Pác Nặm, Bắc Kạn": [
    "an thắng, pác nặm, bắc kạn",
    "an thawsng, pasc nawjm, bawsc kajn"
  ],
  "An Thới, Bình Thuỷ, Cần Thơ": [
    "an thới, bình thuỷ, cần thơ",
    "an thowsi, bifnh thuyr, caafn thow"
  ],
  "An Thới, Mỏ Cày Nam, Bến Tre": [
    "an thới, mỏ cày nam, bến tre",
    "an thowsi, mor cafy nam, beesn tre"
  ],
  "An Thới, Phú Quốc, Kiên Giang": [
    "an thới, phú quốc, kiên giang",
    "an thowsi, phus quoosc, kieen giang"
  ],
  "An Trường, Càng Long, Trà Vinh": [
    "an trường, càng long, trà vinh",
    "an truwowfng, cafng long, traf vinh"
  ],
  "An Tây, Huế, Thừa Thiên Huế": [
    "an tây, huế, thừa thiên huế",
    "an taay, huees, thuwfa thieen huees"
  ],
  "An Tịnh, Trảng Bàng, Tây Ninh": [
    "an tịnh, trảng bàng, tây ninh",
    "an tijnh, trarng bafng, taay ninh"
  ],
  "An Vinh, Quỳnh Phụ, Thái Bình": [
    "an vinh, quỳnh phụ, thái bình",
    "an vinh, quyfnh phuj, thasi bifnh"
  ],
  "An Viễn, Trảng Bom, Đồng Nai": [
    "an viễn, trảng bom, đồng nai",
    "an vieexn, trarng bom, ddoofng nai"
  ],
  "An Điền, Thạnh Phú, Bến Tre": [
    "an điền, thạnh phú, bến tre",
    "an ddieefn, thajnh phus, beesn tre"
  ],
  "An Ấp, Quỳnh Phụ, Thái Bình": [
    "an ấp, quỳnh phụ, thái bình",
    "an aasp, quyfnh phuj, thasi bifnh"
  ],
  "Ba Hàng, Phổ Yên, Thái Nguyên": [
    "ba hàng, phổ yên, thái nguyên",
    "ba hafng, phoor yeen, thasi nguyeen"
  ],
  "Ba Lòng, Đa Krông, Quảng Trị": [
    "ba lòng, đa krông, quảng trị",
    "ba lofng, dda kroong, quarng trij"
  ],
  "Ba Đồn, Ba Đồn, Quảng Bình": [
    "ba đồn, ba đồn, quảng bình",
    "ba ddoofn, ba ddoofn, quarng bifnh"
  ],
  "Ban Công, Bá Thước, Thanh Hóa": [
    "ban công, bá thước, thanh hóa",
    "ban coong, bas thuwowsc, thanh hosa"
  ],
  "Bok Tới, Hoài Ân, Bình Định": [
    "bok tới, hoài ân, bình định",
    "bok towsi, hoafi aan, bifnh ddijnh"
  ],
  "Bon Phặng, Thuận Châu, Sơn La": [
    "bon phặng, thuận châu, sơn la",
    "bon phawjng, thuaajn chaau, sown la"
  ],
  "Bành Trạch, Ba Bể, Bắc Kạn": [
    "bành trạch, ba bể, bắc kạn",
    "bafnh trajch, ba beer, bawsc kajn"
  ],
  "Bàu Hàm, Trảng Bom, Đồng Nai": [
    "bàu hàm, trảng bom, đồng nai",
    "bafu hafm, trarng bom, ddoofng nai"
  ],
  "Bãi Cháy, Hạ Long, Quảng Ninh": [
    "bãi cháy, hạ long, quảng ninh",
    "baxi chasy, haj long, quarng ninh"
  ],
  "Bãi Trành, Như Xuân, Thanh Hóa": [
    "bãi trành, như xuân, thanh hóa",
    "baxi trafnh, nhuw xuaan, thanh hosa"
  ],
  "Bình An, Bình Sơn, Quảng Ngãi": [
    "bình an, bình sơn, quảng ngãi",
    "bifnh an, bifnh sown, quarng ngaxi"
  ],
  "Bình An, Châu Thành, Kiên Giang": [
    "bình an, châu thành, kiên giang",
    "bifnh an, chaau thafnh, kieen giang"
  ],
  "Bình An, Thăng Bình, Quảng Nam": [
    "bình an, thăng bình, quảng nam",
    "bifnh an, thawng bifnh, quarng nam"
  ],
  "Bình Hẻm, Lạc Sơn, Hoà Bình": [
    "bình hẻm, lạc sơn, hoà bình",
    "bifnh herm, lajc sown, hoaf bifnh"
  ],
  "Bình Khánh, Long Xuyên, An Giang": [
    "bình khánh, long xuyên, an giang",
    "bifnh khasnh, long xuyeen, an giang"
  ],
  "Bình Long, Võ Nhai, Thái Nguyên": [
    "bình long, võ nhai, thái nguyên",
    "bifnh long, vox nhai, thasi nguyeen"
  ],
  "Bình Lư, Tam Đường, Lai Châu": [
    "bình lư, tam đường, lai châu",
    "bifnh luw, tam dduwowfng, lai chaau"
  ],
  "Bình Minh, Nam Trực, Nam Định": [
    "bình minh, nam trực, nam định",
    "bifnh minh, nam truwjc, nam ddijnh"
  ],
  "Bình Phú, Cai Lậy, Tiền Giang": [
    "bình phú, cai lậy, tiền giang",
    "bifnh phus, cai laajy, tieefn giang"
  ],
  "Bình Phúc, Văn Quan, Lạng Sơn": [
    "bình phúc, văn quan, lạng sơn",
    "bifnh phusc, vawn quan, lajng sown"
  ],
  "Bình Quới, Châu Thành, Long An": [
    "bình quới, châu thành, long an",
    "bifnh quowsi, chaau thafnh, long an"
  ],
  "Bình Sa, Thăng Bình, Quảng Nam": [
    "bình sa, thăng bình, quảng nam",
    "bifnh sa, thawng bifnh, quarng nam"
  ],
  "Bình Thành, Đức Huệ, Long An": [
    "bình thành, đức huệ, long an",
    "bifnh thafnh, dduwsc hueej, long an"
  ],
  "Bình Trung, Cao Lộc, Lạng Sơn": [
    "bình trung, cao lộc, lạng sơn",
    "bifnh trung, cao loojc, lajng sown"
  ],
  "Bình Đức, Long Xuyên, An Giang": [
    "bình đức, long xuyên, an giang",
    "bifnh dduwsc, long xuyeen, an giang"
  ],
  "Bích Đào, Ninh Bình, Ninh Bình": [
    "bích đào, ninh bình, ninh bình",
    "bisch ddafo, ninh bifnh, ninh bifnh"
  ],
  "Bó Mười, Thuận Châu, Sơn La": [
    "bó mười, thuận châu, sơn la",
    "bos muwowfi, thuaajn chaau, sown la"
  ],
  "Bút Sơn, Hoằng Hóa, Thanh Hóa": [
    "bút sơn, hoằng hóa, thanh hóa",
    "bust sown, hoawfng hosa, thanh hosa"
  ],
  "Bạch Hạ, Phú Xuyên, Hà Nội": [
    "bạch hạ, phú xuyên, hà nội",
    "bajch haj, phus xuyeen, haf nooji"
  ],
  "Bạch Lưu, Sông Lô, Vĩnh Phúc": [
    "bạch lưu, sông lô, vĩnh phúc",
    "bajch luwu, soong loo, vixnh phusc"
  ],
  "Bạch Đích, Yên Minh, Hà Giang": [
    "bạch đích, yên minh, hà giang",
    "bajch ddisch, yeen minh, haf giang"
  ],
  "Bạch Đằng, Hoà An, Cao Bằng": [
    "bạch đằng, hoà an, cao bằng",
    "bajch ddawfng, hoaf an, cao bawfng"
  ],
  "Bản Hon, Tam Đường, Lai Châu": [
    "bản hon, tam đường, lai châu",
    "barn hon, tam dduwowfng, lai chaau"
  ],
  "Bản Lầm, Thuận Châu, Sơn La": [
    "bản lầm, thuận châu, sơn la",
    "barn laafm, thuaajn chaau, sown la"
  ],
  "Bản Rịa, Quang Bình, Hà Giang": [
    "bản rịa, quang bình, hà giang",
    "barn rija, quang bifnh, haf giang"
  ],
  "Bảo Hưng, Trấn Yên, Yên Bái": [
    "bảo hưng, trấn yên, yên bái",
    "baro huwng, traasn yeen, yeen basi"
  ],
  "Bảo Thắng, Kỳ Sơn, Nghệ An": [
    "bảo thắng, kỳ sơn, nghệ an",
    "baro thawsng, kyf sown, ngheej an"
  ],
  "Bảo Đài, Lục Nam, Bắc Giang": [
    "bảo đài, lục nam, bắc giang",
    "baro ddafi, lujc nam, bawsc giang"
  ],
  "Bắc Hồng, Đông Anh, Hà Nội": [
    "bắc hồng, đông anh, hà nội",
    "bawsc hoofng, ddoong anh, haf nooji"
  ],
  "Bắc Lý, Hiệp Hòa, Bắc Giang": [
    "bắc lý, hiệp hòa, bắc giang",
    "bawsc lys, hieejp hofa, bawsc giang"
  ],
  "Bắc Lũng, Lục Nam, Bắc Giang": [
    "bắc lũng, lục nam, bắc giang",
    "bawsc luxng, lujc nam, bawsc giang"
  ],
  "Bắc Sơn, Bắc Sơn, Lạng Sơn": [
    "bắc sơn, bắc sơn, lạng sơn",
    "bawsc sown, bawsc sown, lajng sown"
  ],
  "Bắc Sơn, Kiến An, Hải Phòng": [
    "bắc sơn, kiến an, hải phòng",
    "bawsc sown, kieesn an, hari phofng"
  ],
  "Bắc Sơn, Tam Điệp, Ninh Bình": [
    "bắc sơn, tam điệp, ninh bình",
    "bawsc sown, tam ddieejp, ninh bifnh"
  ],
  "Bắc Sơn, Uông Bí, Quảng Ninh": [
    "bắc sơn, uông bí, quảng ninh",
    "bawsc sown, uoong bis, quarng ninh"
  ],
  "Bắc Sơn, Đô Lương, Nghệ An": [
    "bắc sơn, đô lương, nghệ an",
    "bawsc sown, ddoo luwowng, ngheej an"
  ],
  "Bắc Xa, Đình Lập, Lạng Sơn": [
    "bắc xa, đình lập, lạng sơn",
    "bawsc xa, ddifnh laajp, lajng sown"
  ],
  "Bằng Lang, Quang Bình, Hà Giang": [
    "bằng lang, quang bình, hà giang",
    "bawfng lang, quang bifnh, haf giang"
  ],
  "Bến Cầu, Bến Cầu, Tây Ninh": [
    "bến cầu, bến cầu, tây ninh",
    "beesn caafu, beesn caafu, taay ninh"
  ],
  "Bến Gót, Việt Trì, Phú Thọ": [
    "bến gót, việt trì, phú thọ",
    "beesn gost, vieejt trif, phus thoj"
  ],
  "Bồi Sơn, Đô Lương, Nghệ An": [
    "bồi sơn, đô lương, nghệ an",
    "boofi sown, ddoo luwowng, ngheej an"
  ],
  "Bộc Bố, Pác Nặm, Bắc Kạn": [
    "bộc bố, pác nặm, bắc kạn",
    "boojc boos, pasc nawjm, bawsc kajn"
  ],
  "Bửu Hòa, Biên Hòa, Đồng Nai": [
    "bửu hòa, biên hòa, đồng nai",
    "buwru hofa, bieen hofa, ddoofng nai"
  ],
  "Bửu Long, Biên Hòa, Đồng Nai": [
    "bửu long, biên hòa, đồng nai",
    "buwru long, bieen hofa, ddoofng nai"
  ],
  "Cam An Bắc, Cam Lâm, Khánh Hòa": [
    "cam an bắc, cam lâm, khánh hòa",
    "cam an bawsc, cam laam, khasnh hofa"
  ],
  "Cam Chính, Cam Lộ, Quảng Trị": [
    "cam chính, cam lộ, quảng trị",
    "cam chisnh, cam looj, quarng trij"
  ],
  "Cam Hiếu, Cam Lộ, Quảng Trị": [
    "cam hiếu, cam lộ, quảng trị",
    "cam hieesu, cam looj, quarng trij"
  ],
  "Cam Nghĩa, Cam Lộ, Quảng Trị": [
    "cam nghĩa, cam lộ, quảng trị",
    "cam nghixa, cam looj, quarng trij"
  ],
  "Cam Thành, Cam Lộ, Quảng Trị": [
    "cam thành, cam lộ, quảng trị",
    "cam thafnh, cam looj, quarng trij"
  ],
  "Cam Thủy, Cam Lộ, Quảng Trị": [
    "cam thủy, cam lộ, quảng trị",
    "cam thury, cam looj, quarng trij"
  ],
  "Canh Hòa, Vân Canh, Bình Định": [
    "canh hòa, vân canh, bình định",
    "canh hofa, vaan canh, bifnh ddijnh"
  ],
  "Canh Nậu, Yên Thế, Bắc Giang": [
    "canh nậu, yên thế, bắc giang",
    "canh naaju, yeen thees, bawsc giang"
  ],
  "Canh Vinh, Vân Canh, Bình Định": [
    "canh vinh, vân canh, bình định",
    "canh vinh, vaan canh, bifnh ddijnh"
  ],
  "Cao An, Cẩm Giàng, Hải Dương": [
    "cao an, cẩm giàng, hải dương",
    "cao an, caarm giafng, hari duwowng"
  ],
  "Cao Minh, Vĩnh Bảo, Hải Phòng": [
    "cao minh, vĩnh bảo, hải phòng",
    "cao minh, vixnh baro, hari phofng"
  ],
  "Cao Thượng, Ba Bể, Bắc Kạn": [
    "cao thượng, ba bể, bắc kạn",
    "cao thuwowjng, ba beer, bawsc kajn"
  ],
  "Chi Lăng, Lạng Sơn, Lạng Sơn": [
    "chi lăng, lạng sơn, lạng sơn",
    "chi lawng, lajng sown, lajng sown"
  ],
  "Chiêu Vũ, Bắc Sơn, Lạng Sơn": [
    "chiêu vũ, bắc sơn, lạng sơn",
    "chieeu vux, bawsc sown, lajng sown"
  ],
  "Chiềng Hặc, Yên Châu, Sơn La": [
    "chiềng hặc, yên châu, sơn la",
    "chieefng hawjc, yeen chaau, sown la"
  ],
  "Chiềng Khoong, Sông Mã, Sơn La": [
    "chiềng khoong, sông mã, sơn la",
    "chieefng khoong, soong max, sown la"
  ],
  "Chiềng La, Thuận Châu, Sơn La": [
    "chiềng la, thuận châu, sơn la",
    "chieefng la, thuaajn chaau, sown la"
  ],
  "Chiềng Ly, Thuận Châu, Sơn La": [
    "chiềng ly, thuận châu, sơn la",
    "chieefng ly, thuaajn chaau, sown la"
  ],
  "Chiềng Lương, Mai Sơn, Sơn La": [
    "chiềng lương, mai sơn, sơn la",
    "chieefng luwowng, mai sown, sown la"
  ],
  "Chiềng Pằn, Yên Châu, Sơn La": [
    "chiềng pằn, yên châu, sơn la",
    "chieefng pawfn, yeen chaau, sown la"
  ],
  "Chiềng Sàng, Yên Châu, Sơn La": [
    "chiềng sàng, yên châu, sơn la",
    "chieefng safng, yeen chaau, sown la"
  ],
  "Chiềng Sơn, Mộc Châu, Sơn La": [
    "chiềng sơn, mộc châu, sơn la",
    "chieefng sown, moojc chaau, sown la"
  ],
  "Chiềng Sại, Bắc Yên, Sơn La": [
    "chiềng sại, bắc yên, sơn la",
    "chieefng saji, bawsc yeen, sown la"
  ],
  "Chiềng Ơn, Quỳnh Nhai, Sơn La": [
    "chiềng ơn, quỳnh nhai, sơn la",
    "chieefng own, quyfnh nhai, sown la"
  ],
  "Chu Điện, Lục Nam, Bắc Giang": [
    "chu điện, lục nam, bắc giang",
    "chu ddieejn, lujc nam, bawsc giang"
  ],
  "Chuyên Ngoại, Duy Tiên, Hà Nam": [
    "chuyên ngoại, duy tiên, hà nam",
    "chuyeen ngoaji, duy tieen, haf nam"
  ],
  "Chân Sơn, Yên Sơn, Tuyên Quang": [
    "chân sơn, yên sơn, tuyên quang",
    "chaan sown, yeen sown, tuyeen quang"
  ],
  "Châu Bình, Quỳ Châu, Nghệ An": [
    "châu bình, quỳ châu, nghệ an",
    "chaau bifnh, quyf chaau, ngheej an"
  ],
  "Châu Bính, Quỳ Châu, Nghệ An": [
    "châu bính, quỳ châu, nghệ an",
    "chaau bisnh, quyf chaau, ngheej an"
  ],
  "Châu Hoàn, Quỳ Châu, Nghệ An": [
    "châu hoàn, quỳ châu, nghệ an",
    "chaau hoafn, quyf chaau, ngheej an"
  ],
  "Châu Hội, Quỳ Châu, Nghệ An": [
    "châu hội, quỳ châu, nghệ an",
    "chaau hooji, quyf chaau, ngheej an"
  ],
  "Châu Lộc, Quỳ Hợp, Nghệ An": [
    "châu lộc, quỳ hợp, nghệ an",
    "chaau loojc, quyf howjp, ngheej an"
  ],
  "Châu Phong, Quỳ Châu, Nghệ An": [
    "châu phong, quỳ châu, nghệ an",
    "chaau phong, quyf chaau, ngheej an"
  ],
  "Châu Quang, Quỳ Hợp, Nghệ An": [
    "châu quang, quỳ hợp, nghệ an",
    "chaau quang, quyf howjp, ngheej an"
  ],
  "Châu Thái, Quỳ Hợp, Nghệ An": [
    "châu thái, quỳ hợp, nghệ an",
    "chaau thasi, quyf howjp, ngheej an"
  ],
  "Châu Thôn, Quế Phong, Nghệ An": [
    "châu thôn, quế phong, nghệ an",
    "chaau thoon, quees phong, ngheej an"
  ],
  "Châu Điền, Cầu Kè, Trà Vinh": [
    "châu điền, cầu kè, trà vinh",
    "chaau ddieefn, caafu kef, traf vinh"
  ],
  "Chí Minh, Chí Linh, Hải Dương": [
    "chí minh, chí linh, hải dương",
    "chis minh, chis linh, hari duwowng"
  ],
  "Chí Minh, Tứ Kỳ, Hải Dương": [
    "chí minh, tứ kỳ, hải dương",
    "chis minh, tuws kyf, hari duwowng"
  ],
  "Chí Tân, Khoái Châu, Hưng Yên": [
    "chí tân, khoái châu, hưng yên",
    "chis taan, khoasi chaau, huwng yeen"
  ],
  "Chí Đám, Đoan Hùng, Phú Thọ": [
    "chí đám, đoan hùng, phú thọ",
    "chis ddasm, ddoan hufng, phus thoj"
  ],
  "Chí Đạo, Lạc Sơn, Hoà Bình": [
    "chí đạo, lạc sơn, hoà bình",
    "chis ddajo, lajc sown, hoaf bifnh"
  ],
  "Chỉ Đạo, Văn Lâm, Hưng Yên": [
    "chỉ đạo, văn lâm, hưng yên",
    "chir ddajo, vawn laam, huwng yeen"
  ],
  "Chợ Lách, Chợ Lách, Bến Tre": [
    "chợ lách, chợ lách, bến tre",
    "chowj lasch, chowj lasch, beesn tre"
  ],
  "Cái Khế, Ninh Kiều, Cần Thơ": [
    "cái khế, ninh kiều, cần thơ",
    "casi khees, ninh kieefu, caafn thow"
  ],
  "Cái Nước, Cái Nước, Cà Mau": [
    "cái nước, cái nước, cà mau",
    "casi nuwowsc, casi nuwowsc, caf mau"
  ],
  "Cái Đôi Vàm, Phú Tân, Cà Mau": [
    "cái đôi vàm, phú tân, cà mau",
    "casi ddooi vafm, phus taan, caf mau"
  ],
  "Cát Hanh, Phù Cát, Bình Định": [
    "cát hanh, phù cát, bình định",
    "cast hanh, phuf cast, bifnh ddijnh"
  ],
  "Cát Lái, Quận 2, Hồ Chí Minh": [
    "cát lái, quận 2, hồ chí minh",
    "cast lasi, quaajn 2, hoof chis minh"
  ],
  "Cát Lâm, Phù Cát, Bình Định": [
    "cát lâm, phù cát, bình định",
    "cast laam, phuf cast, bifnh ddijnh"
  ],
  "Cát Minh, Phù Cát, Bình Định": [
    "cát minh, phù cát, bình định",
    "cast minh, phuf cast, bifnh ddijnh"
  ],
  "Cát Quế, Hoài Đức, Hà Nội": [
    "cát quế, hoài đức, hà nội",
    "cast quees, hoafi dduwsc, haf nooji"
  ],
  "Cát Sơn, Phù Cát, Bình Định": [
    "cát sơn, phù cát, bình định",
    "cast sown, phuf cast, bifnh ddijnh"
  ],
  "Cát Tài, Phù Cát, Bình Định": [
    "cát tài, phù cát, bình định",
    "cast tafi, phuf cast, bifnh ddijnh"
  ],
  "Cát Tân, Phù Cát, Bình Định": [
    "cát tân, phù cát, bình định",
    "cast taan, phuf cast, bifnh ddijnh"
  ],
  "Cây Gáo, Trảng Bom, Đồng Nai": [
    "cây gáo, trảng bom, đồng nai",
    "caay gaso, trarng bom, ddoofng nai"
  ],
  "Cô Giang, Quận 1, Hồ Chí Minh": [
    "cô giang, quận 1, hồ chí minh",
    "coo giang, quaajn 1, hoof chis minh"
  ],
  "Cúc Phương, Nho Quan, Ninh Bình": [
    "cúc phương, nho quan, ninh bình",
    "cusc phuwowng, nho quan, ninh bifnh"
  ],
  "Căm Muộn, Quế Phong, Nghệ An": [
    "căm muộn, quế phong, nghệ an",
    "cawm muoojn, quees phong, ngheej an"
  ],
  "Cư K Róa, M'Đrắk, Đắk Lắk": [
    "cư k róa, m'đrắk, đắk lắk",
    "cuw k rosa, m'ddrawsk, ddawsk lawsk"
  ],
  "Cư KTy, Krông Bông, Đắk Lắk": [
    "cư kty, krông bông, đắk lắk",
    "cuw kty, kroong boong, ddawsk lawsk"
  ],
  "Cư Pui, Krông Bông, Đắk Lắk": [
    "cư pui, krông bông, đắk lắk",
    "cuw pui, kroong boong, ddawsk lawsk"
  ],
  "Cường Lợi, Na Rì, Bắc Kạn": [
    "cường lợi, na rì, bắc kạn",
    "cuwowfng lowji, na rif, bawsc kajn"
  ],
  "Cấp Dẫn, Cẩm Khê, Phú Thọ": [
    "cấp dẫn, cẩm khê, phú thọ",
    "caasp daaxn, caarm khee, phus thoj"
  ],
  "Cần Yên, Hà Quảng, Cao Bằng": [
    "cần yên, hà quảng, cao bằng",
    "caafn yeen, haf quarng, cao bawfng"
  ],
  "Cầu Kho, Quận 1, Hồ Chí Minh": [
    "cầu kho, quận 1, hồ chí minh",
    "caafu kho, quaajn 1, hoof chis minh"
  ],
  "Cầu Ngang, Cầu Ngang, Trà Vinh": [
    "cầu ngang, cầu ngang, trà vinh",
    "caafu ngang, caafu ngang, traf vinh"
  ],
  "Cầu Quan, Tiểu Cần, Trà Vinh": [
    "cầu quan, tiểu cần, trà vinh",
    "caafu quan, tieeru caafn, traf vinh"
  ],
  "Cẩm Minh, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm minh, cẩm xuyên, hà tĩnh",
    "caarm minh, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Mỹ, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm mỹ, cẩm xuyên, hà tĩnh",
    "caarm myx, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Quan, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm quan, cẩm xuyên, hà tĩnh",
    "caarm quan, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Sơn, Cai Lậy, Tiền Giang": [
    "cẩm sơn, cai lậy, tiền giang",
    "caarm sown, cai laajy, tieefn giang"
  ],
  "Cẩm Sơn, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm sơn, cẩm xuyên, hà tĩnh",
    "caarm sown, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Tú, Cẩm Thủy, Thanh Hóa": [
    "cẩm tú, cẩm thủy, thanh hóa",
    "caarm tus, caarm thury, thanh hosa"
  ],
  "Cổ Lễ, Trực Ninh, Nam Định": [
    "cổ lễ, trực ninh, nam định",
    "coor leex, truwjc ninh, nam ddijnh"
  ],
  "Cộng Hòa, Hưng Hà, Thái Bình": [
    "cộng hòa, hưng hà, thái bình",
    "coojng hofa, huwng haf, thasi bifnh"
  ],
  "Cửa Nam, Nam Định, Nam Định": [
    "cửa nam, nam định, nam định",
    "cuwra nam, nam ddijnh, nam ddijnh"
  ],
  "Cửa Đại, Hội An, Quảng Nam": [
    "cửa đại, hội an, quảng nam",
    "cuwra ddaji, hooji an, quarng nam"
  ],
  "Di Trạch, Hoài Đức, Hà Nội": [
    "di trạch, hoài đức, hà nội",
    "di trajch, hoafi dduwsc, haf nooji"
  ],
  "Diên An, Diên Khánh, Khánh Hòa": [
    "diên an, diên khánh, khánh hòa",
    "dieen an, dieen khasnh, khasnh hofa"
  ],
  "Diễn Hoa, Diễn Châu, Nghệ An": [
    "diễn hoa, diễn châu, nghệ an",
    "dieexn hoa, dieexn chaau, ngheej an"
  ],
  "Diễn Kim, Diễn Châu, Nghệ An": [
    "diễn kim, diễn châu, nghệ an",
    "dieexn kim, dieexn chaau, ngheej an"
  ],
  "Dray Bhăng, Cư Kuin, Đắk Lắk": [
    "dray bhăng, cư kuin, đắk lắk",
    "dray bhawng, cuw kuin, ddawsk lawsk"
  ],
  "Duy Nghĩa, Duy Xuyên, Quảng Nam": [
    "duy nghĩa, duy xuyên, quảng nam",
    "duy nghixa, duy xuyeen, quarng nam"
  ],
  "Duy Thành, Duy Xuyên, Quảng Nam": [
    "duy thành, duy xuyên, quảng nam",
    "duy thafnh, duy xuyeen, quarng nam"
  ],
  "Dân Chủ, Hạ Long, Quảng Ninh": [
    "dân chủ, hạ long, quảng ninh",
    "daan chur, haj long, quarng ninh"
  ],
  "Dân Hóa, Minh Hóa, Quảng Bình": [
    "dân hóa, minh hóa, quảng bình",
    "daan hosa, minh hosa, quarng bifnh"
  ],
  "Dân Quyền, Tam Nông, Phú Thọ": [
    "dân quyền, tam nông, phú thọ",
    "daan quyeefn, tam noong, phus thoj"
  ],
  "Dũng Nghĩa, Vũ Thư, Thái Bình": [
    "dũng nghĩa, vũ thư, thái bình",
    "duxng nghixa, vux thuw, thasi bifnh"
  ],
  "Dữu Lâu, Việt Trì, Phú Thọ": [
    "dữu lâu, việt trì, phú thọ",
    "duwxu laau, vieejt trif, phus thoj"
  ],
  "Ea Bông, Krông A Na, Đắk Lắk": [
    "ea bông, krông a na, đắk lắk",
    "ea boong, kroong a na, ddawsk lawsk"
  ],
  "Ea D'Rơng, Cư M'gar, Đắk Lắk": [
    "ea d'rơng, cư m'gar, đắk lắk",
    "ea d'rowng, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Drông, Buôn Hồ, Đắk Lắk": [
    "ea drông, buôn hồ, đắk lắk",
    "ea droong, buoon hoof, ddawsk lawsk"
  ],
  "Ea Dăh, Krông Năng, Đắk Lắk": [
    "ea dăh, krông năng, đắk lắk",
    "ea dawh, kroong nawng, ddawsk lawsk"
  ],
  "Ea H'đinh, Cư M'gar, Đắk Lắk": [
    "ea h'đinh, cư m'gar, đắk lắk",
    "ea h'ddinh, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Hồ, Krông Năng, Đắk Lắk": [
    "ea hồ, krông năng, đắk lắk",
    "ea hoof, kroong nawng, ddawsk lawsk"
  ],
  "Ea M' Doal, M'Đrắk, Đắk Lắk": [
    "ea m' doal, m'đrắk, đắk lắk",
    "ea m' doal, m'ddrawsk, ddawsk lawsk"
  ],
  "Ea M'DRóh, Cư M'gar, Đắk Lắk": [
    "ea m'dróh, cư m'gar, đắk lắk",
    "ea m'drosh, cuw m'gar, ddawsk lawsk"
  ],
  "Ea Nuôl, Buôn Đôn, Đắk Lắk": [
    "ea nuôl, buôn đôn, đắk lắk",
    "ea nuool, buoon ddoon, ddawsk lawsk"
  ],
  "Ea Phê, Krông Pắc, Đắk Lắk": [
    "ea phê, krông pắc, đắk lắk",
    "ea phee, kroong pawsc, ddawsk lawsk"
  ],
  "Ea Trul, Krông Bông, Đắk Lắk": [
    "ea trul, krông bông, đắk lắk",
    "ea trul, kroong boong, ddawsk lawsk"
  ],
  "Ea Tân, Krông Năng, Đắk Lắk": [
    "ea tân, krông năng, đắk lắk",
    "ea taan, kroong nawng, ddawsk lawsk"
  ],
  "Ea Tóh, Krông Năng, Đắk Lắk": [
    "ea tóh, krông năng, đắk lắk",
    "ea tosh, kroong nawng, ddawsk lawsk"
  ],
  "Gia Bình, Trảng Bàng, Tây Ninh": [
    "gia bình, trảng bàng, tây ninh",
    "gia bifnh, trarng bafng, taay ninh"
  ],
  "Gia Lộc, Gia Lộc, Hải Dương": [
    "gia lộc, gia lộc, hải dương",
    "gia loojc, gia loojc, hari duwowng"
  ],
  "Gia Lộc, Trảng Bàng, Tây Ninh": [
    "gia lộc, trảng bàng, tây ninh",
    "gia loojc, trarng bafng, taay ninh"
  ],
  "Gia Miễn, Văn Lãng, Lạng Sơn": [
    "gia miễn, văn lãng, lạng sơn",
    "gia mieexn, vawn laxng, lajng sown"
  ],
  "Gia Thắng, Gia Viễn, Ninh Bình": [
    "gia thắng, gia viễn, ninh bình",
    "gia thawsng, gia vieexn, ninh bifnh"
  ],
  "Gia Thịnh, Gia Viễn, Ninh Bình": [
    "gia thịnh, gia viễn, ninh bình",
    "gia thijnh, gia vieexn, ninh bifnh"
  ],
  "Giang Ly, Khánh Vĩnh, Khánh Hòa": [
    "giang ly, khánh vĩnh, khánh hòa",
    "giang ly, khasnh vixnh, khasnh hofa"
  ],
  "Giao Long, Giao Thủy, Nam Định": [
    "giao long, giao thủy, nam định",
    "giao long, giao thury, nam ddijnh"
  ],
  "Giao Tân, Giao Thủy, Nam Định": [
    "giao tân, giao thủy, nam định",
    "giao taan, giao thury, nam ddijnh"
  ],
  "Gio Việt, Gio Linh, Quảng Trị": [
    "gio việt, gio linh, quảng trị",
    "gio vieejt, gio linh, quarng trij"
  ],
  "Giới Phiên, Yên Bái, Yên Bái": [
    "giới phiên, yên bái, yên bái",
    "giowsi phieen, yeen basi, yeen basi"
  ],
  "Hiền Chung, Quan Hóa, Thanh Hóa": [
    "hiền chung, quan hóa, thanh hóa",
    "hieefn chung, quan hosa, thanh hosa"
  ],
  "Hiệp An, Kinh Môn, Hải Dương": [
    "hiệp an, kinh môn, hải dương",
    "hieejp an, kinh moon, hari duwowng"
  ],
  "Hiệp Hòa, Cầu Ngang, Trà Vinh": [
    "hiệp hòa, cầu ngang, trà vinh",
    "hieejp hofa, caafu ngang, traf vinh"
  ],
  "Hiệp Tân, Hòa Thành, Tây Ninh": [
    "hiệp tân, hòa thành, tây ninh",
    "hieejp taan, hofa thafnh, taay ninh"
  ],
  "Hiệp Xương, Phú Tân, An Giang": [
    "hiệp xương, phú tân, an giang",
    "hieejp xuwowng, phus taan, an giang"
  ],
  "Hoang Thèn, Phong Thổ, Lai Châu": [
    "hoang thèn, phong thổ, lai châu",
    "hoang thefn, phong thoor, lai chaau"
  ],
  "Hoà Thuận, Tam Kỳ, Quảng Nam": [
    "hoà thuận, tam kỳ, quảng nam",
    "hoaf thuaajn, tam kyf, quarng nam"
  ],
  "Hoàng An, Hiệp Hòa, Bắc Giang": [
    "hoàng an, hiệp hòa, bắc giang",
    "hoafng an, hieejp hofa, bawsc giang"
  ],
  "Hoàng Hanh, Hưng Yên, Hưng Yên": [
    "hoàng hanh, hưng yên, hưng yên",
    "hoafng hanh, huwng yeen, huwng yeen"
  ],
  "Hoàng Long, Phú Xuyên, Hà Nội": [
    "hoàng long, phú xuyên, hà nội",
    "hoafng long, phus xuyeen, haf nooji"
  ],
  "Hoạt Giang, Hà Trung, Thanh Hóa": [
    "hoạt giang, hà trung, thanh hóa",
    "hoajt giang, haf trung, thanh hosa"
  ],
  "Hy Cương, Việt Trì, Phú Thọ": [
    "hy cương, việt trì, phú thọ",
    "hy cuwowng, vieejt trif, phus thoj"
  ],
  "Hà Huy Tập, Hà Tĩnh, Hà Tĩnh": [
    "hà huy tập, hà tĩnh, hà tĩnh",
    "haf huy taajp, haf tixnh, haf tixnh"
  ],
  "Hà Khánh, Hạ Long, Quảng Ninh": [
    "hà khánh, hạ long, quảng ninh",
    "haf khasnh, haj long, quarng ninh"
  ],
  "Hà Khẩu, Hạ Long, Quảng Ninh": [
    "hà khẩu, hạ long, quảng ninh",
    "haf khaaru, haj long, quarng ninh"
  ],
  "Hà Lang, Chiêm Hóa, Tuyên Quang": [
    "hà lang, chiêm hóa, tuyên quang",
    "haf lang, chieem hosa, tuyeen quang"
  ],
  "Hà Lâm, Đạ Huoai, Lâm Đồng": [
    "hà lâm, đạ huoai, lâm đồng",
    "haf laam, ddaj huoai, laam ddoofng"
  ],
  "Hà Thanh, Tứ Kỳ, Hải Dương": [
    "hà thanh, tứ kỳ, hải dương",
    "haf thanh, tuws kyf, hari duwowng"
  ],
  "Hà Thạch, Phú Thọ, Phú Thọ": [
    "hà thạch, phú thọ, phú thọ",
    "haf thajch, phus thoj, phus thoj"
  ],
  "Hàm Ninh, Phú Quốc, Kiên Giang": [
    "hàm ninh, phú quốc, kiên giang",
    "hafm ninh, phus quoosc, kieen giang"
  ],
  "Hàm Rồng, Thanh Hóa, Thanh Hóa": [
    "hàm rồng, thanh hóa, thanh hóa",
    "hafm roofng, thanh hosa, thanh hosa"
  ],
  "Hàm Tử, Khoái Châu, Hưng Yên": [
    "hàm tử, khoái châu, hưng yên",
    "hafm tuwr, khoasi chaau, huwng yeen"
  ],
  "Hàng Bài, Hoàn Kiếm, Hà Nội": [
    "hàng bài, hoàn kiếm, hà nội",
    "hafng bafi, hoafn kieesm, haf nooji"
  ],
  "Hàng Bồ, Hoàn Kiếm, Hà Nội": [
    "hàng bồ, hoàn kiếm, hà nội",
    "hafng boof, hoafn kieesm, haf nooji"
  ],
  "Hàng Bột, Đống Đa, Hà Nội": [
    "hàng bột, đống đa, hà nội",
    "hafng boojt, ddoosng dda, haf nooji"
  ],
  "Hán Quảng, Quế Võ, Bắc Ninh": [
    "hán quảng, quế võ, bắc ninh",
    "hasn quarng, quees vox, bawsc ninh"
  ],
  "Hòa An, Krông Pắc, Đắk Lắk": [
    "hòa an, krông pắc, đắk lắk",
    "hofa an, kroong pawsc, ddawsk lawsk"
  ],
  "Hòa Bình, Biên Hòa, Đồng Nai": [
    "hòa bình, biên hòa, đồng nai",
    "hofa bifnh, bieen hofa, ddoofng nai"
  ],
  "Hòa Bình, Hoà Bình, Bạc Liêu": [
    "hòa bình, hoà bình, bạc liêu",
    "hofa bifnh, hoaf bifnh, bajc lieeu"
  ],
  "Hòa Bình, Hạ Long, Quảng Ninh": [
    "hòa bình, hạ long, quảng ninh",
    "hofa bifnh, haj long, quarng ninh"
  ],
  "Hòa Cuông, Trấn Yên, Yên Bái": [
    "hòa cuông, trấn yên, yên bái",
    "hofa cuoong, traasn yeen, yeen basi"
  ],
  "Hòa Hiệp, Cư Kuin, Đắk Lắk": [
    "hòa hiệp, cư kuin, đắk lắk",
    "hofa hieejp, cuw kuin, ddawsk lawsk"
  ],
  "Hòa Hương, Tam Kỳ, Quảng Nam": [
    "hòa hương, tam kỳ, quảng nam",
    "hofa huwowng, tam kyf, quarng nam"
  ],
  "Hòa Hải, Hương Khê, Hà Tĩnh": [
    "hòa hải, hương khê, hà tĩnh",
    "hofa hari, huwowng khee, haf tixnh"
  ],
  "Hòa Hội, Châu Thành, Tây Ninh": [
    "hòa hội, châu thành, tây ninh",
    "hofa hooji, chaau thafnh, taay ninh"
  ],
  "Hòa Khánh, Cái Bè, Tiền Giang": [
    "hòa khánh, cái bè, tiền giang",
    "hofa khasnh, casi bef, tieefn giang"
  ],
  "Hòa Lạc, Đức Thọ, Hà Tĩnh": [
    "hòa lạc, đức thọ, hà tĩnh",
    "hofa lajc, dduwsc thoj, haf tixnh"
  ],
  "Hòa Lộc, Hậu Lộc, Thanh Hóa": [
    "hòa lộc, hậu lộc, thanh hóa",
    "hofa loojc, haaju loojc, thanh hosa"
  ],
  "Hòa Lợi, Châu Thành, Trà Vinh": [
    "hòa lợi, châu thành, trà vinh",
    "hofa lowji, chaau thafnh, traf vinh"
  ],
  "Hòa Lợi, Thạnh Phú, Bến Tre": [
    "hòa lợi, thạnh phú, bến tre",
    "hofa lowji, thajnh phus, beesn tre"
  ],
  "Hòa Minh, Tuy Phong, Bình Thuận": [
    "hòa minh, tuy phong, bình thuận",
    "hofa minh, tuy phong, bifnh thuaajn"
  ],
  "Hòa Nghĩa, Chợ Lách, Bến Tre": [
    "hòa nghĩa, chợ lách, bến tre",
    "hofa nghixa, chowj lasch, beesn tre"
  ],
  "Hòa Phát, Cẩm Lệ, Đà Nẵng": [
    "hòa phát, cẩm lệ, đà nẵng",
    "hofa phast, caarm leej, ddaf nawxng"
  ],
  "Hòa Phú, Củ Chi, Hồ Chí Minh": [
    "hòa phú, củ chi, hồ chí minh",
    "hofa phus, cur chi, hoof chis minh"
  ],
  "Hòa Sơn, Hiệp Hòa, Bắc Giang": [
    "hòa sơn, hiệp hòa, bắc giang",
    "hofa sown, hieejp hofa, bawsc giang"
  ],
  "Hòa Sơn, Hữu Lũng, Lạng Sơn": [
    "hòa sơn, hữu lũng, lạng sơn",
    "hofa sown, huwxu luxng, lajng sown"
  ],
  "Hòa Sơn, Lương Sơn, Hoà Bình": [
    "hòa sơn, lương sơn, hoà bình",
    "hofa sown, luwowng sown, hoaf bifnh"
  ],
  "Hòa Thành, Đông Hòa, Phú Yên": [
    "hòa thành, đông hòa, phú yên",
    "hofa thafnh, ddoong hofa, phus yeen"
  ],
  "Hòa Thạch, Quốc Oai, Hà Nội": [
    "hòa thạch, quốc oai, hà nội",
    "hofa thajch, quoosc oai, haf nooji"
  ],
  "Hòa Thạnh, Tam Bình, Vĩnh Long": [
    "hòa thạnh, tam bình, vĩnh long",
    "hofa thajnh, tam bifnh, vixnh long"
  ],
  "Hòa Tiến, Hòa Vang, Đà Nẵng": [
    "hòa tiến, hòa vang, đà nẵng",
    "hofa tieesn, hofa vang, ddaf nawxng"
  ],
  "Hòa Tiến, Hưng Hà, Thái Bình": [
    "hòa tiến, hưng hà, thái bình",
    "hofa tieesn, huwng haf, thasi bifnh"
  ],
  "Hòa Tiến, Yên Phong, Bắc Ninh": [
    "hòa tiến, yên phong, bắc ninh",
    "hofa tieesn, yeen phong, bawsc ninh"
  ],
  "Hòa Tịnh, Mang Thít, Vĩnh Long": [
    "hòa tịnh, mang thít, vĩnh long",
    "hofa tijnh, mang thist, vixnh long"
  ],
  "Hòa Xuân, Cẩm Lệ, Đà Nẵng": [
    "hòa xuân, cẩm lệ, đà nẵng",
    "hofa xuaan, caarm leej, ddaf nawxng"
  ],
  "Hóa Sơn, Minh Hóa, Quảng Bình": [
    "hóa sơn, minh hóa, quảng bình",
    "hosa sown, minh hosa, quarng bifnh"
  ],
  "Hùng Dũng, Hưng Hà, Thái Bình": [
    "hùng dũng, hưng hà, thái bình",
    "hufng duxng, huwng haf, thasi bifnh"
  ],
  "Hùng Hòa, Tiểu Cần, Trà Vinh": [
    "hùng hòa, tiểu cần, trà vinh",
    "hufng hofa, tieeru caafn, traf vinh"
  ],
  "Hùng Long, Đoan Hùng, Phú Thọ": [
    "hùng long, đoan hùng, phú thọ",
    "hufng long, ddoan hufng, phus thoj"
  ],
  "Hưng Mỹ, Châu Thành, Trà Vinh": [
    "hưng mỹ, châu thành, trà vinh",
    "huwng myx, chaau thafnh, traf vinh"
  ],
  "Hưng Nhân, Hưng Hà, Thái Bình": [
    "hưng nhân, hưng hà, thái bình",
    "huwng nhaan, huwng haf, thasi bifnh"
  ],
  "Hưng Thi, Lạc Thủy, Hoà Bình": [
    "hưng thi, lạc thủy, hoà bình",
    "huwng thi, lajc thury, hoaf bifnh"
  ],
  "Hương An, Quế Sơn, Quảng Nam": [
    "hương an, quế sơn, quảng nam",
    "huwowng an, quees sown, quarng nam"
  ],
  "Hương Xạ, Hạ Hoà, Phú Thọ": [
    "hương xạ, hạ hoà, phú thọ",
    "huwowng xaj, haj hoaf, phus thoj"
  ],
  "Hạ Long, Nam Định, Nam Định": [
    "hạ long, nam định, nam định",
    "haj long, nam ddijnh, nam ddijnh"
  ],
  "Hạ Đình, Thanh Xuân, Hà Nội": [
    "hạ đình, thanh xuân, hà nội",
    "haj ddifnh, thanh xuaan, haf nooji"
  ],
  "Hạnh Sơn, Nghĩa Lộ, Yên Bái": [
    "hạnh sơn, nghĩa lộ, yên bái",
    "hajnh sown, nghixa looj, yeen basi"
  ],
  "Hạp Lĩnh, Bắc Ninh, Bắc Ninh": [
    "hạp lĩnh, bắc ninh, bắc ninh",
    "hajp lixnh, bawsc ninh, bawsc ninh"
  ],
  "Hải Anh, Hải Hậu, Nam Định": [
    "hải anh, hải hậu, nam định",
    "hari anh, hari haaju, nam ddijnh"
  ],
  "Hải Hà, Hải Hậu, Nam Định": [
    "hải hà, hải hậu, nam định",
    "hari haf, hari haaju, nam ddijnh"
  ],
  "Hải Lý, Hải Hậu, Nam Định": [
    "hải lý, hải hậu, nam định",
    "hari lys, hari haaju, nam ddijnh"
  ],
  "Hải Lựu, Sông Lô, Vĩnh Phúc": [
    "hải lựu, sông lô, vĩnh phúc",
    "hari luwju, soong loo, vixnh phusc"
  ],
  "Hải Nam, Hải Hậu, Nam Định": [
    "hải nam, hải hậu, nam định",
    "hari nam, hari haaju, nam ddijnh"
  ],
  "Hải Yến, Cao Lộc, Lạng Sơn": [
    "hải yến, cao lộc, lạng sơn",
    "hari yeesn, cao loojc, lajng sown"
  ],
  "Hồ Sơn, Hữu Lũng, Lạng Sơn": [
    "hồ sơn, hữu lũng, lạng sơn",
    "hoof sown, huwxu luxng, lajng sown"
  ],
  "Hồ Xá, Vĩnh Linh, Quảng Trị": [
    "hồ xá, vĩnh linh, quảng trị",
    "hoof xas, vixnh linh, quarng trij"
  ],
  "Hồng Gai, Hạ Long, Quảng Ninh": [
    "hồng gai, hạ long, quảng ninh",
    "hoofng gai, haj long, quarng ninh"
  ],
  "Hồng Hà, Hạ Long, Quảng Ninh": [
    "hồng hà, hạ long, quảng ninh",
    "hoofng haf, haj long, quarng ninh"
  ],
  "Hồng Minh, Hưng Hà, Thái Bình": [
    "hồng minh, hưng hà, thái bình",
    "hoofng minh, huwng haf, thasi bifnh"
  ],
  "Hồng Minh, Phú Xuyên, Hà Nội": [
    "hồng minh, phú xuyên, hà nội",
    "hoofng minh, phus xuyeen, haf nooji"
  ],
  "Hồng Phong, Vũ Thư, Thái Bình": [
    "hồng phong, vũ thư, thái bình",
    "hoofng phong, vux thuw, thasi bifnh"
  ],
  "Hồng Quang, Ứng Hòa, Hà Nội": [
    "hồng quang, ứng hòa, hà nội",
    "hoofng quang, uwsng hofa, haf nooji"
  ],
  "Hồng Sơn, Mỹ Đức, Hà Nội": [
    "hồng sơn, mỹ đức, hà nội",
    "hoofng sown, myx dduwsc, haf nooji"
  ],
  "Hồng Thái, Na Hang, Tuyên Quang": [
    "hồng thái, na hang, tuyên quang",
    "hoofng thasi, na hang, tuyeen quang"
  ],
  "Hội Hoan, Văn Lãng, Lạng Sơn": [
    "hội hoan, văn lãng, lạng sơn",
    "hooji hoan, vawn laxng, lajng sown"
  ],
  "Hợp Giang, Cao Bằng, Cao Bằng": [
    "hợp giang, cao bằng, cao bằng",
    "howjp giang, cao bawfng, cao bawfng"
  ],
  "Hợp Lý, Triệu Sơn, Thanh Hóa": [
    "hợp lý, triệu sơn, thanh hóa",
    "howjp lys, trieeju sown, thanh hosa"
  ],
  "Hợp Thanh, Mỹ Đức, Hà Nội": [
    "hợp thanh, mỹ đức, hà nội",
    "howjp thanh, myx dduwsc, haf nooji"
  ],
  "Hữu Kiên, Chi Lăng, Lạng Sơn": [
    "hữu kiên, chi lăng, lạng sơn",
    "huwxu kieen, chi lawng, lajng sown"
  ],
  "Hữu Sản, Bắc Quang, Hà Giang": [
    "hữu sản, bắc quang, hà giang",
    "huwxu sarn, bawsc quang, haf giang"
  ],
  "Hựu Thạnh, Đức Hòa, Long An": [
    "hựu thạnh, đức hòa, long an",
    "huwju thajnh, dduwsc hofa, long an"
  ],
  "Ka Dăng, Đông Giang, Quảng Nam": [
    "ka dăng, đông giang, quảng nam",
    "ka dawng, ddoong giang, quarng nam"
  ],
  "Kha Sơn, Phú Bình, Thái Nguyên": [
    "kha sơn, phú bình, thái nguyên",
    "kha sown, phus bifnh, thasi nguyeen"
  ],
  "Khai Quang, Vĩnh Yên, Vĩnh Phúc": [
    "khai quang, vĩnh yên, vĩnh phúc",
    "khai quang, vixnh yeen, vixnh phusc"
  ],
  "Khe Mo, Đồng Hỷ, Thái Nguyên": [
    "khe mo, đồng hỷ, thái nguyên",
    "khe mo, ddoofng hyr, thasi nguyeen"
  ],
  "Khuôn Lùng, Xín Mần, Hà Giang": [
    "khuôn lùng, xín mần, hà giang",
    "khuoon lufng, xisn maafn, haf giang"
  ],
  "Khánh Cư, Yên Khánh, Ninh Bình": [
    "khánh cư, yên khánh, ninh bình",
    "khasnh cuw, yeen khasnh, ninh bifnh"
  ],
  "Khánh Hợp, Nghi Lộc, Nghệ An": [
    "khánh hợp, nghi lộc, nghệ an",
    "khasnh howjp, nghi loojc, ngheej an"
  ],
  "Khánh Khê, Văn Quan, Lạng Sơn": [
    "khánh khê, văn quan, lạng sơn",
    "khasnh khee, vawn quan, lajng sown"
  ],
  "Khánh Thượng, Ba Vì, Hà Nội": [
    "khánh thượng, ba vì, hà nội",
    "khasnh thuwowjng, ba vif, haf nooji"
  ],
  "Khả Cửu, Thanh Sơn, Phú Thọ": [
    "khả cửu, thanh sơn, phú thọ",
    "khar cuwru, thanh sown, phus thoj"
  ],
  "Kim Quan, Thạch Thất, Hà Nội": [
    "kim quan, thạch thất, hà nội",
    "kim quan, thajch thaast, haf nooji"
  ],
  "Kim Sơn, Lục Ngạn, Bắc Giang": [
    "kim sơn, lục ngạn, bắc giang",
    "kim sown, lujc ngajn, bawsc giang"
  ],
  "Kim Thạch, Vị Xuyên, Hà Giang": [
    "kim thạch, vị xuyên, hà giang",
    "kim thajch, vij xuyeen, haf giang"
  ],
  "Kim Tân, Kim Thành, Hải Dương": [
    "kim tân, kim thành, hải dương",
    "kim taan, kim thafnh, hari duwowng"
  ],
  "Kim Đồng, Thạch An, Cao Bằng": [
    "kim đồng, thạch an, cao bằng",
    "kim ddoofng, thajch an, cao bawfng"
  ],
  "Kim Đức, Việt Trì, Phú Thọ": [
    "kim đức, việt trì, phú thọ",
    "kim dduwsc, vieejt trif, phus thoj"
  ],
  "Kiến Bình, Tân Thạnh, Long An": [
    "kiến bình, tân thạnh, long an",
    "kieesn bifnh, taan thajnh, long an"
  ],
  "Kiến Hưng, Hà Đông, Hà Nội": [
    "kiến hưng, hà đông, hà nội",
    "kieesn huwng, haf ddoong, haf nooji"
  ],
  "Kế Sách, Kế Sách, Sóc Trăng": [
    "kế sách, kế sách, sóc trăng",
    "kees sasch, kees sasch, sosc trawng"
  ],
  "Kỳ Thượng, Kỳ Anh, Hà Tĩnh": [
    "kỳ thượng, kỳ anh, hà tĩnh",
    "kyf thuwowjng, kyf anh, haf tixnh"
  ],
  "Kỳ Tân, Bá Thước, Thanh Hóa": [
    "kỳ tân, bá thước, thanh hóa",
    "kyf taan, bas thuwowsc, thanh hosa"
  ],
  "La Ngà, Định Quán, Đồng Nai": [
    "la ngà, định quán, đồng nai",
    "la ngaf, ddijnh quasn, ddoofng nai"
  ],
  "La Ngâu, Tánh Linh, Bình Thuận": [
    "la ngâu, tánh linh, bình thuận",
    "la ngaau, tasnh linh, bifnh thuaajn"
  ],
  "Lang Minh, Xuân Lộc, Đồng Nai": [
    "lang minh, xuân lộc, đồng nai",
    "lang minh, xuaan loojc, ddoofng nai"
  ],
  "Lang Quán, Yên Sơn, Tuyên Quang": [
    "lang quán, yên sơn, tuyên quang",
    "lang quasn, yeen sown, tuyeen quang"
  ],
  "Linh Hải, Gio Linh, Quảng Trị": [
    "linh hải, gio linh, quảng trị",
    "linh hari, gio linh, quarng trij"
  ],
  "Liêm Thuận, Thanh Liêm, Hà Nam": [
    "liêm thuận, thanh liêm, hà nam",
    "lieem thuaajn, thanh lieem, haf nam"
  ],
  "Liên Am, Vĩnh Bảo, Hải Phòng": [
    "liên am, vĩnh bảo, hải phòng",
    "lieen am, vixnh baro, hari phofng"
  ],
  "Liên Chung, Tân Yên, Bắc Giang": [
    "liên chung, tân yên, bắc giang",
    "lieen chung, taan yeen, bawsc giang"
  ],
  "Liên Hội, Văn Quan, Lạng Sơn": [
    "liên hội, văn quan, lạng sơn",
    "lieen hooji, vawn quan, lajng sown"
  ],
  "Liên Hợp, Quỳ Hợp, Nghệ An": [
    "liên hợp, quỳ hợp, nghệ an",
    "lieen howjp, quyf howjp, ngheej an"
  ],
  "Liên Minh, Võ Nhai, Thái Nguyên": [
    "liên minh, võ nhai, thái nguyên",
    "lieen minh, vox nhai, thasi nguyeen"
  ],
  "Liên Minh, Vụ Bản, Nam Định": [
    "liên minh, vụ bản, nam định",
    "lieen minh, vuj barn, nam ddijnh"
  ],
  "Liên Minh, Đức Thọ, Hà Tĩnh": [
    "liên minh, đức thọ, hà tĩnh",
    "lieen minh, dduwsc thoj, haf tixnh"
  ],
  "Liên Đầm, Di Linh, Lâm Đồng": [
    "liên đầm, di linh, lâm đồng",
    "lieen ddaafm, di linh, laam ddoofng"
  ],
  "Long An, Châu Thành, Tiền Giang": [
    "long an, châu thành, tiền giang",
    "long an, chaau thafnh, tieefn giang"
  ],
  "Long Bình, Biên Hòa, Đồng Nai": [
    "long bình, biên hòa, đồng nai",
    "long bifnh, bieen hofa, ddoofng nai"
  ],
  "Long Hòa, Bình Thuỷ, Cần Thơ": [
    "long hòa, bình thuỷ, cần thơ",
    "long hofa, bifnh thuyr, caafn thow"
  ],
  "Long Hưng, Biên Hòa, Đồng Nai": [
    "long hưng, biên hòa, đồng nai",
    "long huwng, bieen hofa, ddoofng nai"
  ],
  "Long Hưng, Gò Công, Tiền Giang": [
    "long hưng, gò công, tiền giang",
    "long huwng, gof coong, tieefn giang"
  ],
  "Long Hậu, Lai Vung, Đồng Tháp": [
    "long hậu, lai vung, đồng tháp",
    "long haaju, lai vung, ddoofng thasp"
  ],
  "Long Hữu, Duyên Hải, Trà Vinh": [
    "long hữu, duyên hải, trà vinh",
    "long huwxu, duyeen hari, traf vinh"
  ],
  "Long Khánh, Bến Cầu, Tây Ninh": [
    "long khánh, bến cầu, tây ninh",
    "long khasnh, beesn caafu, taay ninh"
  ],
  "Long Môn, Minh Long, Quảng Ngãi": [
    "long môn, minh long, quảng ngãi",
    "long moon, minh long, quarng ngaxi"
  ],
  "Long Mỹ, Giồng Trôm, Bến Tre": [
    "long mỹ, giồng trôm, bến tre",
    "long myx, gioofng troom, beesn tre"
  ],
  "Long Sơn, Minh Long, Quảng Ngãi": [
    "long sơn, minh long, quảng ngãi",
    "long sown, minh long, quarng ngaxi"
  ],
  "Long Sơn, Đắk Mil, Đắk Nông": [
    "long sơn, đắk mil, đắk nông",
    "long sown, ddawsk mil, ddawsk noong"
  ],
  "Long Thuận, Thủ Thừa, Long An": [
    "long thuận, thủ thừa, long an",
    "long thuaajn, thur thuwfa, long an"
  ],
  "Long Thành, Yên Thành, Nghệ An": [
    "long thành, yên thành, nghệ an",
    "long thafnh, yeen thafnh, ngheej an"
  ],
  "Long Thạnh, Thủ Thừa, Long An": [
    "long thạnh, thủ thừa, long an",
    "long thajnh, thur thuwfa, long an"
  ],
  "Long Thới, Chợ Lách, Bến Tre": [
    "long thới, chợ lách, bến tre",
    "long thowsi, chowj lasch, beesn tre"
  ],
  "Long Tiên, Cai Lậy, Tiền Giang": [
    "long tiên, cai lậy, tiền giang",
    "long tieen, cai laajy, tieefn giang"
  ],
  "Long Toàn, Duyên Hải, Trà Vinh": [
    "long toàn, duyên hải, trà vinh",
    "long toafn, duyeen hari, traf vinh"
  ],
  "Long Trung, Cai Lậy, Tiền Giang": [
    "long trung, cai lậy, tiền giang",
    "long trung, cai laajy, tieefn giang"
  ],
  "Long Vĩnh, Châu Thành, Tây Ninh": [
    "long vĩnh, châu thành, tây ninh",
    "long vixnh, chaau thafnh, taay ninh"
  ],
  "Long Vĩnh, Duyên Hải, Trà Vinh": [
    "long vĩnh, duyên hải, trà vinh",
    "long vixnh, duyeen hari, traf vinh"
  ],
  "Long Xuyên, Phúc Thọ, Hà Nội": [
    "long xuyên, phúc thọ, hà nội",
    "long xuyeen, phusc thoj, haf nooji"
  ],
  "Long Đức, Long Phú, Sóc Trăng": [
    "long đức, long phú, sóc trăng",
    "long dduwsc, long phus, sosc trawng"
  ],
  "Làng Nhì, Trạm Tấu, Yên Bái": [
    "làng nhì, trạm tấu, yên bái",
    "lafng nhif, trajm taasu, yeen basi"
  ],
  "Lâm Sơn, Lương Sơn, Hoà Bình": [
    "lâm sơn, lương sơn, hoà bình",
    "laam sown, luwowng sown, hoaf bifnh"
  ],
  "Lâm Thao, Lương Tài, Bắc Ninh": [
    "lâm thao, lương tài, bắc ninh",
    "laam thao, luwowng tafi, bawsc ninh"
  ],
  "Lãng Công, Sông Lô, Vĩnh Phúc": [
    "lãng công, sông lô, vĩnh phúc",
    "laxng coong, soong loo, vixnh phusc"
  ],
  "Lãng Sơn, Yên Dũng, Bắc Giang": [
    "lãng sơn, yên dũng, bắc giang",
    "laxng sown, yeen duxng, bawsc giang"
  ],
  "Lê Lợi, An Dương, Hải Phòng": [
    "lê lợi, an dương, hải phòng",
    "lee lowji, an duwowng, hari phofng"
  ],
  "Lê Lợi, Bắc Giang, Bắc Giang": [
    "lê lợi, bắc giang, bắc giang",
    "lee lowji, bawsc giang, bawsc giang"
  ],
  "Lê Lợi, Chí Linh, Hải Dương": [
    "lê lợi, chí linh, hải dương",
    "lee lowji, chis linh, hari duwowng"
  ],
  "Lê Lợi, Gia Lộc, Hải Dương": [
    "lê lợi, gia lộc, hải dương",
    "lee lowji, gia loojc, hari duwowng"
  ],
  "Lê Lợi, Qui Nhơn, Bình Định": [
    "lê lợi, qui nhơn, bình định",
    "lee lowji, qui nhown, bifnh ddijnh"
  ],
  "Lăng Can, Lâm Bình, Tuyên Quang": [
    "lăng can, lâm bình, tuyên quang",
    "lawng can, laam bifnh, tuyeen quang"
  ],
  "Lĩnh Toại, Hà Trung, Thanh Hóa": [
    "lĩnh toại, hà trung, thanh hóa",
    "lixnh toaji, haf trung, thanh hosa"
  ],
  "Lũng Cao, Bá Thước, Thanh Hóa": [
    "lũng cao, bá thước, thanh hóa",
    "luxng cao, bas thuwowsc, thanh hosa"
  ],
  "Lũng Táo, Đồng Văn, Hà Giang": [
    "lũng táo, đồng văn, hà giang",
    "luxng taso, ddoofng vawn, haf giang"
  ],
  "Lưu Phương, Kim Sơn, Ninh Bình": [
    "lưu phương, kim sơn, ninh bình",
    "luwu phuwowng, kim sown, ninh bifnh"
  ],
  "Lương An Trà, Tri Tôn, An Giang": [
    "lương an trà, tri tôn, an giang",
    "luwowng an traf, tri toon, an giang"
  ],
  "Lương Bình, Bến Lức, Long An": [
    "lương bình, bến lức, long an",
    "luwowng bifnh, beesn luwsc, long an"
  ],
  "Lương Nha, Thanh Sơn, Phú Thọ": [
    "lương nha, thanh sơn, phú thọ",
    "luwowng nha, thanh sown, phus thoj"
  ],
  "Lương Tài, Văn Lâm, Hưng Yên": [
    "lương tài, văn lâm, hưng yên",
    "luwowng tafi, vawn laam, huwng yeen"
  ],
  "Lạc Hồng, Văn Lâm, Hưng Yên": [
    "lạc hồng, văn lâm, hưng yên",
    "lajc hoofng, vawn laam, huwng yeen"
  ],
  "Lạc Sơn, Đô Lương, Nghệ An": [
    "lạc sơn, đô lương, nghệ an",
    "lajc sown, ddoo luwowng, ngheej an"
  ],
  "Lạc Sỹ, Yên Thủy, Hoà Bình": [
    "lạc sỹ, yên thủy, hoà bình",
    "lajc syx, yeen thury, hoaf bifnh"
  ],
  "Lạc Đạo, Văn Lâm, Hưng Yên": [
    "lạc đạo, văn lâm, hưng yên",
    "lajc ddajo, vawn laam, huwng yeen"
  ],
  "Lại Yên, Hoài Đức, Hà Nội": [
    "lại yên, hoài đức, hà nội",
    "laji yeen, hoafi dduwsc, haf nooji"
  ],
  "Lấp Vò, Lấp Vò, Đồng Tháp": [
    "lấp vò, lấp vò, đồng tháp",
    "laasp vof, laasp vof, ddoofng thasp"
  ],
  "Lộc Nam, Bảo Lâm, Lâm Đồng": [
    "lộc nam, bảo lâm, lâm đồng",
    "loojc nam, baro laam, laam ddoofng"
  ],
  "Lộc Sơn, Hậu Lộc, Thanh Hóa": [
    "lộc sơn, hậu lộc, thanh hóa",
    "loojc sown, haaju loojc, thanh hosa"
  ],
  "Lộc Thọ, Nha Trang, Khánh Hòa": [
    "lộc thọ, nha trang, khánh hòa",
    "loojc thoj, nha trang, khasnh hofa"
  ],
  "Lộc Yên, Hương Khê, Hà Tĩnh": [
    "lộc yên, hương khê, hà tĩnh",
    "loojc yeen, huwowng khee, haf tixnh"
  ],
  "Lợi Bình Nhơn, Tân An, Long An": [
    "lợi bình nhơn, tân an, long an",
    "lowji bifnh nhown, taan an, long an"
  ],
  "Mai Dịch, Cầu Giấy, Hà Nội": [
    "mai dịch, cầu giấy, hà nội",
    "mai dijch, caafu giaasy, haf nooji"
  ],
  "Mai Long, Nguyên Bình, Cao Bằng": [
    "mai long, nguyên bình, cao bằng",
    "mai long, nguyeen bifnh, cao bawfng"
  ],
  "Mai Lạp, Chợ Mới, Bắc Kạn": [
    "mai lạp, chợ mới, bắc kạn",
    "mai lajp, chowj mowsi, bawsc kajn"
  ],
  "Mai Trung, Hiệp Hòa, Bắc Giang": [
    "mai trung, hiệp hòa, bắc giang",
    "mai trung, hieejp hofa, bawsc giang"
  ],
  "Minh Chuẩn, Lục Yên, Yên Bái": [
    "minh chuẩn, lục yên, yên bái",
    "minh chuaarn, lujc yeen, yeen basi"
  ],
  "Minh Châu, Diễn Châu, Nghệ An": [
    "minh châu, diễn châu, nghệ an",
    "minh chaau, dieexn chaau, ngheej an"
  ],
  "Minh Hòa, Hữu Lũng, Lạng Sơn": [
    "minh hòa, hữu lũng, lạng sơn",
    "minh hofa, huwxu luxng, lajng sown"
  ],
  "Minh Hòa, Kinh Môn, Hải Dương": [
    "minh hòa, kinh môn, hải dương",
    "minh hofa, kinh moon, hari duwowng"
  ],
  "Minh Hóa, Minh Hóa, Quảng Bình": [
    "minh hóa, minh hóa, quảng bình",
    "minh hosa, minh hosa, quarng bifnh"
  ],
  "Minh Lộc, Hậu Lộc, Thanh Hóa": [
    "minh lộc, hậu lộc, thanh hóa",
    "minh loojc, haaju loojc, thanh hosa"
  ],
  "Minh Nông, Việt Trì, Phú Thọ": [
    "minh nông, việt trì, phú thọ",
    "minh noong, vieejt trif, phus thoj"
  ],
  "Minh Quang, Tam Đảo, Vĩnh Phúc": [
    "minh quang, tam đảo, vĩnh phúc",
    "minh quang, tam ddaro, vixnh phusc"
  ],
  "Minh Sơn, Hữu Lũng, Lạng Sơn": [
    "minh sơn, hữu lũng, lạng sơn",
    "minh sown, huwxu luxng, lajng sown"
  ],
  "Minh Sơn, Ngọc Lặc, Thanh Hóa": [
    "minh sơn, ngọc lặc, thanh hóa",
    "minh sown, ngojc lawjc, thanh hosa"
  ],
  "Minh Sơn, Triệu Sơn, Thanh Hóa": [
    "minh sơn, triệu sơn, thanh hóa",
    "minh sown, trieeju sown, thanh hosa"
  ],
  "Minh Thành, Yên Thành, Nghệ An": [
    "minh thành, yên thành, nghệ an",
    "minh thafnh, yeen thafnh, ngheej an"
  ],
  "Minh Tâm, Thiệu Hóa, Thanh Hóa": [
    "minh tâm, thiệu hóa, thanh hóa",
    "minh taam, thieeju hosa, thanh hosa"
  ],
  "Minh Tân, Kinh Môn, Hải Dương": [
    "minh tân, kinh môn, hải dương",
    "minh taan, kinh moon, hari duwowng"
  ],
  "Minh Tân, Lương Tài, Bắc Ninh": [
    "minh tân, lương tài, bắc ninh",
    "minh taan, luwowng tafi, bawsc ninh"
  ],
  "Minh Tân, Nam Sách, Hải Dương": [
    "minh tân, nam sách, hải dương",
    "minh taan, nam sasch, hari duwowng"
  ],
  "Mà Cooi, Đông Giang, Quảng Nam": [
    "mà cooi, đông giang, quảng nam",
    "maf cooi, ddoong giang, quarng nam"
  ],
  "Mãn Đức, Tân Lạc, Hoà Bình": [
    "mãn đức, tân lạc, hoà bình",
    "maxn dduwsc, taan lajc, hoaf bifnh"
  ],
  "Mê Linh, Đông Hưng, Thái Bình": [
    "mê linh, đông hưng, thái bình",
    "mee linh, ddoong huwng, thasi bifnh"
  ],
  "Mường Kim, Than Uyên, Lai Châu": [
    "mường kim, than uyên, lai châu",
    "muwowfng kim, than uyeen, lai chaau"
  ],
  "Mường Lai, Lục Yên, Yên Bái": [
    "mường lai, lục yên, yên bái",
    "muwowfng lai, lujc yeen, yeen basi"
  ],
  "Mường Lèo, Sốp Cộp, Sơn La": [
    "mường lèo, sốp cộp, sơn la",
    "muwowfng lefo, soosp coojp, sown la"
  ],
  "Mường Lựm, Yên Châu, Sơn La": [
    "mường lựm, yên châu, sơn la",
    "muwowfng luwjm, yeen chaau, sown la"
  ],
  "Mường Sang, Mộc Châu, Sơn La": [
    "mường sang, mộc châu, sơn la",
    "muwowfng sang, moojc chaau, sown la"
  ],
  "Mường So, Phong Thổ, Lai Châu": [
    "mường so, phong thổ, lai châu",
    "muwowfng so, phong thoor, lai chaau"
  ],
  "Mường Thải, Phù Yên, Sơn La": [
    "mường thải, phù yên, sơn la",
    "muwowfng thari, phuf yeen, sown la"
  ],
  "Mường Trai, Mường La, Sơn La": [
    "mường trai, mường la, sơn la",
    "muwowfng trai, muwowfng la, sown la"
  ],
  "Mường Típ, Kỳ Sơn, Nghệ An": [
    "mường típ, kỳ sơn, nghệ an",
    "muwowfng tisp, kyf sown, ngheej an"
  ],
  "Mường Xén, Kỳ Sơn, Nghệ An": [
    "mường xén, kỳ sơn, nghệ an",
    "muwowfng xesn, kyf sown, ngheej an"
  ],
  "Mường é, Thuận Châu, Sơn La": [
    "mường é, thuận châu, sơn la",
    "muwowfng es, thuaajn chaau, sown la"
  ],
  "Mường Ải, Kỳ Sơn, Nghệ An": [
    "mường ải, kỳ sơn, nghệ an",
    "muwowfng ari, kyf sown, ngheej an"
  ],
  "Mậu Đức, Con Cuông, Nghệ An": [
    "mậu đức, con cuông, nghệ an",
    "maaju dduwsc, con cuoong, ngheej an"
  ],
  "Mỏ Cày, Mỏ Cày Nam, Bến Tre": [
    "mỏ cày, mỏ cày nam, bến tre",
    "mor cafy, mor cafy nam, beesn tre"
  ],
  "Mỹ Cát, Phù Mỹ, Bình Định": [
    "mỹ cát, phù mỹ, bình định",
    "myx cast, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Hà, Lạng Giang, Bắc Giang": [
    "mỹ hà, lạng giang, bắc giang",
    "myx haf, lajng giang, bawsc giang"
  ],
  "Mỹ Hòa, Phù Mỹ, Bình Định": [
    "mỹ hòa, phù mỹ, bình định",
    "myx hofa, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Hưng, Mỹ Lộc, Nam Định": [
    "mỹ hưng, mỹ lộc, nam định",
    "myx huwng, myx loojc, nam ddijnh"
  ],
  "Mỹ Hưng, Thạnh Phú, Bến Tre": [
    "mỹ hưng, thạnh phú, bến tre",
    "myx huwng, thajnh phus, beesn tre"
  ],
  "Mỹ Hương, Mỹ Tú, Sóc Trăng": [
    "mỹ hương, mỹ tú, sóc trăng",
    "myx huwowng, myx tus, sosc trawng"
  ],
  "Mỹ Long, Cao Lãnh, Đồng Tháp": [
    "mỹ long, cao lãnh, đồng tháp",
    "myx long, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Lâm, Hòn Đất, Kiên Giang": [
    "mỹ lâm, hòn đất, kiên giang",
    "myx laam, hofn ddaast, kieen giang"
  ],
  "Mỹ Lộc, Hậu Lộc, Thanh Hóa": [
    "mỹ lộc, hậu lộc, thanh hóa",
    "myx loojc, haaju loojc, thanh hosa"
  ],
  "Mỹ Lộc, Mỹ Lộc, Nam Định": [
    "mỹ lộc, mỹ lộc, nam định",
    "myx loojc, myx loojc, nam ddijnh"
  ],
  "Mỹ Phú, Cao Lãnh, Đồng Tháp": [
    "mỹ phú, cao lãnh, đồng tháp",
    "myx phus, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Phúc, Mỹ Lộc, Nam Định": [
    "mỹ phúc, mỹ lộc, nam định",
    "myx phusc, myx loojc, nam ddijnh"
  ],
  "Mỹ Phương, Ba Bể, Bắc Kạn": [
    "mỹ phương, ba bể, bắc kạn",
    "myx phuwowng, ba beer, bawsc kajn"
  ],
  "Mỹ Quới, Ngã Năm, Sóc Trăng": [
    "mỹ quới, ngã năm, sóc trăng",
    "myx quowsi, ngax nawm, sosc trawng"
  ],
  "Mỹ Thuận, Mỹ Tú, Sóc Trăng": [
    "mỹ thuận, mỹ tú, sóc trăng",
    "myx thuaajn, myx tus, sosc trawng"
  ],
  "Mỹ Thuận, Tân Sơn, Phú Thọ": [
    "mỹ thuận, tân sơn, phú thọ",
    "myx thuaajn, taan sown, phus thoj"
  ],
  "Mỹ Thành, Lạc Sơn, Hoà Bình": [
    "mỹ thành, lạc sơn, hoà bình",
    "myx thafnh, lajc sown, hoaf bifnh"
  ],
  "Mỹ Thành, Mỹ Đức, Hà Nội": [
    "mỹ thành, mỹ đức, hà nội",
    "myx thafnh, myx dduwsc, haf nooji"
  ],
  "Mỹ Thành, Yên Thành, Nghệ An": [
    "mỹ thành, yên thành, nghệ an",
    "myx thafnh, yeen thafnh, ngheej an"
  ],
  "Mỹ Thạnh, Long Xuyên, An Giang": [
    "mỹ thạnh, long xuyên, an giang",
    "myx thajnh, long xuyeen, an giang"
  ],
  "Mỹ Thạnh, Thủ Thừa, Long An": [
    "mỹ thạnh, thủ thừa, long an",
    "myx thajnh, thur thuwfa, long an"
  ],
  "Mỹ Trung, Mỹ Lộc, Nam Định": [
    "mỹ trung, mỹ lộc, nam định",
    "myx trung, myx loojc, nam ddijnh"
  ],
  "Mỹ Trà, Cao Lãnh, Đồng Tháp": [
    "mỹ trà, cao lãnh, đồng tháp",
    "myx traf, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Tài, Phù Mỹ, Bình Định": [
    "mỹ tài, phù mỹ, bình định",
    "myx tafi, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Tân, Cao Lãnh, Đồng Tháp": [
    "mỹ tân, cao lãnh, đồng tháp",
    "myx taan, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Tân, Ngọc Lặc, Thanh Hóa": [
    "mỹ tân, ngọc lặc, thanh hóa",
    "myx taan, ngojc lawjc, thanh hosa"
  ],
  "Mỹ Đức, Hà Tiên, Kiên Giang": [
    "mỹ đức, hà tiên, kiên giang",
    "myx dduwsc, haf tieen, kieen giang"
  ],
  "Na Lay, Mường Lay, Điện Biên": [
    "na lay, mường lay, điện biên",
    "na lay, muwowfng lay, ddieejn bieen"
  ],
  "Na Ư, Điện Biên, Điện Biên": [
    "na ư, điện biên, điện biên",
    "na uw, ddieejn bieen, ddieejn bieen"
  ],
  "Nam Hưng, Nam Sách, Hải Dương": [
    "nam hưng, nam sách, hải dương",
    "nam huwng, nam sasch, hari duwowng"
  ],
  "Nam Hồng, Hồng Lĩnh, Hà Tĩnh": [
    "nam hồng, hồng lĩnh, hà tĩnh",
    "nam hoofng, hoofng lixnh, haf tixnh"
  ],
  "Nam Hồng, Nam Trực, Nam Định": [
    "nam hồng, nam trực, nam định",
    "nam hoofng, nam truwjc, nam ddijnh"
  ],
  "Nam Phong, Nam Định, Nam Định": [
    "nam phong, nam định, nam định",
    "nam phong, nam ddijnh, nam ddijnh"
  ],
  "Nam Phú, Tiền Hải, Thái Bình": [
    "nam phú, tiền hải, thái bình",
    "nam phus, tieefn hari, thasi bifnh"
  ],
  "Nam Sách, Nam Sách, Hải Dương": [
    "nam sách, nam sách, hải dương",
    "nam sasch, nam sasch, hari duwowng"
  ],
  "Nam Sơn, Hoàng Su Phì, Hà Giang": [
    "nam sơn, hoàng su phì, hà giang",
    "nam sown, hoafng su phif, haf giang"
  ],
  "Nam Thượng, Kim Bôi, Hoà Bình": [
    "nam thượng, kim bôi, hoà bình",
    "nam thuwowjng, kim booi, hoaf bifnh"
  ],
  "Nam Tiến, Nam Trực, Nam Định": [
    "nam tiến, nam trực, nam định",
    "nam tieesn, nam truwjc, nam ddijnh"
  ],
  "Nam Triều, Phú Xuyên, Hà Nội": [
    "nam triều, phú xuyên, hà nội",
    "nam trieefu, phus xuyeen, haf nooji"
  ],
  "Nam Trung, Nam Sách, Hải Dương": [
    "nam trung, nam sách, hải dương",
    "nam trung, nam sasch, hari duwowng"
  ],
  "Nam Xuân, Krông Nô, Đắk Nông": [
    "nam xuân, krông nô, đắk nông",
    "nam xuaan, kroong noo, ddawsk noong"
  ],
  "Nam Điền, Thạch Hà, Hà Tĩnh": [
    "nam điền, thạch hà, hà tĩnh",
    "nam ddieefn, thajch haf, haf tixnh"
  ],
  "Nam Đồng, Đống Đa, Hà Nội": [
    "nam đồng, đống đa, hà nội",
    "nam ddoofng, ddoosng dda, haf nooji"
  ],
  "Nga Phượng, Nga Sơn, Thanh Hóa": [
    "nga phượng, nga sơn, thanh hóa",
    "nga phuwowjng, nga sown, thanh hosa"
  ],
  "Nga Trường, Nga Sơn, Thanh Hóa": [
    "nga trường, nga sơn, thanh hóa",
    "nga truwowfng, nga sown, thanh hosa"
  ],
  "Nghi Thiết, Nghi Lộc, Nghệ An": [
    "nghi thiết, nghi lộc, nghệ an",
    "nghi thieest, nghi loojc, ngheej an"
  ],
  "Nghi Thuận, Nghi Lộc, Nghệ An": [
    "nghi thuận, nghi lộc, nghệ an",
    "nghi thuaajn, nghi loojc, ngheej an"
  ],
  "Nghi Thạch, Nghi Lộc, Nghệ An": [
    "nghi thạch, nghi lộc, nghệ an",
    "nghi thajch, nghi loojc, ngheej an"
  ],
  "Nghi Thịnh, Nghi Lộc, Nghệ An": [
    "nghi thịnh, nghi lộc, nghệ an",
    "nghi thijnh, nghi loojc, ngheej an"
  ],
  "Nghi Đồng, Nghi Lộc, Nghệ An": [
    "nghi đồng, nghi lộc, nghệ an",
    "nghi ddoofng, nghi loojc, ngheej an"
  ],
  "Nghĩa Lộ, Nghĩa Lộ, Yên Bái": [
    "nghĩa lộ, nghĩa lộ, yên bái",
    "nghixa looj, nghixa looj, yeen basi"
  ],
  "Nghĩa Mai, Nghĩa Đàn, Nghệ An": [
    "nghĩa mai, nghĩa đàn, nghệ an",
    "nghixa mai, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Sơn, Văn Chấn, Yên Bái": [
    "nghĩa sơn, văn chấn, yên bái",
    "nghixa sown, vawn chaasn, yeen basi"
  ],
  "Nghĩa Tâm, Văn Chấn, Yên Bái": [
    "nghĩa tâm, văn chấn, yên bái",
    "nghixa taam, vawn chaasn, yeen basi"
  ],
  "Nghĩa Xá, Lê Chân, Hải Phòng": [
    "nghĩa xá, lê chân, hải phòng",
    "nghixa xas, lee chaan, hari phofng"
  ],
  "Nguyên Hòa, Phù Cừ, Hưng Yên": [
    "nguyên hòa, phù cừ, hưng yên",
    "nguyeen hofa, phuf cuwf, huwng yeen"
  ],
  "Nguyên Khê, Đông Anh, Hà Nội": [
    "nguyên khê, đông anh, hà nội",
    "nguyeen khee, ddoong anh, haf nooji"
  ],
  "Nguyễn Huệ, Hoà An, Cao Bằng": [
    "nguyễn huệ, hoà an, cao bằng",
    "nguyeexn hueej, hoaf an, cao bawfng"
  ],
  "Nguyễn Trãi, Ân Thi, Hưng Yên": [
    "nguyễn trãi, ân thi, hưng yên",
    "nguyeexn traxi, aan thi, huwng yeen"
  ],
  "Ngã Bảy, Ngã Bảy, Hậu Giang": [
    "ngã bảy, ngã bảy, hậu giang",
    "ngax bary, ngax bary, haaju giang"
  ],
  "Ngô Mây, Phù Cát, Bình Định": [
    "ngô mây, phù cát, bình định",
    "ngoo maay, phuf cast, bifnh ddijnh"
  ],
  "Ngô Mây, Qui Nhơn, Bình Định": [
    "ngô mây, qui nhơn, bình định",
    "ngoo maay, qui nhown, bifnh ddijnh"
  ],
  "Ngũ Lạc, Duyên Hải, Trà Vinh": [
    "ngũ lạc, duyên hải, trà vinh",
    "ngux lajc, duyeen hari, traf vinh"
  ],
  "Ngư Lộc, Hậu Lộc, Thanh Hóa": [
    "ngư lộc, hậu lộc, thanh hóa",
    "nguw loojc, haaju loojc, thanh hosa"
  ],
  "Ngọc Chánh, Đầm Dơi, Cà Mau": [
    "ngọc chánh, đầm dơi, cà mau",
    "ngojc chasnh, ddaafm dowi, caf mau"
  ],
  "Ngọc Hồi, Thanh Trì, Hà Nội": [
    "ngọc hồi, thanh trì, hà nội",
    "ngojc hoofi, thanh trif, haf nooji"
  ],
  "Ngọc Khánh, Ba Đình, Hà Nội": [
    "ngọc khánh, ba đình, hà nội",
    "ngojc khasnh, ba ddifnh, haf nooji"
  ],
  "Ngọc Linh, Vị Xuyên, Hà Giang": [
    "ngọc linh, vị xuyên, hà giang",
    "ngojc linh, vij xuyeen, haf giang"
  ],
  "Ngọc Lâu, Lạc Sơn, Hoà Bình": [
    "ngọc lâu, lạc sơn, hoà bình",
    "ngojc laau, lajc sown, hoaf bifnh"
  ],
  "Ngọc Lĩnh, Tĩnh Gia, Thanh Hóa": [
    "ngọc lĩnh, tĩnh gia, thanh hóa",
    "ngojc lixnh, tixnh gia, thanh hosa"
  ],
  "Ngọc Minh, Vị Xuyên, Hà Giang": [
    "ngọc minh, vị xuyên, hà giang",
    "ngojc minh, vij xuyeen, haf giang"
  ],
  "Ngọc Mỹ, Tân Lạc, Hoà Bình": [
    "ngọc mỹ, tân lạc, hoà bình",
    "ngojc myx, taan lajc, hoaf bifnh"
  ],
  "Ngọc Sơn, Lạc Sơn, Hoà Bình": [
    "ngọc sơn, lạc sơn, hoà bình",
    "ngojc sown, lajc sown, hoaf bifnh"
  ],
  "Ngọc Sơn, Thạch Hà, Hà Tĩnh": [
    "ngọc sơn, thạch hà, hà tĩnh",
    "ngojc sown, thajch haf, haf tixnh"
  ],
  "Ngọc Vân, Tân Yên, Bắc Giang": [
    "ngọc vân, tân yên, bắc giang",
    "ngojc vaan, taan yeen, bawsc giang"
  ],
  "Nhi Sơn, Mường Lát, Thanh Hóa": [
    "nhi sơn, mường lát, thanh hóa",
    "nhi sown, muwowfng last, thanh hosa"
  ],
  "Nhà Mát, Bạc Liêu, Bạc Liêu": [
    "nhà mát, bạc liêu, bạc liêu",
    "nhaf mast, bajc lieeu, bajc lieeu"
  ],
  "Nhân Sơn, Đô Lương, Nghệ An": [
    "nhân sơn, đô lương, nghệ an",
    "nhaan sown, ddoo luwowng, ngheej an"
  ],
  "Nhơn Hoà, An Nhơn, Bình Định": [
    "nhơn hoà, an nhơn, bình định",
    "nhown hoaf, an nhown, bifnh ddijnh"
  ],
  "Nhơn Hưng, Tịnh Biên, An Giang": [
    "nhơn hưng, tịnh biên, an giang",
    "nhown huwng, tijnh bieen, an giang"
  ],
  "Nhơn Lý, Qui Nhơn, Bình Định": [
    "nhơn lý, qui nhơn, bình định",
    "nhown lys, qui nhown, bifnh ddijnh"
  ],
  "Nhơn Mỹ, An Nhơn, Bình Định": [
    "nhơn mỹ, an nhơn, bình định",
    "nhown myx, an nhown, bifnh ddijnh"
  ],
  "Nhơn Mỹ, Kế Sách, Sóc Trăng": [
    "nhơn mỹ, kế sách, sóc trăng",
    "nhown myx, kees sasch, sosc trawng"
  ],
  "Nhơn Sơn, Ninh Sơn, Ninh Thuận": [
    "nhơn sơn, ninh sơn, ninh thuận",
    "nhown sown, ninh sown, ninh thuaajn"
  ],
  "Nhơn Thạnh, Bến Tre, Bến Tre": [
    "nhơn thạnh, bến tre, bến tre",
    "nhown thajnh, beesn tre, beesn tre"
  ],
  "Nhơn Tân, An Nhơn, Bình Định": [
    "nhơn tân, an nhơn, bình định",
    "nhown taan, an nhown, bifnh ddijnh"
  ],
  "Như Cố, Chợ Mới, Bắc Kạn": [
    "như cố, chợ mới, bắc kạn",
    "nhuw coos, chowj mowsi, bawsc kajn"
  ],
  "Như Quỳnh, Văn Lâm, Hưng Yên": [
    "như quỳnh, văn lâm, hưng yên",
    "nhuw quyfnh, vawn laam, huwng yeen"
  ],
  "Như Thụy, Sông Lô, Vĩnh Phúc": [
    "như thụy, sông lô, vĩnh phúc",
    "nhuw thujy, soong loo, vixnh phusc"
  ],
  "Nhạo Sơn, Sông Lô, Vĩnh Phúc": [
    "nhạo sơn, sông lô, vĩnh phúc",
    "nhajo sown, soong loo, vixnh phusc"
  ],
  "Nhật Quang, Phù Cừ, Hưng Yên": [
    "nhật quang, phù cừ, hưng yên",
    "nhaajt quang, phuf cuwf, huwng yeen"
  ],
  "Nhật Tân, Tiên Lữ, Hưng Yên": [
    "nhật tân, tiên lữ, hưng yên",
    "nhaajt taan, tieen luwx, huwng yeen"
  ],
  "Nhị Mỹ, Cai Lậy, Tiền Giang": [
    "nhị mỹ, cai lậy, tiền giang",
    "nhij myx, cai laajy, tieefn giang"
  ],
  "Nhị Quý, Cai Lậy, Tiền Giang": [
    "nhị quý, cai lậy, tiền giang",
    "nhij quys, cai laajy, tieefn giang"
  ],
  "Nhị Thành, Thủ Thừa, Long An": [
    "nhị thành, thủ thừa, long an",
    "nhij thafnh, thur thuwfa, long an"
  ],
  "Nhữ Hán, Yên Sơn, Tuyên Quang": [
    "nhữ hán, yên sơn, tuyên quang",
    "nhuwx hasn, yeen sown, tuyeen quang"
  ],
  "Nhữ Khê, Yên Sơn, Tuyên Quang": [
    "nhữ khê, yên sơn, tuyên quang",
    "nhuwx khee, yeen sown, tuyeen quang"
  ],
  "Nhựt Chánh, Bến Lức, Long An": [
    "nhựt chánh, bến lức, long an",
    "nhuwjt chasnh, beesn luwsc, long an"
  ],
  "Ninh Hiệp, Ninh Hòa, Khánh Hòa": [
    "ninh hiệp, ninh hòa, khánh hòa",
    "ninh hieejp, ninh hofa, khasnh hofa"
  ],
  "Ninh Hòa, Hồng Dân, Bạc Liêu": [
    "ninh hòa, hồng dân, bạc liêu",
    "ninh hofa, hoofng daan, bajc lieeu"
  ],
  "Ninh Khang, Vĩnh Lộc, Thanh Hóa": [
    "ninh khang, vĩnh lộc, thanh hóa",
    "ninh khang, vixnh loojc, thanh hosa"
  ],
  "Ninh Khánh, Ninh Bình, Ninh Bình": [
    "ninh khánh, ninh bình, ninh bình",
    "ninh khasnh, ninh bifnh, ninh bifnh"
  ],
  "Ninh Nhất, Ninh Bình, Ninh Bình": [
    "ninh nhất, ninh bình, ninh bình",
    "ninh nhaast, ninh bifnh, ninh bifnh"
  ],
  "Ninh Sơn, Việt Yên, Bắc Giang": [
    "ninh sơn, việt yên, bắc giang",
    "ninh sown, vieejt yeen, bawsc giang"
  ],
  "Ninh Thủy, Ninh Hòa, Khánh Hòa": [
    "ninh thủy, ninh hòa, khánh hòa",
    "ninh thury, ninh hofa, khasnh hofa"
  ],
  "Ninh Tiến, Ninh Bình, Ninh Bình": [
    "ninh tiến, ninh bình, ninh bình",
    "ninh tieesn, ninh bifnh, ninh bifnh"
  ],
  "Ninh Đông, Ninh Hòa, Khánh Hòa": [
    "ninh đông, ninh hòa, khánh hòa",
    "ninh ddoong, ninh hofa, khasnh hofa"
  ],
  "Nà Hỳ, Nậm Pồ, Điện Biên": [
    "nà hỳ, nậm pồ, điện biên",
    "naf hyf, naajm poof, ddieejn bieen"
  ],
  "Nà Khoa, Nậm Pồ, Điện Biên": [
    "nà khoa, nậm pồ, điện biên",
    "naf khoa, naajm poof, ddieejn bieen"
  ],
  "Nà Phặc, Ngân Sơn, Bắc Kạn": [
    "nà phặc, ngân sơn, bắc kạn",
    "naf phawjc, ngaan sown, bawsc kajn"
  ],
  "Nàng Mau, Vị Thuỷ, Hậu Giang": [
    "nàng mau, vị thuỷ, hậu giang",
    "nafng mau, vij thuyr, haaju giang"
  ],
  "Nánh Nghê, Đà Bắc, Hoà Bình": [
    "nánh nghê, đà bắc, hoà bình",
    "nasnh nghee, ddaf bawsc, hoaf bifnh"
  ],
  "Nâm Nung, Krông Nô, Đắk Nông": [
    "nâm nung, krông nô, đắk nông",
    "naam nung, kroong noo, ddawsk noong"
  ],
  "Nậm Búng, Văn Chấn, Yên Bái": [
    "nậm búng, văn chấn, yên bái",
    "naajm busng, vawn chaasn, yeen basi"
  ],
  "Nậm Hàng, Nậm Nhùn, Lai Châu": [
    "nậm hàng, nậm nhùn, lai châu",
    "naajm hafng, naajm nhufn, lai chaau"
  ],
  "Nậm Khao, Mường Tè, Lai Châu": [
    "nậm khao, mường tè, lai châu",
    "naajm khao, muwowfng tef, lai chaau"
  ],
  "Nậm Lành, Văn Chấn, Yên Bái": [
    "nậm lành, văn chấn, yên bái",
    "naajm lafnh, vawn chaasn, yeen basi"
  ],
  "Nậm Lầu, Thuận Châu, Sơn La": [
    "nậm lầu, thuận châu, sơn la",
    "naajm laafu, thuaajn chaau, sown la"
  ],
  "Nậm Nhùn, Nậm Nhùn, Lai Châu": [
    "nậm nhùn, nậm nhùn, lai châu",
    "naajm nhufn, naajm nhufn, lai chaau"
  ],
  "Pa Tần, Nậm Pồ, Điện Biên": [
    "pa tần, nậm pồ, điện biên",
    "pa taafn, naajm poof, ddieejn bieen"
  ],
  "Phan Thanh, Bảo Lạc, Cao Bằng": [
    "phan thanh, bảo lạc, cao bằng",
    "phan thanh, baro lajc, cao bawfng"
  ],
  "Phan, Dương Minh Châu, Tây Ninh": [
    "phan, dương minh châu, tây ninh",
    "phan, duwowng minh chaau, taay ninh"
  ],
  "Phi Hải, Quảng Hòa, Cao Bằng": [
    "phi hải, quảng hòa, cao bằng",
    "phi hari, quarng hofa, cao bawfng"
  ],
  "Phiêng Khoài, Yên Châu, Sơn La": [
    "phiêng khoài, yên châu, sơn la",
    "phieeng khoafi, yeen chaau, sown la"
  ],
  "Phong Châu, Phú Thọ, Phú Thọ": [
    "phong châu, phú thọ, phú thọ",
    "phong chaau, phus thoj, phus thoj"
  ],
  "Phong Hòa, Lai Vung, Đồng Tháp": [
    "phong hòa, lai vung, đồng tháp",
    "phong hofa, lai vung, ddoofng thasp"
  ],
  "Phong Quang, Vị Xuyên, Hà Giang": [
    "phong quang, vị xuyên, hà giang",
    "phong quang, vij xuyeen, haf giang"
  ],
  "Phong Thạnh, Cầu Kè, Trà Vinh": [
    "phong thạnh, cầu kè, trà vinh",
    "phong thajnh, caafu kef, traf vinh"
  ],
  "Phong Thổ, Phong Thổ, Lai Châu": [
    "phong thổ, phong thổ, lai châu",
    "phong thoor, phong thoor, lai chaau"
  ],
  "Pháo Đài, Hà Tiên, Kiên Giang": [
    "pháo đài, hà tiên, kiên giang",
    "phaso ddafi, haf tieen, kieen giang"
  ],
  "Phù Long, Cát Hải, Hải Phòng": [
    "phù long, cát hải, hải phòng",
    "phuf long, cast hari, hari phofng"
  ],
  "Phù Lương, Quế Võ, Bắc Ninh": [
    "phù lương, quế võ, bắc ninh",
    "phuf luwowng, quees vox, bawsc ninh"
  ],
  "Phù Mỹ, Phù Mỹ, Bình Định": [
    "phù mỹ, phù mỹ, bình định",
    "phuf myx, phuf myx, bifnh ddijnh"
  ],
  "Phú Cường, Sóc Sơn, Hà Nội": [
    "phú cường, sóc sơn, hà nội",
    "phus cuwowfng, sosc sown, haf nooji"
  ],
  "Phú Cần, Tiểu Cần, Trà Vinh": [
    "phú cần, tiểu cần, trà vinh",
    "phus caafn, tieeru caafn, traf vinh"
  ],
  "Phú Hòa, Lương Tài, Bắc Ninh": [
    "phú hòa, lương tài, bắc ninh",
    "phus hofa, luwowng tafi, bawsc ninh"
  ],
  "Phú Khương, Bến Tre, Bến Tre": [
    "phú khương, bến tre, bến tre",
    "phus khuwowng, beesn tre, beesn tre"
  ],
  "Phú Kim, Thạch Thất, Hà Nội": [
    "phú kim, thạch thất, hà nội",
    "phus kim, thajch thaast, haf nooji"
  ],
  "Phú Lương, Hà Đông, Hà Nội": [
    "phú lương, hà đông, hà nội",
    "phus luwowng, haf ddoong, haf nooji"
  ],
  "Phú Lộc, Hậu Lộc, Thanh Hóa": [
    "phú lộc, hậu lộc, thanh hóa",
    "phus loojc, haaju loojc, thanh hosa"
  ],
  "Phú Mỡ, Đồng Xuân, Phú Yên": [
    "phú mỡ, đồng xuân, phú yên",
    "phus mowx, ddoofng xuaan, phus yeen"
  ],
  "Phú Mỹ, Quận 7, Hồ Chí Minh": [
    "phú mỹ, quận 7, hồ chí minh",
    "phus myx, quaajn 7, hoof chis minh"
  ],
  "Phú Nghiêm, Quan Hóa, Thanh Hóa": [
    "phú nghiêm, quan hóa, thanh hóa",
    "phus nghieem, quan hosa, thanh hosa"
  ],
  "Phú Ninh, Tam Nông, Đồng Tháp": [
    "phú ninh, tam nông, đồng tháp",
    "phus ninh, tam noong, ddoofng thasp"
  ],
  "Phú Phong, Hương Khê, Hà Tĩnh": [
    "phú phong, hương khê, hà tĩnh",
    "phus phong, huwowng khee, haf tixnh"
  ],
  "Phú Thiện, Phú Thiện, Gia Lai": [
    "phú thiện, phú thiện, gia lai",
    "phus thieejn, phus thieejn, gia lai"
  ],
  "Phú Thành, Yên Thành, Nghệ An": [
    "phú thành, yên thành, nghệ an",
    "phus thafnh, yeen thafnh, ngheej an"
  ],
  "Phú Thịnh, Tam Bình, Vĩnh Long": [
    "phú thịnh, tam bình, vĩnh long",
    "phus thijnh, tam bifnh, vixnh long"
  ],
  "Phú Thịnh, Yên Bình, Yên Bái": [
    "phú thịnh, yên bình, yên bái",
    "phus thijnh, yeen bifnh, yeen basi"
  ],
  "Phú Xuyên, Phú Xuyên, Hà Nội": [
    "phú xuyên, phú xuyên, hà nội",
    "phus xuyeen, phus xuyeen, haf nooji"
  ],
  "Phú Xuân, Thọ Xuân, Thanh Hóa": [
    "phú xuân, thọ xuân, thanh hóa",
    "phus xuaan, thoj xuaan, thanh hosa"
  ],
  "Phúc Ninh, Yên Sơn, Tuyên Quang": [
    "phúc ninh, yên sơn, tuyên quang",
    "phusc ninh, yeen sown, tuyeen quang"
  ],
  "Phúc Sen, Quảng Hòa, Cao Bằng": [
    "phúc sen, quảng hòa, cao bằng",
    "phusc sen, quarng hofa, cao bawfng"
  ],
  "Phúc Thành, Vũ Thư, Thái Bình": [
    "phúc thành, vũ thư, thái bình",
    "phusc thafnh, vux thuw, thasi bifnh"
  ],
  "Phúc Thọ, Lâm Hà, Lâm Đồng": [
    "phúc thọ, lâm hà, lâm đồng",
    "phusc thoj, laam haf, laam ddoofng"
  ],
  "Phúc Thọ, Phúc Thọ, Hà Nội": [
    "phúc thọ, phúc thọ, hà nội",
    "phusc thoj, phusc thoj, haf nooji"
  ],
  "Phúc Tân, Hoàn Kiếm, Hà Nội": [
    "phúc tân, hoàn kiếm, hà nội",
    "phusc taan, hoafn kieesm, haf nooji"
  ],
  "Phương Tú, Ứng Hòa, Hà Nội": [
    "phương tú, ứng hòa, hà nội",
    "phuwowng tus, uwsng hofa, haf nooji"
  ],
  "Phước Hưng, Trà Cú, Trà Vinh": [
    "phước hưng, trà cú, trà vinh",
    "phuwowsc huwng, traf cus, traf vinh"
  ],
  "Phước Tân, Sơn Hòa, Phú Yên": [
    "phước tân, sơn hòa, phú yên",
    "phuwowsc taan, sown hofa, phus yeen"
  ],
  "Phường 1, Mỹ Tho, Tiền Giang": [
    "phường 1, mỹ tho, tiền giang",
    "phuwowfng 1, myx tho, tieefn giang"
  ],
  "Phường 1, Ngã Năm, Sóc Trăng": [
    "phường 1, ngã năm, sóc trăng",
    "phuwowfng 1, ngax nawm, sosc trawng"
  ],
  "Phường 1, Vĩnh Long, Vĩnh Long": [
    "phường 1, vĩnh long, vĩnh long",
    "phuwowfng 1, vixnh long, vixnh long"
  ],
  "Phường 2, Mỹ Tho, Tiền Giang": [
    "phường 2, mỹ tho, tiền giang",
    "phuwowfng 2, myx tho, tieefn giang"
  ],
  "Phường 2, Ngã Năm, Sóc Trăng": [
    "phường 2, ngã năm, sóc trăng",
    "phuwowfng 2, ngax nawm, sosc trawng"
  ],
  "Phường 2, Vĩnh Long, Vĩnh Long": [
    "phường 2, vĩnh long, vĩnh long",
    "phuwowfng 2, vixnh long, vixnh long"
  ],
  "Phường 3, Mỹ Tho, Tiền Giang": [
    "phường 3, mỹ tho, tiền giang",
    "phuwowfng 3, myx tho, tieefn giang"
  ],
  "Phường 3, Ngã Năm, Sóc Trăng": [
    "phường 3, ngã năm, sóc trăng",
    "phuwowfng 3, ngax nawm, sosc trawng"
  ],
  "Phường 3, Vĩnh Long, Vĩnh Long": [
    "phường 3, vĩnh long, vĩnh long",
    "phuwowfng 3, vixnh long, vixnh long"
  ],
  "Phường 4, Mỹ Tho, Tiền Giang": [
    "phường 4, mỹ tho, tiền giang",
    "phuwowfng 4, myx tho, tieefn giang"
  ],
  "Phường 4, Vĩnh Long, Vĩnh Long": [
    "phường 4, vĩnh long, vĩnh long",
    "phuwowfng 4, vixnh long, vixnh long"
  ],
  "Phường 5, Mỹ Tho, Tiền Giang": [
    "phường 5, mỹ tho, tiền giang",
    "phuwowfng 5, myx tho, tieefn giang"
  ],
  "Phường 5, Vĩnh Long, Vĩnh Long": [
    "phường 5, vĩnh long, vĩnh long",
    "phuwowfng 5, vixnh long, vixnh long"
  ],
  "Phường 6, Mỹ Tho, Tiền Giang": [
    "phường 6, mỹ tho, tiền giang",
    "phuwowfng 6, myx tho, tieefn giang"
  ],
  "Phường 7, Mỹ Tho, Tiền Giang": [
    "phường 7, mỹ tho, tiền giang",
    "phuwowfng 7, myx tho, tieefn giang"
  ],
  "Phường 8, Mỹ Tho, Tiền Giang": [
    "phường 8, mỹ tho, tiền giang",
    "phuwowfng 8, myx tho, tieefn giang"
  ],
  "Phường 8, Vĩnh Long, Vĩnh Long": [
    "phường 8, vĩnh long, vĩnh long",
    "phuwowfng 8, vixnh long, vixnh long"
  ],
  "Phường 9, Mỹ Tho, Tiền Giang": [
    "phường 9, mỹ tho, tiền giang",
    "phuwowfng 9, myx tho, tieefn giang"
  ],
  "Phường 9, Vĩnh Long, Vĩnh Long": [
    "phường 9, vĩnh long, vĩnh long",
    "phuwowfng 9, vixnh long, vixnh long"
  ],
  "Phố Cáo, Đồng Văn, Hà Giang": [
    "phố cáo, đồng văn, hà giang",
    "phoos caso, ddoofng vawn, haf giang"
  ],
  "Pác Miầu, Bảo Lâm, Cao Bằng": [
    "pác miầu, bảo lâm, cao bằng",
    "pasc miaafu, baro laam, cao bawfng"
  ],
  "Pú Trạng, Nghĩa Lộ, Yên Bái": [
    "pú trạng, nghĩa lộ, yên bái",
    "pus trajng, nghixa looj, yeen basi"
  ],
  "Pú Xi, Tuần Giáo, Điện Biên": [
    "pú xi, tuần giáo, điện biên",
    "pus xi, tuaafn giaso, ddieejn bieen"
  ],
  "Pải Lủng, Mèo Vạc, Hà Giang": [
    "pải lủng, mèo vạc, hà giang",
    "pari lurng, mefo vajc, haf giang"
  ],
  "Quang Lãng, Phú Xuyên, Hà Nội": [
    "quang lãng, phú xuyên, hà nội",
    "quang laxng, phus xuyeen, haf nooji"
  ],
  "Quang Phong, Quế Phong, Nghệ An": [
    "quang phong, quế phong, nghệ an",
    "quang phong, quees phong, ngheej an"
  ],
  "Quang Sơn, Tam Điệp, Ninh Bình": [
    "quang sơn, tam điệp, ninh bình",
    "quang sown, tam ddieejp, ninh bifnh"
  ],
  "Quang Sơn, Đô Lương, Nghệ An": [
    "quang sơn, đô lương, nghệ an",
    "quang sown, ddoo luwowng, ngheej an"
  ],
  "Quang Thiện, Kim Sơn, Ninh Bình": [
    "quang thiện, kim sơn, ninh bình",
    "quang thieejn, kim sown, ninh bifnh"
  ],
  "Quang Tiến, Thái Hoà, Nghệ An": [
    "quang tiến, thái hoà, nghệ an",
    "quang tieesn, thasi hoaf, ngheej an"
  ],
  "Quang Trung, Bình Gia, Lạng Sơn": [
    "quang trung, bình gia, lạng sơn",
    "quang trung, bifnh gia, lajng sown"
  ],
  "Quang Trung, Bỉm Sơn, Thanh Hóa": [
    "quang trung, bỉm sơn, thanh hóa",
    "quang trung, birm sown, thanh hosa"
  ],
  "Quang Trung, Hưng Yên, Hưng Yên": [
    "quang trung, hưng yên, hưng yên",
    "quang trung, huwng yeen, huwng yeen"
  ],
  "Quang Trung, Phú Xuyên, Hà Nội": [
    "quang trung, phú xuyên, hà nội",
    "quang trung, phus xuyeen, haf nooji"
  ],
  "Quang Trung, Đống Đa, Hà Nội": [
    "quang trung, đống đa, hà nội",
    "quang trung, ddoosng dda, haf nooji"
  ],
  "Quang Vinh, Biên Hòa, Đồng Nai": [
    "quang vinh, biên hòa, đồng nai",
    "quang vinh, bieen hofa, ddoofng nai"
  ],
  "Quách Phẩm, Đầm Dơi, Cà Mau": [
    "quách phẩm, đầm dơi, cà mau",
    "quasch phaarm, ddaafm dowi, caf mau"
  ],
  "Quí Quân, Yên Sơn, Tuyên Quang": [
    "quí quân, yên sơn, tuyên quang",
    "quis quaan, yeen sown, tuyeen quang"
  ],
  "Quý Quân, Hà Quảng, Cao Bằng": [
    "quý quân, hà quảng, cao bằng",
    "quys quaan, haf quarng, cao bawfng"
  ],
  "Quản Bạ, Quản Bạ, Hà Giang": [
    "quản bạ, quản bạ, hà giang",
    "quarn baj, quarn baj, haf giang"
  ],
  "Quảng Cư, Sầm Sơn, Thanh Hóa": [
    "quảng cư, sầm sơn, thanh hóa",
    "quarng cuw, saafm sown, thanh hosa"
  ],
  "Quảng La, Hạ Long, Quảng Ninh": [
    "quảng la, hạ long, quảng ninh",
    "quarng la, haj long, quarng ninh"
  ],
  "Quảng Lạc, Nho Quan, Ninh Bình": [
    "quảng lạc, nho quan, ninh bình",
    "quarng lajc, nho quan, ninh bifnh"
  ],
  "Quế Long, Quế Sơn, Quảng Nam": [
    "quế long, quế sơn, quảng nam",
    "quees long, quees sown, quarng nam"
  ],
  "Quế Lâm, Nông Sơn, Quảng Nam": [
    "quế lâm, nông sơn, quảng nam",
    "quees laam, noong sown, quarng nam"
  ],
  "Quế Minh, Quế Sơn, Quảng Nam": [
    "quế minh, quế sơn, quảng nam",
    "quees minh, quees sown, quarng nam"
  ],
  "Quế Mỹ, Quế Sơn, Quảng Nam": [
    "quế mỹ, quế sơn, quảng nam",
    "quees myx, quees sown, quarng nam"
  ],
  "Quế Phú, Quế Sơn, Quảng Nam": [
    "quế phú, quế sơn, quảng nam",
    "quees phus, quees sown, quarng nam"
  ],
  "Quới An,  Vũng Liêm, Vĩnh Long": [
    "quới an,  vũng liêm, vĩnh long",
    "quowsi an,  vuxng lieem, vixnh long"
  ],
  "Quỳ Hợp, Quỳ Hợp, Nghệ An": [
    "quỳ hợp, quỳ hợp, nghệ an",
    "quyf howjp, quyf howjp, ngheej an"
  ],
  "Quỳnh Dị, Hoàng Mai, Nghệ An": [
    "quỳnh dị, hoàng mai, nghệ an",
    "quyfnh dij, hoafng mai, ngheej an"
  ],
  "Quỳnh Phú, Gia Bình, Bắc Ninh": [
    "quỳnh phú, gia bình, bắc ninh",
    "quyfnh phus, gia bifnh, bawsc ninh"
  ],
  "Quỳnh Vinh, Hoàng Mai, Nghệ An": [
    "quỳnh vinh, hoàng mai, nghệ an",
    "quyfnh vinh, hoafng mai, ngheej an"
  ],
  "Sa Rài, Tân Hồng, Đồng Tháp": [
    "sa rài, tân hồng, đồng tháp",
    "sa rafi, taan hoofng, ddoofng thasp"
  ],
  "Sao Đỏ, Chí Linh, Hải Dương": [
    "sao đỏ, chí linh, hải dương",
    "sao ddor, chis linh, hari duwowng"
  ],
  "Song Khê, Bắc Giang, Bắc Giang": [
    "song khê, bắc giang, bắc giang",
    "song khee, bawsc giang, bawsc giang"
  ],
  "Song Lộc, Châu Thành, Trà Vinh": [
    "song lộc, châu thành, trà vinh",
    "song loojc, chaau thafnh, traf vinh"
  ],
  "Sài Đồng, Long Biên, Hà Nội": [
    "sài đồng, long biên, hà nội",
    "safi ddoofng, long bieen, haf nooji"
  ],
  "Sóc Sơn, Hòn Đất, Kiên Giang": [
    "sóc sơn, hòn đất, kiên giang",
    "sosc sown, hofn ddaast, kieen giang"
  ],
  "Sơn Bình, Hương Sơn, Hà Tĩnh": [
    "sơn bình, hương sơn, hà tĩnh",
    "sown bifnh, huwowng sown, haf tixnh"
  ],
  "Sơn Châu, Hương Sơn, Hà Tĩnh": [
    "sơn châu, hương sơn, hà tĩnh",
    "sown chaau, huwowng sown, haf tixnh"
  ],
  "Sơn Dung, Sơn Tây, Quảng Ngãi": [
    "sơn dung, sơn tây, quảng ngãi",
    "sown dung, sown taay, quarng ngaxi"
  ],
  "Sơn Giang, Hương Sơn, Hà Tĩnh": [
    "sơn giang, hương sơn, hà tĩnh",
    "sown giang, huwowng sown, haf tixnh"
  ],
  "Sơn Giang, Sơn Hà, Quảng Ngãi": [
    "sơn giang, sơn hà, quảng ngãi",
    "sown giang, sown haf, quarng ngaxi"
  ],
  "Sơn Hà, Thái Thụy, Thái Bình": [
    "sơn hà, thái thụy, thái bình",
    "sown haf, thasi thujy, thasi bifnh"
  ],
  "Sơn Hải, Bảo Thắng, Lào Cai": [
    "sơn hải, bảo thắng, lào cai",
    "sown hari, baro thawsng, lafo cai"
  ],
  "Sơn Hải, Quỳnh Lưu, Nghệ An": [
    "sơn hải, quỳnh lưu, nghệ an",
    "sown hari, quyfnh luwu, ngheej an"
  ],
  "Sơn Hải, Sơn Hà, Quảng Ngãi": [
    "sơn hải, sơn hà, quảng ngãi",
    "sown hari, sown haf, quarng ngaxi"
  ],
  "Sơn Kim 1, Hương Sơn, Hà Tĩnh": [
    "sơn kim 1, hương sơn, hà tĩnh",
    "sown kim 1, huwowng sown, haf tixnh"
  ],
  "Sơn Kim 2, Hương Sơn, Hà Tĩnh": [
    "sơn kim 2, hương sơn, hà tĩnh",
    "sown kim 2, huwowng sown, haf tixnh"
  ],
  "Sơn Long, Sơn Tây, Quảng Ngãi": [
    "sơn long, sơn tây, quảng ngãi",
    "sown long, sown taay, quarng ngaxi"
  ],
  "Sơn Lâm, Khánh Sơn, Khánh Hòa": [
    "sơn lâm, khánh sơn, khánh hòa",
    "sown laam, khasnh sown, khasnh hofa"
  ],
  "Sơn Lĩnh, Hương Sơn, Hà Tĩnh": [
    "sơn lĩnh, hương sơn, hà tĩnh",
    "sown lixnh, huwowng sown, haf tixnh"
  ],
  "Sơn Lập, Bảo Lạc, Cao Bằng": [
    "sơn lập, bảo lạc, cao bằng",
    "sown laajp, baro lajc, cao bawfng"
  ],
  "Sơn Màu, Sơn Tây, Quảng Ngãi": [
    "sơn màu, sơn tây, quảng ngãi",
    "sown mafu, sown taay, quarng ngaxi"
  ],
  "Sơn Mùa, Sơn Tây, Quảng Ngãi": [
    "sơn mùa, sơn tây, quảng ngãi",
    "sown mufa, sown taay, quarng ngaxi"
  ],
  "Sơn Mỹ, Hàm Tân, Bình Thuận": [
    "sơn mỹ, hàm tân, bình thuận",
    "sown myx, hafm taan, bifnh thuaajn"
  ],
  "Sơn Phú, Giồng Trôm, Bến Tre": [
    "sơn phú, giồng trôm, bến tre",
    "sown phus, gioofng troom, beesn tre"
  ],
  "Sơn Phước, Sơn Hòa, Phú Yên": [
    "sơn phước, sơn hòa, phú yên",
    "sown phuwowsc, sown hofa, phus yeen"
  ],
  "Sơn Thành, Yên Thành, Nghệ An": [
    "sơn thành, yên thành, nghệ an",
    "sown thafnh, yeen thafnh, ngheej an"
  ],
  "Sơn Tinh, Sơn Tây, Quảng Ngãi": [
    "sơn tinh, sơn tây, quảng ngãi",
    "sown tinh, sown taay, quarng ngaxi"
  ],
  "Sơn Trung, Hương Sơn, Hà Tĩnh": [
    "sơn trung, hương sơn, hà tĩnh",
    "sown trung, huwowng sown, haf tixnh"
  ],
  "Sơn Trung, Sơn Hà, Quảng Ngãi": [
    "sơn trung, sơn hà, quảng ngãi",
    "sown trung, sown haf, quarng ngaxi"
  ],
  "Sơn Tân, Sơn Tây, Quảng Ngãi": [
    "sơn tân, sơn tây, quảng ngãi",
    "sown taan, sown taay, quarng ngaxi"
  ],
  "Sơn Viên, Nông Sơn, Quảng Nam": [
    "sơn viên, nông sơn, quảng nam",
    "sown vieen, noong sown, quarng nam"
  ],
  "Sơn Điền, Di Linh, Lâm Đồng": [
    "sơn điền, di linh, lâm đồng",
    "sown ddieefn, di linh, laam ddoofng"
  ],
  "Sơn Điện, Quan Sơn, Thanh Hóa": [
    "sơn điện, quan sơn, thanh hóa",
    "sown ddieejn, quan sown, thanh hosa"
  ],
  "Sủng Là, Đồng Văn, Hà Giang": [
    "sủng là, đồng văn, hà giang",
    "surng laf, ddoofng vawn, haf giang"
  ],
  "Sủng Máng, Mèo Vạc, Hà Giang": [
    "sủng máng, mèo vạc, hà giang",
    "surng masng, mefo vajc, haf giang"
  ],
  "Sủng Tráng, Yên Minh, Hà Giang": [
    "sủng tráng, yên minh, hà giang",
    "surng trasng, yeen minh, haf giang"
  ],
  "Tam Giang, Núi Thành, Quảng Nam": [
    "tam giang, núi thành, quảng nam",
    "tam giang, nusi thafnh, quarng nam"
  ],
  "Tam Hiệp, Biên Hòa, Đồng Nai": [
    "tam hiệp, biên hòa, đồng nai",
    "tam hieejp, bieen hofa, ddoofng nai"
  ],
  "Tam Hiệp, Bình Đại, Bến Tre": [
    "tam hiệp, bình đại, bến tre",
    "tam hieejp, bifnh ddaji, beesn tre"
  ],
  "Tam Hiệp, Yên Thế, Bắc Giang": [
    "tam hiệp, yên thế, bắc giang",
    "tam hieejp, yeen thees, bawsc giang"
  ],
  "Tam Hải, Núi Thành, Quảng Nam": [
    "tam hải, núi thành, quảng nam",
    "tam hari, nusi thafnh, quarng nam"
  ],
  "Tam Hồng, Yên Lạc, Vĩnh Phúc": [
    "tam hồng, yên lạc, vĩnh phúc",
    "tam hoofng, yeen lajc, vixnh phusc"
  ],
  "Tam Kỳ, Kim Thành, Hải Dương": [
    "tam kỳ, kim thành, hải dương",
    "tam kyf, kim thafnh, hari duwowng"
  ],
  "Tam Quang, Núi Thành, Quảng Nam": [
    "tam quang, núi thành, quảng nam",
    "tam quang, nusi thafnh, quarng nam"
  ],
  "Tam Thanh, Lạng Sơn, Lạng Sơn": [
    "tam thanh, lạng sơn, lạng sơn",
    "tam thanh, lajng sown, lajng sown"
  ],
  "Tam Thanh, Phú Quí, Bình Thuận": [
    "tam thanh, phú quí, bình thuận",
    "tam thanh, phus quis, bifnh thuaajn"
  ],
  "Tam Thuấn, Phúc Thọ, Hà Nội": [
    "tam thuấn, phúc thọ, hà nội",
    "tam thuaasn, phusc thoj, haf nooji"
  ],
  "Tam Tiến, Yên Thế, Bắc Giang": [
    "tam tiến, yên thế, bắc giang",
    "tam tieesn, yeen thees, bawsc giang"
  ],
  "Tam Đa, Sơn Dương, Tuyên Quang": [
    "tam đa, sơn dương, tuyên quang",
    "tam dda, sown duwowng, tuyeen quang"
  ],
  "Tam Đảo, Tam Đảo, Vĩnh Phúc": [
    "tam đảo, tam đảo, vĩnh phúc",
    "tam ddaro, tam ddaro, vixnh phusc"
  ],
  "Thanh An, Thanh Chương, Nghệ An": [
    "thanh an, thanh chương, nghệ an",
    "thanh an, thanh chuwowng, ngheej an"
  ],
  "Thanh An, Vĩnh Thạnh, Cần Thơ": [
    "thanh an, vĩnh thạnh, cần thơ",
    "thanh an, vixnh thajnh, caafn thow"
  ],
  "Thanh Bình, Ninh Bình, Ninh Bình": [
    "thanh bình, ninh bình, ninh bình",
    "thanh bifnh, ninh bifnh, ninh bifnh"
  ],
  "Thanh Cao, Lương Sơn, Hoà Bình": [
    "thanh cao, lương sơn, hoà bình",
    "thanh cao, luwowng sown, hoaf bifnh"
  ],
  "Thanh Hà, Thanh Hà, Hải Dương": [
    "thanh hà, thanh hà, hải dương",
    "thanh haf, thanh haf, hari duwowng"
  ],
  "Thanh Hòa, Cai Lậy, Tiền Giang": [
    "thanh hòa, cai lậy, tiền giang",
    "thanh hofa, cai laajy, tieefn giang"
  ],
  "Thanh Hương, Thanh Liêm, Hà Nam": [
    "thanh hương, thanh liêm, hà nam",
    "thanh huwowng, thanh lieem, haf nam"
  ],
  "Thanh Hối, Tân Lạc, Hoà Bình": [
    "thanh hối, tân lạc, hoà bình",
    "thanh hoosi, taan lajc, hoaf bifnh"
  ],
  "Thanh Liệt, Thanh Trì, Hà Nội": [
    "thanh liệt, thanh trì, hà nội",
    "thanh lieejt, thanh trif, haf nooji"
  ],
  "Thanh Long, Hà Quảng, Cao Bằng": [
    "thanh long, hà quảng, cao bằng",
    "thanh long, haf quarng, cao bawfng"
  ],
  "Thanh Long, Văn Lãng, Lạng Sơn": [
    "thanh long, văn lãng, lạng sơn",
    "thanh long, vawn laxng, lajng sown"
  ],
  "Thanh Mai, Chợ Mới, Bắc Kạn": [
    "thanh mai, chợ mới, bắc kạn",
    "thanh mai, chowj mowsi, bawsc kajn"
  ],
  "Thanh Mỹ, Châu Thành, Trà Vinh": [
    "thanh mỹ, châu thành, trà vinh",
    "thanh myx, chaau thafnh, traf vinh"
  ],
  "Thanh Nguyên, Thanh Liêm, Hà Nam": [
    "thanh nguyên, thanh liêm, hà nam",
    "thanh nguyeen, thanh lieem, haf nam"
  ],
  "Thanh Nhật, Hạ Lang, Cao Bằng": [
    "thanh nhật, hạ lang, cao bằng",
    "thanh nhaajt, haj lang, cao bawfng"
  ],
  "Thanh Phong, Như Xuân, Thanh Hóa": [
    "thanh phong, như xuân, thanh hóa",
    "thanh phong, nhuw xuaan, thanh hosa"
  ],
  "Thanh Quân, Như Xuân, Thanh Hóa": [
    "thanh quân, như xuân, thanh hóa",
    "thanh quaan, nhuw xuaan, thanh hosa"
  ],
  "Thanh Sơn, Uông Bí, Quảng Ninh": [
    "thanh sơn, uông bí, quảng ninh",
    "thanh sown, uoong bis, quarng ninh"
  ],
  "Thanh Thủy, Tĩnh Gia, Thanh Hóa": [
    "thanh thủy, tĩnh gia, thanh hóa",
    "thanh thury, tixnh gia, thanh hosa"
  ],
  "Thanh Trù, Vĩnh Yên, Vĩnh Phúc": [
    "thanh trù, vĩnh yên, vĩnh phúc",
    "thanh truf, vixnh yeen, vixnh phusc"
  ],
  "Thanh Xuân, Như Xuân, Thanh Hóa": [
    "thanh xuân, như xuân, thanh hóa",
    "thanh xuaan, nhuw xuaan, thanh hosa"
  ],
  "Thanh Xá, Thanh Hà, Hải Dương": [
    "thanh xá, thanh hà, hải dương",
    "thanh xas, thanh haf, hari duwowng"
  ],
  "Thanh Đức, Long Hồ, Vĩnh Long": [
    "thanh đức, long hồ, vĩnh long",
    "thanh dduwsc, long hoof, vixnh long"
  ],
  "Thanh, Hướng Hóa, Quảng Trị": [
    "thanh, hướng hóa, quảng trị",
    "thanh, huwowsng hosa, quarng trij"
  ],
  "Thiên Phủ, Quan Hóa, Thanh Hóa": [
    "thiên phủ, quan hóa, thanh hóa",
    "thieen phur, quan hosa, thanh hosa"
  ],
  "Thuận Mỹ, Châu Thành, Long An": [
    "thuận mỹ, châu thành, long an",
    "thuaajn myx, chaau thafnh, long an"
  ],
  "Thái Bình, Hòa Bình, Hoà Bình": [
    "thái bình, hòa bình, hoà bình",
    "thasi bifnh, hofa bifnh, hoaf bifnh"
  ],
  "Thái Hòa, Hàm Yên, Tuyên Quang": [
    "thái hòa, hàm yên, tuyên quang",
    "thasi hofa, hafm yeen, tuyeen quang"
  ],
  "Thái Hưng, Hưng Hà, Thái Bình": [
    "thái hưng, hưng hà, thái bình",
    "thasi huwng, huwng haf, thasi bifnh"
  ],
  "Thái Học, Bảo Lâm, Cao Bằng": [
    "thái học, bảo lâm, cao bằng",
    "thasi hojc, baro laam, cao bawfng"
  ],
  "Thái Sơn, Hàm Yên, Tuyên Quang": [
    "thái sơn, hàm yên, tuyên quang",
    "thasi sown, hafm yeen, tuyeen quang"
  ],
  "Thái Sơn, Đô Lương, Nghệ An": [
    "thái sơn, đô lương, nghệ an",
    "thasi sown, ddoo luwowng, ngheej an"
  ],
  "Thèn Phàng, Xín Mần, Hà Giang": [
    "thèn phàng, xín mần, hà giang",
    "thefn phafng, xisn maafn, haf giang"
  ],
  "Thèn Sin, Tam Đường, Lai Châu": [
    "thèn sin, tam đường, lai châu",
    "thefn sin, tam dduwowfng, lai chaau"
  ],
  "Thường Nga, Can Lộc, Hà Tĩnh": [
    "thường nga, can lộc, hà tĩnh",
    "thuwowfng nga, can loojc, haf tixnh"
  ],
  "Thượng Hà, Bảo Yên, Lào Cai": [
    "thượng hà, bảo yên, lào cai",
    "thuwowjng haf, baro yeen, lafo cai"
  ],
  "Thạch Bàn, Long Biên, Hà Nội": [
    "thạch bàn, long biên, hà nội",
    "thajch bafn, long bieen, haf nooji"
  ],
  "Thạch Bình, Hà Tĩnh, Hà Tĩnh": [
    "thạch bình, hà tĩnh, hà tĩnh",
    "thajch bifnh, haf tixnh, haf tixnh"
  ],
  "Thạch Bình, Nho Quan, Ninh Bình": [
    "thạch bình, nho quan, ninh bình",
    "thajch bifnh, nho quan, ninh bifnh"
  ],
  "Thạch Châu, Lộc Hà, Hà Tĩnh": [
    "thạch châu, lộc hà, hà tĩnh",
    "thajch chaau, loojc haf, haf tixnh"
  ],
  "Thạch Hà, Thạch Hà, Hà Tĩnh": [
    "thạch hà, thạch hà, hà tĩnh",
    "thajch haf, thajch haf, haf tixnh"
  ],
  "Thạch Hưng, Hà Tĩnh, Hà Tĩnh": [
    "thạch hưng, hà tĩnh, hà tĩnh",
    "thajch huwng, haf tixnh, haf tixnh"
  ],
  "Thạch Sơn, Lâm Thao, Phú Thọ": [
    "thạch sơn, lâm thao, phú thọ",
    "thajch sown, laam thao, phus thoj"
  ],
  "Thạch Trung, Hà Tĩnh, Hà Tĩnh": [
    "thạch trung, hà tĩnh, hà tĩnh",
    "thajch trung, haf tixnh, haf tixnh"
  ],
  "Thạch Yên, Cao Phong, Hoà Bình": [
    "thạch yên, cao phong, hoà bình",
    "thajch yeen, cao phong, hoaf bifnh"
  ],
  "Thạnh Hóa, Thạnh Hóa, Long An": [
    "thạnh hóa, thạnh hóa, long an",
    "thajnh hosa, thajnh hosa, long an"
  ],
  "Thạnh Lợi, Bến Lức, Long An": [
    "thạnh lợi, bến lức, long an",
    "thajnh lowji, beesn luwsc, long an"
  ],
  "Thạnh Phú, Cái Nước, Cà Mau": [
    "thạnh phú, cái nước, cà mau",
    "thajnh phus, casi nuwowsc, caf mau"
  ],
  "Thạnh Phú, Thạnh Hóa, Long An": [
    "thạnh phú, thạnh hóa, long an",
    "thajnh phus, thajnh hosa, long an"
  ],
  "Thạnh Tây, Tân Biên, Tây Ninh": [
    "thạnh tây, tân biên, tây ninh",
    "thajnh taay, taan bieen, taay ninh"
  ],
  "Thẩm Dương, Văn Bàn, Lào Cai": [
    "thẩm dương, văn bàn, lào cai",
    "thaarm duwowng, vawn bafn, lafo cai"
  ],
  "Thị Cầu, Bắc Ninh, Bắc Ninh": [
    "thị cầu, bắc ninh, bắc ninh",
    "thij caafu, bawsc ninh, bawsc ninh"
  ],
  "Thịnh Lộc, Lộc Hà, Hà Tĩnh": [
    "thịnh lộc, lộc hà, hà tĩnh",
    "thijnh loojc, loojc haf, haf tixnh"
  ],
  "Thọ An, Đan Phượng, Hà Nội": [
    "thọ an, đan phượng, hà nội",
    "thoj an, ddan phuwowjng, haf nooji"
  ],
  "Thọ Hợp, Quỳ Hợp, Nghệ An": [
    "thọ hợp, quỳ hợp, nghệ an",
    "thoj howjp, quyf howjp, ngheej an"
  ],
  "Thọ Lâm, Thọ Xuân, Thanh Hóa": [
    "thọ lâm, thọ xuân, thanh hóa",
    "thoj laam, thoj xuaan, thanh hosa"
  ],
  "Thọ Lộc, Phúc Thọ, Hà Nội": [
    "thọ lộc, phúc thọ, hà nội",
    "thoj loojc, phusc thoj, haf nooji"
  ],
  "Thọ Quang, Sơn Trà, Đà Nẵng": [
    "thọ quang, sơn trà, đà nẵng",
    "thoj quang, sown traf, ddaf nawxng"
  ],
  "Thọ Sơn, Việt Trì, Phú Thọ": [
    "thọ sơn, việt trì, phú thọ",
    "thoj sown, vieejt trif, phus thoj"
  ],
  "Thọ Vinh, Kim Động, Hưng Yên": [
    "thọ vinh, kim động, hưng yên",
    "thoj vinh, kim ddoojng, huwng yeen"
  ],
  "Thọ Điền, Vũ Quang, Hà Tĩnh": [
    "thọ điền, vũ quang, hà tĩnh",
    "thoj ddieefn, vux quang, haf tixnh"
  ],
  "Thới Bình, Thới Bình, Cà Mau": [
    "thới bình, thới bình, cà mau",
    "thowsi bifnh, thowsi bifnh, caf mau"
  ],
  "Thới Lai, Bình Đại, Bến Tre": [
    "thới lai, bình đại, bến tre",
    "thowsi lai, bifnh ddaji, beesn tre"
  ],
  "Thới Sơn, Mỹ Tho, Tiền Giang": [
    "thới sơn, mỹ tho, tiền giang",
    "thowsi sown, myx tho, tieefn giang"
  ],
  "Thới Sơn, Tịnh Biên, An Giang": [
    "thới sơn, tịnh biên, an giang",
    "thowsi sown, tijnh bieen, an giang"
  ],
  "Thới Tân, Thới Lai, Cần Thơ": [
    "thới tân, thới lai, cần thơ",
    "thowsi taan, thowsi lai, caafn thow"
  ],
  "Thụy Hòa, Yên Phong, Bắc Ninh": [
    "thụy hòa, yên phong, bắc ninh",
    "thujy hofa, yeen phong, bawsc ninh"
  ],
  "Thụy Lôi, Tiên Lữ, Hưng Yên": [
    "thụy lôi, tiên lữ, hưng yên",
    "thujy looi, tieen luwx, huwng yeen"
  ],
  "Thủ Thừa, Thủ Thừa, Long An": [
    "thủ thừa, thủ thừa, long an",
    "thur thuwfa, thur thuwfa, long an"
  ],
  "Tinh Nhuệ, Thanh Sơn, Phú Thọ": [
    "tinh nhuệ, thanh sơn, phú thọ",
    "tinh nhueej, thanh sown, phus thoj"
  ],
  "Tiên Cát, Việt Trì, Phú Thọ": [
    "tiên cát, việt trì, phú thọ",
    "tieen cast, vieejt trif, phus thoj"
  ],
  "Tiên Dược, Sóc Sơn, Hà Nội": [
    "tiên dược, sóc sơn, hà nội",
    "tieen duwowjc, sosc sown, haf nooji"
  ],
  "Tiên Hải, Hà Tiên, Kiên Giang": [
    "tiên hải, hà tiên, kiên giang",
    "tieen hari, haf tieen, kieen giang"
  ],
  "Tiên Long, Châu Thành, Bến Tre": [
    "tiên long, châu thành, bến tre",
    "tieen long, chaau thafnh, beesn tre"
  ],
  "Tiêu Sơn, Đoan Hùng, Phú Thọ": [
    "tiêu sơn, đoan hùng, phú thọ",
    "tieeu sown, ddoan hufng, phus thoj"
  ],
  "Tiêu Động, Bình Lục, Hà Nam": [
    "tiêu động, bình lục, hà nam",
    "tieeu ddoojng, bifnh lujc, haf nam"
  ],
  "Tiến Thắng, Mê Linh, Hà Nội": [
    "tiến thắng, mê linh, hà nội",
    "tieesn thawsng, mee linh, haf nooji"
  ],
  "Tiến Thịnh, Mê Linh, Hà Nội": [
    "tiến thịnh, mê linh, hà nội",
    "tieesn thijnh, mee linh, haf nooji"
  ],
  "Tri Hải, Ninh Hải, Ninh Thuận": [
    "tri hải, ninh hải, ninh thuận",
    "tri hari, ninh hari, ninh thuaajn"
  ],
  "Tri Phú, Chiêm Hóa, Tuyên Quang": [
    "tri phú, chiêm hóa, tuyên quang",
    "tri phus, chieem hosa, tuyeen quang"
  ],
  "Trinh Phú, Kế Sách, Sóc Trăng": [
    "trinh phú, kế sách, sóc trăng",
    "trinh phus, kees sasch, sosc trawng"
  ],
  "Trung Dũng, Tiên Lữ, Hưng Yên": [
    "trung dũng, tiên lữ, hưng yên",
    "trung duxng, tieen luwx, huwng yeen"
  ],
  "Trung Hoà, Cầu Giấy, Hà Nội": [
    "trung hoà, cầu giấy, hà nội",
    "trung hoaf, caafu giaasy, haf nooji"
  ],
  "Trung Hoà, Ngân Sơn, Bắc Kạn": [
    "trung hoà, ngân sơn, bắc kạn",
    "trung hoaf, ngaan sown, bawsc kajn"
  ],
  "Trung Hưng, Cờ Đỏ, Cần Thơ": [
    "trung hưng, cờ đỏ, cần thơ",
    "trung huwng, cowf ddor, caafn thow"
  ],
  "Trung Lương, Bình Lục, Hà Nam": [
    "trung lương, bình lục, hà nam",
    "trung luwowng, bifnh lujc, haf nam"
  ],
  "Trung Minh, Yên Sơn, Tuyên Quang": [
    "trung minh, yên sơn, tuyên quang",
    "trung minh, yeen sown, tuyeen quang"
  ],
  "Trung Môn, Yên Sơn, Tuyên Quang": [
    "trung môn, yên sơn, tuyên quang",
    "trung moon, yeen sown, tuyeen quang"
  ],
  "Trung Sơn, Gio Linh, Quảng Trị": [
    "trung sơn, gio linh, quảng trị",
    "trung sown, gio linh, quarng trij"
  ],
  "Trung Sơn, Tam Điệp, Ninh Bình": [
    "trung sơn, tam điệp, ninh bình",
    "trung sown, tam ddieejp, ninh bifnh"
  ],
  "Trung Sơn, Yên Sơn, Tuyên Quang": [
    "trung sơn, yên sơn, tuyên quang",
    "trung sown, yeen sown, tuyeen quang"
  ],
  "Trung Sơn, Đô Lương, Nghệ An": [
    "trung sơn, đô lương, nghệ an",
    "trung sown, ddoo luwowng, ngheej an"
  ],
  "Trung Thành, Quan Hóa, Thanh Hóa": [
    "trung thành, quan hóa, thanh hóa",
    "trung thafnh, quan hosa, thanh hosa"
  ],
  "Trung Tiến, Quan Sơn, Thanh Hóa": [
    "trung tiến, quan sơn, thanh hóa",
    "trung tieesn, quan sown, thanh hosa"
  ],
  "Trà Cang, Nam Trà My, Quảng Nam": [
    "trà cang, nam trà my, quảng nam",
    "traf cang, nam traf my, quarng nam"
  ],
  "Trà Cổ, Móng Cái, Quảng Ninh": [
    "trà cổ, móng cái, quảng ninh",
    "traf coor, mosng casi, quarng ninh"
  ],
  "Trà Dơn, Nam Trà My, Quảng Nam": [
    "trà dơn, nam trà my, quảng nam",
    "traf down, nam traf my, quarng nam"
  ],
  "Trà Ka, Bắc Trà My, Quảng Nam": [
    "trà ka, bắc trà my, quảng nam",
    "traf ka, bawsc traf my, quarng nam"
  ],
  "Trà Leng, Nam Trà My, Quảng Nam": [
    "trà leng, nam trà my, quảng nam",
    "traf leng, nam traf my, quarng nam"
  ],
  "Trà Linh, Nam Trà My, Quảng Nam": [
    "trà linh, nam trà my, quảng nam",
    "traf linh, nam traf my, quarng nam"
  ],
  "Trà Lồng, Long Mỹ, Hậu Giang": [
    "trà lồng, long mỹ, hậu giang",
    "traf loofng, long myx, haaju giang"
  ],
  "Trà My, Bắc Trà My, Quảng Nam": [
    "trà my, bắc trà my, quảng nam",
    "traf my, bawsc traf my, quarng nam"
  ],
  "Trà Nóc, Bình Thuỷ, Cần Thơ": [
    "trà nóc, bình thuỷ, cần thơ",
    "traf nosc, bifnh thuyr, caafn thow"
  ],
  "Trà Vinh, Nam Trà My, Quảng Nam": [
    "trà vinh, nam trà my, quảng nam",
    "traf vinh, nam traf my, quarng nam"
  ],
  "Trà Vân, Nam Trà My, Quảng Nam": [
    "trà vân, nam trà my, quảng nam",
    "traf vaan, nam traf my, quarng nam"
  ],
  "Tràng Các, Văn Quan, Lạng Sơn": [
    "tràng các, văn quan, lạng sơn",
    "trafng casc, vawn quan, lajng sown"
  ],
  "Tràng Cát, Hải An, Hải Phòng": [
    "tràng cát, hải an, hải phòng",
    "trafng cast, hari an, hari phofng"
  ],
  "Tràng Xá, Võ Nhai, Thái Nguyên": [
    "tràng xá, võ nhai, thái nguyên",
    "trafng xas, vox nhai, thasi nguyeen"
  ],
  "Trì Quang, Bảo Thắng, Lào Cai": [
    "trì quang, bảo thắng, lào cai",
    "trif quang, baro thawsng, lafo cai"
  ],
  "Trí Bình, Châu Thành, Tây Ninh": [
    "trí bình, châu thành, tây ninh",
    "tris bifnh, chaau thafnh, taay ninh"
  ],
  "Trường Yên, Hoa Lư, Ninh Bình": [
    "trường yên, hoa lư, ninh bình",
    "truwowfng yeen, hoa luw, ninh bifnh"
  ],
  "Trại Cau, Lê Chân, Hải Phòng": [
    "trại cau, lê chân, hải phòng",
    "traji cau, lee chaan, hari phofng"
  ],
  "Trấn Ninh, Văn Quan, Lạng Sơn": [
    "trấn ninh, văn quan, lạng sơn",
    "traasn ninh, vawn quan, lajng sown"
  ],
  "Trị Quận, Phù Ninh, Phú Thọ": [
    "trị quận, phù ninh, phú thọ",
    "trij quaajn, phuf ninh, phus thoj"
  ],
  "Trọng Con, Thạch An, Cao Bằng": [
    "trọng con, thạch an, cao bằng",
    "trojng con, thajch an, cao bawfng"
  ],
  "Tu Mơ Rông, Tu Mơ Rông, Kon Tum": [
    "tu mơ rông, tu mơ rông, kon tum",
    "tu mow roong, tu mow roong, kon tum"
  ],
  "Tu Tra, Đơn Dương, Lâm Đồng": [
    "tu tra, đơn dương, lâm đồng",
    "tu tra, ddown duwowng, laam ddoofng"
  ],
  "Tà Long, Đa Krông, Quảng Trị": [
    "tà long, đa krông, quảng trị",
    "taf long, dda kroong, quarng trij"
  ],
  "Tà Lùng, Quảng Hòa, Cao Bằng": [
    "tà lùng, quảng hòa, cao bằng",
    "taf lufng, quarng hofa, cao bawfng"
  ],
  "Tà Tổng, Mường Tè, Lai Châu": [
    "tà tổng, mường tè, lai châu",
    "taf toorng, muwowfng tef, lai chaau"
  ],
  "Tào Xuyên, Thanh Hóa, Thanh Hóa": [
    "tào xuyên, thanh hóa, thanh hóa",
    "tafo xuyeen, thanh hosa, thanh hosa"
  ],
  "Tái Sơn, Tứ Kỳ, Hải Dương": [
    "tái sơn, tứ kỳ, hải dương",
    "tasi sown, tuws kyf, hari duwowng"
  ],
  "Tân An, Quảng Yên, Quảng Ninh": [
    "tân an, quảng yên, quảng ninh",
    "taan an, quarng yeen, quarng ninh"
  ],
  "Tân Biên, Biên Hòa, Đồng Nai": [
    "tân biên, biên hòa, đồng nai",
    "taan bieen, bieen hofa, ddoofng nai"
  ],
  "Tân Bình, Cai Lậy, Tiền Giang": [
    "tân bình, cai lậy, tiền giang",
    "taan bifnh, cai laajy, tieefn giang"
  ],
  "Tân Bình, Tam Điệp, Ninh Bình": [
    "tân bình, tam điệp, ninh bình",
    "taan bifnh, tam ddieejp, ninh bifnh"
  ],
  "Tân Dân, Chí Linh, Hải Dương": [
    "tân dân, chí linh, hải dương",
    "taan daan, chis linh, hari duwowng"
  ],
  "Tân Dân, Khoái Châu, Hưng Yên": [
    "tân dân, khoái châu, hưng yên",
    "taan daan, khoasi chaau, huwng yeen"
  ],
  "Tân Dân, Kinh Môn, Hải Dương": [
    "tân dân, kinh môn, hải dương",
    "taan daan, kinh moon, hari duwowng"
  ],
  "Tân Hoa, Lục Ngạn, Bắc Giang": [
    "tân hoa, lục ngạn, bắc giang",
    "taan hoa, lujc ngajn, bawsc giang"
  ],
  "Tân Hoà, Tân Hiệp, Kiên Giang": [
    "tân hoà, tân hiệp, kiên giang",
    "taan hoaf, taan hieejp, kieen giang"
  ],
  "Tân Hào, Giồng Trôm, Bến Tre": [
    "tân hào, giồng trôm, bến tre",
    "taan hafo, gioofng troom, beesn tre"
  ],
  "Tân Hóa, Minh Hóa, Quảng Bình": [
    "tân hóa, minh hóa, quảng bình",
    "taan hosa, minh hosa, quarng bifnh"
  ],
  "Tân Hùng, Tiểu Cần, Trà Vinh": [
    "tân hùng, tiểu cần, trà vinh",
    "taan hufng, tieeru caafn, traf vinh"
  ],
  "Tân Hưng Tây, Phú Tân, Cà Mau": [
    "tân hưng tây, phú tân, cà mau",
    "taan huwng taay, phus taan, caf mau"
  ],
  "Tân Hương, Yên Bình, Yên Bái": [
    "tân hương, yên bình, yên bái",
    "taan huwowng, yeen bifnh, yeen basi"
  ],
  "Tân Hội, Cai Lậy, Tiền Giang": [
    "tân hội, cai lậy, tiền giang",
    "taan hooji, cai laajy, tieefn giang"
  ],
  "Tân Kim, Phú Bình, Thái Nguyên": [
    "tân kim, phú bình, thái nguyên",
    "taan kim, phus bifnh, thasi nguyeen"
  ],
  "Tân Kỳ, Tứ Kỳ, Hải Dương": [
    "tân kỳ, tứ kỳ, hải dương",
    "taan kyf, tuws kyf, hari duwowng"
  ],
  "Tân Lập, Bắc Sơn, Lạng Sơn": [
    "tân lập, bắc sơn, lạng sơn",
    "taan laajp, bawsc sown, lajng sown"
  ],
  "Tân Minh, Hàm Tân, Bình Thuận": [
    "tân minh, hàm tân, bình thuận",
    "taan minh, hafm taan, bifnh thuaajn"
  ],
  "Tân Mỹ, Bắc Giang, Bắc Giang": [
    "tân mỹ, bắc giang, bắc giang",
    "taan myx, bawsc giang, bawsc giang"
  ],
  "Tân Mỹ, Lấp Vò, Đồng Tháp": [
    "tân mỹ, lấp vò, đồng tháp",
    "taan myx, laasp vof, ddoofng thasp"
  ],
  "Tân Nguyên, Yên Bình, Yên Bái": [
    "tân nguyên, yên bình, yên bái",
    "taan nguyeen, yeen bifnh, yeen basi"
  ],
  "Tân Phong, Biên Hòa, Đồng Nai": [
    "tân phong, biên hòa, đồng nai",
    "taan phong, bieen hofa, ddoofng nai"
  ],
  "Tân Phong, Cai Lậy, Tiền Giang": [
    "tân phong, cai lậy, tiền giang",
    "taan phong, cai laajy, tieefn giang"
  ],
  "Tân Phong, Thạnh Phú, Bến Tre": [
    "tân phong, thạnh phú, bến tre",
    "taan phong, thajnh phus, beesn tre"
  ],
  "Tân Phú, Quận 7, Hồ Chí Minh": [
    "tân phú, quận 7, hồ chí minh",
    "taan phus, quaajn 7, hoof chis minh"
  ],
  "Tân Phú, Quận 9, Hồ Chí Minh": [
    "tân phú, quận 9, hồ chí minh",
    "taan phus, quaajn 9, hoof chis minh"
  ],
  "Tân Phúc, Lang Chánh, Thanh Hóa": [
    "tân phúc, lang chánh, thanh hóa",
    "taan phusc, lang chasnh, thanh hosa"
  ],
  "Tân Phước, La Gi, Bình Thuận": [
    "tân phước, la gi, bình thuận",
    "taan phuwowsc, la gi, bifnh thuaajn"
  ],
  "Tân Quới, Bình Tân, Vĩnh Long": [
    "tân quới, bình tân, vĩnh long",
    "taan quowsi, bifnh taan, vixnh long"
  ],
  "Tân Sơn, Chợ Mới, Bắc Kạn": [
    "tân sơn, chợ mới, bắc kạn",
    "taan sown, chowj mowsi, bawsc kajn"
  ],
  "Tân Sỏi, Yên Thế, Bắc Giang": [
    "tân sỏi, yên thế, bắc giang",
    "taan sori, yeen thees, bawsc giang"
  ],
  "Tân Thanh, Văn Lãng, Lạng Sơn": [
    "tân thanh, văn lãng, lạng sơn",
    "taan thanh, vawn laxng, lajng sown"
  ],
  "Tân Thành, Bình Tân, Vĩnh Long": [
    "tân thành, bình tân, vĩnh long",
    "taan thafnh, bifnh taan, vixnh long"
  ],
  "Tân Thành, Bắc Quang, Hà Giang": [
    "tân thành, bắc quang, hà giang",
    "taan thafnh, bawsc quang, haf giang"
  ],
  "Tân Thành, Cao Lộc, Lạng Sơn": [
    "tân thành, cao lộc, lạng sơn",
    "taan thafnh, cao loojc, lajng sown"
  ],
  "Tân Thành, Ninh Bình, Ninh Bình": [
    "tân thành, ninh bình, ninh bình",
    "taan thafnh, ninh bifnh, ninh bifnh"
  ],
  "Tân Thành, Yên Thành, Nghệ An": [
    "tân thành, yên thành, nghệ an",
    "taan thafnh, yeen thafnh, ngheej an"
  ],
  "Tân Thượng, Văn Bàn, Lào Cai": [
    "tân thượng, văn bàn, lào cai",
    "taan thuwowjng, vawn bafn, lafo cai"
  ],
  "Tân Thạnh, Giá Rai, Bạc Liêu": [
    "tân thạnh, giá rai, bạc liêu",
    "taan thajnh, gias rai, bajc lieeu"
  ],
  "Tân Thạnh, Tam Kỳ, Quảng Nam": [
    "tân thạnh, tam kỳ, quảng nam",
    "taan thajnh, tam kyf, quarng nam"
  ],
  "Tân Thạnh, Tân Thạnh, Long An": [
    "tân thạnh, tân thạnh, long an",
    "taan thajnh, taan thajnh, long an"
  ],
  "Tân Tiến, Hưng Hà, Thái Bình": [
    "tân tiến, hưng hà, thái bình",
    "taan tieesn, huwng haf, thasi bifnh"
  ],
  "Tân Tiến, Văn Giang, Hưng Yên": [
    "tân tiến, văn giang, hưng yên",
    "taan tieesn, vawn giang, huwng yeen"
  ],
  "Tân Triều, Thanh Trì, Hà Nội": [
    "tân triều, thanh trì, hà nội",
    "taan trieefu, thanh trif, haf nooji"
  ],
  "Tân Trung, Gò Công, Tiền Giang": [
    "tân trung, gò công, tiền giang",
    "taan trung, gof coong, tieefn giang"
  ],
  "Tân Vinh, Lương Sơn, Hoà Bình": [
    "tân vinh, lương sơn, hoà bình",
    "taan vinh, luwowng sown, hoaf bifnh"
  ],
  "Tân Vạn, Biên Hòa, Đồng Nai": [
    "tân vạn, biên hòa, đồng nai",
    "taan vajn, bieen hofa, ddoofng nai"
  ],
  "Tân Xã, Thạch Thất, Hà Nội": [
    "tân xã, thạch thất, hà nội",
    "taan xax, thajch thaast, haf nooji"
  ],
  "Tân Đoàn, Văn Quan, Lạng Sơn": [
    "tân đoàn, văn quan, lạng sơn",
    "taan ddoafn, vawn quan, lajng sown"
  ],
  "Tây Cốc, Đoan Hùng, Phú Thọ": [
    "tây cốc, đoan hùng, phú thọ",
    "taay coosc, ddoan hufng, phus thoj"
  ],
  "Tây Hoà, Trảng Bom, Đồng Nai": [
    "tây hoà, trảng bom, đồng nai",
    "taay hoaf, trarng bom, ddoofng nai"
  ],
  "Tây Phú, Tây Sơn, Bình Định": [
    "tây phú, tây sơn, bình định",
    "taay phus, taay sown, bifnh ddijnh"
  ],
  "Tây Thành, Yên Thành, Nghệ An": [
    "tây thành, yên thành, nghệ an",
    "taay thafnh, yeen thafnh, ngheej an"
  ],
  "Tây Vinh, Tây Sơn, Bình Định": [
    "tây vinh, tây sơn, bình định",
    "taay vinh, taay sown, bifnh ddijnh"
  ],
  "Tích Giang, Phúc Thọ, Hà Nội": [
    "tích giang, phúc thọ, hà nội",
    "tisch giang, phusc thoj, haf nooji"
  ],
  "Tích Sơn, Vĩnh Yên, Vĩnh Phúc": [
    "tích sơn, vĩnh yên, vĩnh phúc",
    "tisch sown, vixnh yeen, vixnh phusc"
  ],
  "Tích Thiện, Trà Ôn, Vĩnh Long": [
    "tích thiện, trà ôn, vĩnh long",
    "tisch thieejn, traf oon, vixnh long"
  ],
  "Tòng Đậu, Mai Châu, Hoà Bình": [
    "tòng đậu, mai châu, hoà bình",
    "tofng ddaaju, mai chaau, hoaf bifnh"
  ],
  "Tô Hạp, Khánh Sơn, Khánh Hòa": [
    "tô hạp, khánh sơn, khánh hòa",
    "too hajp, khasnh sown, khasnh hofa"
  ],
  "Túc Đán, Trạm Tấu, Yên Bái": [
    "túc đán, trạm tấu, yên bái",
    "tusc ddasn, trajm taasu, yeen basi"
  ],
  "Tường Tiến, Phù Yên, Sơn La": [
    "tường tiến, phù yên, sơn la",
    "tuwowfng tieesn, phuf yeen, sown la"
  ],
  "Tượng Lĩnh, Kim Bảng, Hà Nam": [
    "tượng lĩnh, kim bảng, hà nam",
    "tuwowjng lixnh, kim barng, haf nam"
  ],
  "Tả Củ Tỷ, Bắc Hà, Lào Cai": [
    "tả củ tỷ, bắc hà, lào cai",
    "tar cur tyr, bawsc haf, lafo cai"
  ],
  "Tả Phìn, Đồng Văn, Hà Giang": [
    "tả phìn, đồng văn, hà giang",
    "tar phifn, ddoofng vawn, haf giang"
  ],
  "Tống Trân, Phù Cừ, Hưng Yên": [
    "tống trân, phù cừ, hưng yên",
    "toosng traan, phuf cuwf, huwng yeen"
  ],
  "Tứ Dân, Khoái Châu, Hưng Yên": [
    "tứ dân, khoái châu, hưng yên",
    "tuws daan, khoasi chaau, huwng yeen"
  ],
  "Tứ Kỳ, Tứ Kỳ, Hải Dương": [
    "tứ kỳ, tứ kỳ, hải dương",
    "tuws kyf, tuws kyf, hari duwowng"
  ],
  "Tử Du, Lập Thạch, Vĩnh Phúc": [
    "tử du, lập thạch, vĩnh phúc",
    "tuwr du, laajp thajch, vixnh phusc"
  ],
  "Viên An, Trần Đề, Sóc Trăng": [
    "viên an, trần đề, sóc trăng",
    "vieen an, traafn ddeef, sosc trawng"
  ],
  "Việt Hùng, Quế Võ, Bắc Ninh": [
    "việt hùng, quế võ, bắc ninh",
    "vieejt hufng, quees vox, bawsc ninh"
  ],
  "Việt Hùng, Vũ Thư, Thái Bình": [
    "việt hùng, vũ thư, thái bình",
    "vieejt hufng, vux thuw, thasi bifnh"
  ],
  "Việt Hùng, Đông Anh, Hà Nội": [
    "việt hùng, đông anh, hà nội",
    "vieejt hufng, ddoong anh, haf nooji"
  ],
  "Việt Hưng, Long Biên, Hà Nội": [
    "việt hưng, long biên, hà nội",
    "vieejt huwng, long bieen, haf nooji"
  ],
  "Việt Hưng, Văn Lâm, Hưng Yên": [
    "việt hưng, văn lâm, hưng yên",
    "vieejt huwng, vawn laam, huwng yeen"
  ],
  "Việt Lâm, Vị Xuyên, Hà Giang": [
    "việt lâm, vị xuyên, hà giang",
    "vieejt laam, vij xuyeen, haf giang"
  ],
  "Việt Tiến, Bảo Yên, Lào Cai": [
    "việt tiến, bảo yên, lào cai",
    "vieejt tieesn, baro yeen, lafo cai"
  ],
  "Việt Vinh, Bắc Quang, Hà Giang": [
    "việt vinh, bắc quang, hà giang",
    "vieejt vinh, bawsc quang, haf giang"
  ],
  "Việt Đoàn, Tiên Du, Bắc Ninh": [
    "việt đoàn, tiên du, bắc ninh",
    "vieejt ddoafn, tieen du, bawsc ninh"
  ],
  "Vàng Danh, Uông Bí, Quảng Ninh": [
    "vàng danh, uông bí, quảng ninh",
    "vafng danh, uoong bis, quarng ninh"
  ],
  "Vân Canh, Vân Canh, Bình Định": [
    "vân canh, vân canh, bình định",
    "vaan canh, vaan canh, bifnh ddijnh"
  ],
  "Vân Du, Thạch Thành, Thanh Hóa": [
    "vân du, thạch thành, thanh hóa",
    "vaan du, thajch thafnh, thanh hosa"
  ],
  "Vân Nham, Hữu Lũng, Lạng Sơn": [
    "vân nham, hữu lũng, lạng sơn",
    "vaan nham, huwxu luxng, lajng sown"
  ],
  "Vân Thủy, Chi Lăng, Lạng Sơn": [
    "vân thủy, chi lăng, lạng sơn",
    "vaan thury, chi lawng, lajng sown"
  ],
  "Vân Trình, Thạch An, Cao Bằng": [
    "vân trình, thạch an, cao bằng",
    "vaan trifnh, thajch an, cao bawfng"
  ],
  "Vân Tùng, Ngân Sơn, Bắc Kạn": [
    "vân tùng, ngân sơn, bắc kạn",
    "vaan tufng, ngaan sown, bawsc kajn"
  ],
  "Vô Điếm, Bắc Quang, Hà Giang": [
    "vô điếm, bắc quang, hà giang",
    "voo ddieesm, bawsc quang, haf giang"
  ],
  "Văn Hoàng, Phú Xuyên, Hà Nội": [
    "văn hoàng, phú xuyên, hà nội",
    "vawn hoafng, phus xuyeen, haf nooji"
  ],
  "Văn Miếu, Thanh Sơn, Phú Thọ": [
    "văn miếu, thanh sơn, phú thọ",
    "vawn mieesu, thanh sown, phus thoj"
  ],
  "Văn Miếu, Đống Đa, Hà Nội": [
    "văn miếu, đống đa, hà nội",
    "vawn mieesu, ddoosng dda, haf nooji"
  ],
  "Văn Nghĩa, Lạc Sơn, Hoà Bình": [
    "văn nghĩa, lạc sơn, hoà bình",
    "vawn nghixa, lajc sown, hoaf bifnh"
  ],
  "Văn Phương, Nho Quan, Ninh Bình": [
    "văn phương, nho quan, ninh bình",
    "vawn phuwowng, nho quan, ninh bifnh"
  ],
  "Văn Sơn, Triệu Sơn, Thanh Hóa": [
    "văn sơn, triệu sơn, thanh hóa",
    "vawn sown, trieeju sown, thanh hosa"
  ],
  "Văn Thành, Yên Thành, Nghệ An": [
    "văn thành, yên thành, nghệ an",
    "vawn thafnh, yeen thafnh, ngheej an"
  ],
  "Văn Tố, Tứ Kỳ, Hải Dương": [
    "văn tố, tứ kỳ, hải dương",
    "vawn toos, tuws kyf, hari duwowng"
  ],
  "Văn Điển, Thanh Trì, Hà Nội": [
    "văn điển, thanh trì, hà nội",
    "vawn ddieern, thanh trif, haf nooji"
  ],
  "Vĩnh An, Sơn Động, Bắc Giang": [
    "vĩnh an, sơn động, bắc giang",
    "vixnh an, sown ddoojng, bawsc giang"
  ],
  "Vĩnh An, Vĩnh Bảo, Hải Phòng": [
    "vĩnh an, vĩnh bảo, hải phòng",
    "vixnh an, vixnh baro, hari phofng"
  ],
  "Vĩnh Bình, Châu Thành, An Giang": [
    "vĩnh bình, châu thành, an giang",
    "vixnh bifnh, chaau thafnh, an giang"
  ],
  "Vĩnh Bình, Chợ Lách, Bến Tre": [
    "vĩnh bình, chợ lách, bến tre",
    "vixnh bifnh, chowj lasch, beesn tre"
  ],
  "Vĩnh Châu, Châu Đốc, An Giang": [
    "vĩnh châu, châu đốc, an giang",
    "vixnh chaau, chaau ddoosc, an giang"
  ],
  "Vĩnh Hào, Vụ Bản, Nam Định": [
    "vĩnh hào, vụ bản, nam định",
    "vixnh hafo, vuj barn, nam ddijnh"
  ],
  "Vĩnh Hòa, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh hòa, vĩnh lộc, thanh hóa",
    "vixnh hofa, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Hải, Nha Trang, Khánh Hòa": [
    "vĩnh hải, nha trang, khánh hòa",
    "vixnh hari, nha trang, khasnh hofa"
  ],
  "Vĩnh Hảo, Bắc Quang, Hà Giang": [
    "vĩnh hảo, bắc quang, hà giang",
    "vixnh haro, bawsc quang, haf giang"
  ],
  "Vĩnh Khúc, Văn Giang, Hưng Yên": [
    "vĩnh khúc, văn giang, hưng yên",
    "vixnh khusc, vawn giang, huwng yeen"
  ],
  "Vĩnh Long, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh long, vĩnh lộc, thanh hóa",
    "vixnh long, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Lợi, Châu Thành, An Giang": [
    "vĩnh lợi, châu thành, an giang",
    "vixnh lowji, chaau thafnh, an giang"
  ],
  "Vĩnh Ngọc, Đông Anh, Hà Nội": [
    "vĩnh ngọc, đông anh, hà nội",
    "vixnh ngojc, ddoong anh, haf nooji"
  ],
  "Vĩnh Phong, Bảo Lâm, Cao Bằng": [
    "vĩnh phong, bảo lâm, cao bằng",
    "vixnh phong, baro laam, cao bawfng"
  ],
  "Vĩnh Phúc, Bắc Quang, Hà Giang": [
    "vĩnh phúc, bắc quang, hà giang",
    "vixnh phusc, bawsc quang, haf giang"
  ],
  "Vĩnh Quang, Bảo Lâm, Cao Bằng": [
    "vĩnh quang, bảo lâm, cao bằng",
    "vixnh quang, baro laam, cao bawfng"
  ],
  "Vĩnh Quang, Cao Bằng, Cao Bằng": [
    "vĩnh quang, cao bằng, cao bằng",
    "vixnh quang, cao bawfng, cao bawfng"
  ],
  "Vĩnh Thuận, Vĩnh Hưng, Long An": [
    "vĩnh thuận, vĩnh hưng, long an",
    "vixnh thuaajn, vixnh huwng, long an"
  ],
  "Vĩnh Thái, Nha Trang, Khánh Hòa": [
    "vĩnh thái, nha trang, khánh hòa",
    "vixnh thasi, nha trang, khasnh hofa"
  ],
  "Vĩnh Thọ, Nha Trang, Khánh Hòa": [
    "vĩnh thọ, nha trang, khánh hòa",
    "vixnh thoj, nha trang, khasnh hofa"
  ],
  "Vĩnh Trung, Nha Trang, Khánh Hòa": [
    "vĩnh trung, nha trang, khánh hòa",
    "vixnh trung, nha trang, khasnh hofa"
  ],
  "Vĩnh Trung, Tịnh Biên, An Giang": [
    "vĩnh trung, tịnh biên, an giang",
    "vixnh trung, tijnh bieen, an giang"
  ],
  "Vĩnh Xương, Tân Châu, An Giang": [
    "vĩnh xương, tân châu, an giang",
    "vixnh xuwowng, taan chaau, an giang"
  ],
  "Vĩnh Yên, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh yên, vĩnh lộc, thanh hóa",
    "vixnh yeen, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Ô, Vĩnh Linh, Quảng Trị": [
    "vĩnh ô, vĩnh linh, quảng trị",
    "vixnh oo, vixnh linh, quarng trij"
  ],
  "Vĩnh Đồng, Kim Bôi, Hoà Bình": [
    "vĩnh đồng, kim bôi, hoà bình",
    "vixnh ddoofng, kim booi, hoaf bifnh"
  ],
  "Vũ An, Kiến Xương, Thái Bình": [
    "vũ an, kiến xương, thái bình",
    "vux an, kieesn xuwowng, thasi bifnh"
  ],
  "Vũ Chấn, Võ Nhai, Thái Nguyên": [
    "vũ chấn, võ nhai, thái nguyên",
    "vux chaasn, vox nhai, thasi nguyeen"
  ],
  "Vũ Di, Vĩnh Tường, Vĩnh Phúc": [
    "vũ di, vĩnh tường, vĩnh phúc",
    "vux di, vixnh tuwowfng, vixnh phusc"
  ],
  "Vũ Lạc, Thái Bình, Thái Bình": [
    "vũ lạc, thái bình, thái bình",
    "vux lajc, thasi bifnh, thasi bifnh"
  ],
  "Vũ Minh, Nguyên Bình, Cao Bằng": [
    "vũ minh, nguyên bình, cao bằng",
    "vux minh, nguyeen bifnh, cao bawfng"
  ],
  "Vũ Phúc, Thái Bình, Thái Bình": [
    "vũ phúc, thái bình, thái bình",
    "vux phusc, thasi bifnh, thasi bifnh"
  ],
  "Vạn Giã, Vạn Ninh, Khánh Hòa": [
    "vạn giã, vạn ninh, khánh hòa",
    "vajn giax, vajn ninh, khasnh hofa"
  ],
  "Vạn Long, Vạn Ninh, Khánh Hòa": [
    "vạn long, vạn ninh, khánh hòa",
    "vajn long, vajn ninh, khasnh hofa"
  ],
  "Vạn Phú, Vạn Ninh, Khánh Hòa": [
    "vạn phú, vạn ninh, khánh hòa",
    "vajn phus, vajn ninh, khasnh hofa"
  ],
  "Vị Xuyên, Vị Xuyên, Hà Giang": [
    "vị xuyên, vị xuyên, hà giang",
    "vij xuyeen, vij xuyeen, haf giang"
  ],
  "Vọng Thê, Thoại Sơn, An Giang": [
    "vọng thê, thoại sơn, an giang",
    "vojng thee, thoaji sown, an giang"
  ],
  "Vụ Quang, Đoan Hùng, Phú Thọ": [
    "vụ quang, đoan hùng, phú thọ",
    "vuj quang, ddoan hufng, phus thoj"
  ],
  "Xuân Bái, Thọ Xuân, Thanh Hóa": [
    "xuân bái, thọ xuân, thanh hóa",
    "xuaan basi, thoj xuaan, thanh hosa"
  ],
  "Xuân Bình, Như Xuân, Thanh Hóa": [
    "xuân bình, như xuân, thanh hóa",
    "xuaan bifnh, nhuw xuaan, thanh hosa"
  ],
  "Xuân Bình, Sông Cầu, Phú Yên": [
    "xuân bình, sông cầu, phú yên",
    "xuaan bifnh, soong caafu, phus yeen"
  ],
  "Xuân Dương, Thanh Oai, Hà Nội": [
    "xuân dương, thanh oai, hà nội",
    "xuaan duwowng, thanh oai, haf nooji"
  ],
  "Xuân Giang, Quang Bình, Hà Giang": [
    "xuân giang, quang bình, hà giang",
    "xuaan giang, quang bifnh, haf giang"
  ],
  "Xuân Giao, Bảo Thắng, Lào Cai": [
    "xuân giao, bảo thắng, lào cai",
    "xuaan giao, baro thawsng, lafo cai"
  ],
  "Xuân Hoà, Phúc Yên, Vĩnh Phúc": [
    "xuân hoà, phúc yên, vĩnh phúc",
    "xuaan hoaf, phusc yeen, vixnh phusc"
  ],
  "Xuân Hòa, Hà Quảng, Cao Bằng": [
    "xuân hòa, hà quảng, cao bằng",
    "xuaan hofa, haf quarng, cao bawfng"
  ],
  "Xuân Hòa, Kế Sách, Sóc Trăng": [
    "xuân hòa, kế sách, sóc trăng",
    "xuaan hofa, kees sasch, sosc trawng"
  ],
  "Xuân Hòa, Thọ Xuân, Thanh Hóa": [
    "xuân hòa, thọ xuân, thanh hóa",
    "xuaan hofa, thoj xuaan, thanh hosa"
  ],
  "Xuân Hải, Sông Cầu, Phú Yên": [
    "xuân hải, sông cầu, phú yên",
    "xuaan hari, soong caafu, phus yeen"
  ],
  "Xuân Hồng, Nghi Xuân, Hà Tĩnh": [
    "xuân hồng, nghi xuân, hà tĩnh",
    "xuaan hoofng, nghi xuaan, haf tixnh"
  ],
  "Xuân Khang, Như Thanh, Thanh Hóa": [
    "xuân khang, như thanh, thanh hóa",
    "xuaan khang, nhuw thanh, thanh hosa"
  ],
  "Xuân Lam, Hưng Nguyên, Nghệ An": [
    "xuân lam, hưng nguyên, nghệ an",
    "xuaan lam, huwng nguyeen, ngheej an"
  ],
  "Xuân Lộc, Sông Cầu, Phú Yên": [
    "xuân lộc, sông cầu, phú yên",
    "xuaan loojc, soong caafu, phus yeen"
  ],
  "Xuân Mai, Chương Mỹ, Hà Nội": [
    "xuân mai, chương mỹ, hà nội",
    "xuaan mai, chuwowng myx, haf nooji"
  ],
  "Xuân Minh, Thọ Xuân, Thanh Hóa": [
    "xuân minh, thọ xuân, thanh hóa",
    "xuaan minh, thoj xuaan, thanh hosa"
  ],
  "Xuân Mỹ, Cẩm Mỹ, Đồng Nai": [
    "xuân mỹ, cẩm mỹ, đồng nai",
    "xuaan myx, caarm myx, ddoofng nai"
  ],
  "Xuân Phú, Thọ Xuân, Thanh Hóa": [
    "xuân phú, thọ xuân, thanh hóa",
    "xuaan phus, thoj xuaan, thanh hosa"
  ],
  "Xuân Phú, Yên Dũng, Bắc Giang": [
    "xuân phú, yên dũng, bắc giang",
    "xuaan phus, yeen duxng, bawsc giang"
  ],
  "Xuân Phúc, Như Thanh, Thanh Hóa": [
    "xuân phúc, như thanh, thanh hóa",
    "xuaan phusc, nhuw thanh, thanh hosa"
  ],
  "Xuân Sinh, Thọ Xuân, Thanh Hóa": [
    "xuân sinh, thọ xuân, thanh hóa",
    "xuaan sinh, thoj xuaan, thanh hosa"
  ],
  "Xuân Sơn, Vạn Ninh, Khánh Hòa": [
    "xuân sơn, vạn ninh, khánh hòa",
    "xuaan sown, vajn ninh, khasnh hofa"
  ],
  "Xuân Sơn, Đô Lương, Nghệ An": [
    "xuân sơn, đô lương, nghệ an",
    "xuaan sown, ddoo luwowng, ngheej an"
  ],
  "Xuân Thành, Nghi Xuân, Hà Tĩnh": [
    "xuân thành, nghi xuân, hà tĩnh",
    "xuaan thafnh, nghi xuaan, haf tixnh"
  ],
  "Xuân Thái, Như Thanh, Thanh Hóa": [
    "xuân thái, như thanh, thanh hóa",
    "xuaan thasi, nhuw thanh, thanh hosa"
  ],
  "Xuân Tây, Cẩm Mỹ, Đồng Nai": [
    "xuân tây, cẩm mỹ, đồng nai",
    "xuaan taay, caarm myx, ddoofng nai"
  ],
  "Xuân Tín, Thọ Xuân, Thanh Hóa": [
    "xuân tín, thọ xuân, thanh hóa",
    "xuaan tisn, thoj xuaan, thanh hosa"
  ],
  "Xuân Viên, Yên Lập, Phú Thọ": [
    "xuân viên, yên lập, phú thọ",
    "xuaan vieen, yeen laajp, phus thoj"
  ],
  "Xuân Vân, Yên Sơn, Tuyên Quang": [
    "xuân vân, yên sơn, tuyên quang",
    "xuaan vaan, yeen sown, tuyeen quang"
  ],
  "Xuân Đài, Sông Cầu, Phú Yên": [
    "xuân đài, sông cầu, phú yên",
    "xuaan ddafi, soong caafu, phus yeen"
  ],
  "Xuất Hóa, Lạc Sơn, Hoà Bình": [
    "xuất hóa, lạc sơn, hoà bình",
    "xuaast hosa, lajc sown, hoaf bifnh"
  ],
  "Xuất Lễ, Cao Lộc, Lạng Sơn": [
    "xuất lễ, cao lộc, lạng sơn",
    "xuaast leex, cao loojc, lajng sown"
  ],
  "Xín Chải, Vị Xuyên, Hà Giang": [
    "xín chải, vị xuyên, hà giang",
    "xisn chari, vij xuyeen, haf giang"
  ],
  "Yên Bình, Tam Điệp, Ninh Bình": [
    "yên bình, tam điệp, ninh bình",
    "yeen bifnh, tam ddieejp, ninh bifnh"
  ],
  "Yên Cường, Bắc Mê, Hà Giang": [
    "yên cường, bắc mê, hà giang",
    "yeen cuwowfng, bawsc mee, haf giang"
  ],
  "Yên Cường, Ý Yên, Nam Định": [
    "yên cường, ý yên, nam định",
    "yeen cuwowfng, ys yeen, nam ddijnh"
  ],
  "Yên Dương, Hà Trung, Thanh Hóa": [
    "yên dương, hà trung, thanh hóa",
    "yeen duwowng, haf trung, thanh hosa"
  ],
  "Yên Hân, Chợ Mới, Bắc Kạn": [
    "yên hân, chợ mới, bắc kạn",
    "yeen haan, chowj mowsi, bawsc kajn"
  ],
  "Yên Hóa, Minh Hóa, Quảng Bình": [
    "yên hóa, minh hóa, quảng bình",
    "yeen hosa, minh hosa, quarng bifnh"
  ],
  "Yên Lâm, Yên Định, Thanh Hóa": [
    "yên lâm, yên định, thanh hóa",
    "yeen laam, yeen ddijnh, thanh hosa"
  ],
  "Yên Lạc, Yên Lạc, Vĩnh Phúc": [
    "yên lạc, yên lạc, vĩnh phúc",
    "yeen lajc, yeen lajc, vixnh phusc"
  ],
  "Yên Mỹ, Nông Cống, Thanh Hóa": [
    "yên mỹ, nông cống, thanh hóa",
    "yeen myx, noong coosng, thanh hosa"
  ],
  "Yên Na, Tương Dương, Nghệ An": [
    "yên na, tương dương, nghệ an",
    "yeen na, tuwowng duwowng, ngheej an"
  ],
  "Yên Ninh, Yên Định, Thanh Hóa": [
    "yên ninh, yên định, thanh hóa",
    "yeen ninh, yeen ddijnh, thanh hosa"
  ],
  "Yên Phú, Yên Định, Thanh Hóa": [
    "yên phú, yên định, thanh hóa",
    "yeen phus, yeen ddijnh, thanh hosa"
  ],
  "Yên Phương, Ý Yên, Nam Định": [
    "yên phương, ý yên, nam định",
    "yeen phuwowng, ys yeen, nam ddijnh"
  ],
  "Yên Sơn, Hữu Lũng, Lạng Sơn": [
    "yên sơn, hữu lũng, lạng sơn",
    "yeen sown, huwxu luxng, lajng sown"
  ],
  "Yên Than, Tiên Yên, Quảng Ninh": [
    "yên than, tiên yên, quảng ninh",
    "yeen than, tieen yeen, quarng ninh"
  ],
  "Yên Thanh, Uông Bí, Quảng Ninh": [
    "yên thanh, uông bí, quảng ninh",
    "yeen thanh, uoong bis, quarng ninh"
  ],
  "Yên Thành, Quang Bình, Hà Giang": [
    "yên thành, quang bình, hà giang",
    "yeen thafnh, quang bifnh, haf giang"
  ],
  "Yên Thành, Yên Thành, Nghệ An": [
    "yên thành, yên thành, nghệ an",
    "yeen thafnh, yeen thafnh, ngheej an"
  ],
  "Yên Thường, Gia Lâm, Hà Nội": [
    "yên thường, gia lâm, hà nội",
    "yeen thuwowfng, gia laam, haf nooji"
  ],
  "Yên Thắng, Lục Yên, Yên Bái": [
    "yên thắng, lục yên, yên bái",
    "yeen thawsng, lujc yeen, yeen basi"
  ],
  "Yên Trị, Yên Thủy, Hoà Bình": [
    "yên trị, yên thủy, hoà bình",
    "yeen trij, yeen thury, hoaf bifnh"
  ],
  "Yên Tâm, Yên Định, Thanh Hóa": [
    "yên tâm, yên định, thanh hóa",
    "yeen taam, yeen ddijnh, thanh hosa"
  ],
  "Yến Dương, Ba Bể, Bắc Kạn": [
    "yến dương, ba bể, bắc kạn",
    "yeesn duwowng, ba beer, bawsc kajn"
  ],
  "Ân Hữu, Hoài Ân, Bình Định": [
    "ân hữu, hoài ân, bình định",
    "aan huwxu, hoafi aan, bifnh ddijnh"
  ],
  "Ân Phong, Hoài Ân, Bình Định": [
    "ân phong, hoài ân, bình định",
    "aan phong, hoafi aan, bifnh ddijnh"
  ],
  "Úc Kỳ, Phú Bình, Thái Nguyên": [
    "úc kỳ, phú bình, thái nguyên",
    "usc kyf, phus bifnh, thasi nguyeen"
  ],
  "Đa Kai, Đức Linh, Bình Thuận": [
    "đa kai, đức linh, bình thuận",
    "dda kai, dduwsc linh, bifnh thuaajn"
  ],
  "Đa Lộc, Đồng Xuân, Phú Yên": [
    "đa lộc, đồng xuân, phú yên",
    "dda loojc, ddoofng xuaan, phus yeen"
  ],
  "Đa Thông, Hà Quảng, Cao Bằng": [
    "đa thông, hà quảng, cao bằng",
    "dda thoong, haf quarng, cao bawfng"
  ],
  "Điện Biên, Ba Đình, Hà Nội": [
    "điện biên, ba đình, hà nội",
    "ddieejn bieen, ba ddifnh, haf nooji"
  ],
  "Đoan Hùng, Hưng Hà, Thái Bình": [
    "đoan hùng, hưng hà, thái bình",
    "ddoan hufng, huwng haf, thasi bifnh"
  ],
  "Đoàn Đào, Phù Cừ, Hưng Yên": [
    "đoàn đào, phù cừ, hưng yên",
    "ddoafn ddafo, phuf cuwf, huwng yeen"
  ],
  "Đoọc Mạy, Kỳ Sơn, Nghệ An": [
    "đoọc mạy, kỳ sơn, nghệ an",
    "ddoojc majy, kyf sown, ngheej an"
  ],
  "Đào Xá, Thanh Thuỷ, Phú Thọ": [
    "đào xá, thanh thuỷ, phú thọ",
    "ddafo xas, thanh thuyr, phus thoj"
  ],
  "Đáp Cầu, Bắc Ninh, Bắc Ninh": [
    "đáp cầu, bắc ninh, bắc ninh",
    "ddasp caafu, bawsc ninh, bawsc ninh"
  ],
  "Đô Thành, Yên Thành, Nghệ An": [
    "đô thành, yên thành, nghệ an",
    "ddoo thafnh, yeen thafnh, ngheej an"
  ],
  "Đôn Nhân, Sông Lô, Vĩnh Phúc": [
    "đôn nhân, sông lô, vĩnh phúc",
    "ddoon nhaan, soong loo, vixnh phusc"
  ],
  "Đôn Phục, Con Cuông, Nghệ An": [
    "đôn phục, con cuông, nghệ an",
    "ddoon phujc, con cuoong, ngheej an"
  ],
  "Đông Cuông, Văn Yên, Yên Bái": [
    "đông cuông, văn yên, yên bái",
    "ddoong cuoong, vawn yeen, yeen basi"
  ],
  "Đông Cứu, Gia Bình, Bắc Ninh": [
    "đông cứu, gia bình, bắc ninh",
    "ddoong cuwsu, gia bifnh, bawsc ninh"
  ],
  "Đông Hưng, Cái Nước, Cà Mau": [
    "đông hưng, cái nước, cà mau",
    "ddoong huwng, casi nuwowsc, caf mau"
  ],
  "Đông Hồ, Hà Tiên, Kiên Giang": [
    "đông hồ, hà tiên, kiên giang",
    "ddoong hoof, haf tieen, kieen giang"
  ],
  "Đông Hội, Đông Anh, Hà Nội": [
    "đông hội, đông anh, hà nội",
    "ddoong hooji, ddoong anh, haf nooji"
  ],
  "Đông Khê, Thạch An, Cao Bằng": [
    "đông khê, thạch an, cao bằng",
    "ddoong khee, thajch an, cao bawfng"
  ],
  "Đông Nam, Đông Sơn, Thanh Hóa": [
    "đông nam, đông sơn, thanh hóa",
    "ddoong nam, ddoong sown, thanh hosa"
  ],
  "Đông Ngàn, Từ Sơn, Bắc Ninh": [
    "đông ngàn, từ sơn, bắc ninh",
    "ddoong ngafn, tuwf sown, bawsc ninh"
  ],
  "Đông Phú, Lục Nam, Bắc Giang": [
    "đông phú, lục nam, bắc giang",
    "ddoong phus, lujc nam, bawsc giang"
  ],
  "Đông Sơn, Bỉm Sơn, Thanh Hóa": [
    "đông sơn, bỉm sơn, thanh hóa",
    "ddoong sown, birm sown, thanh hosa"
  ],
  "Đông Sơn, Thanh Hóa, Thanh Hóa": [
    "đông sơn, thanh hóa, thanh hóa",
    "ddoong sown, thanh hosa, thanh hosa"
  ],
  "Đông Thành, Thanh Ba, Phú Thọ": [
    "đông thành, thanh ba, phú thọ",
    "ddoong thafnh, thanh ba, phus thoj"
  ],
  "Đông Thái, An Biên, Kiên Giang": [
    "đông thái, an biên, kiên giang",
    "ddoong thasi, an bieen, kieen giang"
  ],
  "Đông Tân, Thanh Hóa, Thanh Hóa": [
    "đông tân, thanh hóa, thanh hóa",
    "ddoong taan, thanh hosa, thanh hosa"
  ],
  "Đông Vinh, Thanh Hóa, Thanh Hóa": [
    "đông vinh, thanh hóa, thanh hóa",
    "ddoong vinh, thanh hosa, thanh hosa"
  ],
  "Đông Vệ, Thanh Hóa, Thanh Hóa": [
    "đông vệ, thanh hóa, thanh hóa",
    "ddoong veej, thanh hosa, thanh hosa"
  ],
  "Đông Xuân, Quốc Oai, Hà Nội": [
    "đông xuân, quốc oai, hà nội",
    "ddoong xuaan, quoosc oai, haf nooji"
  ],
  "Đông Đô, Hưng Hà, Thái Bình": [
    "đông đô, hưng hà, thái bình",
    "ddoong ddoo, huwng haf, thasi bifnh"
  ],
  "Đăk Tơ Pang, Kông Chro, Gia Lai": [
    "đăk tơ pang, kông chro, gia lai",
    "ddawk tow pang, koong chro, gia lai"
  ],
  "Đường Âm, Bắc Mê, Hà Giang": [
    "đường âm, bắc mê, hà giang",
    "dduwowfng aam, bawsc mee, haf giang"
  ],
  "Đại Cương, Kim Bảng, Hà Nam": [
    "đại cương, kim bảng, hà nam",
    "ddaji cuwowng, kim barng, haf nam"
  ],
  "Đại Hóa, Tân Yên, Bắc Giang": [
    "đại hóa, tân yên, bắc giang",
    "ddaji hosa, taan yeen, bawsc giang"
  ],
  "Đại Hùng, Ứng Hòa, Hà Nội": [
    "đại hùng, ứng hòa, hà nội",
    "ddaji hufng, uwsng hofa, haf nooji"
  ],
  "Đại Phúc, Càng Long, Trà Vinh": [
    "đại phúc, càng long, trà vinh",
    "ddaji phusc, cafng long, traf vinh"
  ],
  "Đại Thịnh, Mê Linh, Hà Nội": [
    "đại thịnh, mê linh, hà nội",
    "ddaji thijnh, mee linh, haf nooji"
  ],
  "Đại Xuân, Quế Võ, Bắc Ninh": [
    "đại xuân, quế võ, bắc ninh",
    "ddaji xuaan, quees vox, bawsc ninh"
  ],
  "Đất Mũi, Ngọc Hiển, Cà Mau": [
    "đất mũi, ngọc hiển, cà mau",
    "ddaast muxi, ngojc hieern, caf mau"
  ],
  "Đắc Tôi, Nam Giang, Quảng Nam": [
    "đắc tôi, nam giang, quảng nam",
    "ddawsc tooi, nam giang, quarng nam"
  ],
  "Đắk Choong, Đắk Glei, Kon Tum": [
    "đắk choong, đắk glei, kon tum",
    "ddawsk choong, ddawsk glei, kon tum"
  ],
  "Đắk Dục, Ngọc Hồi, Kon Tum": [
    "đắk dục, ngọc hồi, kon tum",
    "ddawsk dujc, ngojc hoofi, kon tum"
  ],
  "Đắk KRoong, Đắk Glei, Kon Tum": [
    "đắk kroong, đắk glei, kon tum",
    "ddawsk kroong, ddawsk glei, kon tum"
  ],
  "Đắk Nhoong, Đắk Glei, Kon Tum": [
    "đắk nhoong, đắk glei, kon tum",
    "ddawsk nhoong, ddawsk glei, kon tum"
  ],
  "Đắk Nông, Ngọc Hồi, Kon Tum": [
    "đắk nông, ngọc hồi, kon tum",
    "ddawsk noong, ngojc hoofi, kon tum"
  ],
  "Đắk Rơ Nga, Đắk Tô, Kon Tum": [
    "đắk rơ nga, đắk tô, kon tum",
    "ddawsk row nga, ddawsk too, kon tum"
  ],
  "Đắk Tơ Lung, Kon Rẫy, Kon Tum": [
    "đắk tơ lung, kon rẫy, kon tum",
    "ddawsk tow lung, kon raaxy, kon tum"
  ],
  "Đề Thám, Cao Bằng, Cao Bằng": [
    "đề thám, cao bằng, cao bằng",
    "ddeef thasm, cao bawfng, cao bawfng"
  ],
  "Định Cư, Lạc Sơn, Hoà Bình": [
    "định cư, lạc sơn, hoà bình",
    "ddijnh cuw, lajc sown, hoaf bifnh"
  ],
  "Định Hòa, Gò Quao, Kiên Giang": [
    "định hòa, gò quao, kiên giang",
    "ddijnh hofa, gof quao, kieen giang"
  ],
  "Đốc Tín, Mỹ Đức, Hà Nội": [
    "đốc tín, mỹ đức, hà nội",
    "ddoosc tisn, myx dduwsc, haf nooji"
  ],
  "Đồi 61, Trảng Bom, Đồng Nai": [
    "đồi 61, trảng bom, đồng nai",
    "ddoofi 61, trarng bom, ddoofng nai"
  ],
  "Đồi Ngô, Lục Nam, Bắc Giang": [
    "đồi ngô, lục nam, bắc giang",
    "ddoofi ngoo, lujc nam, bawsc giang"
  ],
  "Đồng Kỵ, Từ Sơn, Bắc Ninh": [
    "đồng kỵ, từ sơn, bắc ninh",
    "ddoofng kyj, tuwf sown, bawsc ninh"
  ],
  "Đồng Loan, Hạ Lang, Cao Bằng": [
    "đồng loan, hạ lang, cao bằng",
    "ddoofng loan, haj lang, cao bawfng"
  ],
  "Đồng Lộc, Can Lộc, Hà Tĩnh": [
    "đồng lộc, can lộc, hà tĩnh",
    "ddoofng loojc, can loojc, haf tixnh"
  ],
  "Đồng Phong, Nho Quan, Ninh Bình": [
    "đồng phong, nho quan, ninh bình",
    "ddoofng phong, nho quan, ninh bifnh"
  ],
  "Đồng Phú, Long Hồ, Vĩnh Long": [
    "đồng phú, long hồ, vĩnh long",
    "ddoofng phus, long hoof, vixnh long"
  ],
  "Đồng Phúc, Ba Bể, Bắc Kạn": [
    "đồng phúc, ba bể, bắc kạn",
    "ddoofng phusc, ba beer, bawsc kajn"
  ],
  "Đồng Sơn, Tân Sơn, Phú Thọ": [
    "đồng sơn, tân sơn, phú thọ",
    "ddoofng sown, taan sown, phus thoj"
  ],
  "Đồng Than, Yên Mỹ, Hưng Yên": [
    "đồng than, yên mỹ, hưng yên",
    "ddoofng than, yeen myx, huwng yeen"
  ],
  "Đồng Tuyển, Lào Cai, Lào Cai": [
    "đồng tuyển, lào cai, lào cai",
    "ddoofng tuyeern, lafo cai, lafo cai"
  ],
  "Đồng Tân, Mai Châu, Hoà Bình": [
    "đồng tân, mai châu, hoà bình",
    "ddoofng taan, mai chaau, hoaf bifnh"
  ],
  "Đồng Tân, Ứng Hòa, Hà Nội": [
    "đồng tân, ứng hòa, hà nội",
    "ddoofng taan, uwsng hofa, haf nooji"
  ],
  "Đồng Xuân, Thanh Ba, Phú Thọ": [
    "đồng xuân, thanh ba, phú thọ",
    "ddoofng xuaan, thanh ba, phus thoj"
  ],
  "Đồng ý, Bắc Sơn, Lạng Sơn": [
    "đồng ý, bắc sơn, lạng sơn",
    "ddoofng ys, bawsc sown, lajng sown"
  ],
  "Đỗ Động, Thanh Oai, Hà Nội": [
    "đỗ động, thanh oai, hà nội",
    "ddoox ddoojng, thanh oai, haf nooji"
  ],
  "Đội Bình, Ứng Hòa, Hà Nội": [
    "đội bình, ứng hòa, hà nội",
    "ddooji bifnh, uwsng hofa, haf nooji"
  ],
  "Động Quan, Lục Yên, Yên Bái": [
    "động quan, lục yên, yên bái",
    "ddoojng quan, lujc yeen, yeen basi"
  ],
  "Đức Bác, Sông Lô, Vĩnh Phúc": [
    "đức bác, sông lô, vĩnh phúc",
    "dduwsc basc, soong loo, vixnh phusc"
  ],
  "Đức Bồng, Vũ Quang, Hà Tĩnh": [
    "đức bồng, vũ quang, hà tĩnh",
    "dduwsc boofng, vux quang, haf tixnh"
  ],
  "Đức Giang, Long Biên, Hà Nội": [
    "đức giang, long biên, hà nội",
    "dduwsc giang, long bieen, haf nooji"
  ],
  "Đức Long, Thạch An, Cao Bằng": [
    "đức long, thạch an, cao bằng",
    "dduwsc long, thajch an, cao bawfng"
  ],
  "Đức Quang, Hạ Lang, Cao Bằng": [
    "đức quang, hạ lang, cao bằng",
    "dduwsc quang, haj lang, cao bawfng"
  ],
  "An Bình, Thuận Thành, Bắc Ninh": [
    "an bình, thuận thành, bắc ninh",
    "an bifnh, thuaajn thafnh, bawsc ninh"
  ],
  "An Cầu, Quỳnh Phụ, Thái Bình": [
    "an cầu, quỳnh phụ, thái bình",
    "an caafu, quyfnh phuj, thasi bifnh"
  ],
  "An Cựu, Huế, Thừa Thiên Huế": [
    "an cựu, huế, thừa thiên huế",
    "an cuwju, huees, thuwfa thieen huees"
  ],
  "An Dương, An Dương, Hải Phòng": [
    "an dương, an dương, hải phòng",
    "an duwowng, an duwowng, hari phofng"
  ],
  "An Dục, Quỳnh Phụ, Thái Bình": [
    "an dục, quỳnh phụ, thái bình",
    "an dujc, quyfnh phuj, thasi bifnh"
  ],
  "An Hiệp, Châu Thành, Sóc Trăng": [
    "an hiệp, châu thành, sóc trăng",
    "an hieejp, chaau thafnh, sosc trawng"
  ],
  "An Khang, Tuyên Quang, Tuyên Quang": [
    "an khang, tuyên quang, tuyên quang",
    "an khang, tuyeen quang, tuyeen quang"
  ],
  "An Lư, Thuỷ Nguyên, Hải Phòng": [
    "an lư, thuỷ nguyên, hải phòng",
    "an luw, thuyr nguyeen, hari phofng"
  ],
  "An Lộc, Bình Long, Bình Phước": [
    "an lộc, bình long, bình phước",
    "an loojc, bifnh long, bifnh phuwowsc"
  ],
  "An Lục Long, Châu Thành, Long An": [
    "an lục long, châu thành, long an",
    "an lujc long, chaau thafnh, long an"
  ],
  "An Nghiệp, Ninh Kiều, Cần Thơ": [
    "an nghiệp, ninh kiều, cần thơ",
    "an nghieejp, ninh kieefu, caafn thow"
  ],
  "An Ninh Đông, Đức Hòa, Long An": [
    "an ninh đông, đức hòa, long an",
    "an ninh ddoong, dduwsc hofa, long an"
  ],
  "An Ninh, Quảng Ninh, Quảng Bình": [
    "an ninh, quảng ninh, quảng bình",
    "an ninh, quarng ninh, quarng bifnh"
  ],
  "An Phong, Thanh Bình, Đồng Tháp": [
    "an phong, thanh bình, đồng tháp",
    "an phong, thanh bifnh, ddoofng thasp"
  ],
  "An Phước, Châu Thành, Bến Tre": [
    "an phước, châu thành, bến tre",
    "an phuwowsc, chaau thafnh, beesn tre"
  ],
  "An Thanh, Quỳnh Phụ, Thái Bình": [
    "an thanh, quỳnh phụ, thái bình",
    "an thanh, quyfnh phuj, thasi bifnh"
  ],
  "An Thái, Quỳnh Phụ, Thái Bình": [
    "an thái, quỳnh phụ, thái bình",
    "an thasi, quyfnh phuj, thasi bifnh"
  ],
  "An Thạnh, Mỏ Cày Nam, Bến Tre": [
    "an thạnh, mỏ cày nam, bến tre",
    "an thajnh, mor cafy nam, beesn tre"
  ],
  "An Thịnh, Lương Tài, Bắc Ninh": [
    "an thịnh, lương tài, bắc ninh",
    "an thijnh, luwowng tafi, bawsc ninh"
  ],
  "An Định, Mỏ Cày Nam, Bến Tre": [
    "an định, mỏ cày nam, bến tre",
    "an ddijnh, mor cafy nam, beesn tre"
  ],
  "An Đồng, An Dương, Hải Phòng": [
    "an đồng, an dương, hải phòng",
    "an ddoofng, an duwowng, hari phofng"
  ],
  "An Đức, Ninh Giang, Hải Dương": [
    "an đức, ninh giang, hải dương",
    "an dduwsc, ninh giang, hari duwowng"
  ],
  "Biển Bạch, Thới Bình, Cà Mau": [
    "biển bạch, thới bình, cà mau",
    "bieern bajch, thowsi bifnh, caf mau"
  ],
  "Bàu Cạn, Long Thành, Đồng Nai": [
    "bàu cạn, long thành, đồng nai",
    "bafu cajn, long thafnh, ddoofng nai"
  ],
  "Bàu Trâm, Long Khánh, Đồng Nai": [
    "bàu trâm, long khánh, đồng nai",
    "bafu traam, long khasnh, ddoofng nai"
  ],
  "Bách Thuận, Vũ Thư, Thái Bình": [
    "bách thuận, vũ thư, thái bình",
    "basch thuaajn, vux thuw, thasi bifnh"
  ],
  "Bãi Thơm, Phú Quốc, Kiên Giang": [
    "bãi thơm, phú quốc, kiên giang",
    "baxi thowm, phus quoosc, kieen giang"
  ],
  "Bình An, Bắc Bình, Bình Thuận": [
    "bình an, bắc bình, bình thuận",
    "bifnh an, bawsc bifnh, bifnh thuaajn"
  ],
  "Bình An, Kiên Lương, Kiên Giang": [
    "bình an, kiên lương, kiên giang",
    "bifnh an, kieen luwowng, kieen giang"
  ],
  "Bình Chuẩn, Con Cuông, Nghệ An": [
    "bình chuẩn, con cuông, nghệ an",
    "bifnh chuaarn, con cuoong, ngheej an"
  ],
  "Bình Dương, Gia Bình, Bắc Ninh": [
    "bình dương, gia bình, bắc ninh",
    "bifnh duwowng, gia bifnh, bawsc ninh"
  ],
  "Bình Hoà, Giồng Trôm, Bến Tre": [
    "bình hoà, giồng trôm, bến tre",
    "bifnh hoaf, gioofng troom, beesn tre"
  ],
  "Bình Hòa Tây, Mộc Hóa, Long An": [
    "bình hòa tây, mộc hóa, long an",
    "bifnh hofa taay, moojc hosa, long an"
  ],
  "Bình Hòa, Giao Thủy, Nam Định": [
    "bình hòa, giao thủy, nam định",
    "bifnh hofa, giao thury, nam ddijnh"
  ],
  "Bình Hòa, Tây Sơn, Bình Định": [
    "bình hòa, tây sơn, bình định",
    "bifnh hofa, taay sown, bifnh ddijnh"
  ],
  "Bình Hòa, Vĩnh Cửu, Đồng Nai": [
    "bình hòa, vĩnh cửu, đồng nai",
    "bifnh hofa, vixnh cuwru, ddoofng nai"
  ],
  "Bình Minh, Khoái Châu, Hưng Yên": [
    "bình minh, khoái châu, hưng yên",
    "bifnh minh, khoasi chaau, huwng yeen"
  ],
  "Bình Minh, Trảng Bom, Đồng Nai": [
    "bình minh, trảng bom, đồng nai",
    "bifnh minh, trarng bom, ddoofng nai"
  ],
  "Bình Mỹ, Củ Chi, Hồ Chí Minh": [
    "bình mỹ, củ chi, hồ chí minh",
    "bifnh myx, cur chi, hoof chis minh"
  ],
  "Bình Nam, Thăng Bình, Quảng Nam": [
    "bình nam, thăng bình, quảng nam",
    "bifnh nam, thawng bifnh, quarng nam"
  ],
  "Bình Nghi, Tây Sơn, Bình Định": [
    "bình nghi, tây sơn, bình định",
    "bifnh nghi, taay sown, bifnh ddijnh"
  ],
  "Bình Sơn, Hòn Đất, Kiên Giang": [
    "bình sơn, hòn đất, kiên giang",
    "bifnh sown, hofn ddaast, kieen giang"
  ],
  "Bình Sơn, Long Thành, Đồng Nai": [
    "bình sơn, long thành, đồng nai",
    "bifnh sown, long thafnh, ddoofng nai"
  ],
  "Bình Sơn, Triệu Sơn, Thanh Hóa": [
    "bình sơn, triệu sơn, thanh hóa",
    "bifnh sown, trieeju sown, thanh hosa"
  ],
  "Bình Thành, Thoại Sơn, An Giang": [
    "bình thành, thoại sơn, an giang",
    "bifnh thafnh, thoaji sown, an giang"
  ],
  "Bình Thạnh, Thủ Thừa, Long An": [
    "bình thạnh, thủ thừa, long an",
    "bifnh thajnh, thur thuwfa, long an"
  ],
  "Bình Thắng, Dĩ An, Bình Dương": [
    "bình thắng, dĩ an, bình dương",
    "bifnh thawsng, dix an, bifnh duwowng"
  ],
  "Bình Tân, Buôn Hồ, Đắk Lắk": [
    "bình tân, buôn hồ, đắk lắk",
    "bifnh taan, buoon hoof, ddawsk lawsk"
  ],
  "Bình Tân, Kiến Tường, Long An": [
    "bình tân, kiến tường, long an",
    "bifnh taan, kieesn tuwowfng, long an"
  ],
  "Bình Tân, Tây Sơn, Bình Định": [
    "bình tân, tây sơn, bình định",
    "bifnh taan, taay sown, bifnh ddijnh"
  ],
  "Bình Tú, Thăng Bình, Quảng Nam": [
    "bình tú, thăng bình, quảng nam",
    "bifnh tus, thawng bifnh, quarng nam"
  ],
  "Bình Văn, Chợ Mới, Bắc Kạn": [
    "bình văn, chợ mới, bắc kạn",
    "bifnh vawn, chowj mowsi, bawsc kajn"
  ],
  "Bình Xuân, Gò Công, Tiền Giang": [
    "bình xuân, gò công, tiền giang",
    "bifnh xuaan, gof coong, tieefn giang"
  ],
  "Bính Xá, Đình Lập, Lạng Sơn": [
    "bính xá, đình lập, lạng sơn",
    "bisnh xas, ddifnh laajp, lajng sown"
  ],
  "Bạch Thượng, Duy Tiên, Hà Nam": [
    "bạch thượng, duy tiên, hà nam",
    "bajch thuwowjng, duy tieen, haf nam"
  ],
  "Bản Công, Trạm Tấu, Yên Bái": [
    "bản công, trạm tấu, yên bái",
    "barn coong, trajm taasu, yeen basi"
  ],
  "Bản Cầm, Bảo Thắng, Lào Cai": [
    "bản cầm, bảo thắng, lào cai",
    "barn caafm, baro thawsng, lafo cai"
  ],
  "Bản Nguyên, Lâm Thao, Phú Thọ": [
    "bản nguyên, lâm thao, phú thọ",
    "barn nguyeen, laam thao, phus thoj"
  ],
  "Bản Sen, Vân Đồn, Quảng Ninh": [
    "bản sen, vân đồn, quảng ninh",
    "barn sen, vaan ddoofn, quarng ninh"
  ],
  "Bản Thi, Chợ Đồn, Bắc Kạn": [
    "bản thi, chợ đồn, bắc kạn",
    "barn thi, chowj ddoofn, bawsc kajn"
  ],
  "Bảo Bình, Cẩm Mỹ, Đồng Nai": [
    "bảo bình, cẩm mỹ, đồng nai",
    "baro bifnh, caarm myx, ddoofng nai"
  ],
  "Bảo Hoà, Xuân Lộc, Đồng Nai": [
    "bảo hoà, xuân lộc, đồng nai",
    "baro hoaf, xuaan loojc, ddoofng nai"
  ],
  "Bảo Lý, Phú Bình, Thái Nguyên": [
    "bảo lý, phú bình, thái nguyên",
    "baro lys, phus bifnh, thasi nguyeen"
  ],
  "Bảo Lạc, Bảo Lạc, Cao Bằng": [
    "bảo lạc, bảo lạc, cao bằng",
    "baro lajc, baro lajc, cao bawfng"
  ],
  "Bảo Thuận, Di Linh, Lâm Đồng": [
    "bảo thuận, di linh, lâm đồng",
    "baro thuaajn, di linh, laam ddoofng"
  ],
  "Bảo Thành, Yên Thành, Nghệ An": [
    "bảo thành, yên thành, nghệ an",
    "baro thafnh, yeen thafnh, ngheej an"
  ],
  "Bảo Toàn, Bảo Lạc, Cao Bằng": [
    "bảo toàn, bảo lạc, cao bằng",
    "baro toafn, baro lajc, cao bawfng"
  ],
  "Bảo Vinh, Long Khánh, Đồng Nai": [
    "bảo vinh, long khánh, đồng nai",
    "baro vinh, long khasnh, ddoofng nai"
  ],
  "Bảo Yên, Thanh Thuỷ, Phú Thọ": [
    "bảo yên, thanh thuỷ, phú thọ",
    "baro yeen, thanh thuyr, phus thoj"
  ],
  "Bắc Hùng, Văn Lãng, Lạng Sơn": [
    "bắc hùng, văn lãng, lạng sơn",
    "bawsc hufng, vawn laxng, lajng sown"
  ],
  "Bắc Sơn, An Dương, Hải Phòng": [
    "bắc sơn, an dương, hải phòng",
    "bawsc sown, an duwowng, hari phofng"
  ],
  "Bắc Sơn, Móng Cái, Quảng Ninh": [
    "bắc sơn, móng cái, quảng ninh",
    "bawsc sown, mosng casi, quarng ninh"
  ],
  "Bắc Sơn, Trảng Bom, Đồng Nai": [
    "bắc sơn, trảng bom, đồng nai",
    "bawsc sown, trarng bom, ddoofng nai"
  ],
  "Bắc Thành, Yên Thành, Nghệ An": [
    "bắc thành, yên thành, nghệ an",
    "bawsc thafnh, yeen thafnh, ngheej an"
  ],
  "Bắc Thủy, Chi Lăng, Lạng Sơn": [
    "bắc thủy, chi lăng, lạng sơn",
    "bawsc thury, chi lawng, lajng sown"
  ],
  "Bằng Cả, Hạ Long, Quảng Ninh": [
    "bằng cả, hạ long, quảng ninh",
    "bawfng car, haj long, quarng ninh"
  ],
  "Bằng Hành, Bắc Quang, Hà Giang": [
    "bằng hành, bắc quang, hà giang",
    "bawfng hafnh, bawsc quang, haf giang"
  ],
  "Bằng Hữu, Chi Lăng, Lạng Sơn": [
    "bằng hữu, chi lăng, lạng sơn",
    "bawfng huwxu, chi lawng, lajng sown"
  ],
  "Bằng Mạc, Chi Lăng, Lạng Sơn": [
    "bằng mạc, chi lăng, lạng sơn",
    "bawfng majc, chi lawng, lajng sown"
  ],
  "Bằng Vân, Ngân Sơn, Bắc Kạn": [
    "bằng vân, ngân sơn, bắc kạn",
    "bawfng vaan, ngaan sown, bawsc kajn"
  ],
  "Bột Xuyên, Mỹ Đức, Hà Nội": [
    "bột xuyên, mỹ đức, hà nội",
    "boojt xuyeen, myx dduwsc, haf nooji"
  ],
  "Ca Thành, Nguyên Bình, Cao Bằng": [
    "ca thành, nguyên bình, cao bằng",
    "ca thafnh, nguyeen bifnh, cao bawfng"
  ],
  "Cam Phúc Nam, Cam Ranh, Khánh Hòa": [
    "cam phúc nam, cam ranh, khánh hòa",
    "cam phusc nam, cam ranh, khasnh hofa"
  ],
  "Cam Tuyền, Cam Lộ, Quảng Trị": [
    "cam tuyền, cam lộ, quảng trị",
    "cam tuyeefn, cam looj, quarng trij"
  ],
  "Canh Liên, Vân Canh, Bình Định": [
    "canh liên, vân canh, bình định",
    "canh lieen, vaan canh, bifnh ddijnh"
  ],
  "Cao Mã Pờ, Quản Bạ, Hà Giang": [
    "cao mã pờ, quản bạ, hà giang",
    "cao max powf, quarn baj, haf giang"
  ],
  "Cao Ngọc, Ngọc Lặc, Thanh Hóa": [
    "cao ngọc, ngọc lặc, thanh hóa",
    "cao ngojc, ngojc lawjc, thanh hosa"
  ],
  "Cao Sơn, Bạch Thông, Bắc Kạn": [
    "cao sơn, bạch thông, bắc kạn",
    "cao sown, bajch thoong, bawsc kajn"
  ],
  "Cao Thắng, Hạ Long, Quảng Ninh": [
    "cao thắng, hạ long, quảng ninh",
    "cao thawsng, haj long, quarng ninh"
  ],
  "Chiêu Yên, Yên Sơn, Tuyên Quang": [
    "chiêu yên, yên sơn, tuyên quang",
    "chieeu yeen, yeen sown, tuyeen quang"
  ],
  "Chiềng Công, Mường La, Sơn La": [
    "chiềng công, mường la, sơn la",
    "chieefng coong, muwowfng la, sown la"
  ],
  "Chiềng Hắc, Mộc Châu, Sơn La": [
    "chiềng hắc, mộc châu, sơn la",
    "chieefng hawsc, moojc chaau, sown la"
  ],
  "Chiềng Khay, Quỳnh Nhai, Sơn La": [
    "chiềng khay, quỳnh nhai, sơn la",
    "chieefng khay, quyfnh nhai, sown la"
  ],
  "Chiềng Muôn, Mường La, Sơn La": [
    "chiềng muôn, mường la, sơn la",
    "chieefng muoon, muwowfng la, sown la"
  ],
  "Chiềng Pha, Thuận Châu, Sơn La": [
    "chiềng pha, thuận châu, sơn la",
    "chieefng pha, thuaajn chaau, sown la"
  ],
  "Chiềng Đông, Yên Châu, Sơn La": [
    "chiềng đông, yên châu, sơn la",
    "chieefng ddoong, yeen chaau, sown la"
  ],
  "Chrôh Pơnan, Phú Thiện, Gia Lai": [
    "chrôh pơnan, phú thiện, gia lai",
    "chrooh pownan, phus thieejn, gia lai"
  ],
  "Chuyên Mỹ, Phú Xuyên, Hà Nội": [
    "chuyên mỹ, phú xuyên, hà nội",
    "chuyeen myx, phus xuyeen, haf nooji"
  ],
  "Chà Cang, Nậm Pồ, Điện Biên": [
    "chà cang, nậm pồ, điện biên",
    "chaf cang, naajm poof, ddieejn bieen"
  ],
  "Chà Nưa, Nậm Pồ, Điện Biên": [
    "chà nưa, nậm pồ, điện biên",
    "chaf nuwa, naajm poof, ddieejn bieen"
  ],
  "Chà Tở, Nậm Pồ, Điện Biên": [
    "chà tở, nậm pồ, điện biên",
    "chaf towr, naajm poof, ddieejn bieen"
  ],
  "Châu Hòa, Giồng Trôm, Bến Tre": [
    "châu hòa, giồng trôm, bến tre",
    "chaau hofa, gioofng troom, beesn tre"
  ],
  "Châu Hưng, Bình Đại, Bến Tre": [
    "châu hưng, bình đại, bến tre",
    "chaau huwng, bifnh ddaji, beesn tre"
  ],
  "Châu Hạnh, Quỳ Châu, Nghệ An": [
    "châu hạnh, quỳ châu, nghệ an",
    "chaau hajnh, quyf chaau, ngheej an"
  ],
  "Châu Hồng, Quỳ Hợp, Nghệ An": [
    "châu hồng, quỳ hợp, nghệ an",
    "chaau hoofng, quyf howjp, ngheej an"
  ],
  "Châu Khánh, Long Phú, Sóc Trăng": [
    "châu khánh, long phú, sóc trăng",
    "chaau khasnh, long phus, sosc trawng"
  ],
  "Châu Minh, Hiệp Hòa, Bắc Giang": [
    "châu minh, hiệp hòa, bắc giang",
    "chaau minh, hieejp hofa, bawsc giang"
  ],
  "Châu Phú A, Châu Đốc, An Giang": [
    "châu phú a, châu đốc, an giang",
    "chaau phus a, chaau ddoosc, an giang"
  ],
  "Châu Phú B, Châu Đốc, An Giang": [
    "châu phú b, châu đốc, an giang",
    "chaau phus b, chaau ddoosc, an giang"
  ],
  "Châu Thành, Quỳ Hợp, Nghệ An": [
    "châu thành, quỳ hợp, nghệ an",
    "chaau thafnh, quyf howjp, ngheej an"
  ],
  "Châu Tiến, Quỳ Châu, Nghệ An": [
    "châu tiến, quỳ châu, nghệ an",
    "chaau tieesn, quyf chaau, ngheej an"
  ],
  "Châu Tiến, Quỳ Hợp, Nghệ An": [
    "châu tiến, quỳ hợp, nghệ an",
    "chaau tieesn, quyf howjp, ngheej an"
  ],
  "Châu Đình, Quỳ Hợp, Nghệ An": [
    "châu đình, quỳ hợp, nghệ an",
    "chaau ddifnh, quyf howjp, ngheej an"
  ],
  "Châu Ổ, Bình Sơn, Quảng Ngãi": [
    "châu ổ, bình sơn, quảng ngãi",
    "chaau oor, bifnh sown, quarng ngaxi"
  ],
  "Chí Công, Tuy Phong, Bình Thuận": [
    "chí công, tuy phong, bình thuận",
    "chis coong, tuy phong, bifnh thuaajn"
  ],
  "Chúc Sơn, Chương Mỹ, Hà Nội": [
    "chúc sơn, chương mỹ, hà nội",
    "chusc sown, chuwowng myx, haf nooji"
  ],
  "Chư KBô, Krông Búk, Đắk Lắk": [
    "chư kbô, krông búk, đắk lắk",
    "chuw kboo, kroong busk, ddawsk lawsk"
  ],
  "Chương Xá, Cẩm Khê, Phú Thọ": [
    "chương xá, cẩm khê, phú thọ",
    "chuwowng xas, caarm khee, phus thoj"
  ],
  "Cuor Đăng, Cư M'gar, Đắk Lắk": [
    "cuor đăng, cư m'gar, đắk lắk",
    "cuor ddawng, cuw m'gar, ddawsk lawsk"
  ],
  "Cách Linh, Quảng Hòa, Cao Bằng": [
    "cách linh, quảng hòa, cao bằng",
    "casch linh, quarng hofa, cao bawfng"
  ],
  "Cái Chiên, Hải Hà, Quảng Ninh": [
    "cái chiên, hải hà, quảng ninh",
    "casi chieen, hari haf, quarng ninh"
  ],
  "Cát Hưng, Phù Cát, Bình Định": [
    "cát hưng, phù cát, bình định",
    "cast huwng, phuf cast, bifnh ddijnh"
  ],
  "Cát Hải, Cát Hải, Hải Phòng": [
    "cát hải, cát hải, hải phòng",
    "cast hari, cast hari, hari phofng"
  ],
  "Cát Hải, Phù Cát, Bình Định": [
    "cát hải, phù cát, bình định",
    "cast hari, phuf cast, bifnh ddijnh"
  ],
  "Cát Nhơn, Phù Cát, Bình Định": [
    "cát nhơn, phù cát, bình định",
    "cast nhown, phuf cast, bifnh ddijnh"
  ],
  "Cát Nê, Đại Từ, Thái Nguyên": [
    "cát nê, đại từ, thái nguyên",
    "cast nee, ddaji tuwf, thasi nguyeen"
  ],
  "Cát Thịnh, Văn Chấn, Yên Bái": [
    "cát thịnh, văn chấn, yên bái",
    "cast thijnh, vawn chaasn, yeen basi"
  ],
  "Cát Tiên, Cát Tiên, Lâm Đồng": [
    "cát tiên, cát tiên, lâm đồng",
    "cast tieen, cast tieen, laam ddoofng"
  ],
  "Cát Trinh, Phù Cát, Bình Định": [
    "cát trinh, phù cát, bình định",
    "cast trinh, phuf cast, bifnh ddijnh"
  ],
  "Cát Văn, Thanh Chương, Nghệ An": [
    "cát văn, thanh chương, nghệ an",
    "cast vawn, thanh chuwowng, ngheej an"
  ],
  "Công Thành, Yên Thành, Nghệ An": [
    "công thành, yên thành, nghệ an",
    "coong thafnh, yeen thafnh, ngheej an"
  ],
  "Cù Vân, Đại Từ, Thái Nguyên": [
    "cù vân, đại từ, thái nguyên",
    "cuf vaan, ddaji tuwf, thasi nguyeen"
  ],
  "Cư Pơng, Krông Búk, Đắk Lắk": [
    "cư pơng, krông búk, đắk lắk",
    "cuw powng, kroong busk, ddawsk lawsk"
  ],
  "Cương Gián, Nghi Xuân, Hà Tĩnh": [
    "cương gián, nghi xuân, hà tĩnh",
    "cuwowng giasn, nghi xuaan, haf tixnh"
  ],
  "Cương Sơn, Lục Nam, Bắc Giang": [
    "cương sơn, lục nam, bắc giang",
    "cuwowng sown, lujc nam, bawsc giang"
  ],
  "Cải Viên, Hà Quảng, Cao Bằng": [
    "cải viên, hà quảng, cao bằng",
    "cari vieen, haf quarng, cao bawfng"
  ],
  "Cần Nông, Hà Quảng, Cao Bằng": [
    "cần nông, hà quảng, cao bằng",
    "caafn noong, haf quarng, cao bawfng"
  ],
  "Cần Đăng, Châu Thành, An Giang": [
    "cần đăng, châu thành, an giang",
    "caafn ddawng, chaau thafnh, an giang"
  ],
  "Cầu Bà, Khánh Vĩnh, Khánh Hòa": [
    "cầu bà, khánh vĩnh, khánh hòa",
    "caafu baf, khasnh vixnh, khasnh hofa"
  ],
  "Cầu Giát, Quỳnh Lưu, Nghệ An": [
    "cầu giát, quỳnh lưu, nghệ an",
    "caafu giast, quyfnh luwu, ngheej an"
  ],
  "Cầu Lộc, Hậu Lộc, Thanh Hóa": [
    "cầu lộc, hậu lộc, thanh hóa",
    "caafu loojc, haaju loojc, thanh hosa"
  ],
  "Cẩm Bình, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm bình, cẩm xuyên, hà tĩnh",
    "caarm bifnh, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Duệ, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm duệ, cẩm xuyên, hà tĩnh",
    "caarm dueej, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Hưng, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm hưng, cẩm xuyên, hà tĩnh",
    "caarm huwng, caarm xuyeen, haf tixnh"
  ],
  "Cẩm La, Quảng Yên, Quảng Ninh": [
    "cẩm la, quảng yên, quảng ninh",
    "caarm la, quarng yeen, quarng ninh"
  ],
  "Cẩm Long, Cẩm Thủy, Thanh Hóa": [
    "cẩm long, cẩm thủy, thanh hóa",
    "caarm long, caarm thury, thanh hosa"
  ],
  "Cẩm Lĩnh, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm lĩnh, cẩm xuyên, hà tĩnh",
    "caarm lixnh, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Lạc, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm lạc, cẩm xuyên, hà tĩnh",
    "caarm lajc, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Lộc, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm lộc, cẩm xuyên, hà tĩnh",
    "caarm loojc, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Phú, Cẩm Thủy, Thanh Hóa": [
    "cẩm phú, cẩm thủy, thanh hóa",
    "caarm phus, caarm thury, thanh hosa"
  ],
  "Cẩm Quang, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm quang, cẩm xuyên, hà tĩnh",
    "caarm quang, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Quý, Cẩm Thủy, Thanh Hóa": [
    "cẩm quý, cẩm thủy, thanh hóa",
    "caarm quys, caarm thury, thanh hosa"
  ],
  "Cẩm Sơn, Mỏ Cày Nam, Bến Tre": [
    "cẩm sơn, mỏ cày nam, bến tre",
    "caarm sown, mor cafy nam, beesn tre"
  ],
  "Cẩm Trung, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm trung, cẩm xuyên, hà tĩnh",
    "caarm trung, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Tâm, Cẩm Thủy, Thanh Hóa": [
    "cẩm tâm, cẩm thủy, thanh hóa",
    "caarm taam, caarm thury, thanh hosa"
  ],
  "Cẩm Tân, Cẩm Thủy, Thanh Hóa": [
    "cẩm tân, cẩm thủy, thanh hóa",
    "caarm taan, caarm thury, thanh hosa"
  ],
  "Cẩm Vân, Cẩm Thủy, Thanh Hóa": [
    "cẩm vân, cẩm thủy, thanh hóa",
    "caarm vaan, caarm thury, thanh hosa"
  ],
  "Cẩm Vĩnh, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm vĩnh, cẩm xuyên, hà tĩnh",
    "caarm vixnh, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Yên, Cẩm Thủy, Thanh Hóa": [
    "cẩm yên, cẩm thủy, thanh hóa",
    "caarm yeen, caarm thury, thanh hosa"
  ],
  "Cốc Pàng, Bảo Lạc, Cao Bằng": [
    "cốc pàng, bảo lạc, cao bằng",
    "coosc pafng, baro lajc, cao bawfng"
  ],
  "Cốc Đán, Ngân Sơn, Bắc Kạn": [
    "cốc đán, ngân sơn, bắc kạn",
    "coosc ddasn, ngaan sown, bawsc kajn"
  ],
  "Cổ Bì, Bình Giang, Hải Dương": [
    "cổ bì, bình giang, hải dương",
    "coor bif, bifnh giang, hari duwowng"
  ],
  "Cổ Lũng, Bá Thước, Thanh Hóa": [
    "cổ lũng, bá thước, thanh hóa",
    "coor luxng, bas thuwowsc, thanh hosa"
  ],
  "Cộng Hòa, Vụ Bản, Nam Định": [
    "cộng hòa, vụ bản, nam định",
    "coojng hofa, vuj barn, nam ddijnh"
  ],
  "Cự Thắng, Thanh Sơn, Phú Thọ": [
    "cự thắng, thanh sơn, phú thọ",
    "cuwj thawsng, thanh sown, phus thoj"
  ],
  "Cự Đồng, Thanh Sơn, Phú Thọ": [
    "cự đồng, thanh sơn, phú thọ",
    "cuwj ddoofng, thanh sown, phus thoj"
  ],
  "Diễn Cát, Diễn Châu, Nghệ An": [
    "diễn cát, diễn châu, nghệ an",
    "dieexn cast, dieexn chaau, ngheej an"
  ],
  "Diễn Kỷ, Diễn Châu, Nghệ An": [
    "diễn kỷ, diễn châu, nghệ an",
    "dieexn kyr, dieexn chaau, ngheej an"
  ],
  "Diễn Lâm, Diễn Châu, Nghệ An": [
    "diễn lâm, diễn châu, nghệ an",
    "dieexn laam, dieexn chaau, ngheej an"
  ],
  "Diễn Mỹ, Diễn Châu, Nghệ An": [
    "diễn mỹ, diễn châu, nghệ an",
    "dieexn myx, dieexn chaau, ngheej an"
  ],
  "Diễn Phú, Diễn Châu, Nghệ An": [
    "diễn phú, diễn châu, nghệ an",
    "dieexn phus, dieexn chaau, ngheej an"
  ],
  "Diễn Tân, Diễn Châu, Nghệ An": [
    "diễn tân, diễn châu, nghệ an",
    "dieexn taan, dieexn chaau, ngheej an"
  ],
  "Diễn Yên, Diễn Châu, Nghệ An": [
    "diễn yên, diễn châu, nghệ an",
    "dieexn yeen, dieexn chaau, ngheej an"
  ],
  "Dray Sáp, Krông A Na, Đắk Lắk": [
    "dray sáp, krông a na, đắk lắk",
    "dray sasp, kroong a na, ddawsk lawsk"
  ],
  "Du Lễ, Kiến Thuỵ, Hải Phòng": [
    "du lễ, kiến thuỵ, hải phòng",
    "du leex, kieesn thuyj, hari phofng"
  ],
  "Dur KMăl, Krông A Na, Đắk Lắk": [
    "dur kmăl, krông a na, đắk lắk",
    "dur kmawl, kroong a na, ddawsk lawsk"
  ],
  "Duy Phiên, Tam Dương, Vĩnh Phúc": [
    "duy phiên, tam dương, vĩnh phúc",
    "duy phieen, tam duwowng, vixnh phusc"
  ],
  "Duyên Hải, Hưng Hà, Thái Bình": [
    "duyên hải, hưng hà, thái bình",
    "duyeen hari, huwng haf, thasi bifnh"
  ],
  "Dân Chủ, Tứ Kỳ, Hải Dương": [
    "dân chủ, tứ kỳ, hải dương",
    "daan chur, tuws kyf, hari duwowng"
  ],
  "Dân Lực, Triệu Sơn, Thanh Hóa": [
    "dân lực, triệu sơn, thanh hóa",
    "daan luwjc, trieeju sown, thanh hosa"
  ],
  "Dân Thành, Duyên Hải, Trà Vinh": [
    "dân thành, duyên hải, trà vinh",
    "daan thafnh, duyeen hari, traf vinh"
  ],
  "Dân Tiến, Võ Nhai, Thái Nguyên": [
    "dân tiến, võ nhai, thái nguyên",
    "daan tieesn, vox nhai, thasi nguyeen"
  ],
  "Dĩnh Kế, Bắc Giang, Bắc Giang": [
    "dĩnh kế, bắc giang, bắc giang",
    "dixnh kees, bawsc giang, bawsc giang"
  ],
  "Dĩnh Trì, Bắc Giang, Bắc Giang": [
    "dĩnh trì, bắc giang, bắc giang",
    "dixnh trif, bawsc giang, bawsc giang"
  ],
  "Dũng Liệt, Yên Phong, Bắc Ninh": [
    "dũng liệt, yên phong, bắc ninh",
    "duxng lieejt, yeen phong, bawsc ninh"
  ],
  "Dương Nội, Hà Đông, Hà Nội": [
    "dương nội, hà đông, hà nội",
    "duwowng nooji, haf ddoong, haf nooji"
  ],
  "Dương Quang, Mỹ Hào, Hưng Yên": [
    "dương quang, mỹ hào, hưng yên",
    "duwowng quang, myx hafo, huwng yeen"
  ],
  "Dực Yên, Đầm Hà, Quảng Ninh": [
    "dực yên, đầm hà, quảng ninh",
    "duwjc yeen, ddaafm haf, quarng ninh"
  ],
  "Ea KNuec, Krông Pắc, Đắk Lắk": [
    "ea knuec, krông pắc, đắk lắk",
    "ea knuec, kroong pawsc, ddawsk lawsk"
  ],
  "Ea Kênh, Krông Pắc, Đắk Lắk": [
    "ea kênh, krông pắc, đắk lắk",
    "ea keenh, kroong pawsc, ddawsk lawsk"
  ],
  "Ea Yông, Krông Pắc, Đắk Lắk": [
    "ea yông, krông pắc, đắk lắk",
    "ea yoong, kroong pawsc, ddawsk lawsk"
  ],
  "Gia Canh, Định Quán, Đồng Nai": [
    "gia canh, định quán, đồng nai",
    "gia canh, ddijnh quasn, ddoofng nai"
  ],
  "Gia Huynh, Tánh Linh, Bình Thuận": [
    "gia huynh, tánh linh, bình thuận",
    "gia huynh, tasnh linh, bifnh thuaajn"
  ],
  "Gia Hòa 1, Mỹ Xuyên, Sóc Trăng": [
    "gia hòa 1, mỹ xuyên, sóc trăng",
    "gia hofa 1, myx xuyeen, sosc trawng"
  ],
  "Gia Hòa 2, Mỹ Xuyên, Sóc Trăng": [
    "gia hòa 2, mỹ xuyên, sóc trăng",
    "gia hofa 2, myx xuyeen, sosc trawng"
  ],
  "Gia Khánh, Gia Lộc, Hải Dương": [
    "gia khánh, gia lộc, hải dương",
    "gia khasnh, gia loojc, hari duwowng"
  ],
  "Gia Luận, Cát Hải, Hải Phòng": [
    "gia luận, cát hải, hải phòng",
    "gia luaajn, cast hari, hari phofng"
  ],
  "Gia Phương, Gia Viễn, Ninh Bình": [
    "gia phương, gia viễn, ninh bình",
    "gia phuwowng, gia vieexn, ninh bifnh"
  ],
  "Gia Viễn, Cát Tiên, Lâm Đồng": [
    "gia viễn, cát tiên, lâm đồng",
    "gia vieexn, cast tieen, laam ddoofng"
  ],
  "Gia Vượng, Gia Viễn, Ninh Bình": [
    "gia vượng, gia viễn, ninh bình",
    "gia vuwowjng, gia vieexn, ninh bifnh"
  ],
  "Giao Châu, Giao Thủy, Nam Định": [
    "giao châu, giao thủy, nam định",
    "giao chaau, giao thury, nam ddijnh"
  ],
  "Giao Hải, Giao Thủy, Nam Định": [
    "giao hải, giao thủy, nam định",
    "giao hari, giao thury, nam ddijnh"
  ],
  "Giao Lạc, Giao Thủy, Nam Định": [
    "giao lạc, giao thủy, nam định",
    "giao lajc, giao thury, nam ddijnh"
  ],
  "Giao Nhân, Giao Thủy, Nam Định": [
    "giao nhân, giao thủy, nam định",
    "giao nhaan, giao thury, nam ddijnh"
  ],
  "Giao Phong, Giao Thủy, Nam Định": [
    "giao phong, giao thủy, nam định",
    "giao phong, giao thury, nam ddijnh"
  ],
  "Giao Thanh, Giao Thủy, Nam Định": [
    "giao thanh, giao thủy, nam định",
    "giao thanh, giao thury, nam ddijnh"
  ],
  "Giao Xuân, Giao Thủy, Nam Định": [
    "giao xuân, giao thủy, nam định",
    "giao xuaan, giao thury, nam ddijnh"
  ],
  "Giao Yến, Giao Thủy, Nam Định": [
    "giao yến, giao thủy, nam định",
    "giao yeesn, giao thury, nam ddijnh"
  ],
  "Giáp Đắt, Đà Bắc, Hoà Bình": [
    "giáp đắt, đà bắc, hoà bình",
    "giasp ddawst, ddaf bawsc, hoaf bifnh"
  ],
  "Hiến Sơn, Đô Lương, Nghệ An": [
    "hiến sơn, đô lương, nghệ an",
    "hieesn sown, ddoo luwowng, ngheej an"
  ],
  "Hiếu Tử, Tiểu Cần, Trà Vinh": [
    "hiếu tử, tiểu cần, trà vinh",
    "hieesu tuwr, tieeru caafn, traf vinh"
  ],
  "Hiền Kiệt, Quan Hóa, Thanh Hóa": [
    "hiền kiệt, quan hóa, thanh hóa",
    "hieefn kieejt, quan hosa, thanh hosa"
  ],
  "Hiệp Hòa, Biên Hòa, Đồng Nai": [
    "hiệp hòa, biên hòa, đồng nai",
    "hieejp hofa, bieen hofa, ddoofng nai"
  ],
  "Hiệp Thạnh, Gò Dầu, Tây Ninh": [
    "hiệp thạnh, gò dầu, tây ninh",
    "hieejp thajnh, gof daafu, taay ninh"
  ],
  "Hoa Sơn, Lập Thạch, Vĩnh Phúc": [
    "hoa sơn, lập thạch, vĩnh phúc",
    "hoa sown, laajp thajch, vixnh phusc"
  ],
  "Hoa Thám, Nguyên Bình, Cao Bằng": [
    "hoa thám, nguyên bình, cao bằng",
    "hoa thasm, nguyeen bifnh, cao bawfng"
  ],
  "Hoà Bình, Tam Nông, Đồng Tháp": [
    "hoà bình, tam nông, đồng tháp",
    "hoaf bifnh, tam noong, ddoofng thasp"
  ],
  "Hoà Lạc, Móng Cái, Quảng Ninh": [
    "hoà lạc, móng cái, quảng ninh",
    "hoaf lajc, mosng casi, quarng ninh"
  ],
  "Hoà Mục, Chợ Mới, Bắc Kạn": [
    "hoà mục, chợ mới, bắc kạn",
    "hoaf mujc, chowj mowsi, bawsc kajn"
  ],
  "Hoài Đức, Lâm Hà, Lâm Đồng": [
    "hoài đức, lâm hà, lâm đồng",
    "hoafi dduwsc, laam haf, laam ddoofng"
  ],
  "Hoàng Cương, Thanh Ba, Phú Thọ": [
    "hoàng cương, thanh ba, phú thọ",
    "hoafng cuwowng, thanh ba, phus thoj"
  ],
  "Hoàng Hoa, Tam Dương, Vĩnh Phúc": [
    "hoàng hoa, tam dương, vĩnh phúc",
    "hoafng hoa, tam duwowng, vixnh phusc"
  ],
  "Hoàng Khai, Yên Sơn, Tuyên Quang": [
    "hoàng khai, yên sơn, tuyên quang",
    "hoafng khai, yeen sown, tuyeen quang"
  ],
  "Hoàng Liệt, Hoàng Mai, Hà Nội": [
    "hoàng liệt, hoàng mai, hà nội",
    "hoafng lieejt, hoafng mai, haf nooji"
  ],
  "Hoàng Xá, Thanh Thuỷ, Phú Thọ": [
    "hoàng xá, thanh thuỷ, phú thọ",
    "hoafng xas, thanh thuyr, phus thoj"
  ],
  "Hoành Bồ, Hạ Long, Quảng Ninh": [
    "hoành bồ, hạ long, quảng ninh",
    "hoafnh boof, haj long, quarng ninh"
  ],
  "Hoả Lựu, Vị Thanh, Hậu Giang": [
    "hoả lựu, vị thanh, hậu giang",
    "hoar luwju, vij thanh, haaju giang"
  ],
  "Huyền Hội, Càng Long, Trà Vinh": [
    "huyền hội, càng long, trà vinh",
    "huyeefn hooji, cafng long, traf vinh"
  ],
  "Huyền Sơn, Lục Nam, Bắc Giang": [
    "huyền sơn, lục nam, bắc giang",
    "huyeefn sown, lujc nam, bawsc giang"
  ],
  "Hà Châu, Phú Bình, Thái Nguyên": [
    "hà châu, phú bình, thái nguyên",
    "haf chaau, phus bifnh, thasi nguyeen"
  ],
  "Hà Giang, Đông Hưng, Thái Bình": [
    "hà giang, đông hưng, thái bình",
    "haf giang, ddoong huwng, thasi bifnh"
  ],
  "Hà Hồi, Thường Tín, Hà Nội": [
    "hà hồi, thường tín, hà nội",
    "haf hoofi, thuwowfng tisn, haf nooji"
  ],
  "Hà Mãn, Thuận Thành, Bắc Ninh": [
    "hà mãn, thuận thành, bắc ninh",
    "haf maxn, thuaajn thafnh, bawsc ninh"
  ],
  "Hàng Bông, Hoàn Kiếm, Hà Nội": [
    "hàng bông, hoàn kiếm, hà nội",
    "hafng boong, hoafn kieesm, haf nooji"
  ],
  "Hàng Bạc, Hoàn Kiếm, Hà Nội": [
    "hàng bạc, hoàn kiếm, hà nội",
    "hafng bajc, hoafn kieesm, haf nooji"
  ],
  "Hàng Gòn, Long Khánh, Đồng Nai": [
    "hàng gòn, long khánh, đồng nai",
    "hafng gofn, long khasnh, ddoofng nai"
  ],
  "Hàng Kênh, Lê Chân, Hải Phòng": [
    "hàng kênh, lê chân, hải phòng",
    "hafng keenh, lee chaan, hari phofng"
  ],
  "Hàng Đào, Hoàn Kiếm, Hà Nội": [
    "hàng đào, hoàn kiếm, hà nội",
    "hafng ddafo, hoafn kieesm, haf nooji"
  ],
  "Hòa An, Phụng Hiệp, Hậu Giang": [
    "hòa an, phụng hiệp, hậu giang",
    "hofa an, phujng hieejp, haaju giang"
  ],
  "Hòa Bình, Hữu Lũng, Lạng Sơn": [
    "hòa bình, hữu lũng, lạng sơn",
    "hofa bifnh, huwxu luxng, lajng sown"
  ],
  "Hòa Lạc, Hữu Lũng, Lạng Sơn": [
    "hòa lạc, hữu lũng, lạng sơn",
    "hofa lajc, huwxu luxng, lajng sown"
  ],
  "Hòa Mỹ Tây, Tây Hoà, Phú Yên": [
    "hòa mỹ tây, tây hoà, phú yên",
    "hofa myx taay, taay hoaf, phus yeen"
  ],
  "Hòa Phú, Chiêm Hóa, Tuyên Quang": [
    "hòa phú, chiêm hóa, tuyên quang",
    "hofa phus, chieem hosa, tuyeen quang"
  ],
  "Hòa Quang Nam, Phú Hoà, Phú Yên": [
    "hòa quang nam, phú hoà, phú yên",
    "hofa quang nam, phus hoaf, phus yeen"
  ],
  "Hòa Thành, Lai Vung, Đồng Tháp": [
    "hòa thành, lai vung, đồng tháp",
    "hofa thafnh, lai vung, ddoofng thasp"
  ],
  "Hòa Tân Tây, Tây Hoà, Phú Yên": [
    "hòa tân tây, tây hoà, phú yên",
    "hofa taan taay, taay hoaf, phus yeen"
  ],
  "Hòa Tú 1, Mỹ Xuyên, Sóc Trăng": [
    "hòa tú 1, mỹ xuyên, sóc trăng",
    "hofa tus 1, myx xuyeen, sosc trawng"
  ],
  "Hòn Thơm, Phú Quốc, Kiên Giang": [
    "hòn thơm, phú quốc, kiên giang",
    "hofn thowm, phus quoosc, kieen giang"
  ],
  "Hóa Hợp, Minh Hóa, Quảng Bình": [
    "hóa hợp, minh hóa, quảng bình",
    "hosa howjp, minh hosa, quarng bifnh"
  ],
  "Hóa Phúc, Minh Hóa, Quảng Bình": [
    "hóa phúc, minh hóa, quảng bình",
    "hosa phusc, minh hosa, quarng bifnh"
  ],
  "Hóa Thanh, Minh Hóa, Quảng Bình": [
    "hóa thanh, minh hóa, quảng bình",
    "hosa thanh, minh hosa, quarng bifnh"
  ],
  "Hóc Môn, Hóc Môn, Hồ Chí Minh": [
    "hóc môn, hóc môn, hồ chí minh",
    "hosc moon, hosc moon, hoof chis minh"
  ],
  "Hùng Lợi, Yên Sơn, Tuyên Quang": [
    "hùng lợi, yên sơn, tuyên quang",
    "hufng lowji, yeen sown, tuyeen quang"
  ],
  "Hùng Sơn, Hiệp Hòa, Bắc Giang": [
    "hùng sơn, hiệp hòa, bắc giang",
    "hufng sown, hieejp hofa, bawsc giang"
  ],
  "Hùng Thành, Yên Thành, Nghệ An": [
    "hùng thành, yên thành, nghệ an",
    "hufng thafnh, yeen thafnh, ngheej an"
  ],
  "Hùng Tiến, Mỹ Đức, Hà Nội": [
    "hùng tiến, mỹ đức, hà nội",
    "hufng tieesn, myx dduwsc, haf nooji"
  ],
  "Hùng Việt, Cẩm Khê, Phú Thọ": [
    "hùng việt, cẩm khê, phú thọ",
    "hufng vieejt, caarm khee, phus thoj"
  ],
  "Hưng Khánh, Trấn Yên, Yên Bái": [
    "hưng khánh, trấn yên, yên bái",
    "huwng khasnh, traasn yeen, yeen basi"
  ],
  "Hưng Lễ, Giồng Trôm, Bến Tre": [
    "hưng lễ, giồng trôm, bến tre",
    "huwng leex, gioofng troom, beesn tre"
  ],
  "Hưng Lộc, Hậu Lộc, Thanh Hóa": [
    "hưng lộc, hậu lộc, thanh hóa",
    "huwng loojc, haaju loojc, thanh hosa"
  ],
  "Hưng Lợi, Ninh Kiều, Cần Thơ": [
    "hưng lợi, ninh kiều, cần thơ",
    "huwng lowji, ninh kieefu, caafn thow"
  ],
  "Hưng Mỹ, Hưng Nguyên, Nghệ An": [
    "hưng mỹ, hưng nguyên, nghệ an",
    "huwng myx, huwng nguyeen, ngheej an"
  ],
  "Hưng Tân, Hưng Nguyên, Nghệ An": [
    "hưng tân, hưng nguyên, nghệ an",
    "huwng taan, huwng nguyeen, ngheej an"
  ],
  "Hưng Tây, Hưng Nguyên, Nghệ An": [
    "hưng tây, hưng nguyên, nghệ an",
    "huwng taay, huwng nguyeen, ngheej an"
  ],
  "Hưng Yên, Hưng Nguyên, Nghệ An": [
    "hưng yên, hưng nguyên, nghệ an",
    "huwng yeen, huwng nguyeen, ngheej an"
  ],
  "Hưng Điền B, Tân Hưng, Long An": [
    "hưng điền b, tân hưng, long an",
    "huwng ddieefn b, taan huwng, long an"
  ],
  "Hưng Đạo, Bình Gia, Lạng Sơn": [
    "hưng đạo, bình gia, lạng sơn",
    "huwng ddajo, bifnh gia, lajng sown"
  ],
  "Hưng Đạo, Cao Bằng, Cao Bằng": [
    "hưng đạo, cao bằng, cao bằng",
    "huwng ddajo, cao bawfng, cao bawfng"
  ],
  "Hưng Đạo, Tiên Lữ, Hưng Yên": [
    "hưng đạo, tiên lữ, hưng yên",
    "huwng ddajo, tieen luwx, huwng yeen"
  ],
  "Hương Lung, Cẩm Khê, Phú Thọ": [
    "hương lung, cẩm khê, phú thọ",
    "huwowng lung, caarm khee, phus thoj"
  ],
  "Hương Mạc, Từ Sơn, Bắc Ninh": [
    "hương mạc, từ sơn, bắc ninh",
    "huwowng majc, tuwf sown, bawsc ninh"
  ],
  "Hương Nộn, Tam Nông, Phú Thọ": [
    "hương nộn, tam nông, phú thọ",
    "huwowng noojn, tam noong, phus thoj"
  ],
  "Hương Sơn, Mỹ Đức, Hà Nội": [
    "hương sơn, mỹ đức, hà nội",
    "huwowng sown, myx dduwsc, haf nooji"
  ],
  "Hương Sơn, Quang Bình, Hà Giang": [
    "hương sơn, quang bình, hà giang",
    "huwowng sown, quang bifnh, haf giang"
  ],
  "Hương Vĩ, Yên Thế, Bắc Giang": [
    "hương vĩ, yên thế, bắc giang",
    "huwowng vix, yeen thees, bawsc giang"
  ],
  "Hạ Long, Vân Đồn, Quảng Ninh": [
    "hạ long, vân đồn, quảng ninh",
    "haj long, vaan ddoofn, quarng ninh"
  ],
  "Hạ Lý, Hồng Bàng, Hải Phòng": [
    "hạ lý, hồng bàng, hải phòng",
    "haj lys, hoofng bafng, hari phofng"
  ],
  "Hạ Mỗ, Đan Phượng, Hà Nội": [
    "hạ mỗ, đan phượng, hà nội",
    "haj moox, ddan phuwowjng, haf nooji"
  ],
  "Hạ Trung, Bá Thước, Thanh Hóa": [
    "hạ trung, bá thước, thanh hóa",
    "haj trung, bas thuwowsc, thanh hosa"
  ],
  "Hải An, Hải Lăng, Quảng Trị": [
    "hải an, hải lăng, quảng trị",
    "hari an, hari lawng, quarng trij"
  ],
  "Hải Ba, Hải Lăng, Quảng Trị": [
    "hải ba, hải lăng, quảng trị",
    "hari ba, hari lawng, quarng trij"
  ],
  "Hải Hoà, Móng Cái, Quảng Ninh": [
    "hải hoà, móng cái, quảng ninh",
    "hari hoaf, mosng casi, quarng ninh"
  ],
  "Hải Hòa, Hải Hậu, Nam Định": [
    "hải hòa, hải hậu, nam định",
    "hari hofa, hari haaju, nam ddijnh"
  ],
  "Hải Long, Hải Hậu, Nam Định": [
    "hải long, hải hậu, nam định",
    "hari long, hari haaju, nam ddijnh"
  ],
  "Hải Lộc, Hậu Lộc, Thanh Hóa": [
    "hải lộc, hậu lộc, thanh hóa",
    "hari loojc, haaju loojc, thanh hosa"
  ],
  "Hải Minh, Hải Hậu, Nam Định": [
    "hải minh, hải hậu, nam định",
    "hari minh, hari haaju, nam ddijnh"
  ],
  "Hải Ninh, Hải Hậu, Nam Định": [
    "hải ninh, hải hậu, nam định",
    "hari ninh, hari haaju, nam ddijnh"
  ],
  "Hải Phú, Hải Hậu, Nam Định": [
    "hải phú, hải hậu, nam định",
    "hari phus, hari haaju, nam ddijnh"
  ],
  "Hải Sơn, Hải Hậu, Nam Định": [
    "hải sơn, hải hậu, nam định",
    "hari sown, hari haaju, nam ddijnh"
  ],
  "Hải Sơn, Móng Cái, Quảng Ninh": [
    "hải sơn, móng cái, quảng ninh",
    "hari sown, mosng casi, quarng ninh"
  ],
  "Hải Sơn, Đồ Sơn, Hải Phòng": [
    "hải sơn, đồ sơn, hải phòng",
    "hari sown, ddoof sown, hari phofng"
  ],
  "Hải Thái, Gio Linh, Quảng Trị": [
    "hải thái, gio linh, quảng trị",
    "hari thasi, gio linh, quarng trij"
  ],
  "Hải Tân, Hải Hậu, Nam Định": [
    "hải tân, hải hậu, nam định",
    "hari taan, hari haaju, nam ddijnh"
  ],
  "Hải Tây, Hải Hậu, Nam Định": [
    "hải tây, hải hậu, nam định",
    "hari taay, hari haaju, nam ddijnh"
  ],
  "Hải Vân, Hải Hậu, Nam Định": [
    "hải vân, hải hậu, nam định",
    "hari vaan, hari haaju, nam ddijnh"
  ],
  "Hải Yên, Móng Cái, Quảng Ninh": [
    "hải yên, móng cái, quảng ninh",
    "hari yeen, mosng casi, quarng ninh"
  ],
  "Hậu Lộc, Hậu Lộc, Thanh Hóa": [
    "hậu lộc, hậu lộc, thanh hóa",
    "haaju loojc, haaju loojc, thanh hosa"
  ],
  "Hậu Thành, Cái Bè, Tiền Giang": [
    "hậu thành, cái bè, tiền giang",
    "haaju thafnh, casi bef, tieefn giang"
  ],
  "Hậu Thành, Yên Thành, Nghệ An": [
    "hậu thành, yên thành, nghệ an",
    "haaju thafnh, yeen thafnh, ngheej an"
  ],
  "Hố Nai 3, Trảng Bom, Đồng Nai": [
    "hố nai 3, trảng bom, đồng nai",
    "hoos nai 3, trarng bom, ddoofng nai"
  ],
  "Hồng Châu, Hưng Yên, Hưng Yên": [
    "hồng châu, hưng yên, hưng yên",
    "hoofng chaau, huwng yeen, huwng yeen"
  ],
  "Hồng Dương, Thanh Oai, Hà Nội": [
    "hồng dương, thanh oai, hà nội",
    "hoofng duwowng, thanh oai, haf nooji"
  ],
  "Hồng Kỳ, Yên Thế, Bắc Giang": [
    "hồng kỳ, yên thế, bắc giang",
    "hoofng kyf, yeen thees, bawsc giang"
  ],
  "Hồng Lĩnh, Hưng Hà, Thái Bình": [
    "hồng lĩnh, hưng hà, thái bình",
    "hoofng lixnh, huwng haf, thasi bifnh"
  ],
  "Hồng Phong, Bình Gia, Lạng Sơn": [
    "hồng phong, bình gia, lạng sơn",
    "hoofng phong, bifnh gia, lajng sown"
  ],
  "Hồng Phong, Cao Lộc, Lạng Sơn": [
    "hồng phong, cao lộc, lạng sơn",
    "hoofng phong, cao loojc, lajng sown"
  ],
  "Hồng Sơn, Đô Lương, Nghệ An": [
    "hồng sơn, đô lương, nghệ an",
    "hoofng sown, ddoo luwowng, ngheej an"
  ],
  "Hồng Sỹ, Hà Quảng, Cao Bằng": [
    "hồng sỹ, hà quảng, cao bằng",
    "hoofng syx, haf quarng, cao bawfng"
  ],
  "Hồng Thái, Bình Gia, Lạng Sơn": [
    "hồng thái, bình gia, lạng sơn",
    "hoofng thasi, bifnh gia, lajng sown"
  ],
  "Hồng Thái, Phú Xuyên, Hà Nội": [
    "hồng thái, phú xuyên, hà nội",
    "hoofng thasi, phus xuyeen, haf nooji"
  ],
  "Hộ Hải, Ninh Hải, Ninh Thuận": [
    "hộ hải, ninh hải, ninh thuận",
    "hooj hari, ninh hari, ninh thuaajn"
  ],
  "Hội Hợp, Vĩnh Yên, Vĩnh Phúc": [
    "hội hợp, vĩnh yên, vĩnh phúc",
    "hooji howjp, vixnh yeen, vixnh phusc"
  ],
  "Hội Xuân, Cai Lậy, Tiền Giang": [
    "hội xuân, cai lậy, tiền giang",
    "hooji xuaan, cai laajy, tieefn giang"
  ],
  "Hợp Châu, Tam Đảo, Vĩnh Phúc": [
    "hợp châu, tam đảo, vĩnh phúc",
    "howjp chaau, tam ddaro, vixnh phusc"
  ],
  "Hợp Hòa, Tam Dương, Vĩnh Phúc": [
    "hợp hòa, tam dương, vĩnh phúc",
    "howjp hofa, tam duwowng, vixnh phusc"
  ],
  "Hợp Hưng, Vụ Bản, Nam Định": [
    "hợp hưng, vụ bản, nam định",
    "howjp huwng, vuj barn, nam ddijnh"
  ],
  "Hợp Thành, Cao Lộc, Lạng Sơn": [
    "hợp thành, cao lộc, lạng sơn",
    "howjp thafnh, cao loojc, lajng sown"
  ],
  "Hợp Thành, Hòa Bình, Hoà Bình": [
    "hợp thành, hòa bình, hoà bình",
    "howjp thafnh, hofa bifnh, hoaf bifnh"
  ],
  "Hợp Thành, Yên Thành, Nghệ An": [
    "hợp thành, yên thành, nghệ an",
    "howjp thafnh, yeen thafnh, ngheej an"
  ],
  "Hợp Tiến, Mỹ Đức, Hà Nội": [
    "hợp tiến, mỹ đức, hà nội",
    "howjp tieesn, myx dduwsc, haf nooji"
  ],
  "Hợp Đức, Tân Yên, Bắc Giang": [
    "hợp đức, tân yên, bắc giang",
    "howjp dduwsc, taan yeen, bawsc giang"
  ],
  "Hữu Lân, Lộc Bình, Lạng Sơn": [
    "hữu lân, lộc bình, lạng sơn",
    "huwxu laan, loojc bifnh, lajng sown"
  ],
  "Hữu Lợi, Yên Thủy, Hoà Bình": [
    "hữu lợi, yên thủy, hoà bình",
    "huwxu lowji, yeen thury, hoaf bifnh"
  ],
  "Hữu Nghị, Hòa Bình, Hoà Bình": [
    "hữu nghị, hòa bình, hoà bình",
    "huwxu nghij, hofa bifnh, hoaf bifnh"
  ],
  "Hữu Văn, Chương Mỹ, Hà Nội": [
    "hữu văn, chương mỹ, hà nội",
    "huwxu vawn, chuwowng myx, haf nooji"
  ],
  "Jơ Ngây, Đông Giang, Quảng Nam": [
    "jơ ngây, đông giang, quảng nam",
    "jow ngaay, ddoong giang, quarng nam"
  ],
  "Ka Đô, Đơn Dương, Lâm Đồng": [
    "ka đô, đơn dương, lâm đồng",
    "ka ddoo, ddown duwowng, laam ddoofng"
  ],
  "Khoan Dụ, Lạc Thủy, Hoà Bình": [
    "khoan dụ, lạc thủy, hoà bình",
    "khoan duj, lajc thury, hoaf bifnh"
  ],
  "Khuê Trung, Cẩm Lệ, Đà Nẵng": [
    "khuê trung, cẩm lệ, đà nẵng",
    "khuee trung, caarm leej, ddaf nawxng"
  ],
  "Khuôn Hà, Lâm Bình, Tuyên Quang": [
    "khuôn hà, lâm bình, tuyên quang",
    "khuoon haf, laam bifnh, tuyeen quang"
  ],
  "Khám Lạng, Lục Nam, Bắc Giang": [
    "khám lạng, lục nam, bắc giang",
    "khasm lajng, lujc nam, bawsc giang"
  ],
  "Khánh Dương, Yên Mô, Ninh Bình": [
    "khánh dương, yên mô, ninh bình",
    "khasnh duwowng, yeen moo, ninh bifnh"
  ],
  "Khánh Hòa, Yên Khánh, Ninh Bình": [
    "khánh hòa, yên khánh, ninh bình",
    "khasnh hofa, yeen khasnh, ninh bifnh"
  ],
  "Khánh Phú, Yên Khánh, Ninh Bình": [
    "khánh phú, yên khánh, ninh bình",
    "khasnh phus, yeen khasnh, ninh bifnh"
  ],
  "Khánh Thịnh, Yên Mô, Ninh Bình": [
    "khánh thịnh, yên mô, ninh bình",
    "khasnh thijnh, yeen moo, ninh bifnh"
  ],
  "Khánh Vân, Yên Khánh, Ninh Bình": [
    "khánh vân, yên khánh, ninh bình",
    "khasnh vaan, yeen khasnh, ninh bifnh"
  ],
  "Khâm Thiên, Đống Đa, Hà Nội": [
    "khâm thiên, đống đa, hà nội",
    "khaam thieen, ddoosng dda, haf nooji"
  ],
  "Khúc Xuyên, Bắc Ninh, Bắc Ninh": [
    "khúc xuyên, bắc ninh, bắc ninh",
    "khusc xuyeen, bawsc ninh, bawsc ninh"
  ],
  "Khương Mai, Thanh Xuân, Hà Nội": [
    "khương mai, thanh xuân, hà nội",
    "khuwowng mai, thanh xuaan, haf nooji"
  ],
  "Khổng Lào, Phong Thổ, Lai Châu": [
    "khổng lào, phong thổ, lai châu",
    "khoorng lafo, phong thoor, lai chaau"
  ],
  "Kim Bình, Chiêm Hóa, Tuyên Quang": [
    "kim bình, chiêm hóa, tuyên quang",
    "kim bifnh, chieem hosa, tuyeen quang"
  ],
  "Kim Hóa, Tuyên Hóa, Quảng Bình": [
    "kim hóa, tuyên hóa, quảng bình",
    "kim hosa, tuyeen hosa, quarng bifnh"
  ],
  "Kim Liên, Kim Thành, Hải Dương": [
    "kim liên, kim thành, hải dương",
    "kim lieen, kim thafnh, hari duwowng"
  ],
  "Kim Long, Huế, Thừa Thiên Huế": [
    "kim long, huế, thừa thiên huế",
    "kim long, huees, thuwfa thieen huees"
  ],
  "Kim Phú, Tuyên Quang, Tuyên Quang": [
    "kim phú, tuyên quang, tuyên quang",
    "kim phus, tuyeen quang, tuyeen quang"
  ],
  "Kim Sơn, Châu Thành, Tiền Giang": [
    "kim sơn, châu thành, tiền giang",
    "kim sown, chaau thafnh, tieefn giang"
  ],
  "Kim Thượng, Tân Sơn, Phú Thọ": [
    "kim thượng, tân sơn, phú thọ",
    "kim thuwowjng, taan sown, phus thoj"
  ],
  "Kim Tân, Thạch Thành, Thanh Hóa": [
    "kim tân, thạch thành, thanh hóa",
    "kim taan, thajch thafnh, thanh hosa"
  ],
  "Kim Xá, Vĩnh Tường, Vĩnh Phúc": [
    "kim xá, vĩnh tường, vĩnh phúc",
    "kim xas, vixnh tuwowfng, vixnh phusc"
  ],
  "Kim Đường, Ứng Hòa, Hà Nội": [
    "kim đường, ứng hòa, hà nội",
    "kim dduwowfng, uwsng hofa, haf nooji"
  ],
  "Kiên Lao, Lục Ngạn, Bắc Giang": [
    "kiên lao, lục ngạn, bắc giang",
    "kieen lao, lujc ngajn, bawsc giang"
  ],
  "Kiên Thành, Trấn Yên, Yên Bái": [
    "kiên thành, trấn yên, yên bái",
    "kieen thafnh, traasn yeen, yeen basi"
  ],
  "Kiến Thành, Chợ Mới, An Giang": [
    "kiến thành, chợ mới, an giang",
    "kieesn thafnh, chowj mowsi, an giang"
  ],
  "Krông Jing, M'Đrắk, Đắk Lắk": [
    "krông jing, m'đrắk, đắk lắk",
    "kroong jing, m'ddrawsk, ddawsk lawsk"
  ],
  "Krông Na, Buôn Đôn, Đắk Lắk": [
    "krông na, buôn đôn, đắk lắk",
    "kroong na, buoon ddoon, ddawsk lawsk"
  ],
  "Ký Phú, Đại Từ, Thái Nguyên": [
    "ký phú, đại từ, thái nguyên",
    "kys phus, ddaji tuwf, thasi nguyeen"
  ],
  "Kế Thành, Kế Sách, Sóc Trăng": [
    "kế thành, kế sách, sóc trăng",
    "kees thafnh, kees sasch, sosc trawng"
  ],
  "Lai Hưng, Bàu Bàng, Bình Dương": [
    "lai hưng, bàu bàng, bình dương",
    "lai huwng, bafu bafng, bifnh duwowng"
  ],
  "Lai Uyên, Bàu Bàng, Bình Dương": [
    "lai uyên, bàu bàng, bình dương",
    "lai uyeen, bafu bafng, bifnh duwowng"
  ],
  "Lang Chánh, Lang Chánh, Thanh Hóa": [
    "lang chánh, lang chánh, thanh hóa",
    "lang chasnh, lang chasnh, thanh hosa"
  ],
  "Lao Và Chải, Yên Minh, Hà Giang": [
    "lao và chải, yên minh, hà giang",
    "lao vaf chari, yeen minh, haf giang"
  ],
  "Linh Phú, Chiêm Hóa, Tuyên Quang": [
    "linh phú, chiêm hóa, tuyên quang",
    "linh phus, chieem hosa, tuyeen quang"
  ],
  "Liên Bảo, Vĩnh Yên, Vĩnh Phúc": [
    "liên bảo, vĩnh yên, vĩnh phúc",
    "lieen baro, vixnh yeen, vixnh phusc"
  ],
  "Liên Bảo, Vụ Bản, Nam Định": [
    "liên bảo, vụ bản, nam định",
    "lieen baro, vuj barn, nam ddijnh"
  ],
  "Liên Châu, Yên Lạc, Vĩnh Phúc": [
    "liên châu, yên lạc, vĩnh phúc",
    "lieen chaau, yeen lajc, vixnh phusc"
  ],
  "Liên Hiệp, Bắc Quang, Hà Giang": [
    "liên hiệp, bắc quang, hà giang",
    "lieen hieejp, bawsc quang, haf giang"
  ],
  "Liên Hiệp, Hưng Hà, Thái Bình": [
    "liên hiệp, hưng hà, thái bình",
    "lieen hieejp, huwng haf, thasi bifnh"
  ],
  "Liên Hiệp, Phúc Thọ, Hà Nội": [
    "liên hiệp, phúc thọ, hà nội",
    "lieen hieejp, phusc thoj, haf nooji"
  ],
  "Liên Hoa, Đông Hưng, Thái Bình": [
    "liên hoa, đông hưng, thái bình",
    "lieen hoa, ddoong huwng, thasi bifnh"
  ],
  "Liên Hà, Đan Phượng, Hà Nội": [
    "liên hà, đan phượng, hà nội",
    "lieen haf, ddan phuwowjng, haf nooji"
  ],
  "Liên Khê, Khoái Châu, Hưng Yên": [
    "liên khê, khoái châu, hưng yên",
    "lieen khee, khoasi chaau, huwng yeen"
  ],
  "Liên Lộc, Hậu Lộc, Thanh Hóa": [
    "liên lộc, hậu lộc, thanh hóa",
    "lieen loojc, haaju loojc, thanh hosa"
  ],
  "Liên Nghĩa, Văn Giang, Hưng Yên": [
    "liên nghĩa, văn giang, hưng yên",
    "lieen nghixa, vawn giang, huwng yeen"
  ],
  "Liên Sơn, Lương Sơn, Hoà Bình": [
    "liên sơn, lương sơn, hoà bình",
    "lieen sown, luwowng sown, hoaf bifnh"
  ],
  "Liên Thành, Yên Thành, Nghệ An": [
    "liên thành, yên thành, nghệ an",
    "lieen thafnh, yeen thafnh, ngheej an"
  ],
  "Liêu Tú, Trần Đề, Sóc Trăng": [
    "liêu tú, trần đề, sóc trăng",
    "lieeu tus, traafn ddeef, sosc trawng"
  ],
  "Long Bình, Quận 9, Hồ Chí Minh": [
    "long bình, quận 9, hồ chí minh",
    "long bifnh, quaajn 9, hoof chis minh"
  ],
  "Long Chánh, Gò Công, Tiền Giang": [
    "long chánh, gò công, tiền giang",
    "long chasnh, gof coong, tieefn giang"
  ],
  "Long Hải, Phú Quí, Bình Thuận": [
    "long hải, phú quí, bình thuận",
    "long hari, phus quis, bifnh thuaajn"
  ],
  "Long Khánh, Cai Lậy, Tiền Giang": [
    "long khánh, cai lậy, tiền giang",
    "long khasnh, cai laajy, tieefn giang"
  ],
  "Long Khánh, Duyên Hải, Trà Vinh": [
    "long khánh, duyên hải, trà vinh",
    "long khasnh, duyeen hari, traf vinh"
  ],
  "Long Phước, Long Hồ, Vĩnh Long": [
    "long phước, long hồ, vĩnh long",
    "long phuwowsc, long hoof, vixnh long"
  ],
  "Long Phụng, Cần Giuộc, Long An": [
    "long phụng, cần giuộc, long an",
    "long phujng, caafn giuoojc, long an"
  ],
  "Long Sơn, Sơn Động, Bắc Giang": [
    "long sơn, sơn động, bắc giang",
    "long sown, sown ddoojng, bawsc giang"
  ],
  "Long Thuận, Bến Cầu, Tây Ninh": [
    "long thuận, bến cầu, tây ninh",
    "long thuaajn, beesn caafu, taay ninh"
  ],
  "Long Thành, Duyên Hải, Trà Vinh": [
    "long thành, duyên hải, trà vinh",
    "long thafnh, duyeen hari, traf vinh"
  ],
  "Long Thới, Tiểu Cần, Trà Vinh": [
    "long thới, tiểu cần, trà vinh",
    "long thowsi, tieeru caafn, traf vinh"
  ],
  "Long Trị A, Long Mỹ, Hậu Giang": [
    "long trị a, long mỹ, hậu giang",
    "long trij a, long myx, haaju giang"
  ],
  "Lái Hiếu, Ngã Bảy, Hậu Giang": [
    "lái hiếu, ngã bảy, hậu giang",
    "lasi hieesu, ngax bary, haaju giang"
  ],
  "Lê Hóa, Tuyên Hóa, Quảng Bình": [
    "lê hóa, tuyên hóa, quảng bình",
    "lee hosa, tuyeen hosa, quarng bifnh"
  ],
  "Lê Hồng Phong, Phủ Lý, Hà Nam": [
    "lê hồng phong, phủ lý, hà nam",
    "lee hoofng phong, phur lys, haf nam"
  ],
  "Lê Lợi, Thường Tín, Hà Nội": [
    "lê lợi, thường tín, hà nội",
    "lee lowji, thuwowfng tisn, haf nooji"
  ],
  "Lô Giang, Đông Hưng, Thái Bình": [
    "lô giang, đông hưng, thái bình",
    "loo giang, ddoong huwng, thasi bifnh"
  ],
  "Lý Học, Vĩnh Bảo, Hải Phòng": [
    "lý học, vĩnh bảo, hải phòng",
    "lys hojc, vixnh baro, hari phofng"
  ],
  "Lăng Thành, Yên Thành, Nghệ An": [
    "lăng thành, yên thành, nghệ an",
    "lawng thafnh, yeen thafnh, ngheej an"
  ],
  "Lũng Nặm, Hà Quảng, Cao Bằng": [
    "lũng nặm, hà quảng, cao bằng",
    "luxng nawjm, haf quarng, cao bawfng"
  ],
  "Lũng Phìn, Đồng Văn, Hà Giang": [
    "lũng phìn, đồng văn, hà giang",
    "luxng phifn, ddoofng vawn, haf giang"
  ],
  "Lương Can, Hà Quảng, Cao Bằng": [
    "lương can, hà quảng, cao bằng",
    "luwowng can, haf quarng, cao bawfng"
  ],
  "Lương Sơn, Yên Lập, Phú Thọ": [
    "lương sơn, yên lập, phú thọ",
    "luwowng sown, yeen laajp, phus thoj"
  ],
  "Lương Tâm, Long Mỹ, Hậu Giang": [
    "lương tâm, long mỹ, hậu giang",
    "luwowng taam, long myx, haaju giang"
  ],
  "Lạc Hòa, Vĩnh Châu, Sóc Trăng": [
    "lạc hòa, vĩnh châu, sóc trăng",
    "lajc hofa, vixnh chaau, sosc trawng"
  ],
  "Lạc Long, Kinh Môn, Hải Dương": [
    "lạc long, kinh môn, hải dương",
    "lajc long, kinh moon, hari duwowng"
  ],
  "Lại Sơn, Kiên Hải, Kiên Giang": [
    "lại sơn, kiên hải, kiên giang",
    "laji sown, kieen hari, kieen giang"
  ],
  "Lộ 25, Thống Nhất, Đồng Nai": [
    "lộ 25, thống nhất, đồng nai",
    "looj 25, thoosng nhaast, ddoofng nai"
  ],
  "Lộc An, Lộc Ninh, Bình Phước": [
    "lộc an, lộc ninh, bình phước",
    "loojc an, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Hòa, Nam Định, Nam Định": [
    "lộc hòa, nam định, nam định",
    "loojc hofa, nam ddijnh, nam ddijnh"
  ],
  "Lộc Hạ, Nam Định, Nam Định": [
    "lộc hạ, nam định, nam định",
    "loojc haj, nam ddijnh, nam ddijnh"
  ],
  "Lộc Lâm, Bảo Lâm, Lâm Đồng": [
    "lộc lâm, bảo lâm, lâm đồng",
    "loojc laam, baro laam, laam ddoofng"
  ],
  "Lộc Nga, Bảo Lộc, Lâm Đồng": [
    "lộc nga, bảo lộc, lâm đồng",
    "loojc nga, baro loojc, laam ddoofng"
  ],
  "Lộc Ninh, Hồng Dân, Bạc Liêu": [
    "lộc ninh, hồng dân, bạc liêu",
    "loojc ninh, hoofng daan, bajc lieeu"
  ],
  "Lộc Phú, Bảo Lâm, Lâm Đồng": [
    "lộc phú, bảo lâm, lâm đồng",
    "loojc phus, baro laam, laam ddoofng"
  ],
  "Lộc Tân, Bảo Lâm, Lâm Đồng": [
    "lộc tân, bảo lâm, lâm đồng",
    "loojc taan, baro laam, laam ddoofng"
  ],
  "Lợi Bác, Lộc Bình, Lạng Sơn": [
    "lợi bác, lộc bình, lạng sơn",
    "lowji basc, loojc bifnh, lajng sown"
  ],
  "Lục Ba, Đại Từ, Thái Nguyên": [
    "lục ba, đại từ, thái nguyên",
    "lujc ba, ddaji tuwf, thasi nguyeen"
  ],
  "Lực Hành, Yên Sơn, Tuyên Quang": [
    "lực hành, yên sơn, tuyên quang",
    "luwjc hafnh, yeen sown, tuyeen quang"
  ],
  "Mai Hóa, Tuyên Hóa, Quảng Bình": [
    "mai hóa, tuyên hóa, quảng bình",
    "mai hosa, tuyeen hosa, quarng bifnh"
  ],
  "Mai Sơn, Tương Dương, Nghệ An": [
    "mai sơn, tương dương, nghệ an",
    "mai sown, tuwowng duwowng, ngheej an"
  ],
  "Mai Đình, Hiệp Hòa, Bắc Giang": [
    "mai đình, hiệp hòa, bắc giang",
    "mai ddifnh, hieejp hofa, bawsc giang"
  ],
  "Mai Động, Kim Động, Hưng Yên": [
    "mai động, kim động, hưng yên",
    "mai ddoojng, kim ddoojng, huwng yeen"
  ],
  "Minh Diệu, Hoà Bình, Bạc Liêu": [
    "minh diệu, hoà bình, bạc liêu",
    "minh dieeju, hoaf bifnh, bajc lieeu"
  ],
  "Minh Hòa, Châu Thành, Kiên Giang": [
    "minh hòa, châu thành, kiên giang",
    "minh hofa, chaau thafnh, kieen giang"
  ],
  "Minh Khai, Hai Bà Trưng, Hà Nội": [
    "minh khai, hai bà trưng, hà nội",
    "minh khai, hai baf truwng, haf nooji"
  ],
  "Minh Khôi, Nông Cống, Thanh Hóa": [
    "minh khôi, nông cống, thanh hóa",
    "minh khooi, noong coosng, thanh hosa"
  ],
  "Minh Phú, Đông Hưng, Thái Bình": [
    "minh phú, đông hưng, thái bình",
    "minh phus, ddoong huwng, thasi bifnh"
  ],
  "Minh Tiến, Đoan Hùng, Phú Thọ": [
    "minh tiến, đoan hùng, phú thọ",
    "minh tieesn, ddoan hufng, phus thoj"
  ],
  "Minh Tâm, Nguyên Bình, Cao Bằng": [
    "minh tâm, nguyên bình, cao bằng",
    "minh taam, nguyeen bifnh, cao bawfng"
  ],
  "Minh Tân, Đông Hưng, Thái Bình": [
    "minh tân, đông hưng, thái bình",
    "minh taan, ddoong huwng, thasi bifnh"
  ],
  "Muổi Nọi, Thuận Châu, Sơn La": [
    "muổi nọi, thuận châu, sơn la",
    "muoori noji, thuaajn chaau, sown la"
  ],
  "Máy Tơ, Ngô Quyền, Hải Phòng": [
    "máy tơ, ngô quyền, hải phòng",
    "masy tow, ngoo quyeefn, hari phofng"
  ],
  "Mường Cang, Than Uyên, Lai Châu": [
    "mường cang, than uyên, lai châu",
    "muwowfng cang, than uyeen, lai chaau"
  ],
  "Mường Chùm, Mường La, Sơn La": [
    "mường chùm, mường la, sơn la",
    "muwowfng chufm, muwowfng la, sown la"
  ],
  "Mường Hoong, Đắk Glei, Kon Tum": [
    "mường hoong, đắk glei, kon tum",
    "muwowfng hoong, ddawsk glei, kon tum"
  ],
  "Mường Khoa, Tân Uyên, Lai Châu": [
    "mường khoa, tân uyên, lai châu",
    "muwowfng khoa, taan uyeen, lai chaau"
  ],
  "Mường Lạn, Sốp Cộp, Sơn La": [
    "mường lạn, sốp cộp, sơn la",
    "muwowfng lajn, soosp coojp, sown la"
  ],
  "Mường Mìn, Quan Sơn, Thanh Hóa": [
    "mường mìn, quan sơn, thanh hóa",
    "muwowfng mifn, quan sown, thanh hosa"
  ],
  "Mường Mít, Than Uyên, Lai Châu": [
    "mường mít, than uyên, lai châu",
    "muwowfng mist, than uyeen, lai chaau"
  ],
  "Mường Mô, Nậm Nhùn, Lai Châu": [
    "mường mô, nậm nhùn, lai châu",
    "muwowfng moo, naajm nhufn, lai chaau"
  ],
  "Mường Than, Than Uyên, Lai Châu": [
    "mường than, than uyên, lai châu",
    "muwowfng than, than uyeen, lai chaau"
  ],
  "Mẫu Sơn, Lộc Bình, Lạng Sơn": [
    "mẫu sơn, lộc bình, lạng sơn",
    "maaxu sown, loojc bifnh, lajng sown"
  ],
  "Mễ Trì, Nam Từ Liêm, Hà Nội": [
    "mễ trì, nam từ liêm, hà nội",
    "meex trif, nam tuwf lieem, haf nooji"
  ],
  "Mồ Sì San, Phong Thổ, Lai Châu": [
    "mồ sì san, phong thổ, lai châu",
    "moof sif san, phong thoor, lai chaau"
  ],
  "Mỹ Bằng, Yên Sơn, Tuyên Quang": [
    "mỹ bằng, yên sơn, tuyên quang",
    "myx bawfng, yeen sown, tuyeen quang"
  ],
  "Mỹ Chánh, Châu Thành, Trà Vinh": [
    "mỹ chánh, châu thành, trà vinh",
    "myx chasnh, chaau thafnh, traf vinh"
  ],
  "Mỹ Châu, Phù Mỹ, Bình Định": [
    "mỹ châu, phù mỹ, bình định",
    "myx chaau, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Hưng, Quảng Hòa, Cao Bằng": [
    "mỹ hưng, quảng hòa, cao bằng",
    "myx huwng, quarng hofa, cao bawfng"
  ],
  "Mỹ Hội, Cao Lãnh, Đồng Tháp": [
    "mỹ hội, cao lãnh, đồng tháp",
    "myx hooji, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Lương, Cái Bè, Tiền Giang": [
    "mỹ lương, cái bè, tiền giang",
    "myx luwowng, casi bef, tieefn giang"
  ],
  "Mỹ Lương, Yên Lập, Phú Thọ": [
    "mỹ lương, yên lập, phú thọ",
    "myx luwowng, yeen laajp, phus thoj"
  ],
  "Mỹ Lộc, Phù Mỹ, Bình Định": [
    "mỹ lộc, phù mỹ, bình định",
    "myx loojc, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Lợi A, Cái Bè, Tiền Giang": [
    "mỹ lợi a, cái bè, tiền giang",
    "myx lowji a, casi bef, tieefn giang"
  ],
  "Mỹ Lợi B, Cái Bè, Tiền Giang": [
    "mỹ lợi b, cái bè, tiền giang",
    "myx lowji b, casi bef, tieefn giang"
  ],
  "Mỹ Lợi, Phù Mỹ, Bình Định": [
    "mỹ lợi, phù mỹ, bình định",
    "myx lowji, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Ngãi, Cao Lãnh, Đồng Tháp": [
    "mỹ ngãi, cao lãnh, đồng tháp",
    "myx ngaxi, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Phong, Phù Mỹ, Bình Định": [
    "mỹ phong, phù mỹ, bình định",
    "myx phong, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Phước, Long Xuyên, An Giang": [
    "mỹ phước, long xuyên, an giang",
    "myx phuwowsc, long xuyeen, an giang"
  ],
  "Mỹ Phước, Mỹ Tú, Sóc Trăng": [
    "mỹ phước, mỹ tú, sóc trăng",
    "myx phuwowsc, myx tus, sosc trawng"
  ],
  "Mỹ Quang, Phù Mỹ, Bình Định": [
    "mỹ quang, phù mỹ, bình định",
    "myx quang, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Thuận, Bình Tân, Vĩnh Long": [
    "mỹ thuận, bình tân, vĩnh long",
    "myx thuaajn, bifnh taan, vixnh long"
  ],
  "Mỹ Thành, Mỹ Lộc, Nam Định": [
    "mỹ thành, mỹ lộc, nam định",
    "myx thafnh, myx loojc, nam ddijnh"
  ],
  "Mỹ Thái, Hòn Đất, Kiên Giang": [
    "mỹ thái, hòn đất, kiên giang",
    "myx thasi, hofn ddaast, kieen giang"
  ],
  "Mỹ Thọ, Cao Lãnh, Đồng Tháp": [
    "mỹ thọ, cao lãnh, đồng tháp",
    "myx thoj, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Thọ, Phù Mỹ, Bình Định": [
    "mỹ thọ, phù mỹ, bình định",
    "myx thoj, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Tiến, Mỹ Lộc, Nam Định": [
    "mỹ tiến, mỹ lộc, nam định",
    "myx tieesn, myx loojc, nam ddijnh"
  ],
  "Mỹ Trinh, Phù Mỹ, Bình Định": [
    "mỹ trinh, phù mỹ, bình định",
    "myx trinh, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Độ, Bắc Giang, Bắc Giang": [
    "mỹ độ, bắc giang, bắc giang",
    "myx ddooj, bawsc giang, bawsc giang"
  ],
  "NT Mộc Châu, Mộc Châu, Sơn La": [
    "nt mộc châu, mộc châu, sơn la",
    "nt moojc chaau, moojc chaau, sown la"
  ],
  "Na Cô Sa, Nậm Pồ, Điện Biên": [
    "na cô sa, nậm pồ, điện biên",
    "na coo sa, naajm poof, ddieejn bieen"
  ],
  "Na Dương, Lộc Bình, Lạng Sơn": [
    "na dương, lộc bình, lạng sơn",
    "na duwowng, loojc bifnh, lajng sown"
  ],
  "Nam Bình, Đắk Song, Đắk Nông": [
    "nam bình, đắk song, đắk nông",
    "nam bifnh, ddawsk song, ddawsk noong"
  ],
  "Nam Cao, Kiến Xương, Thái Bình": [
    "nam cao, kiến xương, thái bình",
    "nam cao, kieesn xuwowng, thasi bifnh"
  ],
  "Nam Chính, Nam Sách, Hải Dương": [
    "nam chính, nam sách, hải dương",
    "nam chisnh, nam sasch, hari duwowng"
  ],
  "Nam Dương, Nam Trực, Nam Định": [
    "nam dương, nam trực, nam định",
    "nam duwowng, nam truwjc, nam ddijnh"
  ],
  "Nam Hoà, Quảng Yên, Quảng Ninh": [
    "nam hoà, quảng yên, quảng ninh",
    "nam hoaf, quarng yeen, quarng ninh"
  ],
  "Nam Hưng, Tiên Lãng, Hải Phòng": [
    "nam hưng, tiên lãng, hải phòng",
    "nam huwng, tieen laxng, hari phofng"
  ],
  "Nam Hưng, Tiền Hải, Thái Bình": [
    "nam hưng, tiền hải, thái bình",
    "nam huwng, tieefn hari, thasi bifnh"
  ],
  "Nam Hải, Tiền Hải, Thái Bình": [
    "nam hải, tiền hải, thái bình",
    "nam hari, tieefn hari, thasi bifnh"
  ],
  "Nam Hồng, Nam Sách, Hải Dương": [
    "nam hồng, nam sách, hải dương",
    "nam hoofng, nam sasch, hari duwowng"
  ],
  "Nam Thanh, Tiền Hải, Thái Bình": [
    "nam thanh, tiền hải, thái bình",
    "nam thanh, tieefn hari, thasi bifnh"
  ],
  "Nam Thắng, Nam Trực, Nam Định": [
    "nam thắng, nam trực, nam định",
    "nam thawsng, nam truwjc, nam ddijnh"
  ],
  "Nam Trung, Tiền Hải, Thái Bình": [
    "nam trung, tiền hải, thái bình",
    "nam trung, tieefn hari, thasi bifnh"
  ],
  "Ngan Dừa, Hồng Dân, Bạc Liêu": [
    "ngan dừa, hồng dân, bạc liêu",
    "ngan duwfa, hoofng daan, bajc lieeu"
  ],
  "Nghi Phương, Nghi Lộc, Nghệ An": [
    "nghi phương, nghi lộc, nghệ an",
    "nghi phuwowng, nghi loojc, ngheej an"
  ],
  "Nghĩa An, Ninh Giang, Hải Dương": [
    "nghĩa an, ninh giang, hải dương",
    "nghixa an, ninh giang, hari duwowng"
  ],
  "Nghĩa Dân, Kim Động, Hưng Yên": [
    "nghĩa dân, kim động, hưng yên",
    "nghixa daan, kim ddoojng, huwng yeen"
  ],
  "Nghĩa Hiệp, Yên Mỹ, Hưng Yên": [
    "nghĩa hiệp, yên mỹ, hưng yên",
    "nghixa hieejp, yeen myx, huwng yeen"
  ],
  "Nghĩa Long, Nghĩa Đàn, Nghệ An": [
    "nghĩa long, nghĩa đàn, nghệ an",
    "nghixa long, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Lâm, Nghĩa Đàn, Nghệ An": [
    "nghĩa lâm, nghĩa đàn, nghệ an",
    "nghixa laam, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Lợi, Nghĩa Lộ, Yên Bái": [
    "nghĩa lợi, nghĩa lộ, yên bái",
    "nghixa lowji, nghixa looj, yeen basi"
  ],
  "Nghĩa Minh, Nghĩa Đàn, Nghệ An": [
    "nghĩa minh, nghĩa đàn, nghệ an",
    "nghixa minh, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Phú, Nghĩa Đàn, Nghệ An": [
    "nghĩa phú, nghĩa đàn, nghệ an",
    "nghixa phus, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Phúc, Nghĩa Lộ, Yên Bái": [
    "nghĩa phúc, nghĩa lộ, yên bái",
    "nghixa phusc, nghixa looj, yeen basi"
  ],
  "Nghĩa Sơn, Nghĩa Đàn, Nghệ An": [
    "nghĩa sơn, nghĩa đàn, nghệ an",
    "nghixa sown, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Tiến, Thái Hoà, Nghệ An": [
    "nghĩa tiến, thái hoà, nghệ an",
    "nghixa tieesn, thasi hoaf, ngheej an"
  ],
  "Nghĩa Trụ, Văn Giang, Hưng Yên": [
    "nghĩa trụ, văn giang, hưng yên",
    "nghixa truj, vawn giang, huwng yeen"
  ],
  "Nghĩa Tân, Cầu Giấy, Hà Nội": [
    "nghĩa tân, cầu giấy, hà nội",
    "nghixa taan, caafu giaasy, haf nooji"
  ],
  "Nghĩa Xuân, Quỳ Hợp, Nghệ An": [
    "nghĩa xuân, quỳ hợp, nghệ an",
    "nghixa xuaan, quyf howjp, ngheej an"
  ],
  "Nghĩa Yên, Nghĩa Đàn, Nghệ An": [
    "nghĩa yên, nghĩa đàn, nghệ an",
    "nghixa yeen, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Đô, Cầu Giấy, Hà Nội": [
    "nghĩa đô, cầu giấy, hà nội",
    "nghixa ddoo, caafu giaasy, haf nooji"
  ],
  "Nghĩa Đồng, Tân Kỳ, Nghệ An": [
    "nghĩa đồng, tân kỳ, nghệ an",
    "nghixa ddoofng, taan kyf, ngheej an"
  ],
  "Nguyên Bình, Tĩnh Gia, Thanh Hóa": [
    "nguyên bình, tĩnh gia, thanh hóa",
    "nguyeen bifnh, tixnh gia, thanh hosa"
  ],
  "Nguyễn Huân, Đầm Dơi, Cà Mau": [
    "nguyễn huân, đầm dơi, cà mau",
    "nguyeexn huaan, ddaafm dowi, caf mau"
  ],
  "Nguyễn Phúc, Yên Bái, Yên Bái": [
    "nguyễn phúc, yên bái, yên bái",
    "nguyeexn phusc, yeen basi, yeen basi"
  ],
  "Nguyễn Trãi, Hà Giang, Hà Giang": [
    "nguyễn trãi, hà giang, hà giang",
    "nguyeexn traxi, haf giang, haf giang"
  ],
  "Ngã Sáu, Châu Thành, Hậu Giang": [
    "ngã sáu, châu thành, hậu giang",
    "ngax sasu, chaau thafnh, haaju giang"
  ],
  "Ngãi Hùng, Tiểu Cần, Trà Vinh": [
    "ngãi hùng, tiểu cần, trà vinh",
    "ngaxi hufng, tieeru caafn, traf vinh"
  ],
  "Ngô Quyền, Tiên Lữ, Hưng Yên": [
    "ngô quyền, tiên lữ, hưng yên",
    "ngoo quyeefn, tieen luwx, huwng yeen"
  ],
  "Ngũ Hiệp, Cai Lậy, Tiền Giang": [
    "ngũ hiệp, cai lậy, tiền giang",
    "ngux hieejp, cai laajy, tieefn giang"
  ],
  "Ngọc Chiến, Mường La, Sơn La": [
    "ngọc chiến, mường la, sơn la",
    "ngojc chieesn, muwowfng la, sown la"
  ],
  "Ngọc Châu, Tân Yên, Bắc Giang": [
    "ngọc châu, tân yên, bắc giang",
    "ngojc chaau, taan yeen, bawsc giang"
  ],
  "Ngọc Chấn, Yên Bình, Yên Bái": [
    "ngọc chấn, yên bình, yên bái",
    "ngojc chaasn, yeen bifnh, yeen basi"
  ],
  "Ngọc Liệp, Quốc Oai, Hà Nội": [
    "ngọc liệp, quốc oai, hà nội",
    "ngojc lieejp, quoosc oai, haf nooji"
  ],
  "Ngọc Lập, Yên Lập, Phú Thọ": [
    "ngọc lập, yên lập, phú thọ",
    "ngojc laajp, yeen laajp, phus thoj"
  ],
  "Ngọc Quan, Đoan Hùng, Phú Thọ": [
    "ngọc quan, đoan hùng, phú thọ",
    "ngojc quan, ddoan hufng, phus thoj"
  ],
  "Ngọc Sơn, Kiến An, Hải Phòng": [
    "ngọc sơn, kiến an, hải phòng",
    "ngojc sown, kieesn an, hari phofng"
  ],
  "Ngọc Sơn, Quỳnh Lưu, Nghệ An": [
    "ngọc sơn, quỳnh lưu, nghệ an",
    "ngojc sown, quyfnh luwu, ngheej an"
  ],
  "Ngọc Sơn, Đô Lương, Nghệ An": [
    "ngọc sơn, đô lương, nghệ an",
    "ngojc sown, ddoo luwowng, ngheej an"
  ],
  "Ngọc Thụy, Long Biên, Hà Nội": [
    "ngọc thụy, long biên, hà nội",
    "ngojc thujy, long bieen, haf nooji"
  ],
  "Ngọc Tảo, Phúc Thọ, Hà Nội": [
    "ngọc tảo, phúc thọ, hà nội",
    "ngojc taro, phusc thoj, haf nooji"
  ],
  "Ngọc Xuân, Cao Bằng, Cao Bằng": [
    "ngọc xuân, cao bằng, cao bằng",
    "ngojc xuaan, cao bawfng, cao bawfng"
  ],
  "Ngổ Luông, Tân Lạc, Hoà Bình": [
    "ngổ luông, tân lạc, hoà bình",
    "ngoor luoong, taan lajc, hoaf bifnh"
  ],
  "Nham Biền, Yên Dũng, Bắc Giang": [
    "nham biền, yên dũng, bắc giang",
    "nham bieefn, yeen duxng, bawsc giang"
  ],
  "Nhân Chính, Thanh Xuân, Hà Nội": [
    "nhân chính, thanh xuân, hà nội",
    "nhaan chisnh, thanh xuaan, haf nooji"
  ],
  "Nhân Lý, Chiêm Hóa, Tuyên Quang": [
    "nhân lý, chiêm hóa, tuyên quang",
    "nhaan lys, chieem hosa, tuyeen quang"
  ],
  "Nhân Mục, Hàm Yên, Tuyên Quang": [
    "nhân mục, hàm yên, tuyên quang",
    "nhaan mujc, hafm yeen, tuyeen quang"
  ],
  "Nhân Nghĩa, Lạc Sơn, Hoà Bình": [
    "nhân nghĩa, lạc sơn, hoà bình",
    "nhaan nghixa, lajc sown, hoaf bifnh"
  ],
  "Nhân Thành, Yên Thành, Nghệ An": [
    "nhân thành, yên thành, nghệ an",
    "nhaan thafnh, yeen thafnh, ngheej an"
  ],
  "Nhân Thắng, Gia Bình, Bắc Ninh": [
    "nhân thắng, gia bình, bắc ninh",
    "nhaan thawsng, gia bifnh, bawsc ninh"
  ],
  "Nhân Đạo, Sông Lô, Vĩnh Phúc": [
    "nhân đạo, sông lô, vĩnh phúc",
    "nhaan ddajo, soong loo, vixnh phusc"
  ],
  "Nhơn Hưng, An Nhơn, Bình Định": [
    "nhơn hưng, an nhơn, bình định",
    "nhown huwng, an nhown, bifnh ddijnh"
  ],
  "Nhơn Hậu, An Nhơn, Bình Định": [
    "nhơn hậu, an nhơn, bình định",
    "nhown haaju, an nhown, bifnh ddijnh"
  ],
  "Nhơn Lộc, An Nhơn, Bình Định": [
    "nhơn lộc, an nhơn, bình định",
    "nhown loojc, an nhown, bifnh ddijnh"
  ],
  "Nhơn Phong, An Nhơn, Bình Định": [
    "nhơn phong, an nhơn, bình định",
    "nhown phong, an nhown, bifnh ddijnh"
  ],
  "Nhơn Phú, Qui Nhơn, Bình Định": [
    "nhơn phú, qui nhơn, bình định",
    "nhown phus, qui nhown, bifnh ddijnh"
  ],
  "Nhơn Phúc, An Nhơn, Bình Định": [
    "nhơn phúc, an nhơn, bình định",
    "nhown phusc, an nhown, bifnh ddijnh"
  ],
  "Nhơn Thọ, An Nhơn, Bình Định": [
    "nhơn thọ, an nhơn, bình định",
    "nhown thoj, an nhown, bifnh ddijnh"
  ],
  "Nhơn Ái, Phong Điền, Cần Thơ": [
    "nhơn ái, phong điền, cần thơ",
    "nhown asi, phong ddieefn, caafn thow"
  ],
  "Nhạc Kỳ, Văn Lãng, Lạng Sơn": [
    "nhạc kỳ, văn lãng, lạng sơn",
    "nhajc kyf, vawn laxng, lajng sown"
  ],
  "Nhạn Môn, Pác Nặm, Bắc Kạn": [
    "nhạn môn, pác nặm, bắc kạn",
    "nhajn moon, pasc nawjm, bawsc kajn"
  ],
  "Nhất Hòa, Bắc Sơn, Lạng Sơn": [
    "nhất hòa, bắc sơn, lạng sơn",
    "nhaast hofa, bawsc sown, lajng sown"
  ],
  "Nhị Hà, Thuận Nam, Ninh Thuận": [
    "nhị hà, thuận nam, ninh thuận",
    "nhij haf, thuaajn nam, ninh thuaajn"
  ],
  "Nhị Mỹ, Cao Lãnh, Đồng Tháp": [
    "nhị mỹ, cao lãnh, đồng tháp",
    "nhij myx, cao laxnh, ddoofng thasp"
  ],
  "Ninh Lai, Sơn Dương, Tuyên Quang": [
    "ninh lai, sơn dương, tuyên quang",
    "ninh lai, sown duwowng, tuyeen quang"
  ],
  "Ninh Phụng, Ninh Hòa, Khánh Hòa": [
    "ninh phụng, ninh hòa, khánh hòa",
    "ninh phujng, ninh hofa, khasnh hofa"
  ],
  "Ninh Sở, Thường Tín, Hà Nội": [
    "ninh sở, thường tín, hà nội",
    "ninh sowr, thuwowfng tisn, haf nooji"
  ],
  "Ninh Xá, Thuận Thành, Bắc Ninh": [
    "ninh xá, thuận thành, bắc ninh",
    "ninh xas, thuaajn thafnh, bawsc ninh"
  ],
  "Nà Khương, Quang Bình, Hà Giang": [
    "nà khương, quang bình, hà giang",
    "naf khuwowng, quang bifnh, haf giang"
  ],
  "Nông Hạ, Chợ Mới, Bắc Kạn": [
    "nông hạ, chợ mới, bắc kạn",
    "noong haj, chowj mowsi, bawsc kajn"
  ],
  "Nông Trang, Việt Trì, Phú Thọ": [
    "nông trang, việt trì, phú thọ",
    "noong trang, vieejt trif, phus thoj"
  ],
  "Nậm Giải, Quế Phong, Nghệ An": [
    "nậm giải, quế phong, nghệ an",
    "naajm giari, quees phong, ngheej an"
  ],
  "Nậm Tin, Nậm Pồ, Điện Biên": [
    "nậm tin, nậm pồ, điện biên",
    "naajm tin, naajm poof, ddieejn bieen"
  ],
  "Nội Thôn, Hà Quảng, Cao Bằng": [
    "nội thôn, hà quảng, cao bằng",
    "nooji thoon, haf quarng, cao bawfng"
  ],
  "Pa Ham, Mường Chà, Điện Biên": [
    "pa ham, mường chà, điện biên",
    "pa ham, muwowfng chaf, ddieejn bieen"
  ],
  "Pa Vây Sử, Phong Thổ, Lai Châu": [
    "pa vây sử, phong thổ, lai châu",
    "pa vaay suwr, phong thoor, lai chaau"
  ],
  "Phan Dũng, Tuy Phong, Bình Thuận": [
    "phan dũng, tuy phong, bình thuận",
    "phan duxng, tuy phong, bifnh thuaajn"
  ],
  "Phan Sào Nam, Phù Cừ, Hưng Yên": [
    "phan sào nam, phù cừ, hưng yên",
    "phan safo nam, phuf cuwf, huwng yeen"
  ],
  "Phi Liêng, Đam Rông, Lâm Đồng": [
    "phi liêng, đam rông, lâm đồng",
    "phi lieeng, ddam roong, laam ddoofng"
  ],
  "Phi Thông, Rạch Giá, Kiên Giang": [
    "phi thông, rạch giá, kiên giang",
    "phi thoong, rajch gias, kieen giang"
  ],
  "Phiêng Luông, Bắc Mê, Hà Giang": [
    "phiêng luông, bắc mê, hà giang",
    "phieeng luoong, bawsc mee, haf giang"
  ],
  "Phiêng Luông, Mộc Châu, Sơn La": [
    "phiêng luông, mộc châu, sơn la",
    "phieeng luoong, moojc chaau, sown la"
  ],
  "Phong Bình, Gio Linh, Quảng Trị": [
    "phong bình, gio linh, quảng trị",
    "phong bifnh, gio linh, quarng trij"
  ],
  "Phong Dụ, Tiên Yên, Quảng Ninh": [
    "phong dụ, tiên yên, quảng ninh",
    "phong duj, tieen yeen, quarng ninh"
  ],
  "Phong Lộc, Hậu Lộc, Thanh Hóa": [
    "phong lộc, hậu lộc, thanh hóa",
    "phong loojc, haaju loojc, thanh hosa"
  ],
  "Phong Mỹ, Cao Lãnh, Đồng Tháp": [
    "phong mỹ, cao lãnh, đồng tháp",
    "phong myx, cao laxnh, ddoofng thasp"
  ],
  "Phong Niên, Bảo Thắng, Lào Cai": [
    "phong niên, bảo thắng, lào cai",
    "phong nieen, baro thawsng, lafo cai"
  ],
  "Phong Nẫm, Kế Sách, Sóc Trăng": [
    "phong nẫm, kế sách, sóc trăng",
    "phong naaxm, kees sasch, sosc trawng"
  ],
  "Phong Phú, Tuy Phong, Bình Thuận": [
    "phong phú, tuy phong, bình thuận",
    "phong phus, tuy phong, bifnh thuaajn"
  ],
  "Phong Sơn, Cẩm Thủy, Thanh Hóa": [
    "phong sơn, cẩm thủy, thanh hóa",
    "phong sown, caarm thury, thanh hosa"
  ],
  "Phong Thạnh, Giá Rai, Bạc Liêu": [
    "phong thạnh, giá rai, bạc liêu",
    "phong thajnh, gias rai, bajc lieeu"
  ],
  "Phình Hồ, Trạm Tấu, Yên Bái": [
    "phình hồ, trạm tấu, yên bái",
    "phifnh hoof, trajm taasu, yeen basi"
  ],
  "Phó Bảng, Đồng Văn, Hà Giang": [
    "phó bảng, đồng văn, hà giang",
    "phos barng, ddoofng vawn, haf giang"
  ],
  "Phù Liễn, Kiến An, Hải Phòng": [
    "phù liễn, kiến an, hải phòng",
    "phuf lieexn, kieesn an, hari phofng"
  ],
  "Phú Bình, Long Khánh, Đồng Nai": [
    "phú bình, long khánh, đồng nai",
    "phus bifnh, long khasnh, ddoofng nai"
  ],
  "Phú Hữu, Quận 9, Hồ Chí Minh": [
    "phú hữu, quận 9, hồ chí minh",
    "phus huwxu, quaajn 9, hoof chis minh"
  ],
  "Phú Khánh, Thạnh Phú, Bến Tre": [
    "phú khánh, thạnh phú, bến tre",
    "phus khasnh, thajnh phus, beesn tre"
  ],
  "Phú Lạc, Tuy Phong, Bình Thuận": [
    "phú lạc, tuy phong, bình thuận",
    "phus lajc, tuy phong, bifnh thuaajn"
  ],
  "Phú Mỹ, Giang Thành, Kiên Giang": [
    "phú mỹ, giang thành, kiên giang",
    "phus myx, giang thafnh, kieen giang"
  ],
  "Phú Nhuận, Như Thanh, Thanh Hóa": [
    "phú nhuận, như thanh, thanh hóa",
    "phus nhuaajn, nhuw thanh, thanh hosa"
  ],
  "Phú Phong, Tây Sơn, Bình Định": [
    "phú phong, tây sơn, bình định",
    "phus phong, taay sown, bifnh ddijnh"
  ],
  "Phú Phụng, Chợ Lách, Bến Tre": [
    "phú phụng, chợ lách, bến tre",
    "phus phujng, chowj lasch, beesn tre"
  ],
  "Phú Thuận, Thoại Sơn, An Giang": [
    "phú thuận, thoại sơn, an giang",
    "phus thuaajn, thoaji sown, an giang"
  ],
  "Phú Thượng, Tây Hồ, Hà Nội": [
    "phú thượng, tây hồ, hà nội",
    "phus thuwowjng, taay hoof, haf nooji"
  ],
  "Phú Thịnh, Phú Ninh, Quảng Nam": [
    "phú thịnh, phú ninh, quảng nam",
    "phus thijnh, phus ninh, quarng nam"
  ],
  "Phú Thịnh, Tân Phú, Đồng Nai": [
    "phú thịnh, tân phú, đồng nai",
    "phus thijnh, taan phus, ddoofng nai"
  ],
  "Phú Thọ, Tam Nông, Đồng Tháp": [
    "phú thọ, tam nông, đồng tháp",
    "phus thoj, tam noong, ddoofng thasp"
  ],
  "Phú Thứ, Kinh Môn, Hải Dương": [
    "phú thứ, kinh môn, hải dương",
    "phus thuws, kinh moon, hari duwowng"
  ],
  "Phú Tâm, Châu Thành, Sóc Trăng": [
    "phú tâm, châu thành, sóc trăng",
    "phus taam, chaau thafnh, sosc trawng"
  ],
  "Phú Tân, Châu Thành, Hậu Giang": [
    "phú tân, châu thành, hậu giang",
    "phus taan, chaau thafnh, haaju giang"
  ],
  "Phú Tân, Châu Thành, Sóc Trăng": [
    "phú tân, châu thành, sóc trăng",
    "phus taan, chaau thafnh, sosc trawng"
  ],
  "Phú Xuân, Nhà Bè, Hồ Chí Minh": [
    "phú xuân, nhà bè, hồ chí minh",
    "phus xuaan, nhaf bef, hoof chis minh"
  ],
  "Phú Xuân, Thái Bình, Thái Bình": [
    "phú xuân, thái bình, thái bình",
    "phus xuaan, thasi bifnh, thasi bifnh"
  ],
  "Phú Điền, Tân Phú, Đồng Nai": [
    "phú điền, tân phú, đồng nai",
    "phus ddieefn, taan phus, ddoofng nai"
  ],
  "Phú Đô, Nam Từ Liêm, Hà Nội": [
    "phú đô, nam từ liêm, hà nội",
    "phus ddoo, nam tuwf lieem, haf nooji"
  ],
  "Phú Đức, Châu Thành, Bến Tre": [
    "phú đức, châu thành, bến tre",
    "phus dduwsc, chaau thafnh, beesn tre"
  ],
  "Phúc Khánh, Hưng Hà, Thái Bình": [
    "phúc khánh, hưng hà, thái bình",
    "phusc khasnh, huwng haf, thasi bifnh"
  ],
  "Phúc Khánh, Yên Lập, Phú Thọ": [
    "phúc khánh, yên lập, phú thọ",
    "phusc khasnh, yeen laajp, phus thoj"
  ],
  "Phúc Thành, Ninh Bình, Ninh Bình": [
    "phúc thành, ninh bình, ninh bình",
    "phusc thafnh, ninh bifnh, ninh bifnh"
  ],
  "Phúc Thành, Yên Thành, Nghệ An": [
    "phúc thành, yên thành, nghệ an",
    "phusc thafnh, yeen thafnh, ngheej an"
  ],
  "Phúc Tiến, Phú Xuyên, Hà Nội": [
    "phúc tiến, phú xuyên, hà nội",
    "phusc tieesn, phus xuyeen, haf nooji"
  ],
  "Phúc Yên, Lâm Bình, Tuyên Quang": [
    "phúc yên, lâm bình, tuyên quang",
    "phusc yeen, laam bifnh, tuyeen quang"
  ],
  "Phúc Đồng, Long Biên, Hà Nội": [
    "phúc đồng, long biên, hà nội",
    "phusc ddoofng, long bieen, haf nooji"
  ],
  "Phăng Sô Lin, Sìn Hồ, Lai Châu": [
    "phăng sô lin, sìn hồ, lai châu",
    "phawng soo lin, sifn hoof, lai chaau"
  ],
  "Phương Mai, Đống Đa, Hà Nội": [
    "phương mai, đống đa, hà nội",
    "phuwowng mai, ddoosng dda, haf nooji"
  ],
  "Phương Trung, Thanh Oai, Hà Nội": [
    "phương trung, thanh oai, hà nội",
    "phuwowng trung, thanh oai, haf nooji"
  ],
  "Phương Độ, Hà Giang, Hà Giang": [
    "phương độ, hà giang, hà giang",
    "phuwowng ddooj, haf giang, haf giang"
  ],
  "Phước Hòa, Tam Kỳ, Quảng Nam": [
    "phước hòa, tam kỳ, quảng nam",
    "phuwowsc hofa, tam kyf, quarng nam"
  ],
  "Phước Hội, La Gi, Bình Thuận": [
    "phước hội, la gi, bình thuận",
    "phuwowsc hooji, la gi, bifnh thuaajn"
  ],
  "Phước Lý, Cần Giuộc, Long An": [
    "phước lý, cần giuộc, long an",
    "phuwowsc lys, caafn giuoojc, long an"
  ],
  "Phước Lộc, La Gi, Bình Thuận": [
    "phước lộc, la gi, bình thuận",
    "phuwowsc loojc, la gi, bifnh thuaajn"
  ],
  "Phước Lợi, Bến Lức, Long An": [
    "phước lợi, bến lức, long an",
    "phuwowsc lowji, beesn luwsc, long an"
  ],
  "Phước Thới, Ô Môn, Cần Thơ": [
    "phước thới, ô môn, cần thơ",
    "phuwowsc thowsi, oo moon, caafn thow"
  ],
  "Phường 1, Cai Lậy, Tiền Giang": [
    "phường 1, cai lậy, tiền giang",
    "phuwowfng 1, cai laajy, tieefn giang"
  ],
  "Phường 1, Duyên Hải, Trà Vinh": [
    "phường 1, duyên hải, trà vinh",
    "phuwowfng 1, duyeen hari, traf vinh"
  ],
  "Phường 1, Gò Công, Tiền Giang": [
    "phường 1, gò công, tiền giang",
    "phuwowfng 1, gof coong, tieefn giang"
  ],
  "Phường 1, Sa Đéc, Đồng Tháp": [
    "phường 1, sa đéc, đồng tháp",
    "phuwowfng 1, sa ddesc, ddoofng thasp"
  ],
  "Phường 10, Mỹ Tho, Tiền Giang": [
    "phường 10, mỹ tho, tiền giang",
    "phuwowfng 10, myx tho, tieefn giang"
  ],
  "Phường 2, Cai Lậy, Tiền Giang": [
    "phường 2, cai lậy, tiền giang",
    "phuwowfng 2, cai laajy, tieefn giang"
  ],
  "Phường 2, Duyên Hải, Trà Vinh": [
    "phường 2, duyên hải, trà vinh",
    "phuwowfng 2, duyeen hari, traf vinh"
  ],
  "Phường 2, Gò Công, Tiền Giang": [
    "phường 2, gò công, tiền giang",
    "phuwowfng 2, gof coong, tieefn giang"
  ],
  "Phường 2, Sa Đéc, Đồng Tháp": [
    "phường 2, sa đéc, đồng tháp",
    "phuwowfng 2, sa ddesc, ddoofng thasp"
  ],
  "Phường 3, Cai Lậy, Tiền Giang": [
    "phường 3, cai lậy, tiền giang",
    "phuwowfng 3, cai laajy, tieefn giang"
  ],
  "Phường 3, Gò Công, Tiền Giang": [
    "phường 3, gò công, tiền giang",
    "phuwowfng 3, gof coong, tieefn giang"
  ],
  "Phường 3, Sa Đéc, Đồng Tháp": [
    "phường 3, sa đéc, đồng tháp",
    "phuwowfng 3, sa ddesc, ddoofng thasp"
  ],
  "Phường 4, Cai Lậy, Tiền Giang": [
    "phường 4, cai lậy, tiền giang",
    "phuwowfng 4, cai laajy, tieefn giang"
  ],
  "Phường 4, Gò Công, Tiền Giang": [
    "phường 4, gò công, tiền giang",
    "phuwowfng 4, gof coong, tieefn giang"
  ],
  "Phường 4, Sa Đéc, Đồng Tháp": [
    "phường 4, sa đéc, đồng tháp",
    "phuwowfng 4, sa ddesc, ddoofng thasp"
  ],
  "Phường 5, Cai Lậy, Tiền Giang": [
    "phường 5, cai lậy, tiền giang",
    "phuwowfng 5, cai laajy, tieefn giang"
  ],
  "Phường 5, Gò Công, Tiền Giang": [
    "phường 5, gò công, tiền giang",
    "phuwowfng 5, gof coong, tieefn giang"
  ],
  "Phượng Mao, Quế Võ, Bắc Ninh": [
    "phượng mao, quế võ, bắc ninh",
    "phuwowjng mao, quees vox, bawsc ninh"
  ],
  "Phố Châu, Hương Sơn, Hà Tĩnh": [
    "phố châu, hương sơn, hà tĩnh",
    "phoos chaau, huwowng sown, haf tixnh"
  ],
  "Phổng Lái, Thuận Châu, Sơn La": [
    "phổng lái, thuận châu, sơn la",
    "phoorng lasi, thuaajn chaau, sown la"
  ],
  "Pố Lồ, Hoàng Su Phì, Hà Giang": [
    "pố lồ, hoàng su phì, hà giang",
    "poos loof, hoafng su phif, haf giang"
  ],
  "Quang Lộc, Hậu Lộc, Thanh Hóa": [
    "quang lộc, hậu lộc, thanh hóa",
    "quang loojc, haaju loojc, thanh hosa"
  ],
  "Quang Minh, Gia Lộc, Hải Dương": [
    "quang minh, gia lộc, hải dương",
    "quang minh, gia loojc, hari duwowng"
  ],
  "Quang Minh, Hiệp Hòa, Bắc Giang": [
    "quang minh, hiệp hòa, bắc giang",
    "quang minh, hieejp hofa, bawsc giang"
  ],
  "Quang Thành, Yên Thành, Nghệ An": [
    "quang thành, yên thành, nghệ an",
    "quang thafnh, yeen thafnh, ngheej an"
  ],
  "Quang Tiến, Hòa Bình, Hoà Bình": [
    "quang tiến, hòa bình, hoà bình",
    "quang tieesn, hofa bifnh, hoaf bifnh"
  ],
  "Quang Tiến, Tân Yên, Bắc Giang": [
    "quang tiến, tân yên, bắc giang",
    "quang tieesn, taan yeen, bawsc giang"
  ],
  "Quang Trung, Uông Bí, Quảng Ninh": [
    "quang trung, uông bí, quảng ninh",
    "quang trung, uoong bis, quarng ninh"
  ],
  "Quang Trung, Vụ Bản, Nam Định": [
    "quang trung, vụ bản, nam định",
    "quang trung, vuj barn, nam ddijnh"
  ],
  "Quang Vĩnh, Đức Thọ, Hà Tĩnh": [
    "quang vĩnh, đức thọ, hà tĩnh",
    "quang vixnh, dduwsc thoj, haf tixnh"
  ],
  "Quy Đạt, Minh Hóa, Quảng Bình": [
    "quy đạt, minh hóa, quảng bình",
    "quy ddajt, minh hosa, quarng bifnh"
  ],
  "Quyết Tiến, Lai Châu, Lai Châu": [
    "quyết tiến, lai châu, lai châu",
    "quyeest tieesn, lai chaau, lai chaau"
  ],
  "Quán Lào, Yên Định, Thanh Hóa": [
    "quán lào, yên định, thanh hóa",
    "quasn lafo, yeen ddijnh, thanh hosa"
  ],
  "Quán Trữ, Kiến An, Hải Phòng": [
    "quán trữ, kiến an, hải phòng",
    "quasn truwx, kieesn an, hari phofng"
  ],
  "Quí Lộc, Yên Định, Thanh Hóa": [
    "quí lộc, yên định, thanh hóa",
    "quis loojc, yeen ddijnh, thanh hosa"
  ],
  "Quý Sơn, Lục Ngạn, Bắc Giang": [
    "quý sơn, lục ngạn, bắc giang",
    "quys sown, lujc ngajn, bawsc giang"
  ],
  "Quảng An, Đầm Hà, Quảng Ninh": [
    "quảng an, đầm hà, quảng ninh",
    "quarng an, ddaafm haf, quarng ninh"
  ],
  "Quảng Cát, Thanh Hóa, Thanh Hóa": [
    "quảng cát, thanh hóa, thanh hóa",
    "quarng cast, thanh hosa, thanh hosa"
  ],
  "Quảng Hà, Hải Hà, Quảng Ninh": [
    "quảng hà, hải hà, quảng ninh",
    "quarng haf, hari haf, quarng ninh"
  ],
  "Quảng Lâm, Bảo Lâm, Cao Bằng": [
    "quảng lâm, bảo lâm, cao bằng",
    "quarng laam, baro laam, cao bawfng"
  ],
  "Quảng Minh, Sầm Sơn, Thanh Hóa": [
    "quảng minh, sầm sơn, thanh hóa",
    "quarng minh, saafm sown, thanh hosa"
  ],
  "Quảng Phú, Thanh Hóa, Thanh Hóa": [
    "quảng phú, thanh hóa, thanh hóa",
    "quarng phus, thanh hosa, thanh hosa"
  ],
  "Quảng Tâm, Thanh Hóa, Thanh Hóa": [
    "quảng tâm, thanh hóa, thanh hóa",
    "quarng taam, thanh hosa, thanh hosa"
  ],
  "Quảng Vinh, Sầm Sơn, Thanh Hóa": [
    "quảng vinh, sầm sơn, thanh hóa",
    "quarng vinh, saafm sown, thanh hosa"
  ],
  "Quế Châu, Quế Sơn, Quảng Nam": [
    "quế châu, quế sơn, quảng nam",
    "quees chaau, quees sown, quarng nam"
  ],
  "Quế Lộc, Nông Sơn, Quảng Nam": [
    "quế lộc, nông sơn, quảng nam",
    "quees loojc, noong sown, quarng nam"
  ],
  "Quế Phong, Quế Sơn, Quảng Nam": [
    "quế phong, quế sơn, quảng nam",
    "quees phong, quees sown, quarng nam"
  ],
  "Quế Trung, Nông Sơn, Quảng Nam": [
    "quế trung, nông sơn, quảng nam",
    "quees trung, noong sown, quarng nam"
  ],
  "Quốc Tuấn, An Lão, Hải Phòng": [
    "quốc tuấn, an lão, hải phòng",
    "quoosc tuaasn, an laxo, hari phofng"
  ],
  "Quỳnh Bá, Quỳnh Lưu, Nghệ An": [
    "quỳnh bá, quỳnh lưu, nghệ an",
    "quyfnh bas, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Hoa, Quỳnh Lưu, Nghệ An": [
    "quỳnh hoa, quỳnh lưu, nghệ an",
    "quyfnh hoa, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Liên, Hoàng Mai, Nghệ An": [
    "quỳnh liên, hoàng mai, nghệ an",
    "quyfnh lieen, hoafng mai, ngheej an"
  ],
  "Quỳnh Lập, Hoàng Mai, Nghệ An": [
    "quỳnh lập, hoàng mai, nghệ an",
    "quyfnh laajp, hoafng mai, ngheej an"
  ],
  "Quỳnh Lộc, Hoàng Mai, Nghệ An": [
    "quỳnh lộc, hoàng mai, nghệ an",
    "quyfnh loojc, hoafng mai, ngheej an"
  ],
  "Quỳnh Tam, Quỳnh Lưu, Nghệ An": [
    "quỳnh tam, quỳnh lưu, nghệ an",
    "quyfnh tam, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Trang, Hoàng Mai, Nghệ An": [
    "quỳnh trang, hoàng mai, nghệ an",
    "quyfnh trang, hoafng mai, ngheej an"
  ],
  "Quỳnh Xuân, Hoàng Mai, Nghệ An": [
    "quỳnh xuân, hoàng mai, nghệ an",
    "quyfnh xuaan, hoafng mai, ngheej an"
  ],
  "Rạch Gốc, Ngọc Hiển, Cà Mau": [
    "rạch gốc, ngọc hiển, cà mau",
    "rajch goosc, ngojc hieern, caf mau"
  ],
  "Sen Phương, Phúc Thọ, Hà Nội": [
    "sen phương, phúc thọ, hà nội",
    "sen phuwowng, phusc thoj, haf nooji"
  ],
  "Song Phụng, Long Phú, Sóc Trăng": [
    "song phụng, long phú, sóc trăng",
    "song phujng, long phus, sosc trawng"
  ],
  "Suối Cao, Xuân Lộc, Đồng Nai": [
    "suối cao, xuân lộc, đồng nai",
    "suoosi cao, xuaan loojc, ddoofng nai"
  ],
  "Suối Tre, Long Khánh, Đồng Nai": [
    "suối tre, long khánh, đồng nai",
    "suoosi tre, long khasnh, ddoofng nai"
  ],
  "Sà Dề Phìn, Sìn Hồ, Lai Châu": [
    "sà dề phìn, sìn hồ, lai châu",
    "saf deef phifn, sifn hoof, lai chaau"
  ],
  "Sàn Viên, Lộc Bình, Lạng Sơn": [
    "sàn viên, lộc bình, lạng sơn",
    "safn vieen, loojc bifnh, lajng sown"
  ],
  "Sóc Đăng, Đoan Hùng, Phú Thọ": [
    "sóc đăng, đoan hùng, phú thọ",
    "sosc ddawng, ddoan hufng, phus thoj"
  ],
  "Sông Bằng, Cao Bằng, Cao Bằng": [
    "sông bằng, cao bằng, cao bằng",
    "soong bawfng, cao bawfng, cao bawfng"
  ],
  "Sông Hiến, Cao Bằng, Cao Bằng": [
    "sông hiến, cao bằng, cao bằng",
    "soong hieesn, cao bawfng, cao bawfng"
  ],
  "Sông Phan, Hàm Tân, Bình Thuận": [
    "sông phan, hàm tân, bình thuận",
    "soong phan, hafm taan, bifnh thuaajn"
  ],
  "Sông Thao, Trảng Bom, Đồng Nai": [
    "sông thao, trảng bom, đồng nai",
    "soong thao, trarng bom, ddoofng nai"
  ],
  "Sơn Bình, Hòn Đất, Kiên Giang": [
    "sơn bình, hòn đất, kiên giang",
    "sown bifnh, hofn ddaast, kieen giang"
  ],
  "Sơn Bình, Khánh Sơn, Khánh Hòa": [
    "sơn bình, khánh sơn, khánh hòa",
    "sown bifnh, khasnh sown, khasnh hofa"
  ],
  "Sơn Bình, Tam Đường, Lai Châu": [
    "sơn bình, tam đường, lai châu",
    "sown bifnh, tam dduwowfng, lai chaau"
  ],
  "Sơn Bằng, Hương Sơn, Hà Tĩnh": [
    "sơn bằng, hương sơn, hà tĩnh",
    "sown bawfng, huwowng sown, haf tixnh"
  ],
  "Sơn Hồng, Hương Sơn, Hà Tĩnh": [
    "sơn hồng, hương sơn, hà tĩnh",
    "sown hoofng, huwowng sown, haf tixnh"
  ],
  "Sơn Kiên, Hòn Đất, Kiên Giang": [
    "sơn kiên, hòn đất, kiên giang",
    "sown kieen, hofn ddaast, kieen giang"
  ],
  "Sơn Kỳ, Tân Phú, Hồ Chí Minh": [
    "sơn kỳ, tân phú, hồ chí minh",
    "sown kyf, taan phus, hoof chis minh"
  ],
  "Sơn Liên, Sơn Tây, Quảng Ngãi": [
    "sơn liên, sơn tây, quảng ngãi",
    "sown lieen, sown taay, quarng ngaxi"
  ],
  "Sơn Lôi, Bình Xuyên, Vĩnh Phúc": [
    "sơn lôi, bình xuyên, vĩnh phúc",
    "sown looi, bifnh xuyeen, vixnh phusc"
  ],
  "Sơn Lương, Văn Chấn, Yên Bái": [
    "sơn lương, văn chấn, yên bái",
    "sown luwowng, vawn chaasn, yeen basi"
  ],
  "Sơn Lập, Sơn Tây, Quảng Ngãi": [
    "sơn lập, sơn tây, quảng ngãi",
    "sown laajp, sown taay, quarng ngaxi"
  ],
  "Sơn Nam, Sơn Dương, Tuyên Quang": [
    "sơn nam, sơn dương, tuyên quang",
    "sown nam, sown duwowng, tuyeen quang"
  ],
  "Sơn Thành, Sơn Hà, Quảng Ngãi": [
    "sơn thành, sơn hà, quảng ngãi",
    "sown thafnh, sown haf, quarng ngaxi"
  ],
  "Sơn Thịnh, Văn Chấn, Yên Bái": [
    "sơn thịnh, văn chấn, yên bái",
    "sown thijnh, vawn chaasn, yeen basi"
  ],
  "Sơn Thủy, Sơn Hà, Quảng Ngãi": [
    "sơn thủy, sơn hà, quảng ngãi",
    "sown thury, sown haf, quarng ngaxi"
  ],
  "Sơn Tiến, Hương Sơn, Hà Tĩnh": [
    "sơn tiến, hương sơn, hà tĩnh",
    "sown tieesn, huwowng sown, haf tixnh"
  ],
  "Sơn Trung, Khánh Sơn, Khánh Hòa": [
    "sơn trung, khánh sơn, khánh hòa",
    "sown trung, khasnh sown, khasnh hofa"
  ],
  "Sơn Định, Chợ Lách, Bến Tre": [
    "sơn định, chợ lách, bến tre",
    "sown ddijnh, chowj lasch, beesn tre"
  ],
  "Tam Chung, Mường Lát, Thanh Hóa": [
    "tam chung, mường lát, thanh hóa",
    "tam chung, muwowfng last, thanh hosa"
  ],
  "Tam Giang Đông, Năm Căn, Cà Mau": [
    "tam giang đông, năm căn, cà mau",
    "tam giang ddoong, nawm cawn, caf mau"
  ],
  "Tam Hiệp, Núi Thành, Quảng Nam": [
    "tam hiệp, núi thành, quảng nam",
    "tam hieejp, nusi thafnh, quarng nam"
  ],
  "Tam Hợp, Bình Xuyên, Vĩnh Phúc": [
    "tam hợp, bình xuyên, vĩnh phúc",
    "tam howjp, bifnh xuyeen, vixnh phusc"
  ],
  "Tam Lập, Phú Giáo, Bình Dương": [
    "tam lập, phú giáo, bình dương",
    "tam laajp, phus giaso, bifnh duwowng"
  ],
  "Tam Nghĩa, Núi Thành, Quảng Nam": [
    "tam nghĩa, núi thành, quảng nam",
    "tam nghixa, nusi thafnh, quarng nam"
  ],
  "Tam Phước, Phú Ninh, Quảng Nam": [
    "tam phước, phú ninh, quảng nam",
    "tam phuwowsc, phus ninh, quarng nam"
  ],
  "Tam Thuận, Thanh Khê, Đà Nẵng": [
    "tam thuận, thanh khê, đà nẵng",
    "tam thuaajn, thanh khee, ddaf nawxng"
  ],
  "Tam Tiến, Núi Thành, Quảng Nam": [
    "tam tiến, núi thành, quảng nam",
    "tam tieesn, nusi thafnh, quarng nam"
  ],
  "Tham Đôn, Mỹ Xuyên, Sóc Trăng": [
    "tham đôn, mỹ xuyên, sóc trăng",
    "tham ddoon, myx xuyeen, sosc trawng"
  ],
  "Thanh Bình, Biên Hòa, Đồng Nai": [
    "thanh bình, biên hòa, đồng nai",
    "thanh bifnh, bieen hofa, ddoofng nai"
  ],
  "Thanh Chi, Thanh Chương, Nghệ An": [
    "thanh chi, thanh chương, nghệ an",
    "thanh chi, thanh chuwowng, ngheej an"
  ],
  "Thanh Hà, Thanh Chương, Nghệ An": [
    "thanh hà, thanh chương, nghệ an",
    "thanh haf, thanh chuwowng, ngheej an"
  ],
  "Thanh Khê, Thanh Hà, Hải Dương": [
    "thanh khê, thanh hà, hải dương",
    "thanh khee, thanh haf, hari duwowng"
  ],
  "Thanh Lang, Thanh Hà, Hải Dương": [
    "thanh lang, thanh hà, hải dương",
    "thanh lang, thanh haf, hari duwowng"
  ],
  "Thanh Mai, Thanh Chương, Nghệ An": [
    "thanh mai, thanh chương, nghệ an",
    "thanh mai, thanh chuwowng, ngheej an"
  ],
  "Thanh Nho, Thanh Chương, Nghệ An": [
    "thanh nho, thanh chương, nghệ an",
    "thanh nho, thanh chuwowng, ngheej an"
  ],
  "Thanh Phước, Gò Dầu, Tây Ninh": [
    "thanh phước, gò dầu, tây ninh",
    "thanh phuwowsc, gof daafu, taay ninh"
  ],
  "Thanh Sơn, Hữu Lũng, Lạng Sơn": [
    "thanh sơn, hữu lũng, lạng sơn",
    "thanh sown, huwxu luxng, lajng sown"
  ],
  "Thanh Sơn, Lương Sơn, Hoà Bình": [
    "thanh sơn, lương sơn, hoà bình",
    "thanh sown, luwowng sown, hoaf bifnh"
  ],
  "Thanh Sơn, Thanh Hà, Hải Dương": [
    "thanh sơn, thanh hà, hải dương",
    "thanh sown, thanh haf, hari duwowng"
  ],
  "Thanh Thủy, Vị Xuyên, Hà Giang": [
    "thanh thủy, vị xuyên, hà giang",
    "thanh thury, vij xuyeen, haf giang"
  ],
  "Thanh Tương, Na Hang, Tuyên Quang": [
    "thanh tương, na hang, tuyên quang",
    "thanh tuwowng, na hang, tuyeen quang"
  ],
  "Thanh Vân, Hiệp Hòa, Bắc Giang": [
    "thanh vân, hiệp hòa, bắc giang",
    "thanh vaan, hieejp hofa, bawsc giang"
  ],
  "Thanh Vân, Tam Dương, Vĩnh Phúc": [
    "thanh vân, tam dương, vĩnh phúc",
    "thanh vaan, tam duwowng, vixnh phusc"
  ],
  "Thanh Đức, Vị Xuyên, Hà Giang": [
    "thanh đức, vị xuyên, hà giang",
    "thanh dduwsc, vij xuyeen, haf giang"
  ],
  "Thiện An, Buôn Hồ, Đắk Lắk": [
    "thiện an, buôn hồ, đắk lắk",
    "thieejn an, buoon hoof, ddawsk lawsk"
  ],
  "Thiện Hòa, Bình Gia, Lạng Sơn": [
    "thiện hòa, bình gia, lạng sơn",
    "thieejn hofa, bifnh gia, lajng sown"
  ],
  "Thiện Long, Bình Gia, Lạng Sơn": [
    "thiện long, bình gia, lạng sơn",
    "thieejn long, bifnh gia, lajng sown"
  ],
  "Thiện Trí, Cái Bè, Tiền Giang": [
    "thiện trí, cái bè, tiền giang",
    "thieejn tris, casi bef, tieefn giang"
  ],
  "Thiệu Vân, Thanh Hóa, Thanh Hóa": [
    "thiệu vân, thanh hóa, thanh hóa",
    "thieeju vaan, thanh hosa, thanh hosa"
  ],
  "Thuận An, Thốt Nốt, Cần Thơ": [
    "thuận an, thốt nốt, cần thơ",
    "thuaajn an, thoost noost, caafn thow"
  ],
  "Thuận An, Đắk Mil, Đắk Nông": [
    "thuận an, đắk mil, đắk nông",
    "thuaajn an, ddawsk mil, ddawsk noong"
  ],
  "Thuận Bình, Thạnh Hóa, Long An": [
    "thuận bình, thạnh hóa, long an",
    "thuaajn bifnh, thajnh hosa, long an"
  ],
  "Thuận Hoà, Vị Xuyên, Hà Giang": [
    "thuận hoà, vị xuyên, hà giang",
    "thuaajn hoaf, vij xuyeen, haf giang"
  ],
  "Thuận Hòa, Cầu Ngang, Trà Vinh": [
    "thuận hòa, cầu ngang, trà vinh",
    "thuaajn hofa, caafu ngang, traf vinh"
  ],
  "Thuận Hòa, Long Mỹ, Hậu Giang": [
    "thuận hòa, long mỹ, hậu giang",
    "thuaajn hofa, long myx, haaju giang"
  ],
  "Thuận Hưng, Mỹ Tú, Sóc Trăng": [
    "thuận hưng, mỹ tú, sóc trăng",
    "thuaajn huwng, myx tus, sosc trawng"
  ],
  "Thuận Thới, Trà Ôn, Vĩnh Long": [
    "thuận thới, trà ôn, vĩnh long",
    "thuaajn thowsi, traf oon, vixnh long"
  ],
  "Thuận Yên, Hà Tiên, Kiên Giang": [
    "thuận yên, hà tiên, kiên giang",
    "thuaajn yeen, haf tieen, kieen giang"
  ],
  "Thành Hòa, Văn Lãng, Lạng Sơn": [
    "thành hòa, văn lãng, lạng sơn",
    "thafnh hofa, vawn laxng, lajng sown"
  ],
  "Thành Long, Châu Thành, Tây Ninh": [
    "thành long, châu thành, tây ninh",
    "thafnh long, chaau thafnh, taay ninh"
  ],
  "Thành Long, Hàm Yên, Tuyên Quang": [
    "thành long, hàm yên, tuyên quang",
    "thafnh long, hafm yeen, tuyeen quang"
  ],
  "Thành Lợi, Bình Tân, Vĩnh Long": [
    "thành lợi, bình tân, vĩnh long",
    "thafnh lowji, bifnh taan, vixnh long"
  ],
  "Thành Trung, Bình Tân, Vĩnh Long": [
    "thành trung, bình tân, vĩnh long",
    "thafnh trung, bifnh taan, vixnh long"
  ],
  "Thái Bình, Châu Thành, Tây Ninh": [
    "thái bình, châu thành, tây ninh",
    "thasi bifnh, chaau thafnh, taay ninh"
  ],
  "Thái Bình, Yên Sơn, Tuyên Quang": [
    "thái bình, yên sơn, tuyên quang",
    "thasi bifnh, yeen sown, tuyeen quang"
  ],
  "Thái Hòa, Triệu Sơn, Thanh Hóa": [
    "thái hòa, triệu sơn, thanh hóa",
    "thasi hofa, trieeju sown, thanh hosa"
  ],
  "Thái Mỹ, Củ Chi, Hồ Chí Minh": [
    "thái mỹ, củ chi, hồ chí minh",
    "thasi myx, cur chi, hoof chis minh"
  ],
  "Thái Niên, Bảo Thắng, Lào Cai": [
    "thái niên, bảo thắng, lào cai",
    "thasi nieen, baro thawsng, lafo cai"
  ],
  "Thái Sơn, Hiệp Hòa, Bắc Giang": [
    "thái sơn, hiệp hòa, bắc giang",
    "thasi sown, hieejp hofa, bawsc giang"
  ],
  "Thái Tân, Nam Sách, Hải Dương": [
    "thái tân, nam sách, hải dương",
    "thasi taan, nam sasch, hari duwowng"
  ],
  "Thân Thuộc, Tân Uyên, Lai Châu": [
    "thân thuộc, tân uyên, lai châu",
    "thaan thuoojc, taan uyeen, lai chaau"
  ],
  "Thông Thụ, Quế Phong, Nghệ An": [
    "thông thụ, quế phong, nghệ an",
    "thoong thuj, quees phong, ngheej an"
  ],
  "Thúy Sơn, Ngọc Lặc, Thanh Hóa": [
    "thúy sơn, ngọc lặc, thanh hóa",
    "thusy sown, ngojc lawjc, thanh hosa"
  ],
  "Thư Phú, Thường Tín, Hà Nội": [
    "thư phú, thường tín, hà nội",
    "thuw phus, thuwowfng tisn, haf nooji"
  ],
  "Thượng Hòa, Nho Quan, Ninh Bình": [
    "thượng hòa, nho quan, ninh bình",
    "thuwowjng hofa, nho quan, ninh bifnh"
  ],
  "Thượng Tân, Bắc Mê, Hà Giang": [
    "thượng tân, bắc mê, hà giang",
    "thuwowjng taan, bawsc mee, haf giang"
  ],
  "Thạch Khê, Thạch Hà, Hà Tĩnh": [
    "thạch khê, thạch hà, hà tĩnh",
    "thajch khee, thajch haf, haf tixnh"
  ],
  "Thạch Long, Thạch Hà, Hà Tĩnh": [
    "thạch long, thạch hà, hà tĩnh",
    "thajch long, thajch haf, haf tixnh"
  ],
  "Thạch Lâm, Bảo Lâm, Cao Bằng": [
    "thạch lâm, bảo lâm, cao bằng",
    "thajch laam, baro laam, cao bawfng"
  ],
  "Thạch Ngàn, Con Cuông, Nghệ An": [
    "thạch ngàn, con cuông, nghệ an",
    "thajch ngafn, con cuoong, ngheej an"
  ],
  "Thạch Sơn, Thạch Hà, Hà Tĩnh": [
    "thạch sơn, thạch hà, hà tĩnh",
    "thajch sown, thajch haf, haf tixnh"
  ],
  "Thạch Thán, Quốc Oai, Hà Nội": [
    "thạch thán, quốc oai, hà nội",
    "thajch thasn, quoosc oai, haf nooji"
  ],
  "Thạch Văn, Thạch Hà, Hà Tĩnh": [
    "thạch văn, thạch hà, hà tĩnh",
    "thajch vawn, thajch haf, haf tixnh"
  ],
  "Thạnh Bình, Tân Biên, Tây Ninh": [
    "thạnh bình, tân biên, tây ninh",
    "thajnh bifnh, taan bieen, taay ninh"
  ],
  "Thạnh Bắc, Tân Biên, Tây Ninh": [
    "thạnh bắc, tân biên, tây ninh",
    "thajnh bawsc, taan bieen, taay ninh"
  ],
  "Thạnh Mỹ, Nam Giang, Quảng Nam": [
    "thạnh mỹ, nam giang, quảng nam",
    "thajnh myx, nam giang, quarng nam"
  ],
  "Thạnh Phú, Cờ Đỏ, Cần Thơ": [
    "thạnh phú, cờ đỏ, cần thơ",
    "thajnh phus, cowf ddor, caafn thow"
  ],
  "Thạnh Đức, Bến Lức, Long An": [
    "thạnh đức, bến lức, long an",
    "thajnh dduwsc, beesn luwsc, long an"
  ],
  "Thạnh Đức, Gò Dầu, Tây Ninh": [
    "thạnh đức, gò dầu, tây ninh",
    "thajnh dduwsc, gof daafu, taay ninh"
  ],
  "Thắng Lợi, Hạ Lang, Cao Bằng": [
    "thắng lợi, hạ lang, cao bằng",
    "thawsng lowji, haj lang, cao bawfng"
  ],
  "Thắng Sơn, Thanh Sơn, Phú Thọ": [
    "thắng sơn, thanh sơn, phú thọ",
    "thawsng sown, thanh sown, phus thoj"
  ],
  "Thịnh Hưng, Yên Bình, Yên Bái": [
    "thịnh hưng, yên bình, yên bái",
    "thijnh huwng, yeen bifnh, yeen basi"
  ],
  "Thịnh Lang, Hòa Bình, Hoà Bình": [
    "thịnh lang, hòa bình, hoà bình",
    "thijnh lang, hofa bifnh, hoaf bifnh"
  ],
  "Thịnh Minh, Hòa Bình, Hoà Bình": [
    "thịnh minh, hòa bình, hoà bình",
    "thijnh minh, hofa bifnh, hoaf bifnh"
  ],
  "Thọ Diên, Thọ Xuân, Thanh Hóa": [
    "thọ diên, thọ xuân, thanh hóa",
    "thoj dieen, thoj xuaan, thanh hosa"
  ],
  "Thọ Dân, Triệu Sơn, Thanh Hóa": [
    "thọ dân, triệu sơn, thanh hóa",
    "thoj daan, trieeju sown, thanh hosa"
  ],
  "Thọ Hải, Thọ Xuân, Thanh Hóa": [
    "thọ hải, thọ xuân, thanh hóa",
    "thoj hari, thoj xuaan, thanh hosa"
  ],
  "Thọ Lập, Thọ Xuân, Thanh Hóa": [
    "thọ lập, thọ xuân, thanh hóa",
    "thoj laajp, thoj xuaan, thanh hosa"
  ],
  "Thọ Lộc, Thọ Xuân, Thanh Hóa": [
    "thọ lộc, thọ xuân, thanh hóa",
    "thoj loojc, thoj xuaan, thanh hosa"
  ],
  "Thọ Phú, Triệu Sơn, Thanh Hóa": [
    "thọ phú, triệu sơn, thanh hóa",
    "thoj phus, trieeju sown, thanh hosa"
  ],
  "Thọ Sơn, Triệu Sơn, Thanh Hóa": [
    "thọ sơn, triệu sơn, thanh hóa",
    "thoj sown, trieeju sown, thanh hosa"
  ],
  "Thọ Thành, Yên Thành, Nghệ An": [
    "thọ thành, yên thành, nghệ an",
    "thoj thafnh, yeen thafnh, ngheej an"
  ],
  "Thọ Tân, Triệu Sơn, Thanh Hóa": [
    "thọ tân, triệu sơn, thanh hóa",
    "thoj taan, trieeju sown, thanh hosa"
  ],
  "Thọ Xuân, Thọ Xuân, Thanh Hóa": [
    "thọ xuân, thọ xuân, thanh hóa",
    "thoj xuaan, thoj xuaan, thanh hosa"
  ],
  "Thổ Sơn, Hòn Đất, Kiên Giang": [
    "thổ sơn, hòn đất, kiên giang",
    "thoor sown, hofn ddaast, kieen giang"
  ],
  "Thới An, Quận 12, Hồ Chí Minh": [
    "thới an, quận 12, hồ chí minh",
    "thowsi an, quaajn 12, hoof chis minh"
  ],
  "Thới Hưng, Cờ Đỏ, Cần Thơ": [
    "thới hưng, cờ đỏ, cần thơ",
    "thowsi huwng, cowf ddor, caafn thow"
  ],
  "Thới Quản, Gò Quao, Kiên Giang": [
    "thới quản, gò quao, kiên giang",
    "thowsi quarn, gof quao, kieen giang"
  ],
  "Thới Xuân, Cờ Đỏ, Cần Thơ": [
    "thới xuân, cờ đỏ, cần thơ",
    "thowsi xuaan, cowf ddor, caafn thow"
  ],
  "Thụy Hùng, Cao Lộc, Lạng Sơn": [
    "thụy hùng, cao lộc, lạng sơn",
    "thujy hufng, cao loojc, lajng sown"
  ],
  "Thụy Hùng, Thạch An, Cao Bằng": [
    "thụy hùng, thạch an, cao bằng",
    "thujy hufng, thajch an, cao bawfng"
  ],
  "Thụy Vân, Việt Trì, Phú Thọ": [
    "thụy vân, việt trì, phú thọ",
    "thujy vaan, vieejt trif, phus thoj"
  ],
  "Thủy Liễu, Gò Quao, Kiên Giang": [
    "thủy liễu, gò quao, kiên giang",
    "thury lieexu, gof quao, kieen giang"
  ],
  "Thủy Đông, Thạnh Hóa, Long An": [
    "thủy đông, thạnh hóa, long an",
    "thury ddoong, thajnh hosa, long an"
  ],
  "Tiên Dương, Đông Anh, Hà Nội": [
    "tiên dương, đông anh, hà nội",
    "tieen duwowng, ddoong anh, haf nooji"
  ],
  "Tiên Kiều, Bắc Quang, Hà Giang": [
    "tiên kiều, bắc quang, hà giang",
    "tieen kieefu, bawsc quang, haf giang"
  ],
  "Tiên Sơn, Việt Yên, Bắc Giang": [
    "tiên sơn, việt yên, bắc giang",
    "tieen sown, vieejt yeen, bawsc giang"
  ],
  "Tiên Yên, Tiên Yên, Quảng Ninh": [
    "tiên yên, tiên yên, quảng ninh",
    "tieen yeen, tieen yeen, quarng ninh"
  ],
  "Tiên Điền, Nghi Xuân, Hà Tĩnh": [
    "tiên điền, nghi xuân, hà tĩnh",
    "tieen ddieefn, nghi xuaan, haf tixnh"
  ],
  "Tiến Bộ, Yên Sơn, Tuyên Quang": [
    "tiến bộ, yên sơn, tuyên quang",
    "tieesn booj, yeen sown, tuyeen quang"
  ],
  "Tiền Phong, Quế Phong, Nghệ An": [
    "tiền phong, quế phong, nghệ an",
    "tieefn phong, quees phong, ngheej an"
  ],
  "Tiền Phong, Đà Bắc, Hoà Bình": [
    "tiền phong, đà bắc, hoà bình",
    "tieefn phong, ddaf bawsc, hoaf bifnh"
  ],
  "Tiền Tiến, Phù Cừ, Hưng Yên": [
    "tiền tiến, phù cừ, hưng yên",
    "tieefn tieesn, phuf cuwf, huwng yeen"
  ],
  "Tiền Yên, Hoài Đức, Hà Nội": [
    "tiền yên, hoài đức, hà nội",
    "tieefn yeen, hoafi dduwsc, haf nooji"
  ],
  "Trung Chải, Nậm Nhùn, Lai Châu": [
    "trung chải, nậm nhùn, lai châu",
    "trung chari, naajm nhufn, lai chaau"
  ],
  "Trung Dũng, Biên Hòa, Đồng Nai": [
    "trung dũng, biên hòa, đồng nai",
    "trung duxng, bieen hofa, ddoofng nai"
  ],
  "Trung Giang, Gio Linh, Quảng Trị": [
    "trung giang, gio linh, quảng trị",
    "trung giang, gio linh, quarng trij"
  ],
  "Trung Hoà, Trảng Bom, Đồng Nai": [
    "trung hoà, trảng bom, đồng nai",
    "trung hoaf, trarng bom, ddoofng nai"
  ],
  "Trung Hà, Chiêm Hóa, Tuyên Quang": [
    "trung hà, chiêm hóa, tuyên quang",
    "trung haf, chieem hosa, tuyeen quang"
  ],
  "Trung Hòa, Chương Mỹ, Hà Nội": [
    "trung hòa, chương mỹ, hà nội",
    "trung hofa, chuwowng myx, haf nooji"
  ],
  "Trung Hóa, Minh Hóa, Quảng Bình": [
    "trung hóa, minh hóa, quảng bình",
    "trung hosa, minh hosa, quarng bifnh"
  ],
  "Trung Hải, Gio Linh, Quảng Trị": [
    "trung hải, gio linh, quảng trị",
    "trung hari, gio linh, quarng trij"
  ],
  "Trung Kiên, Yên Lạc, Vĩnh Phúc": [
    "trung kiên, yên lạc, vĩnh phúc",
    "trung kieen, yeen lajc, vixnh phusc"
  ],
  "Trung Liệt, Đống Đa, Hà Nội": [
    "trung liệt, đống đa, hà nội",
    "trung lieejt, ddoosng dda, haf nooji"
  ],
  "Trung Lý, Mường Lát, Thanh Hóa": [
    "trung lý, mường lát, thanh hóa",
    "trung lys, muwowfng last, thanh hosa"
  ],
  "Trung Nam, Vĩnh Linh, Quảng Trị": [
    "trung nam, vĩnh linh, quảng trị",
    "trung nam, vixnh linh, quarng trij"
  ],
  "Trung Nghĩa, Hưng Yên, Hưng Yên": [
    "trung nghĩa, hưng yên, hưng yên",
    "trung nghixa, huwng yeen, huwng yeen"
  ],
  "Trung Nghĩa, Yên Phong, Bắc Ninh": [
    "trung nghĩa, yên phong, bắc ninh",
    "trung nghixa, yeen phong, bawsc ninh"
  ],
  "Trung Sơn, Việt Yên, Bắc Giang": [
    "trung sơn, việt yên, bắc giang",
    "trung sown, vieejt yeen, bawsc giang"
  ],
  "Trung Thành, Vị Xuyên, Hà Giang": [
    "trung thành, vị xuyên, hà giang",
    "trung thafnh, vij xuyeen, haf giang"
  ],
  "Trung Thành, Yên Thành, Nghệ An": [
    "trung thành, yên thành, nghệ an",
    "trung thafnh, yeen thafnh, ngheej an"
  ],
  "Trung Thành, Đà Bắc, Hoà Bình": [
    "trung thành, đà bắc, hoà bình",
    "trung thafnh, ddaf bawsc, hoaf bifnh"
  ],
  "Trung Thịnh, Xín Mần, Hà Giang": [
    "trung thịnh, xín mần, hà giang",
    "trung thijnh, xisn maafn, haf giang"
  ],
  "Trung Đồng, Tân Uyên, Lai Châu": [
    "trung đồng, tân uyên, lai châu",
    "trung ddoofng, taan uyeen, lai chaau"
  ],
  "Trà Bui, Bắc Trà My, Quảng Nam": [
    "trà bui, bắc trà my, quảng nam",
    "traf bui, bawsc traf my, quarng nam"
  ],
  "Trà Nú, Bắc Trà My, Quảng Nam": [
    "trà nú, bắc trà my, quảng nam",
    "traf nus, bawsc traf my, quarng nam"
  ],
  "Trà Tập, Nam Trà My, Quảng Nam": [
    "trà tập, nam trà my, quảng nam",
    "traf taajp, nam traf my, quarng nam"
  ],
  "Tràm Chim, Tam Nông, Đồng Tháp": [
    "tràm chim, tam nông, đồng tháp",
    "trafm chim, tam noong, ddoofng thasp"
  ],
  "Tràng Minh, Kiến An, Hải Phòng": [
    "tràng minh, kiến an, hải phòng",
    "trafng minh, kieesn an, hari phofng"
  ],
  "Tràng Phái, Văn Quan, Lạng Sơn": [
    "tràng phái, văn quan, lạng sơn",
    "trafng phasi, vawn quan, lajng sown"
  ],
  "Tràng Sơn, Đô Lương, Nghệ An": [
    "tràng sơn, đô lương, nghệ an",
    "trafng sown, ddoo luwowng, ngheej an"
  ],
  "Trưng Trắc, Văn Lâm, Hưng Yên": [
    "trưng trắc, văn lâm, hưng yên",
    "truwng trawsc, vawn laam, huwng yeen"
  ],
  "Trường An, Vĩnh Long, Vĩnh Long": [
    "trường an, vĩnh long, vĩnh long",
    "truwowfng an, vixnh long, vixnh long"
  ],
  "Trường Lạc, Ô Môn, Cần Thơ": [
    "trường lạc, ô môn, cần thơ",
    "truwowfng lajc, oo moon, caafn thow"
  ],
  "Trạm Thản, Phù Ninh, Phú Thọ": [
    "trạm thản, phù ninh, phú thọ",
    "trajm tharn, phuf ninh, phus thoj"
  ],
  "Trấn Yên, Bắc Sơn, Lạng Sơn": [
    "trấn yên, bắc sơn, lạng sơn",
    "traasn yeen, bawsc sown, lajng sown"
  ],
  "Trầm Lộng, Ứng Hòa, Hà Nội": [
    "trầm lộng, ứng hòa, hà nội",
    "traafm loojng, uwsng hofa, haf nooji"
  ],
  "Trần Thới, Cái Nước, Cà Mau": [
    "trần thới, cái nước, cà mau",
    "traafn thowsi, casi nuwowsc, caf mau"
  ],
  "Tuân Đạo, Lạc Sơn, Hoà Bình": [
    "tuân đạo, lạc sơn, hoà bình",
    "tuaan ddajo, lajc sown, hoaf bifnh"
  ],
  "Tà Rụt, Đa Krông, Quảng Trị": [
    "tà rụt, đa krông, quảng trị",
    "taf rujt, dda kroong, quarng trij"
  ],
  "Tài Văn, Trần Đề, Sóc Trăng": [
    "tài văn, trần đề, sóc trăng",
    "tafi vawn, traafn ddeef, sosc trawng"
  ],
  "Tâm Thắng, Cư Jút, Đắk Nông": [
    "tâm thắng, cư jút, đắk nông",
    "taam thawsng, cuw just, ddawsk noong"
  ],
  "Tân Bình, Thái Bình, Thái Bình": [
    "tân bình, thái bình, thái bình",
    "taan bifnh, thasi bifnh, thasi bifnh"
  ],
  "Tân Bình, Vĩnh Cửu, Đồng Nai": [
    "tân bình, vĩnh cửu, đồng nai",
    "taan bifnh, vixnh cuwru, ddoofng nai"
  ],
  "Tân Bình, Đầm Hà, Quảng Ninh": [
    "tân bình, đầm hà, quảng ninh",
    "taan bifnh, ddaafm haf, quarng ninh"
  ],
  "Tân Chánh, Cần Đước, Long An": [
    "tân chánh, cần đước, long an",
    "taan chasnh, caafn dduwowsc, long an"
  ],
  "Tân Châu, Khoái Châu, Hưng Yên": [
    "tân châu, khoái châu, hưng yên",
    "taan chaau, khoasi chaau, huwng yeen"
  ],
  "Tân Châu, Thiệu Hóa, Thanh Hóa": [
    "tân châu, thiệu hóa, thanh hóa",
    "taan chaau, thieeju hosa, thanh hosa"
  ],
  "Tân Chính, Thanh Khê, Đà Nẵng": [
    "tân chính, thanh khê, đà nẵng",
    "taan chisnh, thanh khee, ddaf nawxng"
  ],
  "Tân Hiệp, Biên Hòa, Đồng Nai": [
    "tân hiệp, biên hòa, đồng nai",
    "taan hieejp, bieen hofa, ddoofng nai"
  ],
  "Tân Hiệp, Yên Thế, Bắc Giang": [
    "tân hiệp, yên thế, bắc giang",
    "taan hieejp, yeen thees, bawsc giang"
  ],
  "Tân Hoà, Buôn Đôn, Đắk Lắk": [
    "tân hoà, buôn đôn, đắk lắk",
    "taan hoaf, buoon ddoon, ddawsk lawsk"
  ],
  "Tân Hà, Tuyên Quang, Tuyên Quang": [
    "tân hà, tuyên quang, tuyên quang",
    "taan haf, tuyeen quang, tuyeen quang"
  ],
  "Tân Hà, Đức Linh, Bình Thuận": [
    "tân hà, đức linh, bình thuận",
    "taan haf, dduwsc linh, bifnh thuaajn"
  ],
  "Tân Hòa, Phú Bình, Thái Nguyên": [
    "tân hòa, phú bình, thái nguyên",
    "taan hofa, phus bifnh, thasi nguyeen"
  ],
  "Tân Hưng, Quận 7, Hồ Chí Minh": [
    "tân hưng, quận 7, hồ chí minh",
    "taan huwng, quaajn 7, hoof chis minh"
  ],
  "Tân Hưng, Thốt Nốt, Cần Thơ": [
    "tân hưng, thốt nốt, cần thơ",
    "taan huwng, thoost noost, caafn thow"
  ],
  "Tân Hạnh, Biên Hòa, Đồng Nai": [
    "tân hạnh, biên hòa, đồng nai",
    "taan hajnh, bieen hofa, ddoofng nai"
  ],
  "Tân Hải, Ninh Hải, Ninh Thuận": [
    "tân hải, ninh hải, ninh thuận",
    "taan hari, ninh hari, ninh thuaajn"
  ],
  "Tân Hội, Mỏ Cày Nam, Bến Tre": [
    "tân hội, mỏ cày nam, bến tre",
    "taan hooji, mor cafy nam, beesn tre"
  ],
  "Tân Hội, Tân Hiệp, Kiên Giang": [
    "tân hội, tân hiệp, kiên giang",
    "taan hooji, taan hieejp, kieen giang"
  ],
  "Tân Khang, Nông Cống, Thanh Hóa": [
    "tân khang, nông cống, thanh hóa",
    "taan khang, noong coosng, thanh hosa"
  ],
  "Tân Khánh, Vụ Bản, Nam Định": [
    "tân khánh, vụ bản, nam định",
    "taan khasnh, vuj barn, nam ddijnh"
  ],
  "Tân Liễu, Yên Dũng, Bắc Giang": [
    "tân liễu, yên dũng, bắc giang",
    "taan lieexu, yeen duxng, bawsc giang"
  ],
  "Tân Long, Phú Giáo, Bình Dương": [
    "tân long, phú giáo, bình dương",
    "taan long, phus giaso, bifnh duwowng"
  ],
  "Tân Lãng, Lương Tài, Bắc Ninh": [
    "tân lãng, lương tài, bắc ninh",
    "taan laxng, luwowng tafi, bawsc ninh"
  ],
  "Tân Lược, Bình Tân, Vĩnh Long": [
    "tân lược, bình tân, vĩnh long",
    "taan luwowjc, bifnh taan, vixnh long"
  ],
  "Tân Lạc, Bảo Lâm, Lâm Đồng": [
    "tân lạc, bảo lâm, lâm đồng",
    "taan lajc, baro laam, laam ddoofng"
  ],
  "Tân Lập, Đầm Hà, Quảng Ninh": [
    "tân lập, đầm hà, quảng ninh",
    "taan laajp, ddaafm haf, quarng ninh"
  ],
  "Tân Lộc, Thốt Nốt, Cần Thơ": [
    "tân lộc, thốt nốt, cần thơ",
    "taan loojc, thoost noost, caafn thow"
  ],
  "Tân Minh, Thường Tín, Hà Nội": [
    "tân minh, thường tín, hà nội",
    "taan minh, thuwowfng tisn, haf nooji"
  ],
  "Tân Mỹ, Chiêm Hóa, Tuyên Quang": [
    "tân mỹ, chiêm hóa, tuyên quang",
    "taan myx, chieem hosa, tuyeen quang"
  ],
  "Tân Phong, Quận 7, Hồ Chí Minh": [
    "tân phong, quận 7, hồ chí minh",
    "taan phong, quaajn 7, hoof chis minh"
  ],
  "Tân Phú, Phổ Yên, Thái Nguyên": [
    "tân phú, phổ yên, thái nguyên",
    "taan phus, phoor yeen, thasi nguyeen"
  ],
  "Tân Phúc, Hàm Tân, Bình Thuận": [
    "tân phúc, hàm tân, bình thuận",
    "taan phusc, hafm taan, bifnh thuaajn"
  ],
  "Tân Phúc, Nông Cống, Thanh Hóa": [
    "tân phúc, nông cống, thanh hóa",
    "taan phusc, noong coosng, thanh hosa"
  ],
  "Tân Quý, Tân Phú, Hồ Chí Minh": [
    "tân quý, tân phú, hồ chí minh",
    "taan quys, taan phus, hoof chis minh"
  ],
  "Tân Sơn, Lục Ngạn, Bắc Giang": [
    "tân sơn, lục ngạn, bắc giang",
    "taan sown, lujc ngajn, bawsc giang"
  ],
  "Tân Thanh, Giồng Trôm, Bến Tre": [
    "tân thanh, giồng trôm, bến tre",
    "taan thanh, gioofng troom, beesn tre"
  ],
  "Tân Thành, Bắc Sơn, Lạng Sơn": [
    "tân thành, bắc sơn, lạng sơn",
    "taan thafnh, bawsc sown, lajng sown"
  ],
  "Tân Thành, Hàm Yên, Tuyên Quang": [
    "tân thành, hàm yên, tuyên quang",
    "taan thafnh, hafm yeen, tuyeen quang"
  ],
  "Tân Thành, Lai Vung, Đồng Tháp": [
    "tân thành, lai vung, đồng tháp",
    "taan thafnh, lai vung, ddoofng thasp"
  ],
  "Tân Thành, Ngã Bảy, Hậu Giang": [
    "tân thành, ngã bảy, hậu giang",
    "taan thafnh, ngax bary, haaju giang"
  ],
  "Tân Thành, Vụ Bản, Nam Định": [
    "tân thành, vụ bản, nam định",
    "taan thafnh, vuj barn, nam ddijnh"
  ],
  "Tân Thạnh, Long Phú, Sóc Trăng": [
    "tân thạnh, long phú, sóc trăng",
    "taan thajnh, long phus, sosc trawng"
  ],
  "Tân Thạnh, Thới Lai, Cần Thơ": [
    "tân thạnh, thới lai, cần thơ",
    "taan thajnh, thowsi lai, caafn thow"
  ],
  "Tân Thịnh, Hòa Bình, Hoà Bình": [
    "tân thịnh, hòa bình, hoà bình",
    "taan thijnh, hofa bifnh, hoaf bifnh"
  ],
  "Tân Thịnh, Văn Chấn, Yên Bái": [
    "tân thịnh, văn chấn, yên bái",
    "taan thijnh, vawn chaasn, yeen basi"
  ],
  "Tân Thọ, Nông Cống, Thanh Hóa": [
    "tân thọ, nông cống, thanh hóa",
    "taan thoj, noong coosng, thanh hosa"
  ],
  "Tân Tiến, Biên Hòa, Đồng Nai": [
    "tân tiến, biên hòa, đồng nai",
    "taan tieesn, bieen hofa, ddoofng nai"
  ],
  "Tân Tiến, Vị Thanh, Hậu Giang": [
    "tân tiến, vị thanh, hậu giang",
    "taan tieesn, vij thanh, haaju giang"
  ],
  "Tân Tiến, Yên Sơn, Tuyên Quang": [
    "tân tiến, yên sơn, tuyên quang",
    "taan tieesn, yeen sown, tuyeen quang"
  ],
  "Tân Trung, Mỏ Cày Nam, Bến Tre": [
    "tân trung, mỏ cày nam, bến tre",
    "taan trung, mor cafy nam, beesn tre"
  ],
  "Tân Trịnh, Quang Bình, Hà Giang": [
    "tân trịnh, quang bình, hà giang",
    "taan trijnh, quang bifnh, haf giang"
  ],
  "Tân Tú, Bạch Thông, Bắc Kạn": [
    "tân tú, bạch thông, bắc kạn",
    "taan tus, bajch thoong, bawsc kajn"
  ],
  "Tân Xuân, Hàm Tân, Bình Thuận": [
    "tân xuân, hàm tân, bình thuận",
    "taan xuaan, hafm taan, bifnh thuaajn"
  ],
  "Tân Đồng, Trấn Yên, Yên Bái": [
    "tân đồng, trấn yên, yên bái",
    "taan ddoofng, traasn yeen, yeen basi"
  ],
  "Tây Bình, Tây Sơn, Bình Định": [
    "tây bình, tây sơn, bình định",
    "taay bifnh, taay sown, bifnh ddijnh"
  ],
  "Tây Giang, Tây Sơn, Bình Định": [
    "tây giang, tây sơn, bình định",
    "taay giang, taay sown, bifnh ddijnh"
  ],
  "Tây Mỗ, Nam Từ Liêm, Hà Nội": [
    "tây mỗ, nam từ liêm, hà nội",
    "taay moox, nam tuwf lieem, haf nooji"
  ],
  "Tây Ninh, Tiền Hải, Thái Bình": [
    "tây ninh, tiền hải, thái bình",
    "taay ninh, tieefn hari, thasi bifnh"
  ],
  "Tây Xuân, Tây Sơn, Bình Định": [
    "tây xuân, tây sơn, bình định",
    "taay xuaan, taay sown, bifnh ddijnh"
  ],
  "Tông Lạnh, Thuận Châu, Sơn La": [
    "tông lạnh, thuận châu, sơn la",
    "toong lajnh, thuaajn chaau, sown la"
  ],
  "Tùng Châu, Đức Thọ, Hà Tĩnh": [
    "tùng châu, đức thọ, hà tĩnh",
    "tufng chaau, dduwsc thoj, haf tixnh"
  ],
  "Tùng Ảnh, Đức Thọ, Hà Tĩnh": [
    "tùng ảnh, đức thọ, hà tĩnh",
    "tufng arnh, dduwsc thoj, haf tixnh"
  ],
  "Tú Mịch, Lộc Bình, Lạng Sơn": [
    "tú mịch, lộc bình, lạng sơn",
    "tus mijch, loojc bifnh, lajng sown"
  ],
  "Tăng Thành, Yên Thành, Nghệ An": [
    "tăng thành, yên thành, nghệ an",
    "tawng thafnh, yeen thafnh, ngheej an"
  ],
  "Tương Giang, Từ Sơn, Bắc Ninh": [
    "tương giang, từ sơn, bắc ninh",
    "tuwowng giang, tuwf sown, bawsc ninh"
  ],
  "Tả Lèng, Tam Đường, Lai Châu": [
    "tả lèng, tam đường, lai châu",
    "tar lefng, tam dduwowfng, lai chaau"
  ],
  "Tả Lủng, Đồng Văn, Hà Giang": [
    "tả lủng, đồng văn, hà giang",
    "tar lurng, ddoofng vawn, haf giang"
  ],
  "Tập Ngãi, Tiểu Cần, Trà Vinh": [
    "tập ngãi, tiểu cần, trà vinh",
    "taajp ngaxi, tieeru caafn, traf vinh"
  ],
  "Tế Lợi, Nông Cống, Thanh Hóa": [
    "tế lợi, nông cống, thanh hóa",
    "tees lowji, noong coosng, thanh hosa"
  ],
  "Tế Nông, Nông Cống, Thanh Hóa": [
    "tế nông, nông cống, thanh hóa",
    "tees noong, noong coosng, thanh hosa"
  ],
  "Tịnh Biên, Tịnh Biên, An Giang": [
    "tịnh biên, tịnh biên, an giang",
    "tijnh bieen, tijnh bieen, an giang"
  ],
  "Tứ Quận, Yên Sơn, Tuyên Quang": [
    "tứ quận, yên sơn, tuyên quang",
    "tuws quaajn, yeen sown, tuyeen quang"
  ],
  "Tự Lạn, Việt Yên, Bắc Giang": [
    "tự lạn, việt yên, bắc giang",
    "tuwj lajn, vieejt yeen, bawsc giang"
  ],
  "Viên Thành, Yên Thành, Nghệ An": [
    "viên thành, yên thành, nghệ an",
    "vieen thafnh, yeen thafnh, ngheej an"
  ],
  "Việt Lập, Tân Yên, Bắc Giang": [
    "việt lập, tân yên, bắc giang",
    "vieejt laajp, taan yeen, bawsc giang"
  ],
  "Việt Quang, Bắc Quang, Hà Giang": [
    "việt quang, bắc quang, hà giang",
    "vieejt quang, bawsc quang, haf giang"
  ],
  "Vân Dương, Bắc Ninh, Bắc Ninh": [
    "vân dương, bắc ninh, bắc ninh",
    "vaan duwowng, bawsc ninh, bawsc ninh"
  ],
  "Vân Hội, Tam Dương, Vĩnh Phúc": [
    "vân hội, tam dương, vĩnh phúc",
    "vaan hooji, tam duwowng, vixnh phusc"
  ],
  "Vân Sơn, Sơn Động, Bắc Giang": [
    "vân sơn, sơn động, bắc giang",
    "vaan sown, sown ddoojng, bawsc giang"
  ],
  "Vân Trung, Việt Yên, Bắc Giang": [
    "vân trung, việt yên, bắc giang",
    "vaan trung, vieejt yeen, bawsc giang"
  ],
  "Vân Đồn, Đoan Hùng, Phú Thọ": [
    "vân đồn, đoan hùng, phú thọ",
    "vaan ddoofn, ddoan hufng, phus thoj"
  ],
  "Võ Cường, Bắc Ninh, Bắc Ninh": [
    "võ cường, bắc ninh, bắc ninh",
    "vox cuwowfng, bawsc ninh, bawsc ninh"
  ],
  "Võng Xuyên, Phúc Thọ, Hà Nội": [
    "võng xuyên, phúc thọ, hà nội",
    "voxng xuyeen, phusc thoj, haf nooji"
  ],
  "Văn Phong, Cát Hải, Hải Phòng": [
    "văn phong, cát hải, hải phòng",
    "vawn phong, cast hari, hari phofng"
  ],
  "Văn Phú, Thường Tín, Hà Nội": [
    "văn phú, thường tín, hà nội",
    "vawn phus, thuwowfng tisn, haf nooji"
  ],
  "Văn Tiến, Yên Lạc, Vĩnh Phúc": [
    "văn tiến, yên lạc, vĩnh phúc",
    "vawn tieesn, yeen lajc, vixnh phusc"
  ],
  "Văn Tự, Thường Tín, Hà Nội": [
    "văn tự, thường tín, hà nội",
    "vawn tuwj, thuwowfng tisn, haf nooji"
  ],
  "Văn Đẩu, Kiến An, Hải Phòng": [
    "văn đẩu, kiến an, hải phòng",
    "vawn ddaaru, kieesn an, hari phofng"
  ],
  "Vĩ Dạ, Huế, Thừa Thiên Huế": [
    "vĩ dạ, huế, thừa thiên huế",
    "vix daj, huees, thuwfa thieen huees"
  ],
  "Vĩnh Bình, Hoà Bình, Bạc Liêu": [
    "vĩnh bình, hoà bình, bạc liêu",
    "vixnh bifnh, hoaf bifnh, bajc lieeu"
  ],
  "Vĩnh Chánh, Thoại Sơn, An Giang": [
    "vĩnh chánh, thoại sơn, an giang",
    "vixnh chasnh, thoaji sown, an giang"
  ],
  "Vĩnh Hiệp, Nha Trang, Khánh Hòa": [
    "vĩnh hiệp, nha trang, khánh hòa",
    "vixnh hieejp, nha trang, khasnh hofa"
  ],
  "Vĩnh Hà, Vĩnh Linh, Quảng Trị": [
    "vĩnh hà, vĩnh linh, quảng trị",
    "vixnh haf, vixnh linh, quarng trij"
  ],
  "Vĩnh Hùng, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh hùng, vĩnh lộc, thanh hóa",
    "vixnh hufng, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Hưng, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh hưng, vĩnh lộc, thanh hóa",
    "vixnh huwng, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Hậu, Hoà Bình, Bạc Liêu": [
    "vĩnh hậu, hoà bình, bạc liêu",
    "vixnh haaju, hoaf bifnh, bajc lieeu"
  ],
  "Vĩnh Khánh, Thoại Sơn, An Giang": [
    "vĩnh khánh, thoại sơn, an giang",
    "vixnh khasnh, thoaji sown, an giang"
  ],
  "Vĩnh Lộc, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh lộc, vĩnh lộc, thanh hóa",
    "vixnh loojc, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Ngọc, Nha Trang, Khánh Hòa": [
    "vĩnh ngọc, nha trang, khánh hòa",
    "vixnh ngojc, nha trang, khasnh hofa"
  ],
  "Vĩnh Phúc, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh phúc, vĩnh lộc, thanh hóa",
    "vixnh phusc, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Quang, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh quang, vĩnh lộc, thanh hóa",
    "vixnh quang, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Quới, Ngã Năm, Sóc Trăng": [
    "vĩnh quới, ngã năm, sóc trăng",
    "vixnh quowsi, ngax nawm, sosc trawng"
  ],
  "Vĩnh Quỳnh, Thanh Trì, Hà Nội": [
    "vĩnh quỳnh, thanh trì, hà nội",
    "vixnh quyfnh, thanh trif, haf nooji"
  ],
  "Vĩnh Thành, Châu Thành, An Giang": [
    "vĩnh thành, châu thành, an giang",
    "vixnh thafnh, chaau thafnh, an giang"
  ],
  "Vĩnh Thành, Chợ Lách, Bến Tre": [
    "vĩnh thành, chợ lách, bến tre",
    "vixnh thafnh, chowj lasch, beesn tre"
  ],
  "Vĩnh Thành, Yên Thành, Nghệ An": [
    "vĩnh thành, yên thành, nghệ an",
    "vixnh thafnh, yeen thafnh, ngheej an"
  ],
  "Vĩnh Thắng, Gò Quao, Kiên Giang": [
    "vĩnh thắng, gò quao, kiên giang",
    "vixnh thawsng, gof quao, kieen giang"
  ],
  "Vĩnh Trung, Thanh Khê, Đà Nẵng": [
    "vĩnh trung, thanh khê, đà nẵng",
    "vixnh trung, thanh khee, ddaf nawxng"
  ],
  "Vĩnh Tuy, Hai Bà Trưng, Hà Nội": [
    "vĩnh tuy, hai bà trưng, hà nội",
    "vixnh tuy, hai baf truwng, haf nooji"
  ],
  "Vĩnh Tân, Tuy Phong, Bình Thuận": [
    "vĩnh tân, tuy phong, bình thuận",
    "vixnh taan, tuy phong, bifnh thuaajn"
  ],
  "Vĩnh Tân, Vĩnh Châu, Sóc Trăng": [
    "vĩnh tân, vĩnh châu, sóc trăng",
    "vixnh taan, vixnh chaau, sosc trawng"
  ],
  "Vĩnh Tân, Vĩnh Cửu, Đồng Nai": [
    "vĩnh tân, vĩnh cửu, đồng nai",
    "vixnh taan, vixnh cuwru, ddoofng nai"
  ],
  "Vĩnh Tú, Vĩnh Linh, Quảng Trị": [
    "vĩnh tú, vĩnh linh, quảng trị",
    "vixnh tus, vixnh linh, quarng trij"
  ],
  "Vĩnh Viễn, Long Mỹ, Hậu Giang": [
    "vĩnh viễn, long mỹ, hậu giang",
    "vixnh vieexn, long myx, haaju giang"
  ],
  "Vũ Chính, Thái Bình, Thái Bình": [
    "vũ chính, thái bình, thái bình",
    "vux chisnh, thasi bifnh, thasi bifnh"
  ],
  "Vũ Hoà, Đức Linh, Bình Thuận": [
    "vũ hoà, đức linh, bình thuận",
    "vux hoaf, dduwsc linh, bifnh thuaajn"
  ],
  "Vũ Lăng, Tiền Hải, Thái Bình": [
    "vũ lăng, tiền hải, thái bình",
    "vux lawng, tieefn hari, thasi bifnh"
  ],
  "Vũ Nông, Nguyên Bình, Cao Bằng": [
    "vũ nông, nguyên bình, cao bằng",
    "vux noong, nguyeen bifnh, cao bawfng"
  ],
  "Vũ Đông, Thái Bình, Thái Bình": [
    "vũ đông, thái bình, thái bình",
    "vux ddoong, thasi bifnh, thasi bifnh"
  ],
  "Vượng Lộc, Can Lộc, Hà Tĩnh": [
    "vượng lộc, can lộc, hà tĩnh",
    "vuwowjng loojc, can loojc, haf tixnh"
  ],
  "Vạn Bình, Vạn Ninh, Khánh Hòa": [
    "vạn bình, vạn ninh, khánh hòa",
    "vajn bifnh, vajn ninh, khasnh hofa"
  ],
  "Vạn Hòa, Nông Cống, Thanh Hóa": [
    "vạn hòa, nông cống, thanh hóa",
    "vajn hofa, noong coosng, thanh hosa"
  ],
  "Vạn Hưng, Vạn Ninh, Khánh Hòa": [
    "vạn hưng, vạn ninh, khánh hòa",
    "vajn huwng, vajn ninh, khasnh hofa"
  ],
  "Vạn Ninh, Móng Cái, Quảng Ninh": [
    "vạn ninh, móng cái, quảng ninh",
    "vajn ninh, mosng casi, quarng ninh"
  ],
  "Vạn Thọ, Vạn Ninh, Khánh Hòa": [
    "vạn thọ, vạn ninh, khánh hòa",
    "vajn thoj, vajn ninh, khasnh hofa"
  ],
  "Vị Bình, Vị Thuỷ, Hậu Giang": [
    "vị bình, vị thuỷ, hậu giang",
    "vij bifnh, vij thuyr, haaju giang"
  ],
  "Vị Thanh, Vị Thuỷ, Hậu Giang": [
    "vị thanh, vị thuỷ, hậu giang",
    "vij thanh, vij thuyr, haaju giang"
  ],
  "Vị Trung, Vị Thuỷ, Hậu Giang": [
    "vị trung, vị thuỷ, hậu giang",
    "vij trung, vij thuyr, haaju giang"
  ],
  "Xuân Bảo, Cẩm Mỹ, Đồng Nai": [
    "xuân bảo, cẩm mỹ, đồng nai",
    "xuaan baro, caarm myx, ddoofng nai"
  ],
  "Xuân Cảnh, Sông Cầu, Phú Yên": [
    "xuân cảnh, sông cầu, phú yên",
    "xuaan carnh, soong caafu, phus yeen"
  ],
  "Xuân Giang, Thọ Xuân, Thanh Hóa": [
    "xuân giang, thọ xuân, thanh hóa",
    "xuaan giang, thoj xuaan, thanh hosa"
  ],
  "Xuân Hoà, Long Khánh, Đồng Nai": [
    "xuân hoà, long khánh, đồng nai",
    "xuaan hoaf, long khasnh, ddoofng nai"
  ],
  "Xuân Hòa, Xuân Lộc, Đồng Nai": [
    "xuân hòa, xuân lộc, đồng nai",
    "xuaan hofa, xuaan loojc, ddoofng nai"
  ],
  "Xuân Hóa, Minh Hóa, Quảng Bình": [
    "xuân hóa, minh hóa, quảng bình",
    "xuaan hosa, minh hosa, quarng bifnh"
  ],
  "Xuân Hưng, Thọ Xuân, Thanh Hóa": [
    "xuân hưng, thọ xuân, thanh hóa",
    "xuaan huwng, thoj xuaan, thanh hosa"
  ],
  "Xuân Long, Đồng Xuân, Phú Yên": [
    "xuân long, đồng xuân, phú yên",
    "xuaan long, ddoofng xuaan, phus yeen"
  ],
  "Xuân Lập, Thọ Xuân, Thanh Hóa": [
    "xuân lập, thọ xuân, thanh hóa",
    "xuaan laajp, thoj xuaan, thanh hosa"
  ],
  "Xuân Lộc, Hậu Lộc, Thanh Hóa": [
    "xuân lộc, hậu lộc, thanh hóa",
    "xuaan loojc, haaju loojc, thanh hosa"
  ],
  "Xuân Phong, Thọ Xuân, Thanh Hóa": [
    "xuân phong, thọ xuân, thanh hóa",
    "xuaan phong, thoj xuaan, thanh hosa"
  ],
  "Xuân Phú, Xuân Lộc, Đồng Nai": [
    "xuân phú, xuân lộc, đồng nai",
    "xuaan phus, xuaan loojc, ddoofng nai"
  ],
  "Xuân Quang, Bảo Thắng, Lào Cai": [
    "xuân quang, bảo thắng, lào cai",
    "xuaan quang, baro thawsng, lafo cai"
  ],
  "Xuân Quế, Cẩm Mỹ, Đồng Nai": [
    "xuân quế, cẩm mỹ, đồng nai",
    "xuaan quees, caarm myx, ddoofng nai"
  ],
  "Xuân Thành, Sông Cầu, Phú Yên": [
    "xuân thành, sông cầu, phú yên",
    "xuaan thafnh, soong caafu, phus yeen"
  ],
  "Xuân Thành, Yên Thành, Nghệ An": [
    "xuân thành, yên thành, nghệ an",
    "xuaan thafnh, yeen thafnh, ngheej an"
  ],
  "Xuân Thủy, Yên Lập, Phú Thọ": [
    "xuân thủy, yên lập, phú thọ",
    "xuaan thury, yeen laajp, phus thoj"
  ],
  "Xuân Tâm, Xuân Lộc, Đồng Nai": [
    "xuân tâm, xuân lộc, đồng nai",
    "xuaan taam, xuaan loojc, ddoofng nai"
  ],
  "Xuân Tân, Long Khánh, Đồng Nai": [
    "xuân tân, long khánh, đồng nai",
    "xuaan taan, long khasnh, ddoofng nai"
  ],
  "Xuân Đình, Phúc Thọ, Hà Nội": [
    "xuân đình, phúc thọ, hà nội",
    "xuaan ddifnh, phusc thoj, haf nooji"
  ],
  "Ya Tờ Mốt, Ea Súp, Đắk Lắk": [
    "ya tờ mốt, ea súp, đắk lắk",
    "ya towf moost, ea susp, ddawsk lawsk"
  ],
  "Yang Mao, Krông Bông, Đắk Lắk": [
    "yang mao, krông bông, đắk lắk",
    "yang mao, kroong boong, ddawsk lawsk"
  ],
  "Yang Reh, Krông Bông, Đắk Lắk": [
    "yang reh, krông bông, đắk lắk",
    "yang reh, kroong boong, ddawsk lawsk"
  ],
  "Yên Bình, Hữu Lũng, Lạng Sơn": [
    "yên bình, hữu lũng, lạng sơn",
    "yeen bifnh, huwxu luxng, lajng sown"
  ],
  "Yên Hùng, Yên Định, Thanh Hóa": [
    "yên hùng, yên định, thanh hóa",
    "yeen hufng, yeen ddijnh, thanh hosa"
  ],
  "Yên Kiện, Đoan Hùng, Phú Thọ": [
    "yên kiện, đoan hùng, phú thọ",
    "yeen kieejn, ddoan hufng, phus thoj"
  ],
  "Yên Lương, Thanh Sơn, Phú Thọ": [
    "yên lương, thanh sơn, phú thọ",
    "yeen luwowng, thanh sown, phus thoj"
  ],
  "Yên Lạc, Yên Định, Thanh Hóa": [
    "yên lạc, yên định, thanh hóa",
    "yeen lajc, yeen ddijnh, thanh hosa"
  ],
  "Yên Mỹ, Chợ Đồn, Bắc Kạn": [
    "yên mỹ, chợ đồn, bắc kạn",
    "yeen myx, chowj ddoofn, bawsc kajn"
  ],
  "Yên Mỹ, Lạng Giang, Bắc Giang": [
    "yên mỹ, lạng giang, bắc giang",
    "yeen myx, lajng giang, bawsc giang"
  ],
  "Yên Phong, Yên Định, Thanh Hóa": [
    "yên phong, yên định, thanh hóa",
    "yeen phong, yeen ddijnh, thanh hosa"
  ],
  "Yên Thái, Yên Định, Thanh Hóa": [
    "yên thái, yên định, thanh hóa",
    "yeen thasi, yeen ddijnh, thanh hosa"
  ],
  "Yên Thạch, Sông Lô, Vĩnh Phúc": [
    "yên thạch, sông lô, vĩnh phúc",
    "yeen thajch, soong loo, vixnh phusc"
  ],
  "Yên Thọ, Yên Định, Thanh Hóa": [
    "yên thọ, yên định, thanh hóa",
    "yeen thoj, yeen ddijnh, thanh hosa"
  ],
  "Yên Trung, Yên Định, Thanh Hóa": [
    "yên trung, yên định, thanh hóa",
    "yeen trung, yeen ddijnh, thanh hosa"
  ],
  "Yên Trạch, Cao Lộc, Lạng Sơn": [
    "yên trạch, cao lộc, lạng sơn",
    "yeen trajch, cao loojc, lajng sown"
  ],
  "Yết Kiêu, Hạ Long, Quảng Ninh": [
    "yết kiêu, hạ long, quảng ninh",
    "yeest kieeu, haj long, quarng ninh"
  ],
  "Ái Quốc, Lộc Bình, Lạng Sơn": [
    "ái quốc, lộc bình, lạng sơn",
    "asi quoosc, loojc bifnh, lajng sown"
  ],
  "Ân Nghĩa, Hoài Ân, Bình Định": [
    "ân nghĩa, hoài ân, bình định",
    "aan nghixa, hoafi aan, bifnh ddijnh"
  ],
  "Ân Đức, Hoài Ân, Bình Định": [
    "ân đức, hoài ân, bình định",
    "aan dduwsc, hoafi aan, bifnh ddijnh"
  ],
  "Điền Xá, Nam Trực, Nam Định": [
    "điền xá, nam trực, nam định",
    "ddieefn xas, nam truwjc, nam ddijnh"
  ],
  "Đoan Bái, Hiệp Hòa, Bắc Giang": [
    "đoan bái, hiệp hòa, bắc giang",
    "ddoan basi, hieejp hofa, bawsc giang"
  ],
  "Đoan Hùng, Đoan Hùng, Phú Thọ": [
    "đoan hùng, đoan hùng, phú thọ",
    "ddoan hufng, ddoan hufng, phus thoj"
  ],
  "Đoan Hạ, Thanh Thuỷ, Phú Thọ": [
    "đoan hạ, thanh thuỷ, phú thọ",
    "ddoan haj, thanh thuyr, phus thoj"
  ],
  "Đoàn Kết, Đà Bắc, Hoà Bình": [
    "đoàn kết, đà bắc, hoà bình",
    "ddoafn keest, ddaf bawsc, hoaf bifnh"
  ],
  "Đào Xá, Phú Bình, Thái Nguyên": [
    "đào xá, phú bình, thái nguyên",
    "ddafo xas, phus bifnh, thasi nguyeen"
  ],
  "Đèo Gia, Lục Ngạn, Bắc Giang": [
    "đèo gia, lục ngạn, bắc giang",
    "ddefo gia, lujc ngajn, bawsc giang"
  ],
  "Đình Bảng, Từ Sơn, Bắc Ninh": [
    "đình bảng, từ sơn, bắc ninh",
    "ddifnh barng, tuwf sown, bawsc ninh"
  ],
  "Đình Cả, Võ Nhai, Thái Nguyên": [
    "đình cả, võ nhai, thái nguyên",
    "ddifnh car, vox nhai, thasi nguyeen"
  ],
  "Đôn Châu, Duyên Hải, Trà Vinh": [
    "đôn châu, duyên hải, trà vinh",
    "ddoon chaau, duyeen hari, traf vinh"
  ],
  "Đôn Xuân, Duyên Hải, Trà Vinh": [
    "đôn xuân, duyên hải, trà vinh",
    "ddoon xuaan, duyeen hari, traf vinh"
  ],
  "Đông Bình, Bình Minh, Vĩnh Long": [
    "đông bình, bình minh, vĩnh long",
    "ddoong bifnh, bifnh minh, vixnh long"
  ],
  "Đông Bình, Thới Lai, Cần Thơ": [
    "đông bình, thới lai, cần thơ",
    "ddoong bifnh, thowsi lai, caafn thow"
  ],
  "Đông Cửu, Thanh Sơn, Phú Thọ": [
    "đông cửu, thanh sơn, phú thọ",
    "ddoong cuwru, thanh sown, phus thoj"
  ],
  "Đông Hiếu, Thái Hoà, Nghệ An": [
    "đông hiếu, thái hoà, nghệ an",
    "ddoong hieesu, thasi hoaf, ngheej an"
  ],
  "Đông Hòa, Đông Sơn, Thanh Hóa": [
    "đông hòa, đông sơn, thanh hóa",
    "ddoong hofa, ddoong sown, thanh hosa"
  ],
  "Đông Hưng A, An Minh, Kiên Giang": [
    "đông hưng a, an minh, kiên giang",
    "ddoong huwng a, an minh, kieen giang"
  ],
  "Đông Hưng B, An Minh, Kiên Giang": [
    "đông hưng b, an minh, kiên giang",
    "ddoong huwng b, an minh, kieen giang"
  ],
  "Đông Hưng, Lục Nam, Bắc Giang": [
    "đông hưng, lục nam, bắc giang",
    "ddoong huwng, lujc nam, bawsc giang"
  ],
  "Đông Hải, Thanh Hóa, Thanh Hóa": [
    "đông hải, thanh hóa, thanh hóa",
    "ddoong hari, thanh hosa, thanh hosa"
  ],
  "Đông Khê, Đông Sơn, Thanh Hóa": [
    "đông khê, đông sơn, thanh hóa",
    "ddoong khee, ddoong sown, thanh hosa"
  ],
  "Đông La, Đông Hưng, Thái Bình": [
    "đông la, đông hưng, thái bình",
    "ddoong la, ddoong huwng, thasi bifnh"
  ],
  "Đông Lĩnh, Thanh Hóa, Thanh Hóa": [
    "đông lĩnh, thanh hóa, thanh hóa",
    "ddoong lixnh, thanh hosa, thanh hosa"
  ],
  "Đông Minh, Đông Sơn, Thanh Hóa": [
    "đông minh, đông sơn, thanh hóa",
    "ddoong minh, ddoong sown, thanh hosa"
  ],
  "Đông Ninh, Đông Sơn, Thanh Hóa": [
    "đông ninh, đông sơn, thanh hóa",
    "ddoong ninh, ddoong sown, thanh hosa"
  ],
  "Đông Phong, Yên Phong, Bắc Ninh": [
    "đông phong, yên phong, bắc ninh",
    "ddoong phong, yeen phong, bawsc ninh"
  ],
  "Đông Phú, Quế Sơn, Quảng Nam": [
    "đông phú, quế sơn, quảng nam",
    "ddoong phus, quees sown, quarng nam"
  ],
  "Đông Phú, Đông Sơn, Thanh Hóa": [
    "đông phú, đông sơn, thanh hóa",
    "ddoong phus, ddoong sown, thanh hosa"
  ],
  "Đông Sơn, Tam Điệp, Ninh Bình": [
    "đông sơn, tam điệp, ninh bình",
    "ddoong sown, tam ddieejp, ninh bifnh"
  ],
  "Đông Sơn, Yên Thế, Bắc Giang": [
    "đông sơn, yên thế, bắc giang",
    "ddoong sown, yeen thees, bawsc giang"
  ],
  "Đông Sơn, Đô Lương, Nghệ An": [
    "đông sơn, đô lương, nghệ an",
    "ddoong sown, ddoo luwowng, ngheej an"
  ],
  "Đông Thanh, Lâm Hà, Lâm Đồng": [
    "đông thanh, lâm hà, lâm đồng",
    "ddoong thanh, laam haf, laam ddoofng"
  ],
  "Đông Thành, Đức Huệ, Long An": [
    "đông thành, đức huệ, long an",
    "ddoong thafnh, dduwsc hueej, long an"
  ],
  "Đông Thạnh, An Minh, Kiên Giang": [
    "đông thạnh, an minh, kiên giang",
    "ddoong thajnh, an minh, kieen giang"
  ],
  "Đông Thọ, Thanh Hóa, Thanh Hóa": [
    "đông thọ, thanh hóa, thanh hóa",
    "ddoong thoj, thanh hosa, thanh hosa"
  ],
  "Đông Thọ, Yên Phong, Bắc Ninh": [
    "đông thọ, yên phong, bắc ninh",
    "ddoong thoj, yeen phong, bawsc ninh"
  ],
  "Đông Thới, Cái Nước, Cà Mau": [
    "đông thới, cái nước, cà mau",
    "ddoong thowsi, casi nuwowsc, caf mau"
  ],
  "Đông Văn, Đông Sơn, Thanh Hóa": [
    "đông văn, đông sơn, thanh hóa",
    "ddoong vawn, ddoong sown, thanh hosa"
  ],
  "Đông Xuyên, Long Xuyên, An Giang": [
    "đông xuyên, long xuyên, an giang",
    "ddoong xuyeen, long xuyeen, an giang"
  ],
  "Đông Yên, Đông Sơn, Thanh Hóa": [
    "đông yên, đông sơn, thanh hóa",
    "ddoong yeen, ddoong sown, thanh hosa"
  ],
  "Đông Á, Đông Hưng, Thái Bình": [
    "đông á, đông hưng, thái bình",
    "ddoong as, ddoong huwng, thasi bifnh"
  ],
  "Đường Lâm, Sơn Tây, Hà Nội": [
    "đường lâm, sơn tây, hà nội",
    "dduwowfng laam, sown taay, haf nooji"
  ],
  "Đạ Kho, Đạ Tẻh, Lâm Đồng": [
    "đạ kho, đạ tẻh, lâm đồng",
    "ddaj kho, ddaj terh, laam ddoofng"
  ],
  "Đạ Long, Đam Rông, Lâm Đồng": [
    "đạ long, đam rông, lâm đồng",
    "ddaj long, ddam roong, laam ddoofng"
  ],
  "Đạ Oai, Đạ Huoai, Lâm Đồng": [
    "đạ oai, đạ huoai, lâm đồng",
    "ddaj oai, ddaj huoai, laam ddoofng"
  ],
  "Đạ Pal, Đạ Tẻh, Lâm Đồng": [
    "đạ pal, đạ tẻh, lâm đồng",
    "ddaj pal, ddaj terh, laam ddoofng"
  ],
  "Đạ Rsal, Đam Rông, Lâm Đồng": [
    "đạ rsal, đam rông, lâm đồng",
    "ddaj rsal, ddam roong, laam ddoofng"
  ],
  "Đạ Đờn, Lâm Hà, Lâm Đồng": [
    "đạ đờn, lâm hà, lâm đồng",
    "ddaj ddowfn, laam haf, laam ddoofng"
  ],
  "Đại An, Đại Lộc, Quảng Nam": [
    "đại an, đại lộc, quảng nam",
    "ddaji an, ddaji loojc, quarng nam"
  ],
  "Đại Hưng, Mỹ Đức, Hà Nội": [
    "đại hưng, mỹ đức, hà nội",
    "ddaji huwng, myx dduwsc, haf nooji"
  ],
  "Đại Mạch, Đông Anh, Hà Nội": [
    "đại mạch, đông anh, hà nội",
    "ddaji majch, ddoong anh, haf nooji"
  ],
  "Đại Ngãi, Long Phú, Sóc Trăng": [
    "đại ngãi, long phú, sóc trăng",
    "ddaji ngaxi, long phus, sosc trawng"
  ],
  "Đại Phúc, Bắc Ninh, Bắc Ninh": [
    "đại phúc, bắc ninh, bắc ninh",
    "ddaji phusc, bawsc ninh, bawsc ninh"
  ],
  "Đại Phạm, Hạ Hoà, Phú Thọ": [
    "đại phạm, hạ hoà, phú thọ",
    "ddaji phajm, haj hoaf, phus thoj"
  ],
  "Đại Sơn, Đô Lương, Nghệ An": [
    "đại sơn, đô lương, nghệ an",
    "ddaji sown, ddoo luwowng, ngheej an"
  ],
  "Đại Thành, Quốc Oai, Hà Nội": [
    "đại thành, quốc oai, hà nội",
    "ddaji thafnh, quoosc oai, haf nooji"
  ],
  "Đại Tự, Yên Lạc, Vĩnh Phúc": [
    "đại tự, yên lạc, vĩnh phúc",
    "ddaji tuwj, yeen lajc, vixnh phusc"
  ],
  "Đại Yên, Hạ Long, Quảng Ninh": [
    "đại yên, hạ long, quảng ninh",
    "ddaji yeen, haj long, quarng ninh"
  ],
  "Đại Đồng, Tiên Du, Bắc Ninh": [
    "đại đồng, tiên du, bắc ninh",
    "ddaji ddoofng, tieen du, bawsc ninh"
  ],
  "Đạo Trù, Tam Đảo, Vĩnh Phúc": [
    "đạo trù, tam đảo, vĩnh phúc",
    "ddajo truf, tam ddaro, vixnh phusc"
  ],
  "Đạo Tú, Tam Dương, Vĩnh Phúc": [
    "đạo tú, tam dương, vĩnh phúc",
    "ddajo tus, tam duwowng, vixnh phusc"
  ],
  "Đạp Thanh, Ba Chẽ, Quảng Ninh": [
    "đạp thanh, ba chẽ, quảng ninh",
    "ddajp thanh, ba chex, quarng ninh"
  ],
  "Đầm Hà, Đầm Hà, Quảng Ninh": [
    "đầm hà, đầm hà, quảng ninh",
    "ddaafm haf, ddaafm haf, quarng ninh"
  ],
  "Đập Đá, An Nhơn, Bình Định": [
    "đập đá, an nhơn, bình định",
    "ddaajp ddas, an nhown, bifnh ddijnh"
  ],
  "Đắc Pring, Nam Giang, Quảng Nam": [
    "đắc pring, nam giang, quảng nam",
    "ddawsc pring, nam giang, quarng nam"
  ],
  "Đắc Sở, Hoài Đức, Hà Nội": [
    "đắc sở, hoài đức, hà nội",
    "ddawsc sowr, hoafi dduwsc, haf nooji"
  ],
  "Đắk Ha, Đăk Glong, Đắk Nông": [
    "đắk ha, đăk glong, đắk nông",
    "ddawsk ha, ddawk glong, ddawsk noong"
  ],
  "Đắk Kơ Ning, Kông Chro, Gia Lai": [
    "đắk kơ ning, kông chro, gia lai",
    "ddawsk kow ning, koong chro, gia lai"
  ],
  "Đắk Mil, Đắk Mil, Đắk Nông": [
    "đắk mil, đắk mil, đắk nông",
    "ddawsk mil, ddawsk mil, ddawsk noong"
  ],
  "Đắk Ngo, Tuy Đức, Đắk Nông": [
    "đắk ngo, tuy đức, đắk nông",
    "ddawsk ngo, tuy dduwsc, ddawsk noong"
  ],
  "Đắk Nia, Gia Nghĩa, Đắk Nông": [
    "đắk nia, gia nghĩa, đắk nông",
    "ddawsk nia, gia nghixa, ddawsk noong"
  ],
  "Đằng Lâm, Hải An, Hải Phòng": [
    "đằng lâm, hải an, hải phòng",
    "ddawfng laam, hari an, hari phofng"
  ],
  "Đỉnh Bàn, Thạch Hà, Hà Tĩnh": [
    "đỉnh bàn, thạch hà, hà tĩnh",
    "ddirnh bafn, thajch haf, haf tixnh"
  ],
  "Định An, Lấp Vò, Đồng Tháp": [
    "định an, lấp vò, đồng tháp",
    "ddijnh an, laasp vof, ddoofng thasp"
  ],
  "Định Công, Hoàng Mai, Hà Nội": [
    "định công, hoàng mai, hà nội",
    "ddijnh coong, hoafng mai, haf nooji"
  ],
  "Định Hải, Tĩnh Gia, Thanh Hóa": [
    "định hải, tĩnh gia, thanh hóa",
    "ddijnh hari, tixnh gia, thanh hosa"
  ],
  "Định Môn, Thới Lai, Cần Thơ": [
    "định môn, thới lai, cần thơ",
    "ddijnh moon, thowsi lai, caafn thow"
  ],
  "Định Mỹ, Thoại Sơn, An Giang": [
    "định mỹ, thoại sơn, an giang",
    "ddijnh myx, thoaji sown, an giang"
  ],
  "Đống Đa, Vĩnh Yên, Vĩnh Phúc": [
    "đống đa, vĩnh yên, vĩnh phúc",
    "ddoosng dda, vixnh yeen, vixnh phusc"
  ],
  "Đồng Chum, Đà Bắc, Hoà Bình": [
    "đồng chum, đà bắc, hoà bình",
    "ddoofng chum, ddaf bawsc, hoaf bifnh"
  ],
  "Đồng Khê, Văn Chấn, Yên Bái": [
    "đồng khê, văn chấn, yên bái",
    "ddoofng khee, vawn chaasn, yeen basi"
  ],
  "Đồng Mỏ, Chi Lăng, Lạng Sơn": [
    "đồng mỏ, chi lăng, lạng sơn",
    "ddoofng mor, chi lawng, lajng sown"
  ],
  "Đồng Quang, Quốc Oai, Hà Nội": [
    "đồng quang, quốc oai, hà nội",
    "ddoofng quang, quoosc oai, haf nooji"
  ],
  "Đồng Thanh, Vũ Thư, Thái Bình": [
    "đồng thanh, vũ thư, thái bình",
    "ddoofng thanh, vux thuw, thasi bifnh"
  ],
  "Đồng Tâm, Bắc Quang, Hà Giang": [
    "đồng tâm, bắc quang, hà giang",
    "ddoofng taam, bawsc quang, haf giang"
  ],
  "Đồng Tâm, Mỹ Đức, Hà Nội": [
    "đồng tâm, mỹ đức, hà nội",
    "ddoofng taam, myx dduwsc, haf nooji"
  ],
  "Đồng Văn, Quế Phong, Nghệ An": [
    "đồng văn, quế phong, nghệ an",
    "ddoofng vawn, quees phong, ngheej an"
  ],
  "Đồng Yên, Bắc Quang, Hà Giang": [
    "đồng yên, bắc quang, hà giang",
    "ddoofng yeen, bawsc quang, haf giang"
  ],
  "Độc Lập, Hòa Bình, Hoà Bình": [
    "độc lập, hòa bình, hoà bình",
    "ddoojc laajp, hofa bifnh, hoaf bifnh"
  ],
  "Độc Lập, Hưng Hà, Thái Bình": [
    "độc lập, hưng hà, thái bình",
    "ddoojc laajp, huwng haf, thasi bifnh"
  ],
  "Đức An, Đắk Song, Đắk Nông": [
    "đức an, đắk song, đắk nông",
    "dduwsc an, ddawsk song, ddawsk noong"
  ],
  "Đức Hương, Vũ Quang, Hà Tĩnh": [
    "đức hương, vũ quang, hà tĩnh",
    "dduwsc huwowng, vux quang, haf tixnh"
  ],
  "Đức Ninh, Hàm Yên, Tuyên Quang": [
    "đức ninh, hàm yên, tuyên quang",
    "dduwsc ninh, hafm yeen, tuyeen quang"
  ],
  "Đức Vân, Ngân Sơn, Bắc Kạn": [
    "đức vân, ngân sơn, bắc kạn",
    "dduwsc vaan, ngaan sown, bawsc kajn"
  ],
  "Đức Xuân, Bắc Quang, Hà Giang": [
    "đức xuân, bắc quang, hà giang",
    "dduwsc xuaan, bawsc quang, haf giang"
  ],
  "Đức Xuân, Thạch An, Cao Bằng": [
    "đức xuân, thạch an, cao bằng",
    "dduwsc xuaan, thajch an, cao bawfng"
  ],
  " A Dơi, Hướng Hóa, Quảng Trị": [
    " a dơi, hướng hóa, quảng trị",
    " a dowi, huwowsng hosa, quarng trij"
  ],
  " An Lạc, Bình Tân, Hồ Chí Minh": [
    " an lạc, bình tân, hồ chí minh",
    " an lajc, bifnh taan, hoof chis minh"
  ],
  " Tam Quan, Hoài Nhơn, Bình Định": [
    " tam quan, hoài nhơn, bình định",
    " tam quan, hoafi nhown, bifnh ddijnh"
  ],
  " Đắk Lao, Đắk Mil, Đắk Nông": [
    " đắk lao, đắk mil, đắk nông",
    " ddawsk lao, ddawsk mil, ddawsk noong"
  ],
  ", Côn Đảo, Bà Rịa - Vũng Tàu": [
    ", côn đảo, bà rịa - vũng tàu",
    ", coon ddaro, baf rija - vuxng tafu"
  ],
  "A Ngo, A Lưới, Thừa Thiên Huế": [
    "a ngo, a lưới, thừa thiên huế",
    "a ngo, a luwowsi, thuwfa thieen huees"
  ],
  "An Bình, Kiến Xương, Thái Bình": [
    "an bình, kiến xương, thái bình",
    "an bifnh, kieesn xuwowng, thasi bifnh"
  ],
  "An Hiệp, Quỳnh Phụ, Thái Bình": [
    "an hiệp, quỳnh phụ, thái bình",
    "an hieejp, quyfnh phuj, thasi bifnh"
  ],
  "An Hải Tây, Sơn Trà, Đà Nẵng": [
    "an hải tây, sơn trà, đà nẵng",
    "an hari taay, sown traf, ddaf nawxng"
  ],
  "An Hải, Ninh Phước, Ninh Thuận": [
    "an hải, ninh phước, ninh thuận",
    "an hari, ninh phuwowsc, ninh thuaajn"
  ],
  "An Khánh, Đại Từ, Thái Nguyên": [
    "an khánh, đại từ, thái nguyên",
    "an khasnh, ddaji tuwf, thasi nguyeen"
  ],
  "An Lạc, Hồng Ngự, Đồng Tháp": [
    "an lạc, hồng ngự, đồng tháp",
    "an lajc, hoofng nguwj, ddoofng thasp"
  ],
  "An Lộc, Hồng Ngự, Đồng Tháp": [
    "an lộc, hồng ngự, đồng tháp",
    "an loojc, hoofng nguwj, ddoofng thasp"
  ],
  "An Nhơn, Châu Thành, Đồng Tháp": [
    "an nhơn, châu thành, đồng tháp",
    "an nhown, chaau thafnh, ddoofng thasp"
  ],
  "An Phú, Hớn Quản, Bình Phước": [
    "an phú, hớn quản, bình phước",
    "an phus, howsn quarn, bifnh phuwowsc"
  ],
  "An Phước, Long Thành, Đồng Nai": [
    "an phước, long thành, đồng nai",
    "an phuwowsc, long thafnh, ddoofng nai"
  ],
  "An Quảng Hữu, Trà Cú, Trà Vinh": [
    "an quảng hữu, trà cú, trà vinh",
    "an quarng huwxu, traf cus, traf vinh"
  ],
  "An Sinh, Đông Triều, Quảng Ninh": [
    "an sinh, đông triều, quảng ninh",
    "an sinh, ddoong trieefu, quarng ninh"
  ],
  "An Sơn, Thuỷ Nguyên, Hải Phòng": [
    "an sơn, thuỷ nguyên, hải phòng",
    "an sown, thuyr nguyeen, hari phofng"
  ],
  "An Thượng, Hoài Đức, Hà Nội": [
    "an thượng, hoài đức, hà nội",
    "an thuwowjng, hoafi dduwsc, haf nooji"
  ],
  "An Thượng, Yên Thế, Bắc Giang": [
    "an thượng, yên thế, bắc giang",
    "an thuwowjng, yeen thees, bawsc giang"
  ],
  "An Thạnh, Thuận An, Bình Dương": [
    "an thạnh, thuận an, bình dương",
    "an thajnh, thuaajn an, bifnh duwowng"
  ],
  "An Thủy, Lệ Thủy, Quảng Bình": [
    "an thủy, lệ thủy, quảng bình",
    "an thury, leej thury, quarng bifnh"
  ],
  "An Tràng, Quỳnh Phụ, Thái Bình": [
    "an tràng, quỳnh phụ, thái bình",
    "an trafng, quyfnh phuj, thasi bifnh"
  ],
  "An Trường A, Càng Long, Trà Vinh": [
    "an trường a, càng long, trà vinh",
    "an truwowfng a, cafng long, traf vinh"
  ],
  "An Trạch, Đông Hải, Bạc Liêu": [
    "an trạch, đông hải, bạc liêu",
    "an trajch, ddoong hari, bajc lieeu"
  ],
  "An Điền, Bến Cát, Bình Dương": [
    "an điền, bến cát, bình dương",
    "an ddieefn, beesn cast, bifnh duwowng"
  ],
  "An Đông, Huế, Thừa Thiên Huế": [
    "an đông, huế, thừa thiên huế",
    "an ddoong, huees, thuwfa thieen huees"
  ],
  "Anh Dũng, Dương Kinh, Hải Phòng": [
    "anh dũng, dương kinh, hải phòng",
    "anh duxng, duwowng kinh, hari phofng"
  ],
  "Biên Giới, Châu Thành, Tây Ninh": [
    "biên giới, châu thành, tây ninh",
    "bieen giowsi, chaau thafnh, taay ninh"
  ],
  "Biên Sơn, Lục Ngạn, Bắc Giang": [
    "biên sơn, lục ngạn, bắc giang",
    "bieen sown, lujc ngajn, bawsc giang"
  ],
  "Buôn Choah, Krông Nô, Đắk Nông": [
    "buôn choah, krông nô, đắk nông",
    "buoon choah, kroong noo, ddawsk noong"
  ],
  "Bà Triệu, Nam Định, Nam Định": [
    "bà triệu, nam định, nam định",
    "baf trieeju, nam ddijnh, nam ddijnh"
  ],
  "Bàn Long, Châu Thành, Tiền Giang": [
    "bàn long, châu thành, tiền giang",
    "bafn long, chaau thafnh, tieefn giang"
  ],
  "Bá Hiến, Bình Xuyên, Vĩnh Phúc": [
    "bá hiến, bình xuyên, vĩnh phúc",
    "bas hieesn, bifnh xuyeen, vixnh phusc"
  ],
  "Bách Khoa, Hai Bà Trưng, Hà Nội": [
    "bách khoa, hai bà trưng, hà nội",
    "basch khoa, hai baf truwng, haf nooji"
  ],
  "Bãi Bông, Phổ Yên, Thái Nguyên": [
    "bãi bông, phổ yên, thái nguyên",
    "baxi boong, phoor yeen, thasi nguyeen"
  ],
  "Bình Dân, Kim Thành, Hải Dương": [
    "bình dân, kim thành, hải dương",
    "bifnh daan, kim thafnh, hari duwowng"
  ],
  "Bình Dân, Vân Đồn, Quảng Ninh": [
    "bình dân, vân đồn, quảng ninh",
    "bifnh daan, vaan ddoofn, quarng ninh"
  ],
  "Bình Giang, Hòn Đất, Kiên Giang": [
    "bình giang, hòn đất, kiên giang",
    "bifnh giang, hofn ddaast, kieen giang"
  ],
  "Bình Hiên, Hải Châu, Đà Nẵng": [
    "bình hiên, hải châu, đà nẵng",
    "bifnh hieen, hari chaau, ddaf nawxng"
  ],
  "Bình Hòa Nam, Đức Huệ, Long An": [
    "bình hòa nam, đức huệ, long an",
    "bifnh hofa nam, dduwsc hueej, long an"
  ],
  "Bình Hòa Trung, Mộc Hóa, Long An": [
    "bình hòa trung, mộc hóa, long an",
    "bifnh hofa trung, moojc hosa, long an"
  ],
  "Bình Hòa, Bình Sơn, Quảng Ngãi": [
    "bình hòa, bình sơn, quảng ngãi",
    "bifnh hofa, bifnh sown, quarng ngaxi"
  ],
  "Bình Hòa, Krông A Na, Đắk Lắk": [
    "bình hòa, krông a na, đắk lắk",
    "bifnh hofa, kroong a na, ddawsk lawsk"
  ],
  "Bình Hòa, Thuận An, Bình Dương": [
    "bình hòa, thuận an, bình dương",
    "bifnh hofa, thuaajn an, bifnh duwowng"
  ],
  "Bình Long, Bình Sơn, Quảng Ngãi": [
    "bình long, bình sơn, quảng ngãi",
    "bifnh long, bifnh sown, quarng ngaxi"
  ],
  "Bình Lăng, Tứ Kỳ, Hải Dương": [
    "bình lăng, tứ kỳ, hải dương",
    "bifnh lawng, tuws kyf, hari duwowng"
  ],
  "Bình Lương, Như Xuân, Thanh Hóa": [
    "bình lương, như xuân, thanh hóa",
    "bifnh luwowng, nhuw xuaan, thanh hosa"
  ],
  "Bình Lộc, Long Khánh, Đồng Nai": [
    "bình lộc, long khánh, đồng nai",
    "bifnh loojc, long khasnh, ddoofng nai"
  ],
  "Bình Lợi, Vĩnh Cửu, Đồng Nai": [
    "bình lợi, vĩnh cửu, đồng nai",
    "bifnh lowji, vixnh cuwru, ddoofng nai"
  ],
  "Bình Minh, Bình Sơn, Quảng Ngãi": [
    "bình minh, bình sơn, quảng ngãi",
    "bifnh minh, bifnh sown, quarng ngaxi"
  ],
  "Bình Minh, Thăng Bình, Quảng Nam": [
    "bình minh, thăng bình, quảng nam",
    "bifnh minh, thawng bifnh, quarng nam"
  ],
  "Bình Mỹ, Bình Sơn, Quảng Ngãi": [
    "bình mỹ, bình sơn, quảng ngãi",
    "bifnh myx, bifnh sown, quarng ngaxi"
  ],
  "Bình Ninh, Chợ Gạo, Tiền Giang": [
    "bình ninh, chợ gạo, tiền giang",
    "bifnh ninh, chowj gajo, tieefn giang"
  ],
  "Bình Phan, Chợ Gạo, Tiền Giang": [
    "bình phan, chợ gạo, tiền giang",
    "bifnh phan, chowj gajo, tieefn giang"
  ],
  "Bình Phú, Chiêm Hóa, Tuyên Quang": [
    "bình phú, chiêm hóa, tuyên quang",
    "bifnh phus, chieem hosa, tuyeen quang"
  ],
  "Bình Phú, Thăng Bình, Quảng Nam": [
    "bình phú, thăng bình, quảng nam",
    "bifnh phus, thawng bifnh, quarng nam"
  ],
  "Bình Phú, Thạch Thất, Hà Nội": [
    "bình phú, thạch thất, hà nội",
    "bifnh phus, thajch thaast, haf nooji"
  ],
  "Bình Quý, Thăng Bình, Quảng Nam": [
    "bình quý, thăng bình, quảng nam",
    "bifnh quys, thawng bifnh, quarng nam"
  ],
  "Bình Thuận, Văn Chấn, Yên Bái": [
    "bình thuận, văn chấn, yên bái",
    "bifnh thuaajn, vawn chaasn, yeen basi"
  ],
  "Bình Thạnh, Châu Thành, An Giang": [
    "bình thạnh, châu thành, an giang",
    "bifnh thajnh, chaau thafnh, an giang"
  ],
  "Bình Thạnh, Long Mỹ, Hậu Giang": [
    "bình thạnh, long mỹ, hậu giang",
    "bifnh thajnh, long myx, haaju giang"
  ],
  "Bình Thới, Bình Đại, Bến Tre": [
    "bình thới, bình đại, bến tre",
    "bifnh thowsi, bifnh ddaji, beesn tre"
  ],
  "Bình Yên, Thạch Thất, Hà Nội": [
    "bình yên, thạch thất, hà nội",
    "bifnh yeen, thajch thaast, haf nooji"
  ],
  "Bình Đông, Gò Công, Tiền Giang": [
    "bình đông, gò công, tiền giang",
    "bifnh ddoong, gof coong, tieefn giang"
  ],
  "Bình Đại, Bình Đại, Bến Tre": [
    "bình đại, bình đại, bến tre",
    "bifnh ddaji, bifnh ddaji, beesn tre"
  ],
  "Bù Nho, Phú Riềng, Bình Phước": [
    "bù nho, phú riềng, bình phước",
    "buf nho, phus rieefng, bifnh phuwowsc"
  ],
  "Bạch Hạc, Việt Trì, Phú Thọ": [
    "bạch hạc, việt trì, phú thọ",
    "bajch hajc, vieejt trif, phus thoj"
  ],
  "Bạch Long, Giao Thủy, Nam Định": [
    "bạch long, giao thủy, nam định",
    "bajch long, giao thury, nam ddijnh"
  ],
  "Bạch Mai, Hai Bà Trưng, Hà Nội": [
    "bạch mai, hai bà trưng, hà nội",
    "bajch mai, hai baf truwng, haf nooji"
  ],
  "Bạch Ngọc, Vị Xuyên, Hà Giang": [
    "bạch ngọc, vị xuyên, hà giang",
    "bajch ngojc, vij xuyeen, haf giang"
  ],
  "Bản Giang, Tam Đường, Lai Châu": [
    "bản giang, tam đường, lai châu",
    "barn giang, tam dduwowfng, lai chaau"
  ],
  "Bản Máy, Hoàng Su Phì, Hà Giang": [
    "bản máy, hoàng su phì, hà giang",
    "barn masy, hoafng su phif, haf giang"
  ],
  "Bảo Hiệu, Yên Thủy, Hoà Bình": [
    "bảo hiệu, yên thủy, hoà bình",
    "baro hieeju, yeen thury, hoaf bifnh"
  ],
  "Bảo Quang, Long Khánh, Đồng Nai": [
    "bảo quang, long khánh, đồng nai",
    "baro quang, long khasnh, ddoofng nai"
  ],
  "Bắc Hồng, Hồng Lĩnh, Hà Tĩnh": [
    "bắc hồng, hồng lĩnh, hà tĩnh",
    "bawsc hoofng, hoofng lixnh, haf tixnh"
  ],
  "Bắc Sơn, Phổ Yên, Thái Nguyên": [
    "bắc sơn, phổ yên, thái nguyên",
    "bawsc sown, phoor yeen, thasi nguyeen"
  ],
  "Bắc Việt, Văn Lãng, Lạng Sơn": [
    "bắc việt, văn lãng, lạng sơn",
    "bawsc vieejt, vawn laxng, lajng sown"
  ],
  "Bằng Cốc, Hàm Yên, Tuyên Quang": [
    "bằng cốc, hàm yên, tuyên quang",
    "bawfng coosc, hafm yeen, tuyeen quang"
  ],
  "Bằng Doãn, Đoan Hùng, Phú Thọ": [
    "bằng doãn, đoan hùng, phú thọ",
    "bawfng doaxn, ddoan hufng, phus thoj"
  ],
  "Bằng Luân, Đoan Hùng, Phú Thọ": [
    "bằng luân, đoan hùng, phú thọ",
    "bawfng luaan, ddoan hufng, phus thoj"
  ],
  "Bến Nghé, Quận 1, Hồ Chí Minh": [
    "bến nghé, quận 1, hồ chí minh",
    "beesn nghes, quaajn 1, hoof chis minh"
  ],
  "Bến Quan, Vĩnh Linh, Quảng Trị": [
    "bến quan, vĩnh linh, quảng trị",
    "beesn quan, vixnh linh, quarng trij"
  ],
  "Bến Tắm, Chí Linh, Hải Dương": [
    "bến tắm, chí linh, hải dương",
    "beesn tawsm, chis linh, hari duwowng"
  ],
  "Bồ Sao, Vĩnh Tường, Vĩnh Phúc": [
    "bồ sao, vĩnh tường, vĩnh phúc",
    "boof sao, vixnh tuwowfng, vixnh phusc"
  ],
  "Bồ Xuyên, Thái Bình, Thái Bình": [
    "bồ xuyên, thái bình, thái bình",
    "boof xuyeen, thasi bifnh, thasi bifnh"
  ],
  "Cam Hiệp Nam, Cam Lâm, Khánh Hòa": [
    "cam hiệp nam, cam lâm, khánh hòa",
    "cam hieejp nam, cam laam, khasnh hofa"
  ],
  "Cam Hải Tây, Cam Lâm, Khánh Hòa": [
    "cam hải tây, cam lâm, khánh hòa",
    "cam hari taay, cam laam, khasnh hofa"
  ],
  "Cam Thành Nam, Cam Ranh, Khánh Hòa": [
    "cam thành nam, cam ranh, khánh hòa",
    "cam thafnh nam, cam ranh, khasnh hofa"
  ],
  "Canh Hiển, Vân Canh, Bình Định": [
    "canh hiển, vân canh, bình định",
    "canh hieern, vaan canh, bifnh ddijnh"
  ],
  "Canh Hiệp, Vân Canh, Bình Định": [
    "canh hiệp, vân canh, bình định",
    "canh hieejp, vaan canh, bifnh ddijnh"
  ],
  "Canh Nậu, Thạch Thất, Hà Nội": [
    "canh nậu, thạch thất, hà nội",
    "canh naaju, thajch thaast, haf nooji"
  ],
  "Cao Dương, Lương Sơn, Hoà Bình": [
    "cao dương, lương sơn, hoà bình",
    "cao duwowng, luwowng sown, hoaf bifnh"
  ],
  "Cao Minh, Tràng Định, Lạng Sơn": [
    "cao minh, tràng định, lạng sơn",
    "cao minh, trafng ddijnh, lajng sown"
  ],
  "Cao Sơn, Mường Khương, Lào Cai": [
    "cao sơn, mường khương, lào cai",
    "cao sown, muwowfng khuwowng, lafo cai"
  ],
  "Cao Thăng, Trùng Khánh, Cao Bằng": [
    "cao thăng, trùng khánh, cao bằng",
    "cao thawng, trufng khasnh, cao bawfng"
  ],
  "Cao Thượng, Tân Yên, Bắc Giang": [
    "cao thượng, tân yên, bắc giang",
    "cao thuwowjng, taan yeen, bawsc giang"
  ],
  "Cao Thịnh, Ngọc Lặc, Thanh Hóa": [
    "cao thịnh, ngọc lặc, thanh hóa",
    "cao thijnh, ngojc lawjc, thanh hosa"
  ],
  "Chiềng Bôm, Thuận Châu, Sơn La": [
    "chiềng bôm, thuận châu, sơn la",
    "chieefng boom, thuaajn chaau, sown la"
  ],
  "Chiềng Châu, Mai Châu, Hoà Bình": [
    "chiềng châu, mai châu, hoà bình",
    "chieefng chaau, mai chaau, hoaf bifnh"
  ],
  "Chiềng Khương, Sông Mã, Sơn La": [
    "chiềng khương, sông mã, sơn la",
    "chieefng khuwowng, soong max, sown la"
  ],
  "Chiềng Khừa, Mộc Châu, Sơn La": [
    "chiềng khừa, mộc châu, sơn la",
    "chieefng khuwfa, moojc chaau, sown la"
  ],
  "Chiềng Tương, Yên Châu, Sơn La": [
    "chiềng tương, yên châu, sơn la",
    "chieefng tuwowng, yeen chaau, sown la"
  ],
  "Chân Mộng, Đoan Hùng, Phú Thọ": [
    "chân mộng, đoan hùng, phú thọ",
    "chaan moojng, ddoan hufng, phus thoj"
  ],
  "Châu Bình, Giồng Trôm, Bến Tre": [
    "châu bình, giồng trôm, bến tre",
    "chaau bifnh, gioofng troom, beesn tre"
  ],
  "Châu Hưng, Vĩnh Lợi, Bạc Liêu": [
    "châu hưng, vĩnh lợi, bạc liêu",
    "chaau huwng, vixnh lowji, bajc lieeu"
  ],
  "Châu Nhân, Hưng Nguyên, Nghệ An": [
    "châu nhân, hưng nguyên, nghệ an",
    "chaau nhaan, huwng nguyeen, ngheej an"
  ],
  "Châu Sơn, Đình Lập, Lạng Sơn": [
    "châu sơn, đình lập, lạng sơn",
    "chaau sown, ddifnh laajp, lajng sown"
  ],
  "Châu Thuận, Quỳ Châu, Nghệ An": [
    "châu thuận, quỳ châu, nghệ an",
    "chaau thuaajn, quyf chaau, ngheej an"
  ],
  "Châu Thành, Châu Thành, Bến Tre": [
    "châu thành, châu thành, bến tre",
    "chaau thafnh, chaau thafnh, beesn tre"
  ],
  "Châu Thành, Châu Thành, Trà Vinh": [
    "châu thành, châu thành, trà vinh",
    "chaau thafnh, chaau thafnh, traf vinh"
  ],
  "Châu Thành, Châu Thành, Tây Ninh": [
    "châu thành, châu thành, tây ninh",
    "chaau thafnh, chaau thafnh, taay ninh"
  ],
  "Châu Thắng, Quỳ Châu, Nghệ An": [
    "châu thắng, quỳ châu, nghệ an",
    "chaau thawsng, quyf chaau, ngheej an"
  ],
  "Châu Văn Liêm, Ô Môn, Cần Thơ": [
    "châu văn liêm, ô môn, cần thơ",
    "chaau vawn lieem, oo moon, caafn thow"
  ],
  "Chí Thảo, Quảng Hòa, Cao Bằng": [
    "chí thảo, quảng hòa, cao bằng",
    "chis tharo, quarng hofa, cao bawfng"
  ],
  "Chính Gián, Thanh Khê, Đà Nẵng": [
    "chính gián, thanh khê, đà nẵng",
    "chisnh giasn, thanh khee, ddaf nawxng"
  ],
  "Cuôr KNia, Buôn Đôn, Đắk Lắk": [
    "cuôr knia, buôn đôn, đắk lắk",
    "cuoor knia, buoon ddoon, ddawsk lawsk"
  ],
  "Cành Nàng, Bá Thước, Thanh Hóa": [
    "cành nàng, bá thước, thanh hóa",
    "cafnh nafng, bas thuwowsc, thanh hosa"
  ],
  "Cán Chu Phìn, Mèo Vạc, Hà Giang": [
    "cán chu phìn, mèo vạc, hà giang",
    "casn chu phifn, mefo vajc, haf giang"
  ],
  "Cát Chánh, Phù Cát, Bình Định": [
    "cát chánh, phù cát, bình định",
    "cast chasnh, phuf cast, bifnh ddijnh"
  ],
  "Cát Hiệp, Phù Cát, Bình Định": [
    "cát hiệp, phù cát, bình định",
    "cast hieejp, phuf cast, bifnh ddijnh"
  ],
  "Cát Khánh, Phù Cát, Bình Định": [
    "cát khánh, phù cát, bình định",
    "cast khasnh, phuf cast, bifnh ddijnh"
  ],
  "Cát Thành, Phù Cát, Bình Định": [
    "cát thành, phù cát, bình định",
    "cast thafnh, phuf cast, bifnh ddijnh"
  ],
  "Cát Thành, Trực Ninh, Nam Định": [
    "cát thành, trực ninh, nam định",
    "cast thafnh, truwjc ninh, nam ddijnh"
  ],
  "Cát Tiến, Phù Cát, Bình Định": [
    "cát tiến, phù cát, bình định",
    "cast tieesn, phuf cast, bifnh ddijnh"
  ],
  "Công Bằng, Pác Nặm, Bắc Kạn": [
    "công bằng, pác nặm, bắc kạn",
    "coong bawfng, pasc nawjm, bawsc kajn"
  ],
  "Công Liêm, Nông Cống, Thanh Hóa": [
    "công liêm, nông cống, thanh hóa",
    "coong lieem, noong coosng, thanh hosa"
  ],
  "Cư Drăm, Krông Bông, Đắk Lắk": [
    "cư drăm, krông bông, đắk lắk",
    "cuw drawm, kroong boong, ddawsk lawsk"
  ],
  "Cấm Sơn, Lục Ngạn, Bắc Giang": [
    "cấm sơn, lục ngạn, bắc giang",
    "caasm sown, lujc ngajn, bawsc giang"
  ],
  "Cần Giuộc, Cần Giuộc, Long An": [
    "cần giuộc, cần giuộc, long an",
    "caafn giuoojc, caafn giuoojc, long an"
  ],
  "Cầu Tre, Ngô Quyền, Hải Phòng": [
    "cầu tre, ngô quyền, hải phòng",
    "caafu tre, ngoo quyeefn, hari phofng"
  ],
  "Cẩm Bình, Cẩm Thủy, Thanh Hóa": [
    "cẩm bình, cẩm thủy, thanh hóa",
    "caarm bifnh, caarm thury, thanh hosa"
  ],
  "Cẩm Châu, Cẩm Thủy, Thanh Hóa": [
    "cẩm châu, cẩm thủy, thanh hóa",
    "caarm chaau, caarm thury, thanh hosa"
  ],
  "Cẩm Chế, Thanh Hà, Hải Dương": [
    "cẩm chế, thanh hà, hải dương",
    "caarm chees, thanh haf, hari duwowng"
  ],
  "Cẩm Giang, Cẩm Thủy, Thanh Hóa": [
    "cẩm giang, cẩm thủy, thanh hóa",
    "caarm giang, caarm thury, thanh hosa"
  ],
  "Cẩm Liên, Cẩm Thủy, Thanh Hóa": [
    "cẩm liên, cẩm thủy, thanh hóa",
    "caarm lieen, caarm thury, thanh hosa"
  ],
  "Cẩm Phú, Cẩm Phả, Quảng Ninh": [
    "cẩm phú, cẩm phả, quảng ninh",
    "caarm phus, caarm phar, quarng ninh"
  ],
  "Cẩm Sơn, Cẩm Phả, Quảng Ninh": [
    "cẩm sơn, cẩm phả, quảng ninh",
    "caarm sown, caarm phar, quarng ninh"
  ],
  "Cẩm Thành, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm thành, cẩm xuyên, hà tĩnh",
    "caarm thafnh, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Tây, Cẩm Phả, Quảng Ninh": [
    "cẩm tây, cẩm phả, quảng ninh",
    "caarm taay, caarm phar, quarng ninh"
  ],
  "Cẩm Xuyên, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm xuyên, cẩm xuyên, hà tĩnh",
    "caarm xuyeen, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Yên, Thạch Thất, Hà Nội": [
    "cẩm yên, thạch thất, hà nội",
    "caarm yeen, thajch thaast, haf nooji"
  ],
  "Cổ Dũng, Kim Thành, Hải Dương": [
    "cổ dũng, kim thành, hải dương",
    "coor duxng, kim thafnh, hari duwowng"
  ],
  "Cổ Thành, Chí Linh, Hải Dương": [
    "cổ thành, chí linh, hải dương",
    "coor thafnh, chis linh, hari duwowng"
  ],
  "Cộng Hoà, Chí Linh, Hải Dương": [
    "cộng hoà, chí linh, hải dương",
    "coojng hoaf, chis linh, hari duwowng"
  ],
  "Cộng Hòa, Nam Sách, Hải Dương": [
    "cộng hòa, nam sách, hải dương",
    "coojng hofa, nam sasch, hari duwowng"
  ],
  "Cửa Bắc, Nam Định, Nam Định": [
    "cửa bắc, nam định, nam định",
    "cuwra bawsc, nam ddijnh, nam ddijnh"
  ],
  "Cửa Cạn, Phú Quốc, Kiên Giang": [
    "cửa cạn, phú quốc, kiên giang",
    "cuwra cajn, phus quoosc, kieen giang"
  ],
  "Cửa Việt, Gio Linh, Quảng Trị": [
    "cửa việt, gio linh, quảng trị",
    "cuwra vieejt, gio linh, quarng trij"
  ],
  "Cửa Ông, Cẩm Phả, Quảng Ninh": [
    "cửa ông, cẩm phả, quảng ninh",
    "cuwra oong, caarm phar, quarng ninh"
  ],
  "Cửa Đông, Hoàn Kiếm, Hà Nội": [
    "cửa đông, hoàn kiếm, hà nội",
    "cuwra ddoong, hoafn kieesm, haf nooji"
  ],
  "Dang Kang, Krông Bông, Đắk Lắk": [
    "dang kang, krông bông, đắk lắk",
    "dang kang, kroong boong, ddawsk lawsk"
  ],
  "Diên Hòa, Diên Khánh, Khánh Hòa": [
    "diên hòa, diên khánh, khánh hòa",
    "dieen hofa, dieen khasnh, khasnh hofa"
  ],
  "Diên Lâm, Diên Khánh, Khánh Hòa": [
    "diên lâm, diên khánh, khánh hòa",
    "dieen laam, dieen khasnh, khasnh hofa"
  ],
  "Diên Phú, Diên Khánh, Khánh Hòa": [
    "diên phú, diên khánh, khánh hòa",
    "dieen phus, dieen khasnh, khasnh hofa"
  ],
  "Diên Sơn, Diên Khánh, Khánh Hòa": [
    "diên sơn, diên khánh, khánh hòa",
    "dieen sown, dieen khasnh, khasnh hofa"
  ],
  "Diên Tân, Diên Khánh, Khánh Hòa": [
    "diên tân, diên khánh, khánh hòa",
    "dieen taan, dieen khasnh, khasnh hofa"
  ],
  "Diễn Bích, Diễn Châu, Nghệ An": [
    "diễn bích, diễn châu, nghệ an",
    "dieexn bisch, dieexn chaau, ngheej an"
  ],
  "Diễn Châu, Diễn Châu, Nghệ An": [
    "diễn châu, diễn châu, nghệ an",
    "dieexn chaau, dieexn chaau, ngheej an"
  ],
  "Diễn Hùng, Diễn Châu, Nghệ An": [
    "diễn hùng, diễn châu, nghệ an",
    "dieexn hufng, dieexn chaau, ngheej an"
  ],
  "Diễn Hải, Diễn Châu, Nghệ An": [
    "diễn hải, diễn châu, nghệ an",
    "dieexn hari, dieexn chaau, ngheej an"
  ],
  "Diễn Liên, Diễn Châu, Nghệ An": [
    "diễn liên, diễn châu, nghệ an",
    "dieexn lieen, dieexn chaau, ngheej an"
  ],
  "Diễn Lộc, Diễn Châu, Nghệ An": [
    "diễn lộc, diễn châu, nghệ an",
    "dieexn loojc, dieexn chaau, ngheej an"
  ],
  "Diễn Lợi, Diễn Châu, Nghệ An": [
    "diễn lợi, diễn châu, nghệ an",
    "dieexn lowji, dieexn chaau, ngheej an"
  ],
  "Diễn Phong, Diễn Châu, Nghệ An": [
    "diễn phong, diễn châu, nghệ an",
    "dieexn phong, dieexn chaau, ngheej an"
  ],
  "Diễn Phúc, Diễn Châu, Nghệ An": [
    "diễn phúc, diễn châu, nghệ an",
    "dieexn phusc, dieexn chaau, ngheej an"
  ],
  "Diễn Thái, Diễn Châu, Nghệ An": [
    "diễn thái, diễn châu, nghệ an",
    "dieexn thasi, dieexn chaau, ngheej an"
  ],
  "Diễn Tháp, Diễn Châu, Nghệ An": [
    "diễn tháp, diễn châu, nghệ an",
    "dieexn thasp, dieexn chaau, ngheej an"
  ],
  "Diễn Thọ, Diễn Châu, Nghệ An": [
    "diễn thọ, diễn châu, nghệ an",
    "dieexn thoj, dieexn chaau, ngheej an"
  ],
  "Diễn Trung, Diễn Châu, Nghệ An": [
    "diễn trung, diễn châu, nghệ an",
    "dieexn trung, dieexn chaau, ngheej an"
  ],
  "Diễn Vạn, Diễn Châu, Nghệ An": [
    "diễn vạn, diễn châu, nghệ an",
    "dieexn vajn, dieexn chaau, ngheej an"
  ],
  "Diễn Xuân, Diễn Châu, Nghệ An": [
    "diễn xuân, diễn châu, nghệ an",
    "dieexn xuaan, dieexn chaau, ngheej an"
  ],
  "Duy Ninh, Quảng Ninh, Quảng Bình": [
    "duy ninh, quảng ninh, quảng bình",
    "duy ninh, quarng ninh, quarng bifnh"
  ],
  "Duy Phước, Duy Xuyên, Quảng Nam": [
    "duy phước, duy xuyên, quảng nam",
    "duy phuwowsc, duy xuyeen, quarng nam"
  ],
  "Duyệt Trung, Cao Bằng, Cao Bằng": [
    "duyệt trung, cao bằng, cao bằng",
    "duyeejt trung, cao bawfng, cao bawfng"
  ],
  "Dân Tiến, Khoái Châu, Hưng Yên": [
    "dân tiến, khoái châu, hưng yên",
    "daan tieesn, khoasi chaau, huwng yeen"
  ],
  "Dương Tơ, Phú Quốc, Kiên Giang": [
    "dương tơ, phú quốc, kiên giang",
    "duwowng tow, phus quoosc, kieen giang"
  ],
  "Dị Nậu, Thạch Thất, Hà Nội": [
    "dị nậu, thạch thất, hà nội",
    "dij naaju, thajch thaast, haf nooji"
  ],
  "Ea Kuăng, Krông Pắc, Đắk Lắk": [
    "ea kuăng, krông pắc, đắk lắk",
    "ea kuawng, kroong pawsc, ddawsk lawsk"
  ],
  "Ea Tu, Buôn Ma Thuột, Đắk Lắk": [
    "ea tu, buôn ma thuột, đắk lắk",
    "ea tu, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Ea Yiêng, Krông Pắc, Đắk Lắk": [
    "ea yiêng, krông pắc, đắk lắk",
    "ea yieeng, kroong pawsc, ddawsk lawsk"
  ],
  "Gia Khánh, Bình Xuyên, Vĩnh Phúc": [
    "gia khánh, bình xuyên, vĩnh phúc",
    "gia khasnh, bifnh xuyeen, vixnh phusc"
  ],
  "Gia Lương, Gia Lộc, Hải Dương": [
    "gia lương, gia lộc, hải dương",
    "gia luwowng, gia loojc, hari duwowng"
  ],
  "Gia Ninh, Quảng Ninh, Quảng Bình": [
    "gia ninh, quảng ninh, quảng bình",
    "gia ninh, quarng ninh, quarng bifnh"
  ],
  "Gia Viên, Ngô Quyền, Hải Phòng": [
    "gia viên, ngô quyền, hải phòng",
    "gia vieen, ngoo quyeefn, hari phofng"
  ],
  "Giai Xuân, Phong Điền, Cần Thơ": [
    "giai xuân, phong điền, cần thơ",
    "giai xuaan, phong ddieefn, caafn thow"
  ],
  "Giao Thiện, Lang Chánh, Thanh Hóa": [
    "giao thiện, lang chánh, thanh hóa",
    "giao thieejn, lang chasnh, thanh hosa"
  ],
  "Giao Thạnh, Thạnh Phú, Bến Tre": [
    "giao thạnh, thạnh phú, bến tre",
    "giao thajnh, thajnh phus, beesn tre"
  ],
  "Giao Tiến, Giao Thủy, Nam Định": [
    "giao tiến, giao thủy, nam định",
    "giao tieesn, giao thury, nam ddijnh"
  ],
  "Giáo Hiệu, Pác Nặm, Bắc Kạn": [
    "giáo hiệu, pác nặm, bắc kạn",
    "giaso hieeju, pasc nawjm, bawsc kajn"
  ],
  "Giáp Sơn, Lục Ngạn, Bắc Giang": [
    "giáp sơn, lục ngạn, bắc giang",
    "giasp sown, lujc ngajn, bawsc giang"
  ],
  "Gành Dầu, Phú Quốc, Kiên Giang": [
    "gành dầu, phú quốc, kiên giang",
    "gafnh daafu, phus quoosc, kieen giang"
  ],
  "Gành Hào, Đông Hải, Bạc Liêu": [
    "gành hào, đông hải, bạc liêu",
    "gafnh hafo, ddoong hari, bajc lieeu"
  ],
  "Hiếu Trung, Tiểu Cần, Trà Vinh": [
    "hiếu trung, tiểu cần, trà vinh",
    "hieesu trung, tieeru caafn, traf vinh"
  ],
  "Hiền Hào, Cát Hải, Hải Phòng": [
    "hiền hào, cát hải, hải phòng",
    "hieefn hafo, cast hari, hari phofng"
  ],
  "Hiền Lương, Hạ Hoà, Phú Thọ": [
    "hiền lương, hạ hoà, phú thọ",
    "hieefn luwowng, haj hoaf, phus thoj"
  ],
  "Hiệp Cát, Nam Sách, Hải Dương": [
    "hiệp cát, nam sách, hải dương",
    "hieejp cast, nam sasch, hari duwowng"
  ],
  "Hiệp Hòa, Kinh Môn, Hải Dương": [
    "hiệp hòa, kinh môn, hải dương",
    "hieejp hofa, kinh moon, hari duwowng"
  ],
  "Hiệp Lợi, Ngã Bảy, Hậu Giang": [
    "hiệp lợi, ngã bảy, hậu giang",
    "hieejp lowji, ngax bary, haaju giang"
  ],
  "Hiệp Lực, Ngân Sơn, Bắc Kạn": [
    "hiệp lực, ngân sơn, bắc kạn",
    "hieejp luwjc, ngaan sown, bawsc kajn"
  ],
  "Hiệp Phú, Quận 9, Hồ Chí Minh": [
    "hiệp phú, quận 9, hồ chí minh",
    "hieejp phus, quaajn 9, hoof chis minh"
  ],
  "Hiệp Sơn, Kinh Môn, Hải Dương": [
    "hiệp sơn, kinh môn, hải dương",
    "hieejp sown, kinh moon, hari duwowng"
  ],
  "Hiệp Thạnh, Châu Thành, Long An": [
    "hiệp thạnh, châu thành, long an",
    "hieejp thajnh, chaau thafnh, long an"
  ],
  "Hoà An, Giồng Riềng, Kiên Giang": [
    "hoà an, giồng riềng, kiên giang",
    "hoaf an, gioofng rieefng, kieen giang"
  ],
  "Hoà Bình, Vĩnh Bảo, Hải Phòng": [
    "hoà bình, vĩnh bảo, hải phòng",
    "hoaf bifnh, vixnh baro, hari phofng"
  ],
  "Hoàng Hoa Thám, Ân Thi, Hưng Yên": [
    "hoàng hoa thám, ân thi, hưng yên",
    "hoafng hoa thasm, aan thi, huwng yeen"
  ],
  "Hoàng Lâu, Tam Dương, Vĩnh Phúc": [
    "hoàng lâu, tam dương, vĩnh phúc",
    "hoafng laau, tam duwowng, vixnh phusc"
  ],
  "Hoàng Nam, Nghĩa Hưng, Nam Định": [
    "hoàng nam, nghĩa hưng, nam định",
    "hoafng nam, nghixa huwng, nam ddijnh"
  ],
  "Hoàng Sơn, Nông Cống, Thanh Hóa": [
    "hoàng sơn, nông cống, thanh hóa",
    "hoafng sown, noong coosng, thanh hosa"
  ],
  "Hoàng Thu Phố, Bắc Hà, Lào Cai": [
    "hoàng thu phố, bắc hà, lào cai",
    "hoafng thu phoos, bawsc haf, lafo cai"
  ],
  "Hoàng Tân, Chí Linh, Hải Dương": [
    "hoàng tân, chí linh, hải dương",
    "hoafng taan, chis linh, hari duwowng"
  ],
  "Hoàng Vân, Hiệp Hòa, Bắc Giang": [
    "hoàng vân, hiệp hòa, bắc giang",
    "hoafng vaan, hieejp hofa, bawsc giang"
  ],
  "Hoàng Đan, Tam Dương, Vĩnh Phúc": [
    "hoàng đan, tam dương, vĩnh phúc",
    "hoafng ddan, tam duwowng, vixnh phusc"
  ],
  "Hoành Mô, Bình Liêu, Quảng Ninh": [
    "hoành mô, bình liêu, quảng ninh",
    "hoafnh moo, bifnh lieeu, quarng ninh"
  ],
  "Hoành Sơn, Giao Thủy, Nam Định": [
    "hoành sơn, giao thủy, nam định",
    "hoafnh sown, giao thury, nam ddijnh"
  ],
  "Hoành Sơn, Kinh Môn, Hải Dương": [
    "hoành sơn, kinh môn, hải dương",
    "hoafnh sown, kinh moon, hari duwowng"
  ],
  "Hoả Tiến, Vị Thanh, Hậu Giang": [
    "hoả tiến, vị thanh, hậu giang",
    "hoar tieesn, vij thanh, haaju giang"
  ],
  "Hoằng Hà, Hoằng Hóa, Thanh Hóa": [
    "hoằng hà, hoằng hóa, thanh hóa",
    "hoawfng haf, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Kim, Hoằng Hóa, Thanh Hóa": [
    "hoằng kim, hoằng hóa, thanh hóa",
    "hoawfng kim, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Quang, Thanh Hóa, Thanh Hóa": [
    "hoằng quang, thanh hóa, thanh hóa",
    "hoawfng quang, thanh hosa, thanh hosa"
  ],
  "Huy Khiêm, Tánh Linh, Bình Thuận": [
    "huy khiêm, tánh linh, bình thuận",
    "huy khieem, tasnh linh, bifnh thuaajn"
  ],
  "Huổi Luông, Phong Thổ, Lai Châu": [
    "huổi luông, phong thổ, lai châu",
    "huoori luoong, phong thoor, lai chaau"
  ],
  "Hàng Buồm, Hoàn Kiếm, Hà Nội": [
    "hàng buồm, hoàn kiếm, hà nội",
    "hafng buoofm, hoafn kieesm, haf nooji"
  ],
  "Hàng Trạm, Yên Thủy, Hoà Bình": [
    "hàng trạm, yên thủy, hoà bình",
    "hafng trajm, yeen thury, hoaf bifnh"
  ],
  "Hào Phú, Sơn Dương, Tuyên Quang": [
    "hào phú, sơn dương, tuyên quang",
    "hafo phus, sown duwowng, tuyeen quang"
  ],
  "Hòa Bình, Thường Tín, Hà Nội": [
    "hòa bình, thường tín, hà nội",
    "hofa bifnh, thuwowfng tisn, haf nooji"
  ],
  "Hòa Chính, Chương Mỹ, Hà Nội": [
    "hòa chính, chương mỹ, hà nội",
    "hofa chisnh, chuwowng myx, haf nooji"
  ],
  "Hòa Khánh Nam, Đức Hòa, Long An": [
    "hòa khánh nam, đức hòa, long an",
    "hofa khasnh nam, dduwsc hofa, long an"
  ],
  "Hòa Khương, Hòa Vang, Đà Nẵng": [
    "hòa khương, hòa vang, đà nẵng",
    "hofa khuwowng, hofa vang, ddaf nawxng"
  ],
  "Hòa Lễ, Krông Bông, Đắk Lắk": [
    "hòa lễ, krông bông, đắk lắk",
    "hofa leex, kroong boong, ddawsk lawsk"
  ],
  "Hòa Lợi, Bến Cát, Bình Dương": [
    "hòa lợi, bến cát, bình dương",
    "hofa lowji, beesn cast, bifnh duwowng"
  ],
  "Hòa Minh, Liên Chiểu, Đà Nẵng": [
    "hòa minh, liên chiểu, đà nẵng",
    "hofa minh, lieen chieeru, ddaf nawxng"
  ],
  "Hòa Phước, Hòa Vang, Đà Nẵng": [
    "hòa phước, hòa vang, đà nẵng",
    "hofa phuwowsc, hofa vang, ddaf nawxng"
  ],
  "Hòa Sơn, Krông Bông, Đắk Lắk": [
    "hòa sơn, krông bông, đắk lắk",
    "hofa sown, kroong boong, ddawsk lawsk"
  ],
  "Hòa Thuận, Châu Thành, Trà Vinh": [
    "hòa thuận, châu thành, trà vinh",
    "hofa thuaajn, chaau thafnh, traf vinh"
  ],
  "Hòa Thạnh, Châu Thành, Tây Ninh": [
    "hòa thạnh, châu thành, tây ninh",
    "hofa thajnh, chaau thafnh, taay ninh"
  ],
  "Hòa Tân, Krông Bông, Đắk Lắk": [
    "hòa tân, krông bông, đắk lắk",
    "hofa taan, kroong boong, ddawsk lawsk"
  ],
  "Hòa Tú II, Mỹ Xuyên, Sóc Trăng": [
    "hòa tú ii, mỹ xuyên, sóc trăng",
    "hofa tus ii, myx xuyeen, sosc trawng"
  ],
  "Hòa Đông, Vĩnh Châu, Sóc Trăng": [
    "hòa đông, vĩnh châu, sóc trăng",
    "hofa ddoong, vixnh chaau, sosc trawng"
  ],
  "Hòn Đất, Hòn Đất, Kiên Giang": [
    "hòn đất, hòn đất, kiên giang",
    "hofn ddaast, hofn ddaast, kieen giang"
  ],
  "Hóa Tiến, Minh Hóa, Quảng Bình": [
    "hóa tiến, minh hóa, quảng bình",
    "hosa tieesn, minh hosa, quarng bifnh"
  ],
  "Hùng Mỹ, Chiêm Hóa, Tuyên Quang": [
    "hùng mỹ, chiêm hóa, tuyên quang",
    "hufng myx, chieem hosa, tuyeen quang"
  ],
  "Hùng Vương, Phú Thọ, Phú Thọ": [
    "hùng vương, phú thọ, phú thọ",
    "hufng vuwowng, phus thoj, phus thoj"
  ],
  "Hùng Xuyên, Đoan Hùng, Phú Thọ": [
    "hùng xuyên, đoan hùng, phú thọ",
    "hufng xuyeen, ddoan hufng, phus thoj"
  ],
  "Hùng Đức, Hàm Yên, Tuyên Quang": [
    "hùng đức, hàm yên, tuyên quang",
    "hufng dduwsc, hafm yeen, tuyeen quang"
  ],
  "Húc Nghì, Đa Krông, Quảng Trị": [
    "húc nghì, đa krông, quảng trị",
    "husc nghif, dda kroong, quarng trij"
  ],
  "Hưng Hòa, Bàu Bàng, Bình Dương": [
    "hưng hòa, bàu bàng, bình dương",
    "huwng hofa, bafu bafng, bifnh duwowng"
  ],
  "Hưng Hội, Vĩnh Lợi, Bạc Liêu": [
    "hưng hội, vĩnh lợi, bạc liêu",
    "huwng hooji, vixnh lowji, bajc lieeu"
  ],
  "Hưng Long, Ninh Giang, Hải Dương": [
    "hưng long, ninh giang, hải dương",
    "huwng long, ninh giang, hari duwowng"
  ],
  "Hưng Lĩnh, Hưng Nguyên, Nghệ An": [
    "hưng lĩnh, hưng nguyên, nghệ an",
    "huwng lixnh, huwng nguyeen, ngheej an"
  ],
  "Hưng Lợi, Hưng Nguyên, Nghệ An": [
    "hưng lợi, hưng nguyên, nghệ an",
    "huwng lowji, huwng nguyeen, ngheej an"
  ],
  "Hưng Phong, Giồng Trôm, Bến Tre": [
    "hưng phong, giồng trôm, bến tre",
    "huwng phong, gioofng troom, beesn tre"
  ],
  "Hưng Phúc, Hưng Nguyên, Nghệ An": [
    "hưng phúc, hưng nguyên, nghệ an",
    "huwng phusc, huwng nguyeen, ngheej an"
  ],
  "Hưng Thạnh, Cái Răng, Cần Thơ": [
    "hưng thạnh, cái răng, cần thơ",
    "huwng thajnh, casi rawng, caafn thow"
  ],
  "Hưng Thịnh, Trấn Yên, Yên Bái": [
    "hưng thịnh, trấn yên, yên bái",
    "huwng thijnh, traasn yeen, yeen basi"
  ],
  "Hưng Trung, Hưng Nguyên, Nghệ An": [
    "hưng trung, hưng nguyên, nghệ an",
    "huwng trung, huwng nguyeen, ngheej an"
  ],
  "Hưng Điền A, Vĩnh Hưng, Long An": [
    "hưng điền a, vĩnh hưng, long an",
    "huwng ddieefn a, vixnh huwng, long an"
  ],
  "Hưng Đạo, Bảo Lạc, Cao Bằng": [
    "hưng đạo, bảo lạc, cao bằng",
    "huwng ddajo, baro lajc, cao bawfng"
  ],
  "Hương Cần, Thanh Sơn, Phú Thọ": [
    "hương cần, thanh sơn, phú thọ",
    "huwowng caafn, thanh sown, phus thoj"
  ],
  "Hương Khê, Hương Khê, Hà Tĩnh": [
    "hương khê, hương khê, hà tĩnh",
    "huwowng khee, huwowng khee, haf tixnh"
  ],
  "Hương Long, Hương Khê, Hà Tĩnh": [
    "hương long, hương khê, hà tĩnh",
    "huwowng long, huwowng khee, haf tixnh"
  ],
  "Hương Lâm, Hương Khê, Hà Tĩnh": [
    "hương lâm, hương khê, hà tĩnh",
    "huwowng laam, huwowng khee, haf tixnh"
  ],
  "Hương Mai, Việt Yên, Bắc Giang": [
    "hương mai, việt yên, bắc giang",
    "huwowng mai, vieejt yeen, bawsc giang"
  ],
  "Hương Trà, Hương Khê, Hà Tĩnh": [
    "hương trà, hương khê, hà tĩnh",
    "huwowng traf, huwowng khee, haf tixnh"
  ],
  "Hương Đô, Hương Khê, Hà Tĩnh": [
    "hương đô, hương khê, hà tĩnh",
    "huwowng ddoo, huwowng khee, haf tixnh"
  ],
  "Hướng Thọ Phú, Tân An, Long An": [
    "hướng thọ phú, tân an, long an",
    "huwowsng thoj phus, taan an, long an"
  ],
  "Hạnh Dịch, Quế Phong, Nghệ An": [
    "hạnh dịch, quế phong, nghệ an",
    "hajnh dijch, quees phong, ngheej an"
  ],
  "Hải Bắc, Hải Hậu, Nam Định": [
    "hải bắc, hải hậu, nam định",
    "hari bawsc, hari haaju, nam ddijnh"
  ],
  "Hải Châu, Hải Hậu, Nam Định": [
    "hải châu, hải hậu, nam định",
    "hari chaau, hari haaju, nam ddijnh"
  ],
  "Hải Giang, Hải Hậu, Nam Định": [
    "hải giang, hải hậu, nam định",
    "hari giang, hari haaju, nam ddijnh"
  ],
  "Hải Hưng, Hải Hậu, Nam Định": [
    "hải hưng, hải hậu, nam định",
    "hari huwng, hari haaju, nam ddijnh"
  ],
  "Hải Lộc, Hải Hậu, Nam Định": [
    "hải lộc, hải hậu, nam định",
    "hari loojc, hari haaju, nam ddijnh"
  ],
  "Hải Phong, Hải Hậu, Nam Định": [
    "hải phong, hải hậu, nam định",
    "hari phong, hari haaju, nam ddijnh"
  ],
  "Hải Phúc, Hải Hậu, Nam Định": [
    "hải phúc, hải hậu, nam định",
    "hari phusc, hari haaju, nam ddijnh"
  ],
  "Hải Quang, Hải Hậu, Nam Định": [
    "hải quang, hải hậu, nam định",
    "hari quang, hari haaju, nam ddijnh"
  ],
  "Hải Quy, Hải Lăng, Quảng Trị": [
    "hải quy, hải lăng, quảng trị",
    "hari quy, hari lawng, quarng trij"
  ],
  "Hải Thanh, Hải Hậu, Nam Định": [
    "hải thanh, hải hậu, nam định",
    "hari thanh, hari haaju, nam ddijnh"
  ],
  "Hải Triều, Tiên Lữ, Hưng Yên": [
    "hải triều, tiên lữ, hưng yên",
    "hari trieefu, tieen luwx, huwng yeen"
  ],
  "Hải Trung, Hải Hậu, Nam Định": [
    "hải trung, hải hậu, nam định",
    "hari trung, hari haaju, nam ddijnh"
  ],
  "Hải Xuân, Hải Hậu, Nam Định": [
    "hải xuân, hải hậu, nam định",
    "hari xuaan, hari haaju, nam ddijnh"
  ],
  "Hải Xuân, Móng Cái, Quảng Ninh": [
    "hải xuân, móng cái, quảng ninh",
    "hari xuaan, mosng casi, quarng ninh"
  ],
  "Hậu Thạnh, Long Phú, Sóc Trăng": [
    "hậu thạnh, long phú, sóc trăng",
    "haaju thajnh, long phus, sosc trawng"
  ],
  "Hồ Thầu, Tam Đường, Lai Châu": [
    "hồ thầu, tam đường, lai châu",
    "hoof thaafu, tam dduwowfng, lai chaau"
  ],
  "Hồ Tùng Mậu, Ân Thi, Hưng Yên": [
    "hồ tùng mậu, ân thi, hưng yên",
    "hoof tufng maaju, aan thi, huwng yeen"
  ],
  "Hồng Châu, Yên Lạc, Vĩnh Phúc": [
    "hồng châu, yên lạc, vĩnh phúc",
    "hoofng chaau, yeen lajc, vixnh phusc"
  ],
  "Hồng Hà, Đan Phượng, Hà Nội": [
    "hồng hà, đan phượng, hà nội",
    "hoofng haf, ddan phuwowjng, haf nooji"
  ],
  "Hồng Hóa, Minh Hóa, Quảng Bình": [
    "hồng hóa, minh hóa, quảng bình",
    "hoofng hosa, minh hosa, quarng bifnh"
  ],
  "Hồng Hải, Hạ Long, Quảng Ninh": [
    "hồng hải, hạ long, quảng ninh",
    "hoofng hari, haj long, quarng ninh"
  ],
  "Hồng Quang, Nam Trực, Nam Định": [
    "hồng quang, nam trực, nam định",
    "hoofng quang, nam truwjc, nam ddijnh"
  ],
  "Hồng Thành, Yên Thành, Nghệ An": [
    "hồng thành, yên thành, nghệ an",
    "hoofng thafnh, yeen thafnh, ngheej an"
  ],
  "Hồng Thái, Văn Lãng, Lạng Sơn": [
    "hồng thái, văn lãng, lạng sơn",
    "hoofng thasi, vawn laxng, lajng sown"
  ],
  "Hồng Trị, Bảo Lạc, Cao Bằng": [
    "hồng trị, bảo lạc, cao bằng",
    "hoofng trij, baro lajc, cao bawfng"
  ],
  "Hộ Đáp, Lục Ngạn, Bắc Giang": [
    "hộ đáp, lục ngạn, bắc giang",
    "hooj ddasp, lujc ngajn, bawsc giang"
  ],
  "Hợp Lý, Lập Thạch, Vĩnh Phúc": [
    "hợp lý, lập thạch, vĩnh phúc",
    "howjp lys, laajp thajch, vixnh phusc"
  ],
  "Hợp Nhất, Đoan Hùng, Phú Thọ": [
    "hợp nhất, đoan hùng, phú thọ",
    "howjp nhaast, ddoan hufng, phus thoj"
  ],
  "Hữu Liên, Hữu Lũng, Lạng Sơn": [
    "hữu liên, hữu lũng, lạng sơn",
    "huwxu lieen, huwxu luxng, lajng sown"
  ],
  "Hữu Lũng, Hữu Lũng, Lạng Sơn": [
    "hữu lũng, hữu lũng, lạng sơn",
    "huwxu luxng, huwxu luxng, lajng sown"
  ],
  "Ka Đơn, Đơn Dương, Lâm Đồng": [
    "ka đơn, đơn dương, lâm đồng",
    "ka ddown, ddown duwowng, laam ddoofng"
  ],
  "Khuất Xá, Lộc Bình, Lạng Sơn": [
    "khuất xá, lộc bình, lạng sơn",
    "khuaast xas, loojc bifnh, lajng sown"
  ],
  "Khánh Công, Yên Khánh, Ninh Bình": [
    "khánh công, yên khánh, ninh bình",
    "khasnh coong, yeen khasnh, ninh bifnh"
  ],
  "Khánh Hà, Thường Tín, Hà Nội": [
    "khánh hà, thường tín, hà nội",
    "khasnh haf, thuwowfng tisn, haf nooji"
  ],
  "Khánh Hòa, Vĩnh Châu, Sóc Trăng": [
    "khánh hòa, vĩnh châu, sóc trăng",
    "khasnh hofa, vixnh chaau, sosc trawng"
  ],
  "Khánh Hải, Yên Khánh, Ninh Bình": [
    "khánh hải, yên khánh, ninh bình",
    "khasnh hari, yeen khasnh, ninh bifnh"
  ],
  "Khánh Hội, Yên Khánh, Ninh Bình": [
    "khánh hội, yên khánh, ninh bình",
    "khasnh hooji, yeen khasnh, ninh bifnh"
  ],
  "Khánh Lợi, Yên Khánh, Ninh Bình": [
    "khánh lợi, yên khánh, ninh bình",
    "khasnh lowji, yeen khasnh, ninh bifnh"
  ],
  "Khánh Mậu, Yên Khánh, Ninh Bình": [
    "khánh mậu, yên khánh, ninh bình",
    "khasnh maaju, yeen khasnh, ninh bifnh"
  ],
  "Khánh Nam, Khánh Vĩnh, Khánh Hòa": [
    "khánh nam, khánh vĩnh, khánh hòa",
    "khasnh nam, khasnh vixnh, khasnh hofa"
  ],
  "Khánh Thiện, Lục Yên, Yên Bái": [
    "khánh thiện, lục yên, yên bái",
    "khasnh thieejn, lujc yeen, yeen basi"
  ],
  "Khánh Thành, Yên Thành, Nghệ An": [
    "khánh thành, yên thành, nghệ an",
    "khasnh thafnh, yeen thafnh, ngheej an"
  ],
  "Khánh Tiên, Yên Khánh, Ninh Bình": [
    "khánh tiên, yên khánh, ninh bình",
    "khasnh tieen, yeen khasnh, ninh bifnh"
  ],
  "Khánh Trung, Yên Khánh, Ninh Bình": [
    "khánh trung, yên khánh, ninh bình",
    "khasnh trung, yeen khasnh, ninh bifnh"
  ],
  "Khánh Xuân, Bảo Lạc, Cao Bằng": [
    "khánh xuân, bảo lạc, cao bằng",
    "khasnh xuaan, baro lajc, cao bawfng"
  ],
  "Khánh Yên Hạ, Văn Bàn, Lào Cai": [
    "khánh yên hạ, văn bàn, lào cai",
    "khasnh yeen haj, vawn bafn, lafo cai"
  ],
  "Khắc Niệm, Bắc Ninh, Bắc Ninh": [
    "khắc niệm, bắc ninh, bắc ninh",
    "khawsc nieejm, bawsc ninh, bawsc ninh"
  ],
  "Kim Xuyên, Kim Thành, Hải Dương": [
    "kim xuyên, kim thành, hải dương",
    "kim xuyeen, kim thafnh, hari duwowng"
  ],
  "Kim Đính, Kim Thành, Hải Dương": [
    "kim đính, kim thành, hải dương",
    "kim ddisnh, kim thafnh, hari duwowng"
  ],
  "Kiên Thọ, Ngọc Lặc, Thanh Hóa": [
    "kiên thọ, ngọc lặc, thanh hóa",
    "kieen thoj, ngojc lawjc, thanh hosa"
  ],
  "La Bằng, Đại Từ, Thái Nguyên": [
    "la bằng, đại từ, thái nguyên",
    "la bawfng, ddaji tuwf, thasi nguyeen"
  ],
  "Lam Sơn, Thanh Miện, Hải Dương": [
    "lam sơn, thanh miện, hải dương",
    "lam sown, thanh mieejn, hari duwowng"
  ],
  "Lam Vỹ, Định Hóa, Thái Nguyên": [
    "lam vỹ, định hóa, thái nguyên",
    "lam vyx, ddijnh hosa, thasi nguyeen"
  ],
  "Lam Điền, Chương Mỹ, Hà Nội": [
    "lam điền, chương mỹ, hà nội",
    "lam ddieefn, chuwowng myx, haf nooji"
  ],
  "Lay Nưa, Mường Lay, Điện Biên": [
    "lay nưa, mường lay, điện biên",
    "lay nuwa, muwowfng lay, ddieejn bieen"
  ],
  "Liêm Hải, Trực Ninh, Nam Định": [
    "liêm hải, trực ninh, nam định",
    "lieem hari, truwjc ninh, nam ddijnh"
  ],
  "Liên Hòa, Kim Thành, Hải Dương": [
    "liên hòa, kim thành, hải dương",
    "lieen hofa, kim thafnh, hari duwowng"
  ],
  "Liên Mạc, Thanh Hà, Hải Dương": [
    "liên mạc, thanh hà, hải dương",
    "lieen majc, thanh haf, hari duwowng"
  ],
  "Liên Quan, Thạch Thất, Hà Nội": [
    "liên quan, thạch thất, hà nội",
    "lieen quan, thajch thaast, haf nooji"
  ],
  "Liên Sang, Khánh Vĩnh, Khánh Hòa": [
    "liên sang, khánh vĩnh, khánh hòa",
    "lieen sang, khasnh vixnh, khasnh hofa"
  ],
  "Liệp Tuyết, Quốc Oai, Hà Nội": [
    "liệp tuyết, quốc oai, hà nội",
    "lieejp tuyeest, quoosc oai, haf nooji"
  ],
  "Long Hiệp, Minh Long, Quảng Ngãi": [
    "long hiệp, minh long, quảng ngãi",
    "long hieejp, minh long, quarng ngaxi"
  ],
  "Long Phước, Bến Cầu, Tây Ninh": [
    "long phước, bến cầu, tây ninh",
    "long phuwowsc, beesn caafu, taay ninh"
  ],
  "Long Thuận, Gò Công, Tiền Giang": [
    "long thuận, gò công, tiền giang",
    "long thuaajn, gof coong, tieefn giang"
  ],
  "Long Thành, Long Thành, Đồng Nai": [
    "long thành, long thành, đồng nai",
    "long thafnh, long thafnh, ddoofng nai"
  ],
  "Long Thắng, Lai Vung, Đồng Tháp": [
    "long thắng, lai vung, đồng tháp",
    "long thawsng, lai vung, ddoofng thasp"
  ],
  "Long Thới, Nhà Bè, Hồ Chí Minh": [
    "long thới, nhà bè, hồ chí minh",
    "long thowsi, nhaf bef, hoof chis minh"
  ],
  "Long Trạch, Cần Đước, Long An": [
    "long trạch, cần đước, long an",
    "long trajch, caafn dduwowsc, long an"
  ],
  "Long Tân, Nhơn Trạch, Đồng Nai": [
    "long tân, nhơn trạch, đồng nai",
    "long taan, nhown trajch, ddoofng nai"
  ],
  "Long Xuyên, Kinh Môn, Hải Dương": [
    "long xuyên, kinh môn, hải dương",
    "long xuyeen, kinh moon, hari duwowng"
  ],
  "Long Điền A, Chợ Mới, An Giang": [
    "long điền a, chợ mới, an giang",
    "long ddieefn a, chowj mowsi, an giang"
  ],
  "Long Điền B, Chợ Mới, An Giang": [
    "long điền b, chợ mới, an giang",
    "long ddieefn b, chowj mowsi, an giang"
  ],
  "Long Định, Bình Đại, Bến Tre": [
    "long định, bình đại, bến tre",
    "long ddijnh, bifnh ddaji, beesn tre"
  ],
  "Long Định, Cần Đước, Long An": [
    "long định, cần đước, long an",
    "long ddijnh, caafn dduwowsc, long an"
  ],
  "Long Đống, Bắc Sơn, Lạng Sơn": [
    "long đống, bắc sơn, lạng sơn",
    "long ddoosng, bawsc sown, lajng sown"
  ],
  "Long Đức, Long Thành, Đồng Nai": [
    "long đức, long thành, đồng nai",
    "long dduwsc, long thafnh, ddoofng nai"
  ],
  "Lâm Hóa, Tuyên Hóa, Quảng Bình": [
    "lâm hóa, tuyên hóa, quảng bình",
    "laam hosa, tuyeen hosa, quarng bifnh"
  ],
  "Lâm Thượng, Lục Yên, Yên Bái": [
    "lâm thượng, lục yên, yên bái",
    "laam thuwowjng, lujc yeen, yeen basi"
  ],
  "Lâm Tân, Thạnh Trị, Sóc Trăng": [
    "lâm tân, thạnh trị, sóc trăng",
    "laam taan, thajnh trij, sosc trawng"
  ],
  "Lê Lợi, Ngô Quyền, Hải Phòng": [
    "lê lợi, ngô quyền, hải phòng",
    "lee lowji, ngoo quyeefn, hari phofng"
  ],
  "Lê Thiện, An Dương, Hải Phòng": [
    "lê thiện, an dương, hải phòng",
    "lee thieejn, an duwowng, hari phofng"
  ],
  "Lũng Niêm, Bá Thước, Thanh Hóa": [
    "lũng niêm, bá thước, thanh hóa",
    "luxng nieem, bas thuwowsc, thanh hosa"
  ],
  "Lũng Thầu, Đồng Văn, Hà Giang": [
    "lũng thầu, đồng văn, hà giang",
    "luxng thaafu, ddoofng vawn, haf giang"
  ],
  "Lương Hòa, Châu Thành, Trà Vinh": [
    "lương hòa, châu thành, trà vinh",
    "luwowng hofa, chaau thafnh, traf vinh"
  ],
  "Lương Mông, Ba Chẽ, Quảng Ninh": [
    "lương mông, ba chẽ, quảng ninh",
    "luwowng moong, ba chex, quarng ninh"
  ],
  "Lương Năng, Văn Quan, Lạng Sơn": [
    "lương năng, văn quan, lạng sơn",
    "luwowng nawng, vawn quan, lajng sown"
  ],
  "Lương Sơn, Ninh Sơn, Ninh Thuận": [
    "lương sơn, ninh sơn, ninh thuận",
    "luwowng sown, ninh sown, ninh thuaajn"
  ],
  "Lộc Bình, Lộc Bình, Lạng Sơn": [
    "lộc bình, lộc bình, lạng sơn",
    "loojc bifnh, loojc bifnh, lajng sown"
  ],
  "Lộc Bảo, Bảo Lâm, Lâm Đồng": [
    "lộc bảo, bảo lâm, lâm đồng",
    "loojc baro, baro laam, laam ddoofng"
  ],
  "Lộc Bắc, Bảo Lâm, Lâm Đồng": [
    "lộc bắc, bảo lâm, lâm đồng",
    "loojc bawsc, baro laam, laam ddoofng"
  ],
  "Lộc Hưng, Trảng Bàng, Tây Ninh": [
    "lộc hưng, trảng bàng, tây ninh",
    "loojc huwng, trarng bafng, taay ninh"
  ],
  "Lộc Ngãi, Bảo Lâm, Lâm Đồng": [
    "lộc ngãi, bảo lâm, lâm đồng",
    "loojc ngaxi, baro laam, laam ddoofng"
  ],
  "Lộc Sơn, Bảo Lộc, Lâm Đồng": [
    "lộc sơn, bảo lộc, lâm đồng",
    "loojc sown, baro loojc, laam ddoofng"
  ],
  "Lợi An, Trần Văn Thời, Cà Mau": [
    "lợi an, trần văn thời, cà mau",
    "lowji an, traafn vawn thowfi, caf mau"
  ],
  "Lợi Thuận, Bến Cầu, Tây Ninh": [
    "lợi thuận, bến cầu, tây ninh",
    "lowji thuaajn, beesn caafu, taay ninh"
  ],
  "Minh Châu, Vân Đồn, Quảng Ninh": [
    "minh châu, vân đồn, quảng ninh",
    "minh chaau, vaan ddoofn, quarng ninh"
  ],
  "Minh Hiệp, Lộc Bình, Lạng Sơn": [
    "minh hiệp, lộc bình, lạng sơn",
    "minh hieejp, loojc bifnh, lajng sown"
  ],
  "Minh Hương, Hàm Yên, Tuyên Quang": [
    "minh hương, hàm yên, tuyên quang",
    "minh huwowng, hafm yeen, tuyeen quang"
  ],
  "Minh Khai, Hồng Bàng, Hải Phòng": [
    "minh khai, hồng bàng, hải phòng",
    "minh khai, hoofng bafng, hari phofng"
  ],
  "Minh Lương, Đoan Hùng, Phú Thọ": [
    "minh lương, đoan hùng, phú thọ",
    "minh luwowng, ddoan hufng, phus thoj"
  ],
  "Minh Nghĩa, Nông Cống, Thanh Hóa": [
    "minh nghĩa, nông cống, thanh hóa",
    "minh nghixa, noong coosng, thanh hosa"
  ],
  "Minh Quang, Chiêm Hóa, Tuyên Quang": [
    "minh quang, chiêm hóa, tuyên quang",
    "minh quang, chieem hosa, tuyeen quang"
  ],
  "Minh Thuận, Vụ Bản, Nam Định": [
    "minh thuận, vụ bản, nam định",
    "minh thuaajn, vuj barn, nam ddijnh"
  ],
  "Minh Tiến, Hữu Lũng, Lạng Sơn": [
    "minh tiến, hữu lũng, lạng sơn",
    "minh tieesn, huwxu luxng, lajng sown"
  ],
  "Minh Tiến, Ngọc Lặc, Thanh Hóa": [
    "minh tiến, ngọc lặc, thanh hóa",
    "minh tieesn, ngojc lawjc, thanh hosa"
  ],
  "Minh Đức, Mỏ Cày Nam, Bến Tre": [
    "minh đức, mỏ cày nam, bến tre",
    "minh dduwsc, mor cafy nam, beesn tre"
  ],
  "Minh Đức, Tứ Kỳ, Hải Dương": [
    "minh đức, tứ kỳ, hải dương",
    "minh dduwsc, tuws kyf, hari duwowng"
  ],
  "Minh Đức, Việt Yên, Bắc Giang": [
    "minh đức, việt yên, bắc giang",
    "minh dduwsc, vieejt yeen, bawsc giang"
  ],
  "Minh Đức, Đồ Sơn, Hải Phòng": [
    "minh đức, đồ sơn, hải phòng",
    "minh dduwsc, ddoof sown, hari phofng"
  ],
  "Miền Đồi, Lạc Sơn, Hoà Bình": [
    "miền đồi, lạc sơn, hoà bình",
    "mieefn ddoofi, lajc sown, hoaf bifnh"
  ],
  "Mong Thọ, Châu Thành, Kiên Giang": [
    "mong thọ, châu thành, kiên giang",
    "mong thoj, chaau thafnh, kieen giang"
  ],
  "Mái Dầm, Châu Thành, Hậu Giang": [
    "mái dầm, châu thành, hậu giang",
    "masi daafm, chaau thafnh, haaju giang"
  ],
  "Máy Chai, Ngô Quyền, Hải Phòng": [
    "máy chai, ngô quyền, hải phòng",
    "masy chai, ngoo quyeefn, hari phofng"
  ],
  "Măng Tố, Tánh Linh, Bình Thuận": [
    "măng tố, tánh linh, bình thuận",
    "mawng toos, tasnh linh, bifnh thuaajn"
  ],
  "Mũi Né, Phan Thiết, Bình Thuận": [
    "mũi né, phan thiết, bình thuận",
    "muxi nes, phan thieest, bifnh thuaajn"
  ],
  "Mường Bám, Thuận Châu, Sơn La": [
    "mường bám, thuận châu, sơn la",
    "muwowfng basm, thuaajn chaau, sown la"
  ],
  "Mường Giôn, Quỳnh Nhai, Sơn La": [
    "mường giôn, quỳnh nhai, sơn la",
    "muwowfng gioon, quyfnh nhai, sown la"
  ],
  "Mường Lống, Kỳ Sơn, Nghệ An": [
    "mường lống, kỳ sơn, nghệ an",
    "muwowfng loosng, kyf sown, ngheej an"
  ],
  "Mường Sại, Quỳnh Nhai, Sơn La": [
    "mường sại, quỳnh nhai, sơn la",
    "muwowfng saji, quyfnh nhai, sown la"
  ],
  "Mường Tè, Mường Tè, Lai Châu": [
    "mường tè, mường tè, lai châu",
    "muwowfng tef, muwowfng tef, lai chaau"
  ],
  "Mỏ Chè, Sông Công, Thái Nguyên": [
    "mỏ chè, sông công, thái nguyên",
    "mor chef, soong coong, thasi nguyeen"
  ],
  "Mỹ An, Ngũ Hành Sơn, Đà Nẵng": [
    "mỹ an, ngũ hành sơn, đà nẵng",
    "myx an, ngux hafnh sown, ddaf nawxng"
  ],
  "Mỹ An, Tháp Mười, Đồng Tháp": [
    "mỹ an, tháp mười, đồng tháp",
    "myx an, thasp muwowfi, ddoofng thasp"
  ],
  "Mỹ Chánh, Phù Mỹ, Bình Định": [
    "mỹ chánh, phù mỹ, bình định",
    "myx chasnh, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Hiệp, Cao Lãnh, Đồng Tháp": [
    "mỹ hiệp, cao lãnh, đồng tháp",
    "myx hieejp, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Hiệp, Phù Mỹ, Bình Định": [
    "mỹ hiệp, phù mỹ, bình định",
    "myx hieejp, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Hạnh Nam, Đức Hòa, Long An": [
    "mỹ hạnh nam, đức hòa, long an",
    "myx hajnh nam, dduwsc hofa, long an"
  ],
  "Mỹ Long Nam, Cầu Ngang, Trà Vinh": [
    "mỹ long nam, cầu ngang, trà vinh",
    "myx long nam, caafu ngang, traf vinh"
  ],
  "Mỹ Lâm, Tuyên Quang, Tuyên Quang": [
    "mỹ lâm, tuyên quang, tuyên quang",
    "myx laam, tuyeen quang, tuyeen quang"
  ],
  "Mỹ Phước, Mang Thít, Vĩnh Long": [
    "mỹ phước, mang thít, vĩnh long",
    "myx phuwowsc, mang thist, vixnh long"
  ],
  "Mỹ Quý Tây, Đức Huệ, Long An": [
    "mỹ quý tây, đức huệ, long an",
    "myx quys taay, dduwsc hueej, long an"
  ],
  "Mỹ Thuận, Mỹ Lộc, Nam Định": [
    "mỹ thuận, mỹ lộc, nam định",
    "myx thuaajn, myx loojc, nam ddijnh"
  ],
  "Mỹ Thành, Phù Mỹ, Bình Định": [
    "mỹ thành, phù mỹ, bình định",
    "myx thafnh, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Thái, Lạng Giang, Bắc Giang": [
    "mỹ thái, lạng giang, bắc giang",
    "myx thasi, lajng giang, bawsc giang"
  ],
  "Mỹ Thạnh An, Bến Tre, Bến Tre": [
    "mỹ thạnh an, bến tre, bến tre",
    "myx thajnh an, beesn tre, beesn tre"
  ],
  "Mỹ Thắng, Mỹ Lộc, Nam Định": [
    "mỹ thắng, mỹ lộc, nam định",
    "myx thawsng, myx loojc, nam ddijnh"
  ],
  "Mỹ Thịnh, Mỹ Lộc, Nam Định": [
    "mỹ thịnh, mỹ lộc, nam định",
    "myx thijnh, myx loojc, nam ddijnh"
  ],
  "Mỹ Xuyên, Mỹ Xuyên, Sóc Trăng": [
    "mỹ xuyên, mỹ xuyên, sóc trăng",
    "myx xuyeen, myx xuyeen, sosc trawng"
  ],
  "Mỹ Yên, Đại Từ, Thái Nguyên": [
    "mỹ yên, đại từ, thái nguyên",
    "myx yeen, ddaji tuwf, thasi nguyeen"
  ],
  "Mỹ Đức, Phù Mỹ, Bình Định": [
    "mỹ đức, phù mỹ, bình định",
    "myx dduwsc, phuf myx, bifnh ddijnh"
  ],
  "NT Liên Sơn, Văn Chấn, Yên Bái": [
    "nt liên sơn, văn chấn, yên bái",
    "nt lieen sown, vawn chaasn, yeen basi"
  ],
  "Na Sang, Mường Chà, Điện Biên": [
    "na sang, mường chà, điện biên",
    "na sang, muwowfng chaf, ddieejn bieen"
  ],
  "Nam Chính, Tiền Hải, Thái Bình": [
    "nam chính, tiền hải, thái bình",
    "nam chisnh, tieefn hari, thasi bifnh"
  ],
  "Nam Cường, Nam Trực, Nam Định": [
    "nam cường, nam trực, nam định",
    "nam cuwowfng, nam truwjc, nam ddijnh"
  ],
  "Nam Dương, Hải Châu, Đà Nẵng": [
    "nam dương, hải châu, đà nẵng",
    "nam duwowng, hari chaau, ddaf nawxng"
  ],
  "Nam Hòa, Đồng Hỷ, Thái Nguyên": [
    "nam hòa, đồng hỷ, thái nguyên",
    "nam hofa, ddoofng hyr, thasi nguyeen"
  ],
  "Nam Hồng, Tiền Hải, Thái Bình": [
    "nam hồng, tiền hải, thái bình",
    "nam hoofng, tieefn hari, thasi bifnh"
  ],
  "Nam Lý, Đồng Hới, Quảng Bình": [
    "nam lý, đồng hới, quảng bình",
    "nam lys, ddoofng howsi, quarng bifnh"
  ],
  "Nam Phước, Duy Xuyên, Quảng Nam": [
    "nam phước, duy xuyên, quảng nam",
    "nam phuwowsc, duy xuyeen, quarng nam"
  ],
  "Nam Tiến, Phổ Yên, Thái Nguyên": [
    "nam tiến, phổ yên, thái nguyên",
    "nam tieesn, phoor yeen, thasi nguyeen"
  ],
  "Nghi Công Nam, Nghi Lộc, Nghệ An": [
    "nghi công nam, nghi lộc, nghệ an",
    "nghi coong nam, nghi loojc, ngheej an"
  ],
  "Nghi Trường, Nghi Lộc, Nghệ An": [
    "nghi trường, nghi lộc, nghệ an",
    "nghi truwowfng, nghi loojc, ngheej an"
  ],
  "Nghiên Loan, Pác Nặm, Bắc Kạn": [
    "nghiên loan, pác nặm, bắc kạn",
    "nghieen loan, pasc nawjm, bawsc kajn"
  ],
  "Nghĩa Bình, Nghĩa Đàn, Nghệ An": [
    "nghĩa bình, nghĩa đàn, nghệ an",
    "nghixa bifnh, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Hưng, Nghĩa Đàn, Nghệ An": [
    "nghĩa hưng, nghĩa đàn, nghệ an",
    "nghixa huwng, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Hương, Quốc Oai, Hà Nội": [
    "nghĩa hương, quốc oai, hà nội",
    "nghixa huwowng, quoosc oai, haf nooji"
  ],
  "Nghĩa Hội, Nghĩa Đàn, Nghệ An": [
    "nghĩa hội, nghĩa đàn, nghệ an",
    "nghixa hooji, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Lạc, Nghĩa Đàn, Nghệ An": [
    "nghĩa lạc, nghĩa đàn, nghệ an",
    "nghixa lajc, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Lộ, Cát Hải, Hải Phòng": [
    "nghĩa lộ, cát hải, hải phòng",
    "nghixa looj, cast hari, hari phofng"
  ],
  "Nghĩa Lộc, Nghĩa Đàn, Nghệ An": [
    "nghĩa lộc, nghĩa đàn, nghệ an",
    "nghixa loojc, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Lợi, Nghĩa Đàn, Nghệ An": [
    "nghĩa lợi, nghĩa đàn, nghệ an",
    "nghixa lowji, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Phú, Gia Nghĩa, Đắk Nông": [
    "nghĩa phú, gia nghĩa, đắk nông",
    "nghixa phus, gia nghixa, ddawsk noong"
  ],
  "Nghĩa Thuận, Thái Hoà, Nghệ An": [
    "nghĩa thuận, thái hoà, nghệ an",
    "nghixa thuaajn, thasi hoaf, ngheej an"
  ],
  "Nghĩa Thọ, Nghĩa Đàn, Nghệ An": [
    "nghĩa thọ, nghĩa đàn, nghệ an",
    "nghixa thoj, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Trung, Nghĩa Đàn, Nghệ An": [
    "nghĩa trung, nghĩa đàn, nghệ an",
    "nghixa trung, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Tá, Chợ Đồn, Bắc Kạn": [
    "nghĩa tá, chợ đồn, bắc kạn",
    "nghixa tas, chowj ddoofn, bawsc kajn"
  ],
  "Nghĩa Tân, Gia Nghĩa, Đắk Nông": [
    "nghĩa tân, gia nghĩa, đắk nông",
    "nghixa taan, gia nghixa, ddawsk noong"
  ],
  "Nghĩa Đàn, Nghĩa Đàn, Nghệ An": [
    "nghĩa đàn, nghĩa đàn, nghệ an",
    "nghixa ddafn, nghixa ddafn, ngheej an"
  ],
  "Nguyễn Du, Nam Định, Nam Định": [
    "nguyễn du, nam định, nam định",
    "nguyeexn du, nam ddijnh, nam ddijnh"
  ],
  "Nguyễn Trãi, Hà Đông, Hà Nội": [
    "nguyễn trãi, hà đông, hà nội",
    "nguyeexn traxi, haf ddoong, haf nooji"
  ],
  "Ngã Tư Sở, Đống Đa, Hà Nội": [
    "ngã tư sở, đống đa, hà nội",
    "ngax tuw sowr, ddoosng dda, haf nooji"
  ],
  "Ngô Quyền, Vĩnh Yên, Vĩnh Phúc": [
    "ngô quyền, vĩnh yên, vĩnh phúc",
    "ngoo quyeefn, vixnh yeen, vixnh phusc"
  ],
  "Ngũ Phúc, Kim Thành, Hải Dương": [
    "ngũ phúc, kim thành, hải dương",
    "ngux phusc, kim thafnh, hari duwowng"
  ],
  "Ngư Hóa, Tuyên Hóa, Quảng Bình": [
    "ngư hóa, tuyên hóa, quảng bình",
    "nguw hosa, tuyeen hosa, quarng bifnh"
  ],
  "Ngọc Hiệp, Nha Trang, Khánh Hòa": [
    "ngọc hiệp, nha trang, khánh hòa",
    "ngojc hieejp, nha trang, khasnh hofa"
  ],
  "Ngọc Hòa, Chương Mỹ, Hà Nội": [
    "ngọc hòa, chương mỹ, hà nội",
    "ngojc hofa, chuwowng myx, haf nooji"
  ],
  "Ngọc Kỳ, Tứ Kỳ, Hải Dương": [
    "ngọc kỳ, tứ kỳ, hải dương",
    "ngojc kyf, tuws kyf, hari duwowng"
  ],
  "Ngọc Sơn, Hiệp Hòa, Bắc Giang": [
    "ngọc sơn, hiệp hòa, bắc giang",
    "ngojc sown, hieejp hofa, bawsc giang"
  ],
  "Ngọc Sơn, Ngọc Lặc, Thanh Hóa": [
    "ngọc sơn, ngọc lặc, thanh hóa",
    "ngojc sown, ngojc lawjc, thanh hosa"
  ],
  "Ngọc Thanh, Kim Động, Hưng Yên": [
    "ngọc thanh, kim động, hưng yên",
    "ngojc thanh, kim ddoojng, huwng yeen"
  ],
  "Ngọc Thanh, Phúc Yên, Vĩnh Phúc": [
    "ngọc thanh, phúc yên, vĩnh phúc",
    "ngojc thanh, phusc yeen, vixnh phusc"
  ],
  "Ngọc Trạo, Bỉm Sơn, Thanh Hóa": [
    "ngọc trạo, bỉm sơn, thanh hóa",
    "ngojc trajo, birm sown, thanh hosa"
  ],
  "Ngọc Trạo, Thanh Hóa, Thanh Hóa": [
    "ngọc trạo, thanh hóa, thanh hóa",
    "ngojc trajo, thanh hosa, thanh hosa"
  ],
  "Ngọc Tố, Mỹ Xuyên, Sóc Trăng": [
    "ngọc tố, mỹ xuyên, sóc trăng",
    "ngojc toos, myx xuyeen, sosc trawng"
  ],
  "Ngọc Đào, Hà Quảng, Cao Bằng": [
    "ngọc đào, hà quảng, cao bằng",
    "ngojc ddafo, haf quarng, cao bawfng"
  ],
  "Nhân Hoà, Vĩnh Bảo, Hải Phòng": [
    "nhân hoà, vĩnh bảo, hải phòng",
    "nhaan hoaf, vixnh baro, hari phofng"
  ],
  "Nhân Huệ, Chí Linh, Hải Dương": [
    "nhân huệ, chí linh, hải dương",
    "nhaan hueej, chis linh, hari duwowng"
  ],
  "Nhân Nghĩa, Cẩm Mỹ, Đồng Nai": [
    "nhân nghĩa, cẩm mỹ, đồng nai",
    "nhaan nghixa, caarm myx, ddoofng nai"
  ],
  "Nhôn Mai, Tương Dương, Nghệ An": [
    "nhôn mai, tương dương, nghệ an",
    "nhoon mai, tuwowng duwowng, ngheej an"
  ],
  "Nhơn Bình, Qui Nhơn, Bình Định": [
    "nhơn bình, qui nhơn, bình định",
    "nhown bifnh, qui nhown, bifnh ddijnh"
  ],
  "Nhơn Châu, Qui Nhơn, Bình Định": [
    "nhơn châu, qui nhơn, bình định",
    "nhown chaau, qui nhown, bifnh ddijnh"
  ],
  "Nhơn Hạnh, An Nhơn, Bình Định": [
    "nhơn hạnh, an nhơn, bình định",
    "nhown hajnh, an nhown, bifnh ddijnh"
  ],
  "Nhơn Hải, Ninh Hải, Ninh Thuận": [
    "nhơn hải, ninh hải, ninh thuận",
    "nhown hari, ninh hari, ninh thuaajn"
  ],
  "Nhơn Hải, Qui Nhơn, Bình Định": [
    "nhơn hải, qui nhơn, bình định",
    "nhown hari, qui nhown, bifnh ddijnh"
  ],
  "Nhơn Hội, Qui Nhơn, Bình Định": [
    "nhơn hội, qui nhơn, bình định",
    "nhown hooji, qui nhown, bifnh ddijnh"
  ],
  "Nhơn Khánh, An Nhơn, Bình Định": [
    "nhơn khánh, an nhơn, bình định",
    "nhown khasnh, an nhown, bifnh ddijnh"
  ],
  "Nhơn Thành, An Nhơn, Bình Định": [
    "nhơn thành, an nhơn, bình định",
    "nhown thafnh, an nhown, bifnh ddijnh"
  ],
  "Nhơn Thạnh Trung, Tân An, Long An": [
    "nhơn thạnh trung, tân an, long an",
    "nhown thajnh trung, taan an, long an"
  ],
  "Nhật Tân, Gia Lộc, Hải Dương": [
    "nhật tân, gia lộc, hải dương",
    "nhaajt taan, gia loojc, hari duwowng"
  ],
  "Nhị Khê, Thường Tín, Hà Nội": [
    "nhị khê, thường tín, hà nội",
    "nhij khee, thuwowfng tisn, haf nooji"
  ],
  "Ninh Giang, Ninh Giang, Hải Dương": [
    "ninh giang, ninh giang, hải dương",
    "ninh giang, ninh giang, hari duwowng"
  ],
  "Ninh Hải, Ninh Giang, Hải Dương": [
    "ninh hải, ninh giang, hải dương",
    "ninh hari, ninh giang, hari duwowng"
  ],
  "Ninh Phước, Ninh Hòa, Khánh Hòa": [
    "ninh phước, ninh hòa, khánh hòa",
    "ninh phuwowsc, ninh hofa, khasnh hofa"
  ],
  "Ninh Quới, Hồng Dân, Bạc Liêu": [
    "ninh quới, hồng dân, bạc liêu",
    "ninh quowsi, hoofng daan, bajc lieeu"
  ],
  "Ninh Điền, Châu Thành, Tây Ninh": [
    "ninh điền, châu thành, tây ninh",
    "ninh ddieefn, chaau thafnh, taay ninh"
  ],
  "Nà Bủng, Nậm Pồ, Điện Biên": [
    "nà bủng, nậm pồ, điện biên",
    "naf burng, naajm poof, ddieejn bieen"
  ],
  "Nà Sáy, Tuần Giáo, Điện Biên": [
    "nà sáy, tuần giáo, điện biên",
    "naf sasy, tuaafn giaso, ddieejn bieen"
  ],
  "Nâm N'Đir, Krông Nô, Đắk Nông": [
    "nâm n'đir, krông nô, đắk nông",
    "naam n'ddir, kroong noo, ddawsk noong"
  ],
  "Nùng Nàng, Tam Đường, Lai Châu": [
    "nùng nàng, tam đường, lai châu",
    "nufng nafng, tam dduwowfng, lai chaau"
  ],
  "Núi Thành, Núi Thành, Quảng Nam": [
    "núi thành, núi thành, quảng nam",
    "nusi thafnh, nusi thafnh, quarng nam"
  ],
  "Núi Tượng, Tân Phú, Đồng Nai": [
    "núi tượng, tân phú, đồng nai",
    "nusi tuwowjng, taan phus, ddoofng nai"
  ],
  "Năng Tĩnh, Nam Định, Nam Định": [
    "năng tĩnh, nam định, nam định",
    "nawng tixnh, nam ddijnh, nam ddijnh"
  ],
  "Nậm Chua, Nậm Pồ, Điện Biên": [
    "nậm chua, nậm pồ, điện biên",
    "naajm chua, naajm poof, ddieejn bieen"
  ],
  "Nậm Mười, Văn Chấn, Yên Bái": [
    "nậm mười, văn chấn, yên bái",
    "naajm muwowfi, vawn chaasn, yeen basi"
  ],
  "Nậm Nhoóng, Quế Phong, Nghệ An": [
    "nậm nhoóng, quế phong, nghệ an",
    "naajm nhoosng, quees phong, ngheej an"
  ],
  "Nậm Tỵ, Hoàng Su Phì, Hà Giang": [
    "nậm tỵ, hoàng su phì, hà giang",
    "naajm tyj, hoafng su phif, haf giang"
  ],
  "Nội Hoàng, Yên Dũng, Bắc Giang": [
    "nội hoàng, yên dũng, bắc giang",
    "nooji hoafng, yeen duxng, bawsc giang"
  ],
  "Pa Vệ Sử, Mường Tè, Lai Châu": [
    "pa vệ sử, mường tè, lai châu",
    "pa veej suwr, muwowfng tef, lai chaau"
  ],
  "Pha Long, Mường Khương, Lào Cai": [
    "pha long, mường khương, lào cai",
    "pha long, muwowfng khuwowng, lafo cai"
  ],
  "Phan Hòa, Bắc Bình, Bình Thuận": [
    "phan hòa, bắc bình, bình thuận",
    "phan hofa, bawsc bifnh, bifnh thuaajn"
  ],
  "Phan Lâm, Bắc Bình, Bình Thuận": [
    "phan lâm, bắc bình, bình thuận",
    "phan laam, bawsc bifnh, bifnh thuaajn"
  ],
  "Phan Sơn, Bắc Bình, Bình Thuận": [
    "phan sơn, bắc bình, bình thuận",
    "phan sown, bawsc bifnh, bifnh thuaajn"
  ],
  "Phan Thanh, Nguyên Bình, Cao Bằng": [
    "phan thanh, nguyên bình, cao bằng",
    "phan thanh, nguyeen bifnh, cao bawfng"
  ],
  "Phong Dụ Hạ, Văn Yên, Yên Bái": [
    "phong dụ hạ, văn yên, yên bái",
    "phong duj haj, vawn yeen, yeen basi"
  ],
  "Phong Minh, Lục Ngạn, Bắc Giang": [
    "phong minh, lục ngạn, bắc giang",
    "phong minh, lujc ngajn, bawsc giang"
  ],
  "Phong Nẫm, Giồng Trôm, Bến Tre": [
    "phong nẫm, giồng trôm, bến tre",
    "phong naaxm, gioofng troom, beesn tre"
  ],
  "Phong Vân, Lục Ngạn, Bắc Giang": [
    "phong vân, lục ngạn, bắc giang",
    "phong vaan, lujc ngajn, bawsc giang"
  ],
  "Phìn Hồ, Nậm Pồ, Điện Biên": [
    "phìn hồ, nậm pồ, điện biên",
    "phifn hoof, naajm poof, ddieejn bieen"
  ],
  "Phùng Minh, Ngọc Lặc, Thanh Hóa": [
    "phùng minh, ngọc lặc, thanh hóa",
    "phufng minh, ngojc lawjc, thanh hosa"
  ],
  "Phùng Nguyên, Lâm Thao, Phú Thọ": [
    "phùng nguyên, lâm thao, phú thọ",
    "phufng nguyeen, laam thao, phus thoj"
  ],
  "Phùng Xá, Thạch Thất, Hà Nội": [
    "phùng xá, thạch thất, hà nội",
    "phufng xas, thajch thaast, haf nooji"
  ],
  "Phú An Hòa, Châu Thành, Bến Tre": [
    "phú an hòa, châu thành, bến tre",
    "phus an hofa, chaau thafnh, beesn tre"
  ],
  "Phú Bình, Chiêm Hóa, Tuyên Quang": [
    "phú bình, chiêm hóa, tuyên quang",
    "phus bifnh, chieem hosa, tuyeen quang"
  ],
  "Phú Châu, Đông Hưng, Thái Bình": [
    "phú châu, đông hưng, thái bình",
    "phus chaau, ddoong huwng, thasi bifnh"
  ],
  "Phú Cát, Huế, Thừa Thiên Huế": [
    "phú cát, huế, thừa thiên huế",
    "phus cast, huees, thuwfa thieen huees"
  ],
  "Phú Cường, Hưng Yên, Hưng Yên": [
    "phú cường, hưng yên, hưng yên",
    "phus cuwowfng, huwng yeen, huwng yeen"
  ],
  "Phú Cường, Tân Lạc, Hoà Bình": [
    "phú cường, tân lạc, hoà bình",
    "phus cuwowfng, taan lajc, hoaf bifnh"
  ],
  "Phú Hiệp, Tam Nông, Đồng Tháp": [
    "phú hiệp, tam nông, đồng tháp",
    "phus hieejp, tam noong, ddoofng thasp"
  ],
  "Phú Hòa, Huế, Thừa Thiên Huế": [
    "phú hòa, huế, thừa thiên huế",
    "phus hofa, huees, thuwfa thieen huees"
  ],
  "Phú Hòa, Định Quán, Đồng Nai": [
    "phú hòa, định quán, đồng nai",
    "phus hofa, ddijnh quasn, ddoofng nai"
  ],
  "Phú Hữu, Châu Thành, Hậu Giang": [
    "phú hữu, châu thành, hậu giang",
    "phus huwxu, chaau thafnh, haaju giang"
  ],
  "Phú Khánh, Thái Bình, Thái Bình": [
    "phú khánh, thái bình, thái bình",
    "phus khasnh, thasi bifnh, thasi bifnh"
  ],
  "Phú Lợi, Giang Thành, Kiên Giang": [
    "phú lợi, giang thành, kiên giang",
    "phus lowji, giang thafnh, kieen giang"
  ],
  "Phú Mỹ, Mỏ Cày Bắc, Bến Tre": [
    "phú mỹ, mỏ cày bắc, bến tre",
    "phus myx, mor cafy bawsc, beesn tre"
  ],
  "Phú Nam An, Chương Mỹ, Hà Nội": [
    "phú nam an, chương mỹ, hà nội",
    "phus nam an, chuwowng myx, haf nooji"
  ],
  "Phú Nghĩa, Chương Mỹ, Hà Nội": [
    "phú nghĩa, chương mỹ, hà nội",
    "phus nghixa, chuwowng myx, haf nooji"
  ],
  "Phú Nghĩa, Lạc Thủy, Hoà Bình": [
    "phú nghĩa, lạc thủy, hoà bình",
    "phus nghixa, lajc thury, hoaf bifnh"
  ],
  "Phú Nhuận, Bảo Thắng, Lào Cai": [
    "phú nhuận, bảo thắng, lào cai",
    "phus nhuaajn, baro thawsng, lafo cai"
  ],
  "Phú Nhuận, Cai Lậy, Tiền Giang": [
    "phú nhuận, cai lậy, tiền giang",
    "phus nhuaajn, cai laajy, tieefn giang"
  ],
  "Phú Sơn, Bù Đăng, Bình Phước": [
    "phú sơn, bù đăng, bình phước",
    "phus sown, buf ddawng, bifnh phuwowsc"
  ],
  "Phú Thuận, Bình Đại, Bến Tre": [
    "phú thuận, bình đại, bến tre",
    "phus thuaajn, bifnh ddaji, beesn tre"
  ],
  "Phú Thành, Lạc Thủy, Hoà Bình": [
    "phú thành, lạc thủy, hoà bình",
    "phus thafnh, lajc thury, hoaf bifnh"
  ],
  "Phú Thái, Kim Thành, Hải Dương": [
    "phú thái, kim thành, hải dương",
    "phus thasi, kim thafnh, hari duwowng"
  ],
  "Phú Thịnh, Kim Động, Hưng Yên": [
    "phú thịnh, kim động, hưng yên",
    "phus thijnh, kim ddoojng, huwng yeen"
  ],
  "Phú Thịnh, Yên Sơn, Tuyên Quang": [
    "phú thịnh, yên sơn, tuyên quang",
    "phus thijnh, yeen sown, tuyeen quang"
  ],
  "Phú Trung, Tân Phú, Hồ Chí Minh": [
    "phú trung, tân phú, hồ chí minh",
    "phus trung, taan phus, hoof chis minh"
  ],
  "Phú Tân, Định Quán, Đồng Nai": [
    "phú tân, định quán, đồng nai",
    "phus taan, ddijnh quasn, ddoofng nai"
  ],
  "Phú Túc, Định Quán, Đồng Nai": [
    "phú túc, định quán, đồng nai",
    "phus tusc, ddijnh quasn, ddoofng nai"
  ],
  "Phú Vinh, Định Quán, Đồng Nai": [
    "phú vinh, định quán, đồng nai",
    "phus vinh, ddijnh quasn, ddoofng nai"
  ],
  "Phú Xuân, Bình Xuyên, Vĩnh Phúc": [
    "phú xuân, bình xuyên, vĩnh phúc",
    "phus xuaan, bifnh xuyeen, vixnh phusc"
  ],
  "Phú Đa, Vĩnh Tường, Vĩnh Phúc": [
    "phú đa, vĩnh tường, vĩnh phúc",
    "phus dda, vixnh tuwowfng, vixnh phusc"
  ],
  "Phú Đức, Tam Nông, Đồng Tháp": [
    "phú đức, tam nông, đồng tháp",
    "phus dduwsc, tam noong, ddoofng thasp"
  ],
  "Phúc Sơn, Chiêm Hóa, Tuyên Quang": [
    "phúc sơn, chiêm hóa, tuyên quang",
    "phusc sown, chieem hosa, tuyeen quang"
  ],
  "Phúc Sơn, Sơn Động, Bắc Giang": [
    "phúc sơn, sơn động, bắc giang",
    "phusc sown, sown ddoojng, bawsc giang"
  ],
  "Phúc Tân, Phổ Yên, Thái Nguyên": [
    "phúc tân, phổ yên, thái nguyên",
    "phusc taan, phoor yeen, thasi nguyeen"
  ],
  "Phương Lâm, Hòa Bình, Hoà Bình": [
    "phương lâm, hòa bình, hoà bình",
    "phuwowng laam, hofa bifnh, hoaf bifnh"
  ],
  "Phương Nam, Uông Bí, Quảng Ninh": [
    "phương nam, uông bí, quảng ninh",
    "phuwowng nam, uoong bis, quarng ninh"
  ],
  "Phương Sài, Nha Trang, Khánh Hòa": [
    "phương sài, nha trang, khánh hòa",
    "phuwowng safi, nha trang, khasnh hofa"
  ],
  "Phương Sơn, Lục Nam, Bắc Giang": [
    "phương sơn, lục nam, bắc giang",
    "phuwowng sown, lujc nam, bawsc giang"
  ],
  "Phương Sơn, Nha Trang, Khánh Hòa": [
    "phương sơn, nha trang, khánh hòa",
    "phuwowng sown, nha trang, khasnh hofa"
  ],
  "Phương Viên, Hạ Hoà, Phú Thọ": [
    "phương viên, hạ hoà, phú thọ",
    "phuwowng vieen, haj hoaf, phus thoj"
  ],
  "Phước Hòa, Bác Ái, Ninh Thuận": [
    "phước hòa, bác ái, ninh thuận",
    "phuwowsc hofa, basc asi, ninh thuaajn"
  ],
  "Phước Hòa, Nha Trang, Khánh Hòa": [
    "phước hòa, nha trang, khánh hòa",
    "phuwowsc hofa, nha trang, khasnh hofa"
  ],
  "Phước Hậu, Long Hồ, Vĩnh Long": [
    "phước hậu, long hồ, vĩnh long",
    "phuwowsc haaju, long hoof, vixnh long"
  ],
  "Phước Long, Nha Trang, Khánh Hòa": [
    "phước long, nha trang, khánh hòa",
    "phuwowsc long, nha trang, khasnh hofa"
  ],
  "Phước Lâm, Cần Giuộc, Long An": [
    "phước lâm, cần giuộc, long an",
    "phuwowsc laam, caafn giuoojc, long an"
  ],
  "Phước Mỹ, Sơn Trà, Đà Nẵng": [
    "phước mỹ, sơn trà, đà nẵng",
    "phuwowsc myx, sown traf, ddaf nawxng"
  ],
  "Phước Tuy, Cần Đước, Long An": [
    "phước tuy, cần đước, long an",
    "phuwowsc tuy, caafn dduwowsc, long an"
  ],
  "Phước Tân, Bác Ái, Ninh Thuận": [
    "phước tân, bác ái, ninh thuận",
    "phuwowsc taan, basc asi, ninh thuaajn"
  ],
  "Phước Tân, Nha Trang, Khánh Hòa": [
    "phước tân, nha trang, khánh hòa",
    "phuwowsc taan, nha trang, khasnh hofa"
  ],
  "Phước Đông, Gò Dầu, Tây Ninh": [
    "phước đông, gò dầu, tây ninh",
    "phuwowsc ddoong, gof daafu, taay ninh"
  ],
  "Phường 1, Bạc Liêu, Bạc Liêu": [
    "phường 1, bạc liêu, bạc liêu",
    "phuwowfng 1, bajc lieeu, bajc lieeu"
  ],
  "Phường 1, Cao Lãnh, Đồng Tháp": [
    "phường 1, cao lãnh, đồng tháp",
    "phuwowfng 1, cao laxnh, ddoofng thasp"
  ],
  "Phường 1, Kiến Tường, Long An": [
    "phường 1, kiến tường, long an",
    "phuwowfng 1, kieesn tuwowfng, long an"
  ],
  "Phường 1, Sóc Trăng, Sóc Trăng": [
    "phường 1, sóc trăng, sóc trăng",
    "phuwowfng 1, sosc trawng, sosc trawng"
  ],
  "Phường 1, Vĩnh Châu, Sóc Trăng": [
    "phường 1, vĩnh châu, sóc trăng",
    "phuwowfng 1, vixnh chaau, sosc trawng"
  ],
  "Phường 1, Đà Lạt, Lâm Đồng": [
    "phường 1, đà lạt, lâm đồng",
    "phuwowfng 1, ddaf lajt, laam ddoofng"
  ],
  "Phường 2, Bạc Liêu, Bạc Liêu": [
    "phường 2, bạc liêu, bạc liêu",
    "phuwowfng 2, bajc lieeu, bajc lieeu"
  ],
  "Phường 2, Cao Lãnh, Đồng Tháp": [
    "phường 2, cao lãnh, đồng tháp",
    "phuwowfng 2, cao laxnh, ddoofng thasp"
  ],
  "Phường 2, Kiến Tường, Long An": [
    "phường 2, kiến tường, long an",
    "phuwowfng 2, kieesn tuwowfng, long an"
  ],
  "Phường 2, Sóc Trăng, Sóc Trăng": [
    "phường 2, sóc trăng, sóc trăng",
    "phuwowfng 2, sosc trawng, sosc trawng"
  ],
  "Phường 2, Vĩnh Châu, Sóc Trăng": [
    "phường 2, vĩnh châu, sóc trăng",
    "phuwowfng 2, vixnh chaau, sosc trawng"
  ],
  "Phường 2, Đà Lạt, Lâm Đồng": [
    "phường 2, đà lạt, lâm đồng",
    "phuwowfng 2, ddaf lajt, laam ddoofng"
  ],
  "Phường 3, Bạc Liêu, Bạc Liêu": [
    "phường 3, bạc liêu, bạc liêu",
    "phuwowfng 3, bajc lieeu, bajc lieeu"
  ],
  "Phường 3, Cao Lãnh, Đồng Tháp": [
    "phường 3, cao lãnh, đồng tháp",
    "phuwowfng 3, cao laxnh, ddoofng thasp"
  ],
  "Phường 3, Kiến Tường, Long An": [
    "phường 3, kiến tường, long an",
    "phuwowfng 3, kieesn tuwowfng, long an"
  ],
  "Phường 3, Sóc Trăng, Sóc Trăng": [
    "phường 3, sóc trăng, sóc trăng",
    "phuwowfng 3, sosc trawng, sosc trawng"
  ],
  "Phường 3, Đà Lạt, Lâm Đồng": [
    "phường 3, đà lạt, lâm đồng",
    "phuwowfng 3, ddaf lajt, laam ddoofng"
  ],
  "Phường 4, Cao Lãnh, Đồng Tháp": [
    "phường 4, cao lãnh, đồng tháp",
    "phuwowfng 4, cao laxnh, ddoofng thasp"
  ],
  "Phường 4, Sóc Trăng, Sóc Trăng": [
    "phường 4, sóc trăng, sóc trăng",
    "phuwowfng 4, sosc trawng, sosc trawng"
  ],
  "Phường 4, Đà Lạt, Lâm Đồng": [
    "phường 4, đà lạt, lâm đồng",
    "phuwowfng 4, ddaf lajt, laam ddoofng"
  ],
  "Phường 5, Bạc Liêu, Bạc Liêu": [
    "phường 5, bạc liêu, bạc liêu",
    "phuwowfng 5, bajc lieeu, bajc lieeu"
  ],
  "Phường 5, Sóc Trăng, Sóc Trăng": [
    "phường 5, sóc trăng, sóc trăng",
    "phuwowfng 5, sosc trawng, sosc trawng"
  ],
  "Phường 5, Đà Lạt, Lâm Đồng": [
    "phường 5, đà lạt, lâm đồng",
    "phuwowfng 5, ddaf lajt, laam ddoofng"
  ],
  "Phường 6, Cao Lãnh, Đồng Tháp": [
    "phường 6, cao lãnh, đồng tháp",
    "phuwowfng 6, cao laxnh, ddoofng thasp"
  ],
  "Phường 6, Sóc Trăng, Sóc Trăng": [
    "phường 6, sóc trăng, sóc trăng",
    "phuwowfng 6, sosc trawng, sosc trawng"
  ],
  "Phường 6, Đà Lạt, Lâm Đồng": [
    "phường 6, đà lạt, lâm đồng",
    "phuwowfng 6, ddaf lajt, laam ddoofng"
  ],
  "Phường 7, Bạc Liêu, Bạc Liêu": [
    "phường 7, bạc liêu, bạc liêu",
    "phuwowfng 7, bajc lieeu, bajc lieeu"
  ],
  "Phường 7, Sóc Trăng, Sóc Trăng": [
    "phường 7, sóc trăng, sóc trăng",
    "phuwowfng 7, sosc trawng, sosc trawng"
  ],
  "Phường 7, Đà Lạt, Lâm Đồng": [
    "phường 7, đà lạt, lâm đồng",
    "phuwowfng 7, ddaf lajt, laam ddoofng"
  ],
  "Phường 8, Bạc Liêu, Bạc Liêu": [
    "phường 8, bạc liêu, bạc liêu",
    "phuwowfng 8, bajc lieeu, bajc lieeu"
  ],
  "Phường 8, Sóc Trăng, Sóc Trăng": [
    "phường 8, sóc trăng, sóc trăng",
    "phuwowfng 8, sosc trawng, sosc trawng"
  ],
  "Phường 8, Đà Lạt, Lâm Đồng": [
    "phường 8, đà lạt, lâm đồng",
    "phuwowfng 8, ddaf lajt, laam ddoofng"
  ],
  "Phường 9, Sóc Trăng, Sóc Trăng": [
    "phường 9, sóc trăng, sóc trăng",
    "phuwowfng 9, sosc trawng, sosc trawng"
  ],
  "Phường 9, Đà Lạt, Lâm Đồng": [
    "phường 9, đà lạt, lâm đồng",
    "phuwowfng 9, ddaf lajt, laam ddoofng"
  ],
  "Phượng Vĩ, Cẩm Khê, Phú Thọ": [
    "phượng vĩ, cẩm khê, phú thọ",
    "phuwowjng vix, caarm khee, phus thoj"
  ],
  "Phả Lại, Chí Linh, Hải Dương": [
    "phả lại, chí linh, hải dương",
    "phar laji, chis linh, hari duwowng"
  ],
  "Phố Cò, Sông Công, Thái Nguyên": [
    "phố cò, sông công, thái nguyên",
    "phoos cof, soong coong, thasi nguyeen"
  ],
  "Phổ An, Đức Phổ, Quảng Ngãi": [
    "phổ an, đức phổ, quảng ngãi",
    "phoor an, dduwsc phoor, quarng ngaxi"
  ],
  "Phổng Lăng, Thuận Châu, Sơn La": [
    "phổng lăng, thuận châu, sơn la",
    "phoorng lawng, thuaajn chaau, sown la"
  ],
  "Phổng Lập, Thuận Châu, Sơn La": [
    "phổng lập, thuận châu, sơn la",
    "phoorng laajp, thuaajn chaau, sown la"
  ],
  "Phụng Công, Văn Giang, Hưng Yên": [
    "phụng công, văn giang, hưng yên",
    "phujng coong, vawn giang, huwng yeen"
  ],
  "Pà Vầy Sủ, Xín Mần, Hà Giang": [
    "pà vầy sủ, xín mần, hà giang",
    "paf vaafy sur, xisn maafn, haf giang"
  ],
  "Quan Hồ Thẩn, Si Ma Cai, Lào Cai": [
    "quan hồ thẩn, si ma cai, lào cai",
    "quan hoof thaarn, si ma cai, lafo cai"
  ],
  "Quan Lạn, Vân Đồn, Quảng Ninh": [
    "quan lạn, vân đồn, quảng ninh",
    "quan lajn, vaan ddoofn, quarng ninh"
  ],
  "Quang Châu, Việt Yên, Bắc Giang": [
    "quang châu, việt yên, bắc giang",
    "quang chaau, vieejt yeen, bawsc giang"
  ],
  "Quang Diệm, Hương Sơn, Hà Tĩnh": [
    "quang diệm, hương sơn, hà tĩnh",
    "quang dieejm, huwowng sown, haf tixnh"
  ],
  "Quang Hanh, Cẩm Phả, Quảng Ninh": [
    "quang hanh, cẩm phả, quảng ninh",
    "quang hanh, caarm phar, quarng ninh"
  ],
  "Quang Hán, Trùng Khánh, Cao Bằng": [
    "quang hán, trùng khánh, cao bằng",
    "quang hasn, trufng khasnh, cao bawfng"
  ],
  "Quang Trung, Nam Định, Nam Định": [
    "quang trung, nam định, nam định",
    "quang trung, nam ddijnh, nam ddijnh"
  ],
  "Quang Trung, Ngọc Lặc, Thanh Hóa": [
    "quang trung, ngọc lặc, thanh hóa",
    "quang trung, ngojc lawjc, thanh hosa"
  ],
  "Quang Trung, Qui Nhơn, Bình Định": [
    "quang trung, qui nhơn, bình định",
    "quang trung, qui nhown, bifnh ddijnh"
  ],
  "Quang Trung, Thái Bình, Thái Bình": [
    "quang trung, thái bình, thái bình",
    "quang trung, thasi bifnh, thasi bifnh"
  ],
  "Quang Trung, Tứ Kỳ, Hải Dương": [
    "quang trung, tứ kỳ, hải dương",
    "quang trung, tuws kyf, hari duwowng"
  ],
  "Quang Trọng, Thạch An, Cao Bằng": [
    "quang trọng, thạch an, cao bằng",
    "quang trojng, thajch an, cao bawfng"
  ],
  "Quang Vinh, Trùng Khánh, Cao Bằng": [
    "quang vinh, trùng khánh, cao bằng",
    "quang vinh, trufng khasnh, cao bawfng"
  ],
  "Quy Kỳ, Định Hóa, Thái Nguyên": [
    "quy kỳ, định hóa, thái nguyên",
    "quy kyf, ddijnh hosa, thasi nguyeen"
  ],
  "Quyết Thắng, Lai Châu, Lai Châu": [
    "quyết thắng, lai châu, lai châu",
    "quyeest thawsng, lai chaau, lai chaau"
  ],
  "Quân Chu, Đại Từ, Thái Nguyên": [
    "quân chu, đại từ, thái nguyên",
    "quaan chu, ddaji tuwf, thasi nguyeen"
  ],
  "Quân Hà, Bạch Thông, Bắc Kạn": [
    "quân hà, bạch thông, bắc kạn",
    "quaan haf, bajch thoong, bawsc kajn"
  ],
  "Quơn Long, Chợ Gạo, Tiền Giang": [
    "quơn long, chợ gạo, tiền giang",
    "quown long, chowj gajo, tieefn giang"
  ],
  "Quảng Chu, Chợ Mới, Bắc Kạn": [
    "quảng chu, chợ mới, bắc kạn",
    "quarng chu, chowj mowsi, bawsc kajn"
  ],
  "Quảng Châu, Hưng Yên, Hưng Yên": [
    "quảng châu, hưng yên, hưng yên",
    "quarng chaau, huwng yeen, huwng yeen"
  ],
  "Quảng Châu, Sầm Sơn, Thanh Hóa": [
    "quảng châu, sầm sơn, thanh hóa",
    "quarng chaau, saafm sown, thanh hosa"
  ],
  "Quảng Hùng, Sầm Sơn, Thanh Hóa": [
    "quảng hùng, sầm sơn, thanh hóa",
    "quarng hufng, saafm sown, thanh hosa"
  ],
  "Quảng Hưng, Thanh Hóa, Thanh Hóa": [
    "quảng hưng, thanh hóa, thanh hóa",
    "quarng huwng, thanh hosa, thanh hosa"
  ],
  "Quảng Long, Hải Hà, Quảng Ninh": [
    "quảng long, hải hà, quảng ninh",
    "quarng long, hari haf, quarng ninh"
  ],
  "Quảng Minh, Hải Hà, Quảng Ninh": [
    "quảng minh, hải hà, quảng ninh",
    "quarng minh, hari haf, quarng ninh"
  ],
  "Quảng Phú, Cư M'gar, Đắk Lắk": [
    "quảng phú, cư m'gar, đắk lắk",
    "quarng phus, cuw m'gar, ddawsk lawsk"
  ],
  "Quảng Phú, Thọ Xuân, Thanh Hóa": [
    "quảng phú, thọ xuân, thanh hóa",
    "quarng phus, thoj xuaan, thanh hosa"
  ],
  "Quảng Sơn, Hải Hà, Quảng Ninh": [
    "quảng sơn, hải hà, quảng ninh",
    "quarng sown, hari haf, quarng ninh"
  ],
  "Quảng Sơn, Ninh Sơn, Ninh Thuận": [
    "quảng sơn, ninh sơn, ninh thuận",
    "quarng sown, ninh sown, ninh thuaajn"
  ],
  "Quảng Thọ, Sầm Sơn, Thanh Hóa": [
    "quảng thọ, sầm sơn, thanh hóa",
    "quarng thoj, saafm sown, thanh hosa"
  ],
  "Quất Lâm, Giao Thủy, Nam Định": [
    "quất lâm, giao thủy, nam định",
    "quaast laam, giao thury, nam ddijnh"
  ],
  "Quế Hiệp, Quế Sơn, Quảng Nam": [
    "quế hiệp, quế sơn, quảng nam",
    "quees hieejp, quees sown, quarng nam"
  ],
  "Quốc Oai, Đạ Tẻh, Lâm Đồng": [
    "quốc oai, đạ tẻh, lâm đồng",
    "quoosc oai, ddaj terh, laam ddoofng"
  ],
  "Quỳnh Long, Quỳnh Lưu, Nghệ An": [
    "quỳnh long, quỳnh lưu, nghệ an",
    "quyfnh long, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Lâm, Quỳnh Lưu, Nghệ An": [
    "quỳnh lâm, quỳnh lưu, nghệ an",
    "quyfnh laam, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Minh, Quỳnh Lưu, Nghệ An": [
    "quỳnh minh, quỳnh lưu, nghệ an",
    "quyfnh minh, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Mỹ, Quỳnh Lưu, Nghệ An": [
    "quỳnh mỹ, quỳnh lưu, nghệ an",
    "quyfnh myx, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Sơn, Yên Dũng, Bắc Giang": [
    "quỳnh sơn, yên dũng, bắc giang",
    "quyfnh sown, yeen duxng, bawsc giang"
  ],
  "Quỳnh Tân, Quỳnh Lưu, Nghệ An": [
    "quỳnh tân, quỳnh lưu, nghệ an",
    "quyfnh taan, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Văn, Quỳnh Lưu, Nghệ An": [
    "quỳnh văn, quỳnh lưu, nghệ an",
    "quyfnh vawn, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Yên, Quỳnh Lưu, Nghệ An": [
    "quỳnh yên, quỳnh lưu, nghệ an",
    "quyfnh yeen, quyfnh luwu, ngheej an"
  ],
  "Qưới Sơn, Châu Thành, Bến Tre": [
    "qưới sơn, châu thành, bến tre",
    "quwowsi sown, chaau thafnh, beesn tre"
  ],
  "Sinh Tồn, Trường Sa, Khánh Hòa": [
    "sinh tồn, trường sa, khánh hòa",
    "sinh toofn, truwowfng sa, khasnh hofa"
  ],
  "Song Bình, Chợ Gạo, Tiền Giang": [
    "song bình, chợ gạo, tiền giang",
    "song bifnh, chowj gajo, tieefn giang"
  ],
  "Song Hồ, Thuận Thành, Bắc Ninh": [
    "song hồ, thuận thành, bắc ninh",
    "song hoof, thuaajn thafnh, bawsc ninh"
  ],
  "Suối Cát, Xuân Lộc, Đồng Nai": [
    "suối cát, xuân lộc, đồng nai",
    "suoosi cast, xuaan loojc, ddoofng nai"
  ],
  "Suối Giàng, Văn Chấn, Yên Bái": [
    "suối giàng, văn chấn, yên bái",
    "suoosi giafng, vawn chaasn, yeen basi"
  ],
  "Sính Lủng, Đồng Văn, Hà Giang": [
    "sính lủng, đồng văn, hà giang",
    "sisnh lurng, ddoofng vawn, haf giang"
  ],
  "Sông Cầu, Bắc Kạn, Bắc Kạn": [
    "sông cầu, bắc kạn, bắc kạn",
    "soong caafu, bawsc kajn, bawsc kajn"
  ],
  "Sông Kôn, Đông Giang, Quảng Nam": [
    "sông kôn, đông giang, quảng nam",
    "soong koon, ddoong giang, quarng nam"
  ],
  "Sông Nhạn, Cẩm Mỹ, Đồng Nai": [
    "sông nhạn, cẩm mỹ, đồng nai",
    "soong nhajn, caarm myx, ddoofng nai"
  ],
  "Sông Vệ, Tư Nghĩa, Quảng Ngãi": [
    "sông vệ, tư nghĩa, quảng ngãi",
    "soong veej, tuw nghixa, quarng ngaxi"
  ],
  "Sĩ Bình, Bạch Thông, Bắc Kạn": [
    "sĩ bình, bạch thông, bắc kạn",
    "six bifnh, bajch thoong, bawsc kajn"
  ],
  "Sơn Dương, Hạ Long, Quảng Ninh": [
    "sơn dương, hạ long, quảng ninh",
    "sown duwowng, haj long, quarng ninh"
  ],
  "Sơn Hiệp, Khánh Sơn, Khánh Hòa": [
    "sơn hiệp, khánh sơn, khánh hòa",
    "sown hieejp, khasnh sown, khasnh hofa"
  ],
  "Sơn Hóa, Tuyên Hóa, Quảng Bình": [
    "sơn hóa, tuyên hóa, quảng bình",
    "sown hosa, tuyeen hosa, quarng bifnh"
  ],
  "Sơn Hải, Lục Ngạn, Bắc Giang": [
    "sơn hải, lục ngạn, bắc giang",
    "sown hari, lujc ngajn, bawsc giang"
  ],
  "Sơn Thái, Khánh Vĩnh, Khánh Hòa": [
    "sơn thái, khánh vĩnh, khánh hòa",
    "sown thasi, khasnh vixnh, khasnh hofa"
  ],
  "Sơn Thủy, Thanh Thuỷ, Phú Thọ": [
    "sơn thủy, thanh thuỷ, phú thọ",
    "sown thury, thanh thuyr, phus thoj"
  ],
  "Sơn Trà, Trà Bồng, Quảng Ngãi": [
    "sơn trà, trà bồng, quảng ngãi",
    "sown traf, traf boofng, quarng ngaxi"
  ],
  "Sơn Đồng, Hoài Đức, Hà Nội": [
    "sơn đồng, hoài đức, hà nội",
    "sown ddoofng, hoafi dduwsc, haf nooji"
  ],
  "Sảng Mộc, Võ Nhai, Thái Nguyên": [
    "sảng mộc, võ nhai, thái nguyên",
    "sarng moojc, vox nhai, thasi nguyeen"
  ],
  "Sủng Trái, Đồng Văn, Hà Giang": [
    "sủng trái, đồng văn, hà giang",
    "surng trasi, ddoofng vawn, haf giang"
  ],
  "Tam Anh Nam, Núi Thành, Quảng Nam": [
    "tam anh nam, núi thành, quảng nam",
    "tam anh nam, nusi thafnh, quarng nam"
  ],
  "Tam Giang, Krông Năng, Đắk Lắk": [
    "tam giang, krông năng, đắk lắk",
    "tam giang, kroong nawng, ddawsk lawsk"
  ],
  "Tam Hợp, Tương Dương, Nghệ An": [
    "tam hợp, tương dương, nghệ an",
    "tam howjp, tuwowng duwowng, ngheej an"
  ],
  "Tam Phước, Biên Hòa, Đồng Nai": [
    "tam phước, biên hòa, đồng nai",
    "tam phuwowsc, bieen hofa, ddoofng nai"
  ],
  "Tam Phước, Châu Thành, Bến Tre": [
    "tam phước, châu thành, bến tre",
    "tam phuwowsc, chaau thafnh, beesn tre"
  ],
  "Tam Quang, Tương Dương, Nghệ An": [
    "tam quang, tương dương, nghệ an",
    "tam quang, tuwowng duwowng, ngheej an"
  ],
  "Tam Thái, Tương Dương, Nghệ An": [
    "tam thái, tương dương, nghệ an",
    "tam thasi, tuwowng duwowng, ngheej an"
  ],
  "Tam Thạnh, Núi Thành, Quảng Nam": [
    "tam thạnh, núi thành, quảng nam",
    "tam thajnh, nusi thafnh, quarng nam"
  ],
  "Tam Xuân I, Núi Thành, Quảng Nam": [
    "tam xuân i, núi thành, quảng nam",
    "tam xuaan i, nusi thafnh, quarng nam"
  ],
  "Thanh Bình,  Vũng Liêm, Vĩnh Long": [
    "thanh bình,  vũng liêm, vĩnh long",
    "thanh bifnh,  vuxng lieem, vixnh long"
  ],
  "Thanh Bình, Chương Mỹ, Hà Nội": [
    "thanh bình, chương mỹ, hà nội",
    "thanh bifnh, chuwowng myx, haf nooji"
  ],
  "Thanh Bình, Hải Châu, Đà Nẵng": [
    "thanh bình, hải châu, đà nẵng",
    "thanh bifnh, hari chaau, ddaf nawxng"
  ],
  "Thanh Bình, Trảng Bom, Đồng Nai": [
    "thanh bình, trảng bom, đồng nai",
    "thanh bifnh, trarng bom, ddoofng nai"
  ],
  "Thanh Hòa, Thanh Chương, Nghệ An": [
    "thanh hòa, thanh chương, nghệ an",
    "thanh hofa, thanh chuwowng, ngheej an"
  ],
  "Thanh Hải, Ninh Hải, Ninh Thuận": [
    "thanh hải, ninh hải, ninh thuận",
    "thanh hari, ninh hari, ninh thuaajn"
  ],
  "Thanh Hải, Thanh Hà, Hải Dương": [
    "thanh hải, thanh hà, hải dương",
    "thanh hari, thanh haf, hari duwowng"
  ],
  "Thanh Khai, Thanh Chương, Nghệ An": [
    "thanh khai, thanh chương, nghệ an",
    "thanh khai, thanh chuwowng, ngheej an"
  ],
  "Thanh Khê, Thanh Chương, Nghệ An": [
    "thanh khê, thanh chương, nghệ an",
    "thanh khee, thanh chuwowng, ngheej an"
  ],
  "Thanh Long, Thanh Chương, Nghệ An": [
    "thanh long, thanh chương, nghệ an",
    "thanh long, thanh chuwowng, ngheej an"
  ],
  "Thanh Lâm, Thanh Chương, Nghệ An": [
    "thanh lâm, thanh chương, nghệ an",
    "thanh laam, thanh chuwowng, ngheej an"
  ],
  "Thanh Lương, Nghĩa Lộ, Yên Bái": [
    "thanh lương, nghĩa lộ, yên bái",
    "thanh luwowng, nghixa looj, yeen basi"
  ],
  "Thanh Miếu, Việt Trì, Phú Thọ": [
    "thanh miếu, việt trì, phú thọ",
    "thanh mieesu, vieejt trif, phus thoj"
  ],
  "Thanh Mỹ, Thanh Chương, Nghệ An": [
    "thanh mỹ, thanh chương, nghệ an",
    "thanh myx, thanh chuwowng, ngheej an"
  ],
  "Thanh Ninh, Phú Bình, Thái Nguyên": [
    "thanh ninh, phú bình, thái nguyên",
    "thanh ninh, phus bifnh, thasi nguyeen"
  ],
  "Thanh Quang, Nam Sách, Hải Dương": [
    "thanh quang, nam sách, hải dương",
    "thanh quang, nam sasch, hari duwowng"
  ],
  "Thanh Quang, Thanh Hà, Hải Dương": [
    "thanh quang, thanh hà, hải dương",
    "thanh quang, thanh haf, hari duwowng"
  ],
  "Thanh Sơn, Thanh Chương, Nghệ An": [
    "thanh sơn, thanh chương, nghệ an",
    "thanh sown, thanh chuwowng, ngheej an"
  ],
  "Thanh Vận, Chợ Mới, Bắc Kạn": [
    "thanh vận, chợ mới, bắc kạn",
    "thanh vaajn, chowj mowsi, bawsc kajn"
  ],
  "Thanh Xuân, Thanh Hà, Hải Dương": [
    "thanh xuân, thanh hà, hải dương",
    "thanh xuaan, thanh haf, hari duwowng"
  ],
  "Thanh Yên, Thanh Chương, Nghệ An": [
    "thanh yên, thanh chương, nghệ an",
    "thanh yeen, thanh chuwowng, ngheej an"
  ],
  "Thanh Đình, Việt Trì, Phú Thọ": [
    "thanh đình, việt trì, phú thọ",
    "thanh ddifnh, vieejt trif, phus thoj"
  ],
  "Thiên Cầm, Cẩm Xuyên, Hà Tĩnh": [
    "thiên cầm, cẩm xuyên, hà tĩnh",
    "thieen caafm, caarm xuyeen, haf tixnh"
  ],
  "Thiện Trung, Cái Bè, Tiền Giang": [
    "thiện trung, cái bè, tiền giang",
    "thieejn trung, casi bef, tieefn giang"
  ],
  "Thiệu Duy, Thiệu Hóa, Thanh Hóa": [
    "thiệu duy, thiệu hóa, thanh hóa",
    "thieeju duy, thieeju hosa, thanh hosa"
  ],
  "Thiệu Lý, Thiệu Hóa, Thanh Hóa": [
    "thiệu lý, thiệu hóa, thanh hóa",
    "thieeju lys, thieeju hosa, thanh hosa"
  ],
  "Thiệu Vũ, Thiệu Hóa, Thanh Hóa": [
    "thiệu vũ, thiệu hóa, thanh hóa",
    "thieeju vux, thieeju hosa, thanh hosa"
  ],
  "Thoại Giang, Thoại Sơn, An Giang": [
    "thoại giang, thoại sơn, an giang",
    "thoaji giang, thoaji sown, an giang"
  ],
  "Thuần Mang, Ngân Sơn, Bắc Kạn": [
    "thuần mang, ngân sơn, bắc kạn",
    "thuaafn mang, ngaan sown, bawsc kajn"
  ],
  "Thuần Thiện, Can Lộc, Hà Tĩnh": [
    "thuần thiện, can lộc, hà tĩnh",
    "thuaafn thieejn, can loojc, haf tixnh"
  ],
  "Thuận Châu, Thuận Châu, Sơn La": [
    "thuận châu, thuận châu, sơn la",
    "thuaajn chaau, thuaajn chaau, sown la"
  ],
  "Thuận Hưng, Long Mỹ, Hậu Giang": [
    "thuận hưng, long mỹ, hậu giang",
    "thuaajn huwng, long myx, haaju giang"
  ],
  "Thuận Minh, Thọ Xuân, Thanh Hóa": [
    "thuận minh, thọ xuân, thanh hóa",
    "thuaajn minh, thoj xuaan, thanh hosa"
  ],
  "Thuận Sơn, Đô Lương, Nghệ An": [
    "thuận sơn, đô lương, nghệ an",
    "thuaajn sown, ddoo luwowng, ngheej an"
  ],
  "Thuận, Hướng Hóa, Quảng Trị": [
    "thuận, hướng hóa, quảng trị",
    "thuaajn, huwowsng hosa, quarng trij"
  ],
  "Thành An, Mỏ Cày Bắc, Bến Tre": [
    "thành an, mỏ cày bắc, bến tre",
    "thafnh an, mor cafy bawsc, beesn tre"
  ],
  "Thành An, Thạch Thành, Thanh Hóa": [
    "thành an, thạch thành, thanh hóa",
    "thafnh an, thajch thafnh, thanh hosa"
  ],
  "Thành Lâm, Bá Thước, Thanh Hóa": [
    "thành lâm, bá thước, thanh hóa",
    "thafnh laam, bas thuwowsc, thanh hosa"
  ],
  "Thành Lộc, Hậu Lộc, Thanh Hóa": [
    "thành lộc, hậu lộc, thanh hóa",
    "thafnh loojc, haaju loojc, thanh hosa"
  ],
  "Thành Lợi, Vụ Bản, Nam Định": [
    "thành lợi, vụ bản, nam định",
    "thafnh lowji, vuj barn, nam ddijnh"
  ],
  "Thành Sơn, Bá Thước, Thanh Hóa": [
    "thành sơn, bá thước, thanh hóa",
    "thafnh sown, bas thuwowsc, thanh hosa"
  ],
  "Thành Sơn, Khánh Sơn, Khánh Hòa": [
    "thành sơn, khánh sơn, khánh hòa",
    "thafnh sown, khasnh sown, khasnh hofa"
  ],
  "Thào Chư Phìn, Si Ma Cai, Lào Cai": [
    "thào chư phìn, si ma cai, lào cai",
    "thafo chuw phifn, si ma cai, lafo cai"
  ],
  "Thái Hòa, Tân Uyên, Bình Dương": [
    "thái hòa, tân uyên, bình dương",
    "thasi hofa, taan uyeen, bifnh duwowng"
  ],
  "Thái Học, Chí Linh, Hải Dương": [
    "thái học, chí linh, hải dương",
    "thasi hojc, chis linh, hari duwowng"
  ],
  "Thái Đô, Thái Thụy, Thái Bình": [
    "thái đô, thái thụy, thái bình",
    "thasi ddoo, thasi thujy, thasi bifnh"
  ],
  "Thông Nông, Hà Quảng, Cao Bằng": [
    "thông nông, hà quảng, cao bằng",
    "thoong noong, haf quarng, cao bawfng"
  ],
  "Thăng Long, Kinh Môn, Hải Dương": [
    "thăng long, kinh môn, hải dương",
    "thawng long, kinh moon, hari duwowng"
  ],
  "Thăng Long, Nông Cống, Thanh Hóa": [
    "thăng long, nông cống, thanh hóa",
    "thawng long, noong coosng, thanh hosa"
  ],
  "Thượng Giáo, Ba Bể, Bắc Kạn": [
    "thượng giáo, ba bể, bắc kạn",
    "thuwowjng giaso, ba beer, bawsc kajn"
  ],
  "Thượng Lộc, Can Lộc, Hà Tĩnh": [
    "thượng lộc, can lộc, hà tĩnh",
    "thuwowjng loojc, can loojc, haf tixnh"
  ],
  "Thạc Gián, Thanh Khê, Đà Nẵng": [
    "thạc gián, thanh khê, đà nẵng",
    "thajc giasn, thanh khee, ddaf nawxng"
  ],
  "Thạch Hải, Thạch Hà, Hà Tĩnh": [
    "thạch hải, thạch hà, hà tĩnh",
    "thajch hari, thajch haf, haf tixnh"
  ],
  "Thạch Hội, Thạch Hà, Hà Tĩnh": [
    "thạch hội, thạch hà, hà tĩnh",
    "thajch hooji, thajch haf, haf tixnh"
  ],
  "Thạch Kiệt, Tân Sơn, Phú Thọ": [
    "thạch kiệt, tân sơn, phú thọ",
    "thajch kieejt, taan sown, phus thoj"
  ],
  "Thạch Kênh, Thạch Hà, Hà Tĩnh": [
    "thạch kênh, thạch hà, hà tĩnh",
    "thajch keenh, thajch haf, haf tixnh"
  ],
  "Thạch Liên, Thạch Hà, Hà Tĩnh": [
    "thạch liên, thạch hà, hà tĩnh",
    "thajch lieen, thajch haf, haf tixnh"
  ],
  "Thạch Lạc, Thạch Hà, Hà Tĩnh": [
    "thạch lạc, thạch hà, hà tĩnh",
    "thajch lajc, thajch haf, haf tixnh"
  ],
  "Thạch Trị, Thạch Hà, Hà Tĩnh": [
    "thạch trị, thạch hà, hà tĩnh",
    "thajch trij, thajch haf, haf tixnh"
  ],
  "Thạch Xuân, Thạch Hà, Hà Tĩnh": [
    "thạch xuân, thạch hà, hà tĩnh",
    "thajch xuaan, thajch haf, haf tixnh"
  ],
  "Thạch Đài, Thạch Hà, Hà Tĩnh": [
    "thạch đài, thạch hà, hà tĩnh",
    "thajch ddafi, thajch haf, haf tixnh"
  ],
  "Thạnh An, Vĩnh Thạnh, Cần Thơ": [
    "thạnh an, vĩnh thạnh, cần thơ",
    "thajnh an, vixnh thajnh, caafn thow"
  ],
  "Thạnh Phú, Thạnh Phú, Bến Tre": [
    "thạnh phú, thạnh phú, bến tre",
    "thajnh phus, thajnh phus, beesn tre"
  ],
  "Thạnh Quới, Long Hồ, Vĩnh Long": [
    "thạnh quới, long hồ, vĩnh long",
    "thajnh quowsi, long hoof, vixnh long"
  ],
  "Thạnh Đông, Tân Châu, Tây Ninh": [
    "thạnh đông, tân châu, tây ninh",
    "thajnh ddoong, taan chaau, taay ninh"
  ],
  "Thắng Lợi, Văn Giang, Hưng Yên": [
    "thắng lợi, văn giang, hưng yên",
    "thawsng lowji, vawn giang, huwng yeen"
  ],
  "Thị Nại, Qui Nhơn, Bình Định": [
    "thị nại, qui nhơn, bình định",
    "thij naji, qui nhown, bifnh ddijnh"
  ],
  "Thịnh Liệt, Hoàng Mai, Hà Nội": [
    "thịnh liệt, hoàng mai, hà nội",
    "thijnh lieejt, hoafng mai, haf nooji"
  ],
  "Thịnh Quang, Đống Đa, Hà Nội": [
    "thịnh quang, đống đa, hà nội",
    "thijnh quang, ddoosng dda, haf nooji"
  ],
  "Thịnh Sơn, Đô Lương, Nghệ An": [
    "thịnh sơn, đô lương, nghệ an",
    "thijnh sown, ddoo luwowng, ngheej an"
  ],
  "Thọ Bình, Triệu Sơn, Thanh Hóa": [
    "thọ bình, triệu sơn, thanh hóa",
    "thoj bifnh, trieeju sown, thanh hosa"
  ],
  "Thọ Thế, Triệu Sơn, Thanh Hóa": [
    "thọ thế, triệu sơn, thanh hóa",
    "thoj thees, trieeju sown, thanh hosa"
  ],
  "Thọ Vực, Triệu Sơn, Thanh Hóa": [
    "thọ vực, triệu sơn, thanh hóa",
    "thoj vuwjc, trieeju sown, thanh hosa"
  ],
  "Thống Nhất, Hạ Lang, Cao Bằng": [
    "thống nhất, hạ lang, cao bằng",
    "thoosng nhaast, haj lang, cao bawfng"
  ],
  "Thổ Bình, Lâm Bình, Tuyên Quang": [
    "thổ bình, lâm bình, tuyên quang",
    "thoor bifnh, laam bifnh, tuyeen quang"
  ],
  "Thổ Châu, Phú Quốc, Kiên Giang": [
    "thổ châu, phú quốc, kiên giang",
    "thoor chaau, phus quoosc, kieen giang"
  ],
  "Thới Bình, Ninh Kiều, Cần Thơ": [
    "thới bình, ninh kiều, cần thơ",
    "thowsi bifnh, ninh kieefu, caafn thow"
  ],
  "Thới Đông, Cờ Đỏ, Cần Thơ": [
    "thới đông, cờ đỏ, cần thơ",
    "thowsi ddoong, cowf ddor, caafn thow"
  ],
  "Thụy Hùng, Văn Lãng, Lạng Sơn": [
    "thụy hùng, văn lãng, lạng sơn",
    "thujy hufng, vawn laxng, lajng sown"
  ],
  "Thụy Liễu, Cẩm Khê, Phú Thọ": [
    "thụy liễu, cẩm khê, phú thọ",
    "thujy lieexu, caarm khee, phus thoj"
  ],
  "Tiên An, Tiên Phước, Quảng Nam": [
    "tiên an, tiên phước, quảng nam",
    "tieen an, tieen phuwowsc, quarng nam"
  ],
  "Tiên Lãng, Tiên Yên, Quảng Ninh": [
    "tiên lãng, tiên yên, quảng ninh",
    "tieen laxng, tieen yeen, quarng ninh"
  ],
  "Tiên Lương, Cẩm Khê, Phú Thọ": [
    "tiên lương, cẩm khê, phú thọ",
    "tieen luwowng, caarm khee, phus thoj"
  ],
  "Tiên Minh, Tiên Lãng, Hải Phòng": [
    "tiên minh, tiên lãng, hải phòng",
    "tieen minh, tieen laxng, hari phofng"
  ],
  "Tiên Nguyên, Quang Bình, Hà Giang": [
    "tiên nguyên, quang bình, hà giang",
    "tieen nguyeen, quang bifnh, haf giang"
  ],
  "Tiên Thuận, Bến Cầu, Tây Ninh": [
    "tiên thuận, bến cầu, tây ninh",
    "tieen thuaajn, beesn caafu, taay ninh"
  ],
  "Tiên Thủy, Châu Thành, Bến Tre": [
    "tiên thủy, châu thành, bến tre",
    "tieen thury, chaau thafnh, beesn tre"
  ],
  "Tiến Dũng, Yên Dũng, Bắc Giang": [
    "tiến dũng, yên dũng, bắc giang",
    "tieesn duxng, yeen duxng, bawsc giang"
  ],
  "Tiến Lộc, Hậu Lộc, Thanh Hóa": [
    "tiến lộc, hậu lộc, thanh hóa",
    "tieesn loojc, haaju loojc, thanh hosa"
  ],
  "Tiến Thành, Yên Thành, Nghệ An": [
    "tiến thành, yên thành, nghệ an",
    "tieesn thafnh, yeen thafnh, ngheej an"
  ],
  "Tiến Đức, Hưng Hà, Thái Bình": [
    "tiến đức, hưng hà, thái bình",
    "tieesn dduwsc, huwng haf, thasi bifnh"
  ],
  "Tiền An, Quảng Yên, Quảng Ninh": [
    "tiền an, quảng yên, quảng ninh",
    "tieefn an, quarng yeen, quarng ninh"
  ],
  "Tiền Châu, Phúc Yên, Vĩnh Phúc": [
    "tiền châu, phúc yên, vĩnh phúc",
    "tieefn chaau, phusc yeen, vixnh phusc"
  ],
  "Tiền Phong, Yên Dũng, Bắc Giang": [
    "tiền phong, yên dũng, bắc giang",
    "tieefn phong, yeen duxng, bawsc giang"
  ],
  "Tiểu Cần, Tiểu Cần, Trà Vinh": [
    "tiểu cần, tiểu cần, trà vinh",
    "tieeru caafn, tieeru caafn, traf vinh"
  ],
  "Trung Hòa, Chiêm Hóa, Tuyên Quang": [
    "trung hòa, chiêm hóa, tuyên quang",
    "trung hofa, chieem hosa, tuyeen quang"
  ],
  "Trung Hòa, Chợ Gạo, Tiền Giang": [
    "trung hòa, chợ gạo, tiền giang",
    "trung hofa, chowj gajo, tieefn giang"
  ],
  "Trung Kiên, Thốt Nốt, Cần Thơ": [
    "trung kiên, thốt nốt, cần thơ",
    "trung kieen, thoost noost, caafn thow"
  ],
  "Trung Kênh, Lương Tài, Bắc Ninh": [
    "trung kênh, lương tài, bắc ninh",
    "trung keenh, luwowng tafi, bawsc ninh"
  ],
  "Trung Lèng Hồ, Bát Xát, Lào Cai": [
    "trung lèng hồ, bát xát, lào cai",
    "trung lefng hoof, bast xast, lafo cai"
  ],
  "Trung Mỹ, Bình Xuyên, Vĩnh Phúc": [
    "trung mỹ, bình xuyên, vĩnh phúc",
    "trung myx, bifnh xuyeen, vixnh phusc"
  ],
  "Trung Ngãi,  Vũng Liêm, Vĩnh Long": [
    "trung ngãi,  vũng liêm, vĩnh long",
    "trung ngaxi,  vuxng lieem, vixnh long"
  ],
  "Trung Phụng, Đống Đa, Hà Nội": [
    "trung phụng, đống đa, hà nội",
    "trung phujng, ddoosng dda, haf nooji"
  ],
  "Trung Thu, Tủa Chùa, Điện Biên": [
    "trung thu, tủa chùa, điện biên",
    "trung thu, tura chufa, ddieejn bieen"
  ],
  "Trung Thành, Vụ Bản, Nam Định": [
    "trung thành, vụ bản, nam định",
    "trung thafnh, vuj barn, nam ddijnh"
  ],
  "Trung Thạnh, Cờ Đỏ, Cần Thơ": [
    "trung thạnh, cờ đỏ, cần thơ",
    "trung thajnh, cowf ddor, caafn thow"
  ],
  "Trung Trực, Yên Sơn, Tuyên Quang": [
    "trung trực, yên sơn, tuyên quang",
    "trung truwjc, yeen sown, tuyeen quang"
  ],
  "Trung Văn, Nam Từ Liêm, Hà Nội": [
    "trung văn, nam từ liêm, hà nội",
    "trung vawn, nam tuwf lieem, haf nooji"
  ],
  "Trà Bùi, Trà Bồng, Quảng Ngãi": [
    "trà bùi, trà bồng, quảng ngãi",
    "traf bufi, traf boofng, quarng ngaxi"
  ],
  "Trà Kót, Bắc Trà My, Quảng Nam": [
    "trà kót, bắc trà my, quảng nam",
    "traf kost, bawsc traf my, quarng nam"
  ],
  "Trà Lâm, Trà Bồng, Quảng Ngãi": [
    "trà lâm, trà bồng, quảng ngãi",
    "traf laam, traf boofng, quarng ngaxi"
  ],
  "Trà Lĩnh, Trùng Khánh, Cao Bằng": [
    "trà lĩnh, trùng khánh, cao bằng",
    "traf lixnh, trufng khasnh, cao bawfng"
  ],
  "Trà Phú, Trà Bồng, Quảng Ngãi": [
    "trà phú, trà bồng, quảng ngãi",
    "traf phus, traf boofng, quarng ngaxi"
  ],
  "Trà Sơn, Bắc Trà My, Quảng Nam": [
    "trà sơn, bắc trà my, quảng nam",
    "traf sown, bawsc traf my, quarng nam"
  ],
  "Trà Sơn, Trà Bồng, Quảng Ngãi": [
    "trà sơn, trà bồng, quảng ngãi",
    "traf sown, traf boofng, quarng ngaxi"
  ],
  "Trà Tân, Bắc Trà My, Quảng Nam": [
    "trà tân, bắc trà my, quảng nam",
    "traf taan, bawsc traf my, quarng nam"
  ],
  "Trà Tân, Trà Bồng, Quảng Ngãi": [
    "trà tân, trà bồng, quảng ngãi",
    "traf taan, traf boofng, quarng ngaxi"
  ],
  "Trà Tân, Đức Linh, Bình Thuận": [
    "trà tân, đức linh, bình thuận",
    "traf taan, dduwsc linh, bifnh thuaajn"
  ],
  "Trà Tây, Trà Bồng, Quảng Ngãi": [
    "trà tây, trà bồng, quảng ngãi",
    "traf taay, traf boofng, quarng ngaxi"
  ],
  "Trà Xinh, Trà Bồng, Quảng Ngãi": [
    "trà xinh, trà bồng, quảng ngãi",
    "traf xinh, traf boofng, quarng ngaxi"
  ],
  "Trân Châu, Cát Hải, Hải Phòng": [
    "trân châu, cát hải, hải phòng",
    "traan chaau, cast hari, hari phofng"
  ],
  "Trù Hựu, Lục Ngạn, Bắc Giang": [
    "trù hựu, lục ngạn, bắc giang",
    "truf huwju, lujc ngajn, bawsc giang"
  ],
  "Trưng Nhị, Phúc Yên, Vĩnh Phúc": [
    "trưng nhị, phúc yên, vĩnh phúc",
    "truwng nhij, phusc yeen, vixnh phusc"
  ],
  "Trương Lương, Hoà An, Cao Bằng": [
    "trương lương, hoà an, cao bằng",
    "truwowng luwowng, hoaf an, cao bawfng"
  ],
  "Trường Lâm, Tĩnh Gia, Thanh Hóa": [
    "trường lâm, tĩnh gia, thanh hóa",
    "truwowfng laam, tixnh gia, thanh hosa"
  ],
  "Trường Sơn, An Lão, Hải Phòng": [
    "trường sơn, an lão, hải phòng",
    "truwowfng sown, an laxo, hari phofng"
  ],
  "Trường Thi, Thanh Hóa, Thanh Hóa": [
    "trường thi, thanh hóa, thanh hóa",
    "truwowfng thi, thanh hosa, thanh hosa"
  ],
  "Trạm Trôi, Hoài Đức, Hà Nội": [
    "trạm trôi, hoài đức, hà nội",
    "trajm trooi, hoafi dduwsc, haf nooji"
  ],
  "Trạm Tấu, Trạm Tấu, Yên Bái": [
    "trạm tấu, trạm tấu, yên bái",
    "trajm taasu, trajm taasu, yeen basi"
  ],
  "Trảng Bom, Trảng Bom, Đồng Nai": [
    "trảng bom, trảng bom, đồng nai",
    "trarng bom, trarng bom, ddoofng nai"
  ],
  "Trảng Dài, Biên Hòa, Đồng Nai": [
    "trảng dài, biên hòa, đồng nai",
    "trarng dafi, bieen hofa, ddoofng nai"
  ],
  "Trần Hưng Đạo, Kon Tum, Kon Tum": [
    "trần hưng đạo, kon tum, kon tum",
    "traafn huwng ddajo, kon tum, kon tum"
  ],
  "Trần Lãm, Thái Bình, Thái Bình": [
    "trần lãm, thái bình, thái bình",
    "traafn laxm, thasi bifnh, thasi bifnh"
  ],
  "Trần Phú, Bắc Giang, Bắc Giang": [
    "trần phú, bắc giang, bắc giang",
    "traafn phus, bawsc giang, bawsc giang"
  ],
  "Trần Phú, Chương Mỹ, Hà Nội": [
    "trần phú, chương mỹ, hà nội",
    "traafn phus, chuwowng myx, haf nooji"
  ],
  "Trần Phú, Móng Cái, Quảng Ninh": [
    "trần phú, móng cái, quảng ninh",
    "traafn phus, mosng casi, quarng ninh"
  ],
  "Trần Phú, Qui Nhơn, Bình Định": [
    "trần phú, qui nhơn, bình định",
    "traafn phus, qui nhown, bifnh ddijnh"
  ],
  "Trịnh Tường, Bát Xát, Lào Cai": [
    "trịnh tường, bát xát, lào cai",
    "trijnh tuwowfng, bast xast, lafo cai"
  ],
  "Trừng Xá, Lương Tài, Bắc Ninh": [
    "trừng xá, lương tài, bắc ninh",
    "truwfng xas, luwowng tafi, bawsc ninh"
  ],
  "Trực Mỹ, Trực Ninh, Nam Định": [
    "trực mỹ, trực ninh, nam định",
    "truwjc myx, truwjc ninh, nam ddijnh"
  ],
  "Tuyết Nghĩa, Quốc Oai, Hà Nội": [
    "tuyết nghĩa, quốc oai, hà nội",
    "tuyeest nghixa, quoosc oai, haf nooji"
  ],
  "Tuần Châu, Hạ Long, Quảng Ninh": [
    "tuần châu, hạ long, quảng ninh",
    "tuaafn chaau, haj long, quarng ninh"
  ],
  "Tà Si Láng, Trạm Tấu, Yên Bái": [
    "tà si láng, trạm tấu, yên bái",
    "taf si lasng, trajm taasu, yeen basi"
  ],
  "Tân An Hội, Mang Thít, Vĩnh Long": [
    "tân an hội, mang thít, vĩnh long",
    "taan an hooji, mang thist, vixnh long"
  ],
  "Tân Dĩnh, Lạng Giang, Bắc Giang": [
    "tân dĩnh, lạng giang, bắc giang",
    "taan dixnh, lajng giang, bawsc giang"
  ],
  "Tân Dương, Lai Vung, Đồng Tháp": [
    "tân dương, lai vung, đồng tháp",
    "taan duwowng, lai vung, ddoofng thasp"
  ],
  "Tân Hiệp, Long Thành, Đồng Nai": [
    "tân hiệp, long thành, đồng nai",
    "taan hieejp, long thafnh, ddoofng nai"
  ],
  "Tân Hiệp, Tân Hiệp, Kiên Giang": [
    "tân hiệp, tân hiệp, kiên giang",
    "taan hieejp, taan hieejp, kieen giang"
  ],
  "Tân Hòa, Thanh Bình, Đồng Tháp": [
    "tân hòa, thanh bình, đồng tháp",
    "taan hofa, thanh bifnh, ddoofng thasp"
  ],
  "Tân Hưng, Bàu Bàng, Bình Dương": [
    "tân hưng, bàu bàng, bình dương",
    "taan huwng, bafu bafng, bifnh duwowng"
  ],
  "Tân Hưng, Lạng Giang, Bắc Giang": [
    "tân hưng, lạng giang, bắc giang",
    "taan huwng, lajng giang, bawsc giang"
  ],
  "Tân Hưng, Vĩnh Bảo, Hải Phòng": [
    "tân hưng, vĩnh bảo, hải phòng",
    "taan huwng, vixnh baro, hari phofng"
  ],
  "Tân Hương, Bắc Sơn, Lạng Sơn": [
    "tân hương, bắc sơn, lạng sơn",
    "taan huwowng, bawsc sown, lajng sown"
  ],
  "Tân Hương, Đức Thọ, Hà Tĩnh": [
    "tân hương, đức thọ, hà tĩnh",
    "taan huwowng, dduwsc thoj, haf tixnh"
  ],
  "Tân Học, Thái Thụy, Thái Bình": [
    "tân học, thái thụy, thái bình",
    "taan hojc, thasi thujy, thasi bifnh"
  ],
  "Tân Hội, Đan Phượng, Hà Nội": [
    "tân hội, đan phượng, hà nội",
    "taan hooji, ddan phuwowjng, haf nooji"
  ],
  "Tân Linh, Đại Từ, Thái Nguyên": [
    "tân linh, đại từ, thái nguyên",
    "taan linh, ddaji tuwf, thasi nguyeen"
  ],
  "Tân Liên, Vĩnh Bảo, Hải Phòng": [
    "tân liên, vĩnh bảo, hải phòng",
    "taan lieen, vixnh baro, hari phofng"
  ],
  "Tân Long, Thanh Bình, Đồng Tháp": [
    "tân long, thanh bình, đồng tháp",
    "taan long, thanh bifnh, ddoofng thasp"
  ],
  "Tân Lập, Chợ Đồn, Bắc Kạn": [
    "tân lập, chợ đồn, bắc kạn",
    "taan laajp, chowj ddoofn, bawsc kajn"
  ],
  "Tân Lập, Krông Búk, Đắk Lắk": [
    "tân lập, krông búk, đắk lắk",
    "taan laajp, kroong busk, ddawsk lawsk"
  ],
  "Tân Lập, Lục Ngạn, Bắc Giang": [
    "tân lập, lục ngạn, bắc giang",
    "taan laajp, lujc ngajn, bawsc giang"
  ],
  "Tân Lập, Đan Phượng, Hà Nội": [
    "tân lập, đan phượng, hà nội",
    "taan laajp, ddan phuwowjng, haf nooji"
  ],
  "Tân Mộc, Lục Ngạn, Bắc Giang": [
    "tân mộc, lục ngạn, bắc giang",
    "taan moojc, lujc ngajn, bawsc giang"
  ],
  "Tân Mỹ, Thanh Bình, Đồng Tháp": [
    "tân mỹ, thanh bình, đồng tháp",
    "taan myx, thanh bifnh, ddoofng thasp"
  ],
  "Tân Nghĩa, Cao Lãnh, Đồng Tháp": [
    "tân nghĩa, cao lãnh, đồng tháp",
    "taan nghixa, cao laxnh, ddoofng thasp"
  ],
  "Tân Nghĩa, Hàm Tân, Bình Thuận": [
    "tân nghĩa, hàm tân, bình thuận",
    "taan nghixa, hafm taan, bifnh thuaajn"
  ],
  "Tân Phong, Bình Xuyên, Vĩnh Phúc": [
    "tân phong, bình xuyên, vĩnh phúc",
    "taan phong, bifnh xuyeen, vixnh phusc"
  ],
  "Tân Phong, Ninh Giang, Hải Dương": [
    "tân phong, ninh giang, hải dương",
    "taan phong, ninh giang, hari duwowng"
  ],
  "Tân Phú, Thanh Bình, Đồng Tháp": [
    "tân phú, thanh bình, đồng tháp",
    "taan phus, thanh bifnh, ddoofng thasp"
  ],
  "Tân Phượng, Lục Yên, Yên Bái": [
    "tân phượng, lục yên, yên bái",
    "taan phuwowjng, lujc yeen, yeen basi"
  ],
  "Tân Quang, Lục Ngạn, Bắc Giang": [
    "tân quang, lục ngạn, bắc giang",
    "taan quang, lujc ngajn, bawsc giang"
  ],
  "Tân Quang, Ninh Giang, Hải Dương": [
    "tân quang, ninh giang, hải dương",
    "taan quang, ninh giang, hari duwowng"
  ],
  "Tân Thanh, Lạng Giang, Bắc Giang": [
    "tân thanh, lạng giang, bắc giang",
    "taan thanh, lajng giang, bawsc giang"
  ],
  "Tân Thiềng, Chợ Lách, Bến Tre": [
    "tân thiềng, chợ lách, bến tre",
    "taan thieefng, chowj lasch, beesn tre"
  ],
  "Tân Thành, Hữu Lũng, Lạng Sơn": [
    "tân thành, hữu lũng, lạng sơn",
    "taan thafnh, huwxu luxng, lajng sown"
  ],
  "Tân Thành, Krông Nô, Đắk Nông": [
    "tân thành, krông nô, đắk nông",
    "taan thafnh, kroong noo, ddawsk noong"
  ],
  "Tân Thành, Tân Hiệp, Kiên Giang": [
    "tân thành, tân hiệp, kiên giang",
    "taan thafnh, taan hieejp, kieen giang"
  ],
  "Tân Thượng, Di Linh, Lâm Đồng": [
    "tân thượng, di linh, lâm đồng",
    "taan thuwowjng, di linh, laam ddoofng"
  ],
  "Tân Thạch, Châu Thành, Bến Tre": [
    "tân thạch, châu thành, bến tre",
    "taan thajch, chaau thafnh, beesn tre"
  ],
  "Tân Thắng, Quỳnh Lưu, Nghệ An": [
    "tân thắng, quỳnh lưu, nghệ an",
    "taan thawsng, quyfnh luwu, ngheej an"
  ],
  "Tân Thịnh, Nam Trực, Nam Định": [
    "tân thịnh, nam trực, nam định",
    "taan thijnh, nam truwjc, nam ddijnh"
  ],
  "Tân Tiến, An Dương, Hải Phòng": [
    "tân tiến, an dương, hải phòng",
    "taan tieesn, an duwowng, hari phofng"
  ],
  "Tân Tiến, Bắc Giang, Bắc Giang": [
    "tân tiến, bắc giang, bắc giang",
    "taan tieesn, bawsc giang, bawsc giang"
  ],
  "Tân Tiến, Chương Mỹ, Hà Nội": [
    "tân tiến, chương mỹ, hà nội",
    "taan tieesn, chuwowng myx, haf nooji"
  ],
  "Tân Tiến, Gia Lộc, Hải Dương": [
    "tân tiến, gia lộc, hải dương",
    "taan tieesn, gia loojc, hari duwowng"
  ],
  "Tân Trường, Tĩnh Gia, Thanh Hóa": [
    "tân trường, tĩnh gia, thanh hóa",
    "taan truwowfng, tixnh gia, thanh hosa"
  ],
  "Tân Trạch, Cần Đước, Long An": [
    "tân trạch, cần đước, long an",
    "taan trajch, caafn dduwowsc, long an"
  ],
  "Tân Việt, Thanh Hà, Hải Dương": [
    "tân việt, thanh hà, hải dương",
    "taan vieejt, thanh haf, hari duwowng"
  ],
  "Tân Xuân, Hóc Môn, Hồ Chí Minh": [
    "tân xuân, hóc môn, hồ chí minh",
    "taan xuaan, hosc moon, hoof chis minh"
  ],
  "Tân Ân Tây, Ngọc Hiển, Cà Mau": [
    "tân ân tây, ngọc hiển, cà mau",
    "taan aan taay, ngojc hieern, caf mau"
  ],
  "Tân Đức, Hàm Tân, Bình Thuận": [
    "tân đức, hàm tân, bình thuận",
    "taan dduwsc, hafm taan, bifnh thuaajn"
  ],
  "Tây Giang, Tiền Hải, Thái Bình": [
    "tây giang, tiền hải, thái bình",
    "taay giang, tieefn hari, thasi bifnh"
  ],
  "Tây Hưng, Tiên Lãng, Hải Phòng": [
    "tây hưng, tiên lãng, hải phòng",
    "taay huwng, tieen laxng, hari phofng"
  ],
  "Tây Phong, Tiền Hải, Thái Bình": [
    "tây phong, tiền hải, thái bình",
    "taay phong, tieefn hari, thasi bifnh"
  ],
  "Tô Hiệu, Thường Tín, Hà Nội": [
    "tô hiệu, thường tín, hà nội",
    "too hieeju, thuwowfng tisn, haf nooji"
  ],
  "Tú Sơn, Kiến Thuỵ, Hải Phòng": [
    "tú sơn, kiến thuỵ, hải phòng",
    "tus sown, kieesn thuyj, hari phofng"
  ],
  "Tú Đoạn, Lộc Bình, Lạng Sơn": [
    "tú đoạn, lộc bình, lạng sơn",
    "tus ddoajn, loojc bifnh, lajng sown"
  ],
  "Túng Sán, Hoàng Su Phì, Hà Giang": [
    "túng sán, hoàng su phì, hà giang",
    "tusng sasn, hoafng su phif, haf giang"
  ],
  "Tĩnh Bắc, Lộc Bình, Lạng Sơn": [
    "tĩnh bắc, lộc bình, lạng sơn",
    "tixnh bawsc, loojc bifnh, lajng sown"
  ],
  "Tĩnh Túc, Nguyên Bình, Cao Bằng": [
    "tĩnh túc, nguyên bình, cao bằng",
    "tixnh tusc, nguyeen bifnh, cao bawfng"
  ],
  "Tường Lộc, Tam Bình, Vĩnh Long": [
    "tường lộc, tam bình, vĩnh long",
    "tuwowfng loojc, tam bifnh, vixnh long"
  ],
  "Tường Đa, Châu Thành, Bến Tre": [
    "tường đa, châu thành, bến tre",
    "tuwowfng dda, chaau thafnh, beesn tre"
  ],
  "Tượng Sơn, Thạch Hà, Hà Tĩnh": [
    "tượng sơn, thạch hà, hà tĩnh",
    "tuwowjng sown, thajch haf, haf tixnh"
  ],
  "Tả Thanh Oai, Thanh Trì, Hà Nội": [
    "tả thanh oai, thanh trì, hà nội",
    "tar thanh oai, thanh trif, haf nooji"
  ],
  "Tất Thắng, Thanh Sơn, Phú Thọ": [
    "tất thắng, thanh sơn, phú thọ",
    "taast thawsng, thanh sown, phus thoj"
  ],
  "Tổng Cọt, Hà Quảng, Cao Bằng": [
    "tổng cọt, hà quảng, cao bằng",
    "toorng cojt, haf quarng, cao bawfng"
  ],
  "Tụ Nhân, Hoàng Su Phì, Hà Giang": [
    "tụ nhân, hoàng su phì, hà giang",
    "tuj nhaan, hoafng su phif, haf giang"
  ],
  "Vinh Quang, Chiêm Hóa, Tuyên Quang": [
    "vinh quang, chiêm hóa, tuyên quang",
    "vinh quang, chieem hosa, tuyeen quang"
  ],
  "Vinh Quang, Hoàng Su Phì, Hà Giang": [
    "vinh quang, hoàng su phì, hà giang",
    "vinh quang, hoafng su phif, haf giang"
  ],
  "Vinh Quang, Tiên Lãng, Hải Phòng": [
    "vinh quang, tiên lãng, hải phòng",
    "vinh quang, tieen laxng, hari phofng"
  ],
  "Vinh Quang, Vĩnh Bảo, Hải Phòng": [
    "vinh quang, vĩnh bảo, hải phòng",
    "vinh quang, vixnh baro, hari phofng"
  ],
  "Việt Hòa, Khoái Châu, Hưng Yên": [
    "việt hòa, khoái châu, hưng yên",
    "vieejt hofa, khoasi chaau, huwng yeen"
  ],
  "Việt Hưng, Hạ Long, Quảng Ninh": [
    "việt hưng, hạ long, quảng ninh",
    "vieejt huwng, haj long, quarng ninh"
  ],
  "Việt Hồng, Bắc Quang, Hà Giang": [
    "việt hồng, bắc quang, hà giang",
    "vieejt hoofng, bawsc quang, haf giang"
  ],
  "Việt Hồng, Trấn Yên, Yên Bái": [
    "việt hồng, trấn yên, yên bái",
    "vieejt hoofng, traasn yeen, yeen basi"
  ],
  "Việt Ngọc, Tân Yên, Bắc Giang": [
    "việt ngọc, tân yên, bắc giang",
    "vieejt ngojc, taan yeen, bawsc giang"
  ],
  "Việt Thuận, Vũ Thư, Thái Bình": [
    "việt thuận, vũ thư, thái bình",
    "vieejt thuaajn, vux thuw, thasi bifnh"
  ],
  "Việt Thành, Trấn Yên, Yên Bái": [
    "việt thành, trấn yên, yên bái",
    "vieejt thafnh, traasn yeen, yeen basi"
  ],
  "Việt Thống, Quế Võ, Bắc Ninh": [
    "việt thống, quế võ, bắc ninh",
    "vieejt thoosng, quees vox, bawsc ninh"
  ],
  "Việt Tiến, Thạch Hà, Hà Tĩnh": [
    "việt tiến, thạch hà, hà tĩnh",
    "vieejt tieesn, thajch haf, haf tixnh"
  ],
  "Vân Sơn, Sơn Dương, Tuyên Quang": [
    "vân sơn, sơn dương, tuyên quang",
    "vaan sown, sown duwowng, tuyeen quang"
  ],
  "Vân Tảo, Thường Tín, Hà Nội": [
    "vân tảo, thường tín, hà nội",
    "vaan taro, thuwowfng tisn, haf nooji"
  ],
  "Vô Ngại, Bình Liêu, Quảng Ninh": [
    "vô ngại, bình liêu, quảng ninh",
    "voo ngaji, bifnh lieeu, quarng ninh"
  ],
  "Võ Liệt, Thanh Chương, Nghệ An": [
    "võ liệt, thanh chương, nghệ an",
    "vox lieejt, thanh chuwowng, ngheej an"
  ],
  "Võ Ninh, Quảng Ninh, Quảng Bình": [
    "võ ninh, quảng ninh, quảng bình",
    "vox ninh, quarng ninh, quarng bifnh"
  ],
  "Văn Bình, Thường Tín, Hà Nội": [
    "văn bình, thường tín, hà nội",
    "vawn bifnh, thuwowfng tisn, haf nooji"
  ],
  "Văn Chương, Đống Đa, Hà Nội": [
    "văn chương, đống đa, hà nội",
    "vawn chuwowng, ddoosng dda, haf nooji"
  ],
  "Văn Hóa, Tuyên Hóa, Quảng Bình": [
    "văn hóa, tuyên hóa, quảng bình",
    "vawn hosa, tuyeen hosa, quarng bifnh"
  ],
  "Văn Hội, Ninh Giang, Hải Dương": [
    "văn hội, ninh giang, hải dương",
    "vawn hooji, ninh giang, hari duwowng"
  ],
  "Văn Miếu, Nam Định, Nam Định": [
    "văn miếu, nam định, nam định",
    "vawn mieesu, nam ddijnh, nam ddijnh"
  ],
  "Văn Phú, Sơn Dương, Tuyên Quang": [
    "văn phú, sơn dương, tuyên quang",
    "vawn phus, sown duwowng, tuyeen quang"
  ],
  "Văn Yên, Đại Từ, Thái Nguyên": [
    "văn yên, đại từ, thái nguyên",
    "vawn yeen, ddaji tuwf, thasi nguyeen"
  ],
  "Văn Đức, Chí Linh, Hải Dương": [
    "văn đức, chí linh, hải dương",
    "vawn dduwsc, chis linh, hari duwowng"
  ],
  "Vĩ Thượng, Quang Bình, Hà Giang": [
    "vĩ thượng, quang bình, hà giang",
    "vix thuwowjng, quang bifnh, haf giang"
  ],
  "Vĩnh Bảo, Rạch Giá, Kiên Giang": [
    "vĩnh bảo, rạch giá, kiên giang",
    "vixnh baro, rajch gias, kieen giang"
  ],
  "Vĩnh Hoà, Phú Giáo, Bình Dương": [
    "vĩnh hoà, phú giáo, bình dương",
    "vixnh hoaf, phus giaso, bifnh duwowng"
  ],
  "Vĩnh Hòa, Ninh Giang, Hải Dương": [
    "vĩnh hòa, ninh giang, hải dương",
    "vixnh hofa, ninh giang, hari duwowng"
  ],
  "Vĩnh Hòa, Vĩnh Linh, Quảng Trị": [
    "vĩnh hòa, vĩnh linh, quảng trị",
    "vixnh hofa, vixnh linh, quarng trij"
  ],
  "Vĩnh Hưng, Vĩnh Lợi, Bạc Liêu": [
    "vĩnh hưng, vĩnh lợi, bạc liêu",
    "vixnh huwng, vixnh lowji, bajc lieeu"
  ],
  "Vĩnh Hải, Ninh Hải, Ninh Thuận": [
    "vĩnh hải, ninh hải, ninh thuận",
    "vixnh hari, ninh hari, ninh thuaajn"
  ],
  "Vĩnh Hải, Vĩnh Châu, Sóc Trăng": [
    "vĩnh hải, vĩnh châu, sóc trăng",
    "vixnh hari, vixnh chaau, sosc trawng"
  ],
  "Vĩnh Hảo, Tuy Phong, Bình Thuận": [
    "vĩnh hảo, tuy phong, bình thuận",
    "vixnh haro, tuy phong, bifnh thuaajn"
  ],
  "Vĩnh Hội Đông, An Phú, An Giang": [
    "vĩnh hội đông, an phú, an giang",
    "vixnh hooji ddoong, an phus, an giang"
  ],
  "Vĩnh Khê, Vĩnh Linh, Quảng Trị": [
    "vĩnh khê, vĩnh linh, quảng trị",
    "vixnh khee, vixnh linh, quarng trij"
  ],
  "Vĩnh Kim, Châu Thành, Tiền Giang": [
    "vĩnh kim, châu thành, tiền giang",
    "vixnh kim, chaau thafnh, tieefn giang"
  ],
  "Vĩnh Long, Vĩnh Bảo, Hải Phòng": [
    "vĩnh long, vĩnh bảo, hải phòng",
    "vixnh long, vixnh baro, hari phofng"
  ],
  "Vĩnh Long, Vĩnh Linh, Quảng Trị": [
    "vĩnh long, vĩnh linh, quảng trị",
    "vixnh long, vixnh linh, quarng trij"
  ],
  "Vĩnh Lâm, Vĩnh Linh, Quảng Trị": [
    "vĩnh lâm, vĩnh linh, quảng trị",
    "vixnh laam, vixnh linh, quarng trij"
  ],
  "Vĩnh Lương, Nha Trang, Khánh Hòa": [
    "vĩnh lương, nha trang, khánh hòa",
    "vixnh luwowng, nha trang, khasnh hofa"
  ],
  "Vĩnh Lạc, Rạch Giá, Kiên Giang": [
    "vĩnh lạc, rạch giá, kiên giang",
    "vixnh lajc, rajch gias, kieen giang"
  ],
  "Vĩnh Lập, Thanh Hà, Hải Dương": [
    "vĩnh lập, thanh hà, hải dương",
    "vixnh laajp, thanh haf, hari duwowng"
  ],
  "Vĩnh Lộc, Hồng Dân, Bạc Liêu": [
    "vĩnh lộc, hồng dân, bạc liêu",
    "vixnh loojc, hoofng daan, bajc lieeu"
  ],
  "Vĩnh Lợi, Rạch Giá, Kiên Giang": [
    "vĩnh lợi, rạch giá, kiên giang",
    "vixnh lowji, rajch gias, kieen giang"
  ],
  "Vĩnh Mỹ A, Hoà Bình, Bạc Liêu": [
    "vĩnh mỹ a, hoà bình, bạc liêu",
    "vixnh myx a, hoaf bifnh, bajc lieeu"
  ],
  "Vĩnh Mỹ B, Hoà Bình, Bạc Liêu": [
    "vĩnh mỹ b, hoà bình, bạc liêu",
    "vixnh myx b, hoaf bifnh, bajc lieeu"
  ],
  "Vĩnh Nguyên, Nha Trang, Khánh Hòa": [
    "vĩnh nguyên, nha trang, khánh hòa",
    "vixnh nguyeen, nha trang, khasnh hofa"
  ],
  "Vĩnh Ngươn, Châu Đốc, An Giang": [
    "vĩnh ngươn, châu đốc, an giang",
    "vixnh nguwown, chaau ddoosc, an giang"
  ],
  "Vĩnh Nhuận, Châu Thành, An Giang": [
    "vĩnh nhuận, châu thành, an giang",
    "vixnh nhuaajn, chaau thafnh, an giang"
  ],
  "Vĩnh Niệm, Lê Chân, Hải Phòng": [
    "vĩnh niệm, lê chân, hải phòng",
    "vixnh nieejm, lee chaan, hari phofng"
  ],
  "Vĩnh Phú, Giang Thành, Kiên Giang": [
    "vĩnh phú, giang thành, kiên giang",
    "vixnh phus, giang thafnh, kieen giang"
  ],
  "Vĩnh Phú, Thuận An, Bình Dương": [
    "vĩnh phú, thuận an, bình dương",
    "vixnh phus, thuaajn an, bifnh duwowng"
  ],
  "Vĩnh Quang, Rạch Giá, Kiên Giang": [
    "vĩnh quang, rạch giá, kiên giang",
    "vixnh quang, rajch gias, kieen giang"
  ],
  "Vĩnh Sơn, Vĩnh Linh, Quảng Trị": [
    "vĩnh sơn, vĩnh linh, quảng trị",
    "vixnh sown, vixnh linh, quarng trij"
  ],
  "Vĩnh Thanh, Rạch Giá, Kiên Giang": [
    "vĩnh thanh, rạch giá, kiên giang",
    "vixnh thanh, rajch gias, kieen giang"
  ],
  "Vĩnh Thạnh, Nha Trang, Khánh Hòa": [
    "vĩnh thạnh, nha trang, khánh hòa",
    "vixnh thajnh, nha trang, khasnh hofa"
  ],
  "Vĩnh Thới, Lai Vung, Đồng Tháp": [
    "vĩnh thới, lai vung, đồng tháp",
    "vixnh thowsi, lai vung, ddoofng thasp"
  ],
  "Vĩnh Tiến, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh tiến, vĩnh lộc, thanh hóa",
    "vixnh tieesn, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Trung, Móng Cái, Quảng Ninh": [
    "vĩnh trung, móng cái, quảng ninh",
    "vixnh trung, mosng casi, quarng ninh"
  ],
  "Vĩnh Trung, Vị Thuỷ, Hậu Giang": [
    "vĩnh trung, vị thuỷ, hậu giang",
    "vixnh trung, vij thuyr, haaju giang"
  ],
  "Vĩnh Trạch, Thoại Sơn, An Giang": [
    "vĩnh trạch, thoại sơn, an giang",
    "vixnh trajch, thoaji sown, an giang"
  ],
  "Vĩnh Tân, Tân Uyên, Bình Dương": [
    "vĩnh tân, tân uyên, bình dương",
    "vixnh taan, taan uyeen, bifnh duwowng"
  ],
  "Vũ Hòa, Kiến Xương, Thái Bình": [
    "vũ hòa, kiến xương, thái bình",
    "vux hofa, kieesn xuwowng, thasi bifnh"
  ],
  "Vũ Lễ, Kiến Xương, Thái Bình": [
    "vũ lễ, kiến xương, thái bình",
    "vux leex, kieesn xuwowng, thasi bifnh"
  ],
  "Vũ Ninh, Kiến Xương, Thái Bình": [
    "vũ ninh, kiến xương, thái bình",
    "vux ninh, kieesn xuwowng, thasi bifnh"
  ],
  "Vũ Quí, Kiến Xương, Thái Bình": [
    "vũ quí, kiến xương, thái bình",
    "vux quis, kieesn xuwowng, thasi bifnh"
  ],
  "Vũng Liêm,  Vũng Liêm, Vĩnh Long": [
    "vũng liêm,  vũng liêm, vĩnh long",
    "vuxng lieem,  vuxng lieem, vixnh long"
  ],
  "Vạn Khánh, Vạn Ninh, Khánh Hòa": [
    "vạn khánh, vạn ninh, khánh hòa",
    "vajn khasnh, vajn ninh, khasnh hofa"
  ],
  "Vạn Thạnh, Nha Trang, Khánh Hòa": [
    "vạn thạnh, nha trang, khánh hòa",
    "vajn thajnh, nha trang, khasnh hofa"
  ],
  "Vạn Thắng, Nha Trang, Khánh Hòa": [
    "vạn thắng, nha trang, khánh hòa",
    "vajn thawsng, nha trang, khasnh hofa"
  ],
  "Vạn Thủy, Bắc Sơn, Lạng Sơn": [
    "vạn thủy, bắc sơn, lạng sơn",
    "vajn thury, bawsc sown, lajng sown"
  ],
  "Vạn Yên, Vân Đồn, Quảng Ninh": [
    "vạn yên, vân đồn, quảng ninh",
    "vajn yeen, vaan ddoofn, quarng ninh"
  ],
  "Vần Chải, Đồng Văn, Hà Giang": [
    "vần chải, đồng văn, hà giang",
    "vaafn chari, ddoofng vawn, haf giang"
  ],
  "Vị Hoàng, Nam Định, Nam Định": [
    "vị hoàng, nam định, nam định",
    "vij hoafng, nam ddijnh, nam ddijnh"
  ],
  "Vị Thuỷ, Vị Thuỷ, Hậu Giang": [
    "vị thuỷ, vị thuỷ, hậu giang",
    "vij thuyr, vij thuyr, haaju giang"
  ],
  "Vị Xuyên, Nam Định, Nam Định": [
    "vị xuyên, nam định, nam định",
    "vij xuyeen, nam ddijnh, nam ddijnh"
  ],
  "Vị Đông, Vị Thuỷ, Hậu Giang": [
    "vị đông, vị thuỷ, hậu giang",
    "vij ddoong, vij thuyr, haaju giang"
  ],
  "Vọng Đông, Thoại Sơn, An Giang": [
    "vọng đông, thoại sơn, an giang",
    "vojng ddoong, thoaji sown, an giang"
  ],
  "Xiêng My, Tương Dương, Nghệ An": [
    "xiêng my, tương dương, nghệ an",
    "xieeng my, tuwowng duwowng, ngheej an"
  ],
  "Xuân An, Phan Thiết, Bình Thuận": [
    "xuân an, phan thiết, bình thuận",
    "xuaan an, phan thieest, bifnh thuaajn"
  ],
  "Xuân Bình, Long Khánh, Đồng Nai": [
    "xuân bình, long khánh, đồng nai",
    "xuaan bifnh, long khasnh, ddoofng nai"
  ],
  "Xuân Bắc, Xuân Lộc, Đồng Nai": [
    "xuân bắc, xuân lộc, đồng nai",
    "xuaan bawsc, xuaan loojc, ddoofng nai"
  ],
  "Xuân Cẩm, Hiệp Hòa, Bắc Giang": [
    "xuân cẩm, hiệp hòa, bắc giang",
    "xuaan caarm, hieejp hofa, bawsc giang"
  ],
  "Xuân Hưng, Xuân Lộc, Đồng Nai": [
    "xuân hưng, xuân lộc, đồng nai",
    "xuaan huwng, xuaan loojc, ddoofng nai"
  ],
  "Xuân Hải, Ninh Hải, Ninh Thuận": [
    "xuân hải, ninh hải, ninh thuận",
    "xuaan hari, ninh hari, ninh thuaajn"
  ],
  "Xuân Hồng, Thọ Xuân, Thanh Hóa": [
    "xuân hồng, thọ xuân, thanh hóa",
    "xuaan hoofng, thoj xuaan, thanh hosa"
  ],
  "Xuân Khánh, Ninh Kiều, Cần Thơ": [
    "xuân khánh, ninh kiều, cần thơ",
    "xuaan khasnh, ninh kieefu, caafn thow"
  ],
  "Xuân Lãnh, Đồng Xuân, Phú Yên": [
    "xuân lãnh, đồng xuân, phú yên",
    "xuaan laxnh, ddoofng xuaan, phus yeen"
  ],
  "Xuân Lập, Long Khánh, Đồng Nai": [
    "xuân lập, long khánh, đồng nai",
    "xuaan laajp, long khasnh, ddoofng nai"
  ],
  "Xuân Lập, Lâm Bình, Tuyên Quang": [
    "xuân lập, lâm bình, tuyên quang",
    "xuaan laajp, laam bifnh, tuyeen quang"
  ],
  "Xuân Lộc, Thanh Thuỷ, Phú Thọ": [
    "xuân lộc, thanh thuỷ, phú thọ",
    "xuaan loojc, thanh thuyr, phus thoj"
  ],
  "Xuân Lộc, Triệu Sơn, Thanh Hóa": [
    "xuân lộc, triệu sơn, thanh hóa",
    "xuaan loojc, trieeju sown, thanh hosa"
  ],
  "Xuân Thanh, Long Khánh, Đồng Nai": [
    "xuân thanh, long khánh, đồng nai",
    "xuaan thanh, long khasnh, ddoofng nai"
  ],
  "Xuân Thiên, Thọ Xuân, Thanh Hóa": [
    "xuân thiên, thọ xuân, thanh hóa",
    "xuaan thieen, thoj xuaan, thanh hosa"
  ],
  "Xuân Thượng, Bảo Yên, Lào Cai": [
    "xuân thượng, bảo yên, lào cai",
    "xuaan thuwowjng, baro yeen, lafo cai"
  ],
  "Xuân Thắng, Thới Lai, Cần Thơ": [
    "xuân thắng, thới lai, cần thơ",
    "xuaan thawsng, thowsi lai, caafn thow"
  ],
  "Xuân Thịnh, Sông Cầu, Phú Yên": [
    "xuân thịnh, sông cầu, phú yên",
    "xuaan thijnh, soong caafu, phus yeen"
  ],
  "Xuân Thọ 1, Sông Cầu, Phú Yên": [
    "xuân thọ 1, sông cầu, phú yên",
    "xuaan thoj 1, soong caafu, phus yeen"
  ],
  "Xuân Thọ 2, Sông Cầu, Phú Yên": [
    "xuân thọ 2, sông cầu, phú yên",
    "xuaan thoj 2, soong caafu, phus yeen"
  ],
  "Xuân Thọ, Triệu Sơn, Thanh Hóa": [
    "xuân thọ, triệu sơn, thanh hóa",
    "xuaan thoj, trieeju sown, thanh hosa"
  ],
  "Xuân Thọ, Xuân Lộc, Đồng Nai": [
    "xuân thọ, xuân lộc, đồng nai",
    "xuaan thoj, xuaan loojc, ddoofng nai"
  ],
  "Xuân Thọ, Đà Lạt, Lâm Đồng": [
    "xuân thọ, đà lạt, lâm đồng",
    "xuaan thoj, ddaf lajt, laam ddoofng"
  ],
  "Xuân Trung, Long Khánh, Đồng Nai": [
    "xuân trung, long khánh, đồng nai",
    "xuaan trung, long khasnh, ddoofng nai"
  ],
  "Xuân Đám, Cát Hải, Hải Phòng": [
    "xuân đám, cát hải, hải phòng",
    "xuaan ddasm, cast hari, hari phofng"
  ],
  "Xuân Đông, Cẩm Mỹ, Đồng Nai": [
    "xuân đông, cẩm mỹ, đồng nai",
    "xuaan ddoong, caarm myx, ddoofng nai"
  ],
  "Xuất Hóa, Bắc Kạn, Bắc Kạn": [
    "xuất hóa, bắc kạn, bắc kạn",
    "xuaast hosa, bawsc kajn, bawsc kajn"
  ],
  "Xương Huân, Nha Trang, Khánh Hòa": [
    "xương huân, nha trang, khánh hòa",
    "xuwowng huaan, nha trang, khasnh hofa"
  ],
  "Yên Bình, Thạch Thất, Hà Nội": [
    "yên bình, thạch thất, hà nội",
    "yeen bifnh, thajch thaast, haf nooji"
  ],
  "Yên Bồng, Lạc Thủy, Hoà Bình": [
    "yên bồng, lạc thủy, hoà bình",
    "yeen boofng, lajc thury, hoaf bifnh"
  ],
  "Yên Dương, Tam Đảo, Vĩnh Phúc": [
    "yên dương, tam đảo, vĩnh phúc",
    "yeen duwowng, tam ddaro, vixnh phusc"
  ],
  "Yên Dưỡng, Cẩm Khê, Phú Thọ": [
    "yên dưỡng, cẩm khê, phú thọ",
    "yeen duwowxng, caarm khee, phus thoj"
  ],
  "Yên Hòa, Tương Dương, Nghệ An": [
    "yên hòa, tương dương, nghệ an",
    "yeen hofa, tuwowng duwowng, ngheej an"
  ],
  "Yên Khoái, Lộc Bình, Lạng Sơn": [
    "yên khoái, lộc bình, lạng sơn",
    "yeen khoasi, loojc bifnh, lajng sown"
  ],
  "Yên Lạc, Nguyên Bình, Cao Bằng": [
    "yên lạc, nguyên bình, cao bằng",
    "yeen lajc, nguyeen bifnh, cao bawfng"
  ],
  "Yên Lập, Chiêm Hóa, Tuyên Quang": [
    "yên lập, chiêm hóa, tuyên quang",
    "yeen laajp, chieem hosa, tuyeen quang"
  ],
  "Yên Nghiệp, Lạc Sơn, Hoà Bình": [
    "yên nghiệp, lạc sơn, hoà bình",
    "yeen nghieejp, lajc sown, hoaf bifnh"
  ],
  "Yên Phong, Chợ Đồn, Bắc Kạn": [
    "yên phong, chợ đồn, bắc kạn",
    "yeen phong, chowj ddoofn, bawsc kajn"
  ],
  "Yên Thuận, Hàm Yên, Tuyên Quang": [
    "yên thuận, hàm yên, tuyên quang",
    "yeen thuaajn, hafm yeen, tuyeen quang"
  ],
  "Yên Thắng, Lang Chánh, Thanh Hóa": [
    "yên thắng, lang chánh, thanh hóa",
    "yeen thawsng, lang chasnh, thanh hosa"
  ],
  "Yên Trung, Thạch Thất, Hà Nội": [
    "yên trung, thạch thất, hà nội",
    "yeen trung, thajch thaast, haf nooji"
  ],
  "Yên Đồng, Yên Lạc, Vĩnh Phúc": [
    "yên đồng, yên lạc, vĩnh phúc",
    "yeen ddoofng, yeen lajc, vixnh phusc"
  ],
  "Yết Kiêu, Gia Lộc, Hải Dương": [
    "yết kiêu, gia lộc, hải dương",
    "yeest kieeu, gia loojc, hari duwowng"
  ],
  "Ái Nghĩa, Đại Lộc, Quảng Nam": [
    "ái nghĩa, đại lộc, quảng nam",
    "asi nghixa, ddaji loojc, quarng nam"
  ],
  "Ân Thạnh, Hoài Ân, Bình Định": [
    "ân thạnh, hoài ân, bình định",
    "aan thajnh, hoafi aan, bifnh ddijnh"
  ],
  "Ông Đình, Khoái Châu, Hưng Yên": [
    "ông đình, khoái châu, hưng yên",
    "oong ddifnh, khoasi chaau, huwng yeen"
  ],
  "ĐLiê Ya, Krông Năng, Đắk Lắk": [
    "đliê ya, krông năng, đắk lắk",
    "ddliee ya, kroong nawng, ddawsk lawsk"
  ],
  "Đa Krông, Đa Krông, Quảng Trị": [
    "đa krông, đa krông, quảng trị",
    "dda kroong, dda kroong, quarng trij"
  ],
  "Đa Phúc, Dương Kinh, Hải Phòng": [
    "đa phúc, dương kinh, hải phòng",
    "dda phusc, duwowng kinh, hari phofng"
  ],
  "Đak Nhau, Bù Đăng, Bình Phước": [
    "đak nhau, bù đăng, bình phước",
    "ddak nhau, buf ddawng, bifnh phuwowsc"
  ],
  "Đan Thượng, Hạ Hoà, Phú Thọ": [
    "đan thượng, hạ hoà, phú thọ",
    "ddan thuwowjng, haj hoaf, phus thoj"
  ],
  "Đan Trường, Nghi Xuân, Hà Tĩnh": [
    "đan trường, nghi xuân, hà tĩnh",
    "ddan truwowfng, nghi xuaan, haf tixnh"
  ],
  "Điền Lư, Bá Thước, Thanh Hóa": [
    "điền lư, bá thước, thanh hóa",
    "ddieefn luw, bas thuwowsc, thanh hosa"
  ],
  "Điền Mỹ, Hương Khê, Hà Tĩnh": [
    "điền mỹ, hương khê, hà tĩnh",
    "ddieefn myx, huwowng khee, haf tixnh"
  ],
  "Điền Xá, Tiên Yên, Quảng Ninh": [
    "điền xá, tiên yên, quảng ninh",
    "ddieefn xas, tieen yeen, quarng ninh"
  ],
  "Điện An, Điện Bàn, Quảng Nam": [
    "điện an, điện bàn, quảng nam",
    "ddieejn an, ddieejn bafn, quarng nam"
  ],
  "Điện Biên, Thanh Hóa, Thanh Hóa": [
    "điện biên, thanh hóa, thanh hóa",
    "ddieejn bieen, thanh hosa, thanh hosa"
  ],
  "Điệp Nông, Hưng Hà, Thái Bình": [
    "điệp nông, hưng hà, thái bình",
    "ddieejp noong, huwng haf, thasi bifnh"
  ],
  "Đoàn Kết, Yên Thủy, Hoà Bình": [
    "đoàn kết, yên thủy, hoà bình",
    "ddoafn keest, yeen thury, hoaf bifnh"
  ],
  "Đào Mỹ, Lạng Giang, Bắc Giang": [
    "đào mỹ, lạng giang, bắc giang",
    "ddafo myx, lajng giang, bawsc giang"
  ],
  "Đào Thịnh, Trấn Yên, Yên Bái": [
    "đào thịnh, trấn yên, yên bái",
    "ddafo thijnh, traasn yeen, yeen basi"
  ],
  "Đô Lương, Đô Lương, Nghệ An": [
    "đô lương, đô lương, nghệ an",
    "ddoo luwowng, ddoo luwowng, ngheej an"
  ],
  "Đông Cao, Phổ Yên, Thái Nguyên": [
    "đông cao, phổ yên, thái nguyên",
    "ddoong cao, phoor yeen, thasi nguyeen"
  ],
  "Đông Cơ, Tiền Hải, Thái Bình": [
    "đông cơ, tiền hải, thái bình",
    "ddoong cow, tieefn hari, thasi bifnh"
  ],
  "Đông Hiệp, Cờ Đỏ, Cần Thơ": [
    "đông hiệp, cờ đỏ, cần thơ",
    "ddoong hieejp, cowf ddor, caafn thow"
  ],
  "Đông Hoà, Trảng Bom, Đồng Nai": [
    "đông hoà, trảng bom, đồng nai",
    "ddoong hoaf, trarng bom, ddoofng nai"
  ],
  "Đông Hòa, Thái Bình, Thái Bình": [
    "đông hòa, thái bình, thái bình",
    "ddoong hofa, thasi bifnh, thasi bifnh"
  ],
  "Đông Hải, Duyên Hải, Trà Vinh": [
    "đông hải, duyên hải, trà vinh",
    "ddoong hari, duyeen hari, traf vinh"
  ],
  "Đông Hải, Lê Chân, Hải Phòng": [
    "đông hải, lê chân, hải phòng",
    "ddoong hari, lee chaan, hari phofng"
  ],
  "Đông Kinh, Lạng Sơn, Lạng Sơn": [
    "đông kinh, lạng sơn, lạng sơn",
    "ddoong kinh, lajng sown, lajng sown"
  ],
  "Đông Lỗ, Hiệp Hòa, Bắc Giang": [
    "đông lỗ, hiệp hòa, bắc giang",
    "ddoong loox, hieejp hofa, bawsc giang"
  ],
  "Đông Mỹ, Thái Bình, Thái Bình": [
    "đông mỹ, thái bình, thái bình",
    "ddoong myx, thasi bifnh, thasi bifnh"
  ],
  "Đông Ngũ, Tiên Yên, Quảng Ninh": [
    "đông ngũ, tiên yên, quảng ninh",
    "ddoong ngux, tieen yeen, quarng ninh"
  ],
  "Đông Ninh, Khoái Châu, Hưng Yên": [
    "đông ninh, khoái châu, hưng yên",
    "ddoong ninh, khoasi chaau, huwng yeen"
  ],
  "Đông Quan, Lộc Bình, Lạng Sơn": [
    "đông quan, lộc bình, lạng sơn",
    "ddoong quan, loojc bifnh, lajng sown"
  ],
  "Đông Quang, Đông Sơn, Thanh Hóa": [
    "đông quang, đông sơn, thanh hóa",
    "ddoong quang, ddoong sown, thanh hosa"
  ],
  "Đông Sơn, Chương Mỹ, Hà Nội": [
    "đông sơn, chương mỹ, hà nội",
    "ddoong sown, chuwowng myx, haf nooji"
  ],
  "Đông Thanh, Đông Sơn, Thanh Hóa": [
    "đông thanh, đông sơn, thanh hóa",
    "ddoong thanh, ddoong sown, thanh hosa"
  ],
  "Đông Thành, Bình Minh, Vĩnh Long": [
    "đông thành, bình minh, vĩnh long",
    "ddoong thafnh, bifnh minh, vixnh long"
  ],
  "Đông Thành, Bắc Quang, Hà Giang": [
    "đông thành, bắc quang, hà giang",
    "ddoong thafnh, bawsc quang, haf giang"
  ],
  "Đông Thành, Ninh Bình, Ninh Bình": [
    "đông thành, ninh bình, ninh bình",
    "ddoong thafnh, ninh bifnh, ninh bifnh"
  ],
  "Đông Tiến, Yên Phong, Bắc Ninh": [
    "đông tiến, yên phong, bắc ninh",
    "ddoong tieesn, yeen phong, bawsc ninh"
  ],
  "Đông Xá, Vân Đồn, Quảng Ninh": [
    "đông xá, vân đồn, quảng ninh",
    "ddoong xas, vaan ddoofn, quarng ninh"
  ],
  "Đông Xá, Đông Hưng, Thái Bình": [
    "đông xá, đông hưng, thái bình",
    "ddoong xas, ddoong huwng, thasi bifnh"
  ],
  "Đạ Lây, Đạ Tẻh, Lâm Đồng": [
    "đạ lây, đạ tẻh, lâm đồng",
    "ddaj laay, ddaj terh, laam ddoofng"
  ],
  "Đạ M'ri, Đạ Huoai, Lâm Đồng": [
    "đạ m'ri, đạ huoai, lâm đồng",
    "ddaj m'ri, ddaj huoai, laam ddoofng"
  ],
  "Đạ Ploa, Đạ Huoai, Lâm Đồng": [
    "đạ ploa, đạ huoai, lâm đồng",
    "ddaj ploa, ddaj huoai, laam ddoofng"
  ],
  "Đạ Tông, Đam Rông, Lâm Đồng": [
    "đạ tông, đam rông, lâm đồng",
    "ddaj toong, ddam roong, laam ddoofng"
  ],
  "Đại Hải, Kế Sách, Sóc Trăng": [
    "đại hải, kế sách, sóc trăng",
    "ddaji hari, kees sasch, sosc trawng"
  ],
  "Đại Lãnh, Vạn Ninh, Khánh Hòa": [
    "đại lãnh, vạn ninh, khánh hòa",
    "ddaji laxnh, vajn ninh, khasnh hofa"
  ],
  "Đại Lịch, Văn Chấn, Yên Bái": [
    "đại lịch, văn chấn, yên bái",
    "ddaji lijch, vawn chaasn, yeen basi"
  ],
  "Đại Lộc, Hậu Lộc, Thanh Hóa": [
    "đại lộc, hậu lộc, thanh hóa",
    "ddaji loojc, haaju loojc, thanh hosa"
  ],
  "Đại Nghĩa, Mỹ Đức, Hà Nội": [
    "đại nghĩa, mỹ đức, hà nội",
    "ddaji nghixa, myx dduwsc, haf nooji"
  ],
  "Đại Sơn, Quảng Hòa, Cao Bằng": [
    "đại sơn, quảng hòa, cao bằng",
    "ddaji sown, quarng hofa, cao bawfng"
  ],
  "Đại Sơn, Tứ Kỳ, Hải Dương": [
    "đại sơn, tứ kỳ, hải dương",
    "ddaji sown, tuws kyf, hari duwowng"
  ],
  "Đại Thành, Yên Thành, Nghệ An": [
    "đại thành, yên thành, nghệ an",
    "ddaji thafnh, yeen thafnh, ngheej an"
  ],
  "Đại Tâm, Mỹ Xuyên, Sóc Trăng": [
    "đại tâm, mỹ xuyên, sóc trăng",
    "ddaji taam, myx xuyeen, sosc trawng"
  ],
  "Đại Xuyên, Phú Xuyên, Hà Nội": [
    "đại xuyên, phú xuyên, hà nội",
    "ddaji xuyeen, phus xuyeen, haf nooji"
  ],
  "Đại Yên, Chương Mỹ, Hà Nội": [
    "đại yên, chương mỹ, hà nội",
    "ddaji yeen, chuwowng myx, haf nooji"
  ],
  "Đại Đồng, Văn Lâm, Hưng Yên": [
    "đại đồng, văn lâm, hưng yên",
    "ddaji ddoofng, vawn laam, huwng yeen"
  ],
  "Đại Đồng, Yên Bình, Yên Bái": [
    "đại đồng, yên bình, yên bái",
    "ddaji ddoofng, yeen bifnh, yeen basi"
  ],
  "Đạm Bri, Bảo Lộc, Lâm Đồng": [
    "đạm bri, bảo lộc, lâm đồng",
    "ddajm bri, baro loojc, laam ddoofng"
  ],
  "Đạo Đức, Vị Xuyên, Hà Giang": [
    "đạo đức, vị xuyên, hà giang",
    "ddajo dduwsc, vij xuyeen, haf giang"
  ],
  "Đậu Liêu, Hồng Lĩnh, Hà Tĩnh": [
    "đậu liêu, hồng lĩnh, hà tĩnh",
    "ddaaju lieeu, hoofng lixnh, haf tixnh"
  ],
  "Đắk DRông, Cư Jút, Đắk Nông": [
    "đắk drông, cư jút, đắk nông",
    "ddawsk droong, cuw just, ddawsk noong"
  ],
  "Đắk Drô, Krông Nô, Đắk Nông": [
    "đắk drô, krông nô, đắk nông",
    "ddawsk droo, kroong noo, ddawsk noong"
  ],
  "Đắk Mâm, Krông Nô, Đắk Nông": [
    "đắk mâm, krông nô, đắk nông",
    "ddawsk maam, kroong noo, ddawsk noong"
  ],
  "Đắk Nang, Krông Nô, Đắk Nông": [
    "đắk nang, krông nô, đắk nông",
    "ddawsk nang, kroong noo, ddawsk noong"
  ],
  "Đắk R'La, Đắk Mil, Đắk Nông": [
    "đắk r'la, đắk mil, đắk nông",
    "ddawsk r'la, ddawsk mil, ddawsk noong"
  ],
  "Đắk Som, Đăk Glong, Đắk Nông": [
    "đắk som, đăk glong, đắk nông",
    "ddawsk som, ddawk glong, ddawsk noong"
  ],
  "Đắk Sôr, Krông Nô, Đắk Nông": [
    "đắk sôr, krông nô, đắk nông",
    "ddawsk soor, kroong noo, ddawsk noong"
  ],
  "Đằng Hải, Hải An, Hải Phòng": [
    "đằng hải, hải an, hải phòng",
    "ddawfng hari, hari an, hari phofng"
  ],
  "Đặng Sơn, Đô Lương, Nghệ An": [
    "đặng sơn, đô lương, nghệ an",
    "ddawjng sown, ddoo luwowng, ngheej an"
  ],
  "Đề Thám, Thái Bình, Thái Bình": [
    "đề thám, thái bình, thái bình",
    "ddeef thasm, thasi bifnh, thasi bifnh"
  ],
  "Địch Quả, Thanh Sơn, Phú Thọ": [
    "địch quả, thanh sơn, phú thọ",
    "ddijch quar, thanh sown, phus thoj"
  ],
  "Định Hòa, Lai Vung, Đồng Tháp": [
    "định hòa, lai vung, đồng tháp",
    "ddijnh hofa, lai vung, ddoofng thasp"
  ],
  "Đống Đa, Qui Nhơn, Bình Định": [
    "đống đa, qui nhơn, bình định",
    "ddoosng dda, qui nhown, bifnh ddijnh"
  ],
  "Đồn Đạc, Ba Chẽ, Quảng Ninh": [
    "đồn đạc, ba chẽ, quảng ninh",
    "ddoofn ddajc, ba chex, quarng ninh"
  ],
  "Đồng Giáp, Văn Quan, Lạng Sơn": [
    "đồng giáp, văn quan, lạng sơn",
    "ddoofng giasp, vawn quan, lajng sown"
  ],
  "Đồng Hoà, Kiến An, Hải Phòng": [
    "đồng hoà, kiến an, hải phòng",
    "ddoofng hoaf, kieesn an, hari phofng"
  ],
  "Đồng Hưu, Yên Thế, Bắc Giang": [
    "đồng hưu, yên thế, bắc giang",
    "ddoofng huwu, yeen thees, bawsc giang"
  ],
  "Đồng Hợp, Quỳ Hợp, Nghệ An": [
    "đồng hợp, quỳ hợp, nghệ an",
    "ddoofng howjp, quyf howjp, ngheej an"
  ],
  "Đồng Kỳ, Yên Thế, Bắc Giang": [
    "đồng kỳ, yên thế, bắc giang",
    "ddoofng kyf, yeen thees, bawsc giang"
  ],
  "Đồng Lâm, Hạ Long, Quảng Ninh": [
    "đồng lâm, hạ long, quảng ninh",
    "ddoofng laam, haj long, quarng ninh"
  ],
  "Đồng Lạc, Yên Lập, Phú Thọ": [
    "đồng lạc, yên lập, phú thọ",
    "ddoofng lajc, yeen laajp, phus thoj"
  ],
  "Đồng Quế, Sông Lô, Vĩnh Phúc": [
    "đồng quế, sông lô, vĩnh phúc",
    "ddoofng quees, soong loo, vixnh phusc"
  ],
  "Đồng Rui, Tiên Yên, Quảng Ninh": [
    "đồng rui, tiên yên, quảng ninh",
    "ddoofng rui, tieen yeen, quarng ninh"
  ],
  "Đồng Sơn, Hạ Long, Quảng Ninh": [
    "đồng sơn, hạ long, quảng ninh",
    "ddoofng sown, haj long, quarng ninh"
  ],
  "Đồng Sơn, Nam Trực, Nam Định": [
    "đồng sơn, nam trực, nam định",
    "ddoofng sown, nam truwjc, nam ddijnh"
  ],
  "Đồng Tiến, Cô Tô, Quảng Ninh": [
    "đồng tiến, cô tô, quảng ninh",
    "ddoofng tieesn, coo too, quarng ninh"
  ],
  "Đồng Tiến, Ứng Hòa, Hà Nội": [
    "đồng tiến, ứng hòa, hà nội",
    "ddoofng tieesn, uwsng hofa, haf nooji"
  ],
  "Đồng Tâm, Vĩnh Yên, Vĩnh Phúc": [
    "đồng tâm, vĩnh yên, vĩnh phúc",
    "ddoofng taam, vixnh yeen, vixnh phusc"
  ],
  "Đồng Tâm, Yên Thế, Bắc Giang": [
    "đồng tâm, yên thế, bắc giang",
    "ddoofng taam, yeen thees, bawsc giang"
  ],
  "Đồng Văn, Yên Lạc, Vĩnh Phúc": [
    "đồng văn, yên lạc, vĩnh phúc",
    "ddoofng vawn, yeen lajc, vixnh phusc"
  ],
  "Đồng Văn, Đồng Văn, Hà Giang": [
    "đồng văn, đồng văn, hà giang",
    "ddoofng vawn, ddoofng vawn, haf giang"
  ],
  "Đội Bình, Yên Sơn, Tuyên Quang": [
    "đội bình, yên sơn, tuyên quang",
    "ddooji bifnh, yeen sown, tuyeen quang"
  ],
  "Đức Giang, Hoài Đức, Hà Nội": [
    "đức giang, hoài đức, hà nội",
    "dduwsc giang, hoafi dduwsc, haf nooji"
  ],
  "Đức Giang, Yên Dũng, Bắc Giang": [
    "đức giang, yên dũng, bắc giang",
    "dduwsc giang, yeen duxng, bawsc giang"
  ],
  "Đức Hạnh, Bảo Lâm, Cao Bằng": [
    "đức hạnh, bảo lâm, cao bằng",
    "dduwsc hajnh, baro laam, cao bawfng"
  ],
  "Đức Hợp, Kim Động, Hưng Yên": [
    "đức hợp, kim động, hưng yên",
    "dduwsc howjp, kim ddoojng, huwng yeen"
  ],
  "Đức Minh, Đắk Mil, Đắk Nông": [
    "đức minh, đắk mil, đắk nông",
    "dduwsc minh, ddawsk mil, ddawsk noong"
  ],
  "Đức Thành, Yên Thành, Nghệ An": [
    "đức thành, yên thành, nghệ an",
    "dduwsc thafnh, yeen thafnh, ngheej an"
  ],
  "Đức Thông, Thạch An, Cao Bằng": [
    "đức thông, thạch an, cao bằng",
    "dduwsc thoong, thajch an, cao bawfng"
  ],
  "Đức Thọ, Đức Thọ, Hà Tĩnh": [
    "đức thọ, đức thọ, hà tĩnh",
    "dduwsc thoj, dduwsc thoj, haf tixnh"
  ],
  "Ứng Hoè, Ninh Giang, Hải Dương": [
    "ứng hoè, ninh giang, hải dương",
    "uwsng hoef, ninh giang, hari duwowng"
  ],
  " Mỹ Lộc, Thái Thụy, Thái Bình": [
    " mỹ lộc, thái thụy, thái bình",
    " myx loojc, thasi thujy, thasi bifnh"
  ],
  "An Hiệp, Châu Thành, Đồng Tháp": [
    "an hiệp, châu thành, đồng tháp",
    "an hieejp, chaau thafnh, ddoofng thasp"
  ],
  "An Hải Bắc, Sơn Trà, Đà Nẵng": [
    "an hải bắc, sơn trà, đà nẵng",
    "an hari bawsc, sown traf, ddaf nawxng"
  ],
  "An Khánh, Châu Thành, Đồng Tháp": [
    "an khánh, châu thành, đồng tháp",
    "an khasnh, chaau thafnh, ddoofng thasp"
  ],
  "An Lạc A, Bình Tân, Hồ Chí Minh": [
    "an lạc a, bình tân, hồ chí minh",
    "an lajc a, bifnh taan, hoof chis minh"
  ],
  "An Lạc Tây, Kế Sách, Sóc Trăng": [
    "an lạc tây, kế sách, sóc trăng",
    "an lajc taay, kees sasch, sosc trawng"
  ],
  "An Lập, Dầu Tiếng, Bình Dương": [
    "an lập, dầu tiếng, bình dương",
    "an laajp, daafu tieesng, bifnh duwowng"
  ],
  "An Phượng, Thanh Hà, Hải Dương": [
    "an phượng, thanh hà, hải dương",
    "an phuwowjng, thanh haf, hari duwowng"
  ],
  "An Thái Trung, Cái Bè, Tiền Giang": [
    "an thái trung, cái bè, tiền giang",
    "an thasi trung, casi bef, tieefn giang"
  ],
  "An Đôn, Quảng Trị, Quảng Trị": [
    "an đôn, quảng trị, quảng trị",
    "an ddoon, quarng trij, quarng trij"
  ],
  "An Đồng, Quỳnh Phụ, Thái Bình": [
    "an đồng, quỳnh phụ, thái bình",
    "an ddoofng, quyfnh phuj, thasi bifnh"
  ],
  "Ba Cụm Nam, Khánh Sơn, Khánh Hòa": [
    "ba cụm nam, khánh sơn, khánh hòa",
    "ba cujm nam, khasnh sown, khasnh hofa"
  ],
  "Bà Điểm, Hóc Môn, Hồ Chí Minh": [
    "bà điểm, hóc môn, hồ chí minh",
    "baf ddieerm, hosc moon, hoof chis minh"
  ],
  "Bàn Đạt, Phú Bình, Thái Nguyên": [
    "bàn đạt, phú bình, thái nguyên",
    "bafn ddajt, phus bifnh, thasi nguyeen"
  ],
  "Bá Xuyên, Sông Công, Thái Nguyên": [
    "bá xuyên, sông công, thái nguyên",
    "bas xuyeen, soong coong, thasi nguyeen"
  ],
  "Bình Châu, Bình Sơn, Quảng Ngãi": [
    "bình châu, bình sơn, quảng ngãi",
    "bifnh chaau, bifnh sown, quarng ngaxi"
  ],
  "Bình Giang, Thăng Bình, Quảng Nam": [
    "bình giang, thăng bình, quảng nam",
    "bifnh giang, thawng bifnh, quarng nam"
  ],
  "Bình Hiệp, Kiến Tường, Long An": [
    "bình hiệp, kiến tường, long an",
    "bifnh hieejp, kieesn tuwowfng, long an"
  ],
  "Bình Hòa Đông, Mộc Hóa, Long An": [
    "bình hòa đông, mộc hóa, long an",
    "bifnh hofa ddoong, moojc hosa, long an"
  ],
  "Bình Hải, Bình Sơn, Quảng Ngãi": [
    "bình hải, bình sơn, quảng ngãi",
    "bifnh hari, bifnh sown, quarng ngaxi"
  ],
  "Bình Hải, Thăng Bình, Quảng Nam": [
    "bình hải, thăng bình, quảng nam",
    "bifnh hari, thawng bifnh, quarng nam"
  ],
  "Bình Khánh, Quận 2, Hồ Chí Minh": [
    "bình khánh, quận 2, hồ chí minh",
    "bifnh khasnh, quaajn 2, hoof chis minh"
  ],
  "Bình Kiều, Khoái Châu, Hưng Yên": [
    "bình kiều, khoái châu, hưng yên",
    "bifnh kieefu, khoasi chaau, huwng yeen"
  ],
  "Bình Liêu, Bình Liêu, Quảng Ninh": [
    "bình liêu, bình liêu, quảng ninh",
    "bifnh lieeu, bifnh lieeu, quarng ninh"
  ],
  "Bình Lâm, Hiệp Đức, Quảng Nam": [
    "bình lâm, hiệp đức, quảng nam",
    "bifnh laam, hieejp dduwsc, quarng nam"
  ],
  "Bình Lãnh, Thăng Bình, Quảng Nam": [
    "bình lãnh, thăng bình, quảng nam",
    "bifnh laxnh, thawng bifnh, quarng nam"
  ],
  "Bình Lộc, Diên Khánh, Khánh Hòa": [
    "bình lộc, diên khánh, khánh hòa",
    "bifnh loojc, dieen khasnh, khasnh hofa"
  ],
  "Bình Minh, Bình Giang, Hải Dương": [
    "bình minh, bình giang, hải dương",
    "bifnh minh, bifnh giang, hari duwowng"
  ],
  "Bình Minh, Bù Đăng, Bình Phước": [
    "bình minh, bù đăng, bình phước",
    "bifnh minh, buf ddawng, bifnh phuwowsc"
  ],
  "Bình Minh, Vĩnh Thuận, Kiên Giang": [
    "bình minh, vĩnh thuận, kiên giang",
    "bifnh minh, vixnh thuaajn, kieen giang"
  ],
  "Bình Ngọc, Móng Cái, Quảng Ninh": [
    "bình ngọc, móng cái, quảng ninh",
    "bifnh ngojc, mosng casi, quarng ninh"
  ],
  "Bình Nhâm, Thuận An, Bình Dương": [
    "bình nhâm, thuận an, bình dương",
    "bifnh nhaam, thuaajn an, bifnh duwowng"
  ],
  "Bình Nhân, Chiêm Hóa, Tuyên Quang": [
    "bình nhân, chiêm hóa, tuyên quang",
    "bifnh nhaan, chieem hosa, tuyeen quang"
  ],
  "Bình Phú, Tân Hồng, Đồng Tháp": [
    "bình phú, tân hồng, đồng tháp",
    "bifnh phus, taan hoofng, ddoofng thasp"
  ],
  "Bình Phước, Mang Thít, Vĩnh Long": [
    "bình phước, mang thít, vĩnh long",
    "bifnh phuwowsc, mang thist, vixnh long"
  ],
  "Bình Quế, Thăng Bình, Quảng Nam": [
    "bình quế, thăng bình, quảng nam",
    "bifnh quees, thawng bifnh, quarng nam"
  ],
  "Bình Sơn, Hiệp Đức, Quảng Nam": [
    "bình sơn, hiệp đức, quảng nam",
    "bifnh sown, hieejp dduwsc, quarng nam"
  ],
  "Bình Sơn, Sông Công, Thái Nguyên": [
    "bình sơn, sông công, thái nguyên",
    "bifnh sown, soong coong, thasi nguyeen"
  ],
  "Bình Thành, Giồng Trôm, Bến Tre": [
    "bình thành, giồng trôm, bến tre",
    "bifnh thafnh, gioofng troom, beesn tre"
  ],
  "Bình Thành, Lấp Vò, Đồng Tháp": [
    "bình thành, lấp vò, đồng tháp",
    "bifnh thafnh, laasp vof, ddoofng thasp"
  ],
  "Bình Thành, Tây Sơn, Bình Định": [
    "bình thành, tây sơn, bình định",
    "bifnh thafnh, taay sown, bifnh ddijnh"
  ],
  "Bình Thạnh, Thạnh Phú, Bến Tre": [
    "bình thạnh, thạnh phú, bến tre",
    "bifnh thajnh, thajnh phus, beesn tre"
  ],
  "Bình Thắng, Bình Đại, Bến Tre": [
    "bình thắng, bình đại, bến tre",
    "bifnh thawsng, bifnh ddaji, beesn tre"
  ],
  "Bình Thủy, Bình Thuỷ, Cần Thơ": [
    "bình thủy, bình thuỷ, cần thơ",
    "bifnh thury, bifnh thuyr, caafn thow"
  ],
  "Bình Trung, Bình Sơn, Quảng Ngãi": [
    "bình trung, bình sơn, quảng ngãi",
    "bifnh trung, bifnh sown, quarng ngaxi"
  ],
  "Bình Trung, Chợ Đồn, Bắc Kạn": [
    "bình trung, chợ đồn, bắc kạn",
    "bifnh trung, chowj ddoofn, bawsc kajn"
  ],
  "Bình Trung, Thăng Bình, Quảng Nam": [
    "bình trung, thăng bình, quảng nam",
    "bifnh trung, thawng bifnh, quarng nam"
  ],
  "Bình Trị, Bình Sơn, Quảng Ngãi": [
    "bình trị, bình sơn, quảng ngãi",
    "bifnh trij, bifnh sown, quarng ngaxi"
  ],
  "Bình Trị, Thăng Bình, Quảng Nam": [
    "bình trị, thăng bình, quảng nam",
    "bifnh trij, thawng bifnh, quarng nam"
  ],
  "Bình Tân, Bắc Bình, Bình Thuận": [
    "bình tân, bắc bình, bình thuận",
    "bifnh taan, bawsc bifnh, bifnh thuaajn"
  ],
  "Bình Yên, Sơn Dương, Tuyên Quang": [
    "bình yên, sơn dương, tuyên quang",
    "bifnh yeen, sown duwowng, tuyeen quang"
  ],
  "Bình Đào, Thăng Bình, Quảng Nam": [
    "bình đào, thăng bình, quảng nam",
    "bifnh ddafo, thawng bifnh, quarng nam"
  ],
  "Bình Định, An Nhơn, Bình Định": [
    "bình định, an nhơn, bình định",
    "bifnh ddijnh, an nhown, bifnh ddijnh"
  ],
  "Bình Định, Yên Lạc, Vĩnh Phúc": [
    "bình định, yên lạc, vĩnh phúc",
    "bifnh ddijnh, yeen lajc, vixnh phusc"
  ],
  "Bùi La Nhân, Đức Thọ, Hà Tĩnh": [
    "bùi la nhân, đức thọ, hà tĩnh",
    "bufi la nhaan, dduwsc thoj, haf tixnh"
  ],
  "Bản Phiệt, Bảo Thắng, Lào Cai": [
    "bản phiệt, bảo thắng, lào cai",
    "barn phieejt, baro thawsng, lafo cai"
  ],
  "Bản Sen, Mường Khương, Lào Cai": [
    "bản sen, mường khương, lào cai",
    "barn sen, muwowfng khuwowng, lafo cai"
  ],
  "Bắc Hưng, Tiên Lãng, Hải Phòng": [
    "bắc hưng, tiên lãng, hải phòng",
    "bawsc huwng, tieen laxng, hari phofng"
  ],
  "Bắc Hải, Tiền Hải, Thái Bình": [
    "bắc hải, tiền hải, thái bình",
    "bawsc hari, tieefn hari, thasi bifnh"
  ],
  "Bắc Lãng, Đình Lập, Lạng Sơn": [
    "bắc lãng, đình lập, lạng sơn",
    "bawsc laxng, ddifnh laajp, lajng sown"
  ],
  "Bắc Lương, Thọ Xuân, Thanh Hóa": [
    "bắc lương, thọ xuân, thanh hóa",
    "bawsc luwowng, thoj xuaan, thanh hosa"
  ],
  "Bắc Quỳnh, Bắc Sơn, Lạng Sơn": [
    "bắc quỳnh, bắc sơn, lạng sơn",
    "bawsc quyfnh, bawsc sown, lajng sown"
  ],
  "Bằng Thành, Pác Nặm, Bắc Kạn": [
    "bằng thành, pác nặm, bắc kạn",
    "bawfng thafnh, pasc nawjm, bawsc kajn"
  ],
  "Bến Thành, Quận 1, Hồ Chí Minh": [
    "bến thành, quận 1, hồ chí minh",
    "beesn thafnh, quaajn 1, hoof chis minh"
  ],
  "Cam Giá, Thái Nguyên, Thái Nguyên": [
    "cam giá, thái nguyên, thái nguyên",
    "cam gias, thasi nguyeen, thasi nguyeen"
  ],
  "Cam Phúc Bắc, Cam Ranh, Khánh Hòa": [
    "cam phúc bắc, cam ranh, khánh hòa",
    "cam phusc bawsc, cam ranh, khasnh hofa"
  ],
  "Cam Thủy, Lệ Thủy, Quảng Bình": [
    "cam thủy, lệ thủy, quảng bình",
    "cam thury, leej thury, quarng bifnh"
  ],
  "Canh Thuận, Vân Canh, Bình Định": [
    "canh thuận, vân canh, bình định",
    "canh thuaajn, vaan canh, bifnh ddijnh"
  ],
  "Cao Phạ, Mù Căng Chải, Yên Bái": [
    "cao phạ, mù căng chải, yên bái",
    "cao phaj, muf cawng chari, yeen basi"
  ],
  "Chi Lăng, Tràng Định, Lạng Sơn": [
    "chi lăng, tràng định, lạng sơn",
    "chi lawng, trafng ddijnh, lajng sown"
  ],
  "Chiến Thắng, An Lão, Hải Phòng": [
    "chiến thắng, an lão, hải phòng",
    "chieesn thawsng, an laxo, hari phofng"
  ],
  "Chiềng Bằng, Quỳnh Nhai, Sơn La": [
    "chiềng bằng, quỳnh nhai, sơn la",
    "chieefng bawfng, quyfnh nhai, sown la"
  ],
  "Chiềng Khoang, Quỳnh Nhai, Sơn La": [
    "chiềng khoang, quỳnh nhai, sơn la",
    "chieefng khoang, quyfnh nhai, sown la"
  ],
  "Chiềng Ngàm, Thuận Châu, Sơn La": [
    "chiềng ngàm, thuận châu, sơn la",
    "chieefng ngafm, thuaajn chaau, sown la"
  ],
  "Chiềng Pấc, Thuận Châu, Sơn La": [
    "chiềng pấc, thuận châu, sơn la",
    "chieefng paasc, thuaajn chaau, sown la"
  ],
  "Chàng Sơn, Thạch Thất, Hà Nội": [
    "chàng sơn, thạch thất, hà nội",
    "chafng sown, thajch thaast, haf nooji"
  ],
  "Châu Cường, Quỳ Hợp, Nghệ An": [
    "châu cường, quỳ hợp, nghệ an",
    "chaau cuwowfng, quyf howjp, ngheej an"
  ],
  "Châu Hóa, Tuyên Hóa, Quảng Bình": [
    "châu hóa, tuyên hóa, quảng bình",
    "chaau hosa, tuyeen hosa, quarng bifnh"
  ],
  "Châu Quế Hạ, Văn Yên, Yên Bái": [
    "châu quế hạ, văn yên, yên bái",
    "chaau quees haj, vawn yeen, yeen basi"
  ],
  "Châu Sơn, Quỳnh Phụ, Thái Bình": [
    "châu sơn, quỳnh phụ, thái bình",
    "chaau sown, quyfnh phuj, thasi bifnh"
  ],
  "Châu Sơn, Sông Công, Thái Nguyên": [
    "châu sơn, sông công, thái nguyên",
    "chaau sown, soong coong, thasi nguyeen"
  ],
  "Châu Thới, Vĩnh Lợi, Bạc Liêu": [
    "châu thới, vĩnh lợi, bạc liêu",
    "chaau thowsi, vixnh lowji, bajc lieeu"
  ],
  "Chí Minh, Tràng Định, Lạng Sơn": [
    "chí minh, tràng định, lạng sơn",
    "chis minh, trafng ddijnh, lajng sown"
  ],
  "Chí Viễn, Trùng Khánh, Cao Bằng": [
    "chí viễn, trùng khánh, cao bằng",
    "chis vieexn, trufng khasnh, cao bawfng"
  ],
  "Chính Nghĩa, Kim Động, Hưng Yên": [
    "chính nghĩa, kim động, hưng yên",
    "chisnh nghixa, kim ddoojng, huwng yeen"
  ],
  "Chấn Thịnh, Văn Chấn, Yên Bái": [
    "chấn thịnh, văn chấn, yên bái",
    "chaasn thijnh, vawn chaasn, yeen basi"
  ],
  "Chợ Chu, Định Hóa, Thái Nguyên": [
    "chợ chu, định hóa, thái nguyên",
    "chowj chu, ddijnh hosa, thasi nguyeen"
  ],
  "Chợ Gạo, Chợ Gạo, Tiền Giang": [
    "chợ gạo, chợ gạo, tiền giang",
    "chowj gajo, chowj gajo, tieefn giang"
  ],
  "Cái Rồng, Vân Đồn, Quảng Ninh": [
    "cái rồng, vân đồn, quảng ninh",
    "casi roofng, vaan ddoofn, quarng ninh"
  ],
  "Cát Thắng, Phù Cát, Bình Định": [
    "cát thắng, phù cát, bình định",
    "cast thawsng, phuf cast, bifnh ddijnh"
  ],
  "Công Chính, Nông Cống, Thanh Hóa": [
    "công chính, nông cống, thanh hóa",
    "coong chisnh, noong coosng, thanh hosa"
  ],
  "Cư Klông, Krông Năng, Đắk Lắk": [
    "cư klông, krông năng, đắk lắk",
    "cuw kloong, kroong nawng, ddawsk lawsk"
  ],
  "Cương Chính, Tiên Lữ, Hưng Yên": [
    "cương chính, tiên lữ, hưng yên",
    "cuwowng chisnh, tieen luwx, huwng yeen"
  ],
  "Cải Đan, Sông Công, Thái Nguyên": [
    "cải đan, sông công, thái nguyên",
    "cari ddan, soong coong, thasi nguyeen"
  ],
  "Cảnh Thụy, Yên Dũng, Bắc Giang": [
    "cảnh thụy, yên dũng, bắc giang",
    "carnh thujy, yeen duxng, bawsc giang"
  ],
  "Cầu Dền, Hai Bà Trưng, Hà Nội": [
    "cầu dền, hai bà trưng, hà nội",
    "caafu deefn, hai baf truwng, haf nooji"
  ],
  "Cẩm Bình, Cẩm Phả, Quảng Ninh": [
    "cẩm bình, cẩm phả, quảng ninh",
    "caarm bifnh, caarm phar, quarng ninh"
  ],
  "Cẩm Dương, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm dương, cẩm xuyên, hà tĩnh",
    "caarm duwowng, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Hải, Cẩm Phả, Quảng Ninh": [
    "cẩm hải, cẩm phả, quảng ninh",
    "caarm hari, caarm phar, quarng ninh"
  ],
  "Cẩm Ngọc, Cẩm Thủy, Thanh Hóa": [
    "cẩm ngọc, cẩm thủy, thanh hóa",
    "caarm ngojc, caarm thury, thanh hosa"
  ],
  "Cẩm Thành, Cẩm Thủy, Thanh Hóa": [
    "cẩm thành, cẩm thủy, thanh hóa",
    "caarm thafnh, caarm thury, thanh hosa"
  ],
  "Cẩm Thạch, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm thạch, cẩm xuyên, hà tĩnh",
    "caarm thajch, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Thịnh, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm thịnh, cẩm xuyên, hà tĩnh",
    "caarm thijnh, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Trung, Cẩm Phả, Quảng Ninh": [
    "cẩm trung, cẩm phả, quảng ninh",
    "caarm trung, caarm phar, quarng ninh"
  ],
  "Cẩm Vũ, Cẩm Giàng, Hải Dương": [
    "cẩm vũ, cẩm giàng, hải dương",
    "caarm vux, caarm giafng, hari duwowng"
  ],
  "Cẩm Đàn, Sơn Động, Bắc Giang": [
    "cẩm đàn, sơn động, bắc giang",
    "caarm ddafn, sown ddoojng, bawsc giang"
  ],
  "Cộng Hòa, Cẩm Phả, Quảng Ninh": [
    "cộng hòa, cẩm phả, quảng ninh",
    "coojng hofa, caarm phar, quarng ninh"
  ],
  "Cộng Hòa, Kim Thành, Hải Dương": [
    "cộng hòa, kim thành, hải dương",
    "coojng hofa, kim thafnh, hari duwowng"
  ],
  "Cộng Lạc, Tứ Kỳ, Hải Dương": [
    "cộng lạc, tứ kỳ, hải dương",
    "coojng lajc, tuws kyf, hari duwowng"
  ],
  "Cửa Tùng, Vĩnh Linh, Quảng Trị": [
    "cửa tùng, vĩnh linh, quảng trị",
    "cuwra tufng, vixnh linh, quarng trij"
  ],
  "Danh Thắng, Hiệp Hòa, Bắc Giang": [
    "danh thắng, hiệp hòa, bắc giang",
    "danh thawsng, hieejp hofa, bawsc giang"
  ],
  "Diên Lạc, Diên Khánh, Khánh Hòa": [
    "diên lạc, diên khánh, khánh hòa",
    "dieen lajc, dieen khasnh, khasnh hofa"
  ],
  "Diên Sanh, Hải Lăng, Quảng Trị": [
    "diên sanh, hải lăng, quảng trị",
    "dieen sanh, hari lawng, quarng trij"
  ],
  "Diên Thọ, Diên Khánh, Khánh Hòa": [
    "diên thọ, diên khánh, khánh hòa",
    "dieen thoj, dieen khasnh, khasnh hofa"
  ],
  "Diên Toàn, Diên Khánh, Khánh Hòa": [
    "diên toàn, diên khánh, khánh hòa",
    "dieen toafn, dieen khasnh, khasnh hofa"
  ],
  "Diên Xuân, Diên Khánh, Khánh Hòa": [
    "diên xuân, diên khánh, khánh hòa",
    "dieen xuaan, dieen khasnh, khasnh hofa"
  ],
  "Diễn Hoàng, Diễn Châu, Nghệ An": [
    "diễn hoàng, diễn châu, nghệ an",
    "dieexn hoafng, dieexn chaau, ngheej an"
  ],
  "Diễn Hạnh, Diễn Châu, Nghệ An": [
    "diễn hạnh, diễn châu, nghệ an",
    "dieexn hajnh, dieexn chaau, ngheej an"
  ],
  "Diễn Hồng, Diễn Châu, Nghệ An": [
    "diễn hồng, diễn châu, nghệ an",
    "dieexn hoofng, dieexn chaau, ngheej an"
  ],
  "Diễn Ngọc, Diễn Châu, Nghệ An": [
    "diễn ngọc, diễn châu, nghệ an",
    "dieexn ngojc, dieexn chaau, ngheej an"
  ],
  "Diễn Thành, Diễn Châu, Nghệ An": [
    "diễn thành, diễn châu, nghệ an",
    "dieexn thafnh, dieexn chaau, ngheej an"
  ],
  "Diễn Đoài, Diễn Châu, Nghệ An": [
    "diễn đoài, diễn châu, nghệ an",
    "dieexn ddoafi, dieexn chaau, ngheej an"
  ],
  "Dân Quyền, Triệu Sơn, Thanh Hóa": [
    "dân quyền, triệu sơn, thanh hóa",
    "daan quyeefn, trieeju sown, thanh hosa"
  ],
  "Dìn Chin, Mường Khương, Lào Cai": [
    "dìn chin, mường khương, lào cai",
    "difn chin, muwowfng khuwowng, lafo cai"
  ],
  "Dương Huy, Cẩm Phả, Quảng Ninh": [
    "dương huy, cẩm phả, quảng ninh",
    "duwowng huy, caarm phar, quarng ninh"
  ],
  "Dạ Trạch, Khoái Châu, Hưng Yên": [
    "dạ trạch, khoái châu, hưng yên",
    "daj trajch, khoasi chaau, huwng yeen"
  ],
  "Dịch Vọng, Cầu Giấy, Hà Nội": [
    "dịch vọng, cầu giấy, hà nội",
    "dijch vojng, caafu giaasy, haf nooji"
  ],
  "Ea Kao, Buôn Ma Thuột, Đắk Lắk": [
    "ea kao, buôn ma thuột, đắk lắk",
    "ea kao, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Ea Tam, Buôn Ma Thuột, Đắk Lắk": [
    "ea tam, buôn ma thuột, đắk lắk",
    "ea tam, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Gia Minh, Thuỷ Nguyên, Hải Phòng": [
    "gia minh, thuỷ nguyên, hải phòng",
    "gia minh, thuyr nguyeen, hari phofng"
  ],
  "Gia Đông, Thuận Thành, Bắc Ninh": [
    "gia đông, thuận thành, bắc ninh",
    "gia ddoong, thuaajn thafnh, bawsc ninh"
  ],
  "Giang Biên, Vĩnh Bảo, Hải Phòng": [
    "giang biên, vĩnh bảo, hải phòng",
    "giang bieen, vixnh baro, hari phofng"
  ],
  "Giao Hương, Giao Thủy, Nam Định": [
    "giao hương, giao thủy, nam định",
    "giao huwowng, giao thury, nam ddijnh"
  ],
  "Giao Thiện, Giao Thủy, Nam Định": [
    "giao thiện, giao thủy, nam định",
    "giao thieejn, giao thury, nam ddijnh"
  ],
  "Giao Thịnh, Giao Thủy, Nam Định": [
    "giao thịnh, giao thủy, nam định",
    "giao thijnh, giao thury, nam ddijnh"
  ],
  "Giáo Liêm, Sơn Động, Bắc Giang": [
    "giáo liêm, sơn động, bắc giang",
    "giaso lieem, sown ddoojng, bawsc giang"
  ],
  "Giếng Đáy, Hạ Long, Quảng Ninh": [
    "giếng đáy, hạ long, quảng ninh",
    "gieesng ddasy, haj long, quarng ninh"
  ],
  "Gáo Giồng, Cao Lãnh, Đồng Tháp": [
    "gáo giồng, cao lãnh, đồng tháp",
    "gaso gioofng, cao laxnh, ddoofng thasp"
  ],
  "Hiếu Liêm, Vĩnh Cửu, Đồng Nai": [
    "hiếu liêm, vĩnh cửu, đồng nai",
    "hieesu lieem, vixnh cuwru, ddoofng nai"
  ],
  "Hiếu Nhơn,  Vũng Liêm, Vĩnh Long": [
    "hiếu nhơn,  vũng liêm, vĩnh long",
    "hieesu nhown,  vuxng lieem, vixnh long"
  ],
  "Hiền Lương, Đà Bắc, Hoà Bình": [
    "hiền lương, đà bắc, hoà bình",
    "hieefn luwowng, ddaf bawsc, hoaf bifnh"
  ],
  "Hiển Khánh, Vụ Bản, Nam Định": [
    "hiển khánh, vụ bản, nam định",
    "hieern khasnh, vuj barn, nam ddijnh"
  ],
  "Hiệp Hoà, Vĩnh Bảo, Hải Phòng": [
    "hiệp hoà, vĩnh bảo, hải phòng",
    "hieejp hoaf, vixnh baro, hari phofng"
  ],
  "Hiệp Thuận, Phúc Thọ, Hà Nội": [
    "hiệp thuận, phúc thọ, hà nội",
    "hieejp thuaajn, phusc thoj, haf nooji"
  ],
  "Hiệp Thành, Ngã Bảy, Hậu Giang": [
    "hiệp thành, ngã bảy, hậu giang",
    "hieejp thafnh, ngax bary, haaju giang"
  ],
  "Hiệp Tân, Tân Phú, Hồ Chí Minh": [
    "hiệp tân, tân phú, hồ chí minh",
    "hieejp taan, taan phus, hoof chis minh"
  ],
  "Hiệp Đức, Cai Lậy, Tiền Giang": [
    "hiệp đức, cai lậy, tiền giang",
    "hieejp dduwsc, cai laajy, tieefn giang"
  ],
  "Hoa Thủy, Lệ Thủy, Quảng Bình": [
    "hoa thủy, lệ thủy, quảng bình",
    "hoa thury, leej thury, quarng bifnh"
  ],
  "Hoà Thuận, Cao Lãnh, Đồng Tháp": [
    "hoà thuận, cao lãnh, đồng tháp",
    "hoaf thuaajn, cao laxnh, ddoofng thasp"
  ],
  "Hoà Thuận, Quảng Hòa, Cao Bằng": [
    "hoà thuận, quảng hòa, cao bằng",
    "hoaf thuaajn, quarng hofa, cao bawfng"
  ],
  "Hoài Mỹ, Hoài Nhơn, Bình Định": [
    "hoài mỹ, hoài nhơn, bình định",
    "hoafi myx, hoafi nhown, bifnh ddijnh"
  ],
  "Hoài Phú, Hoài Nhơn, Bình Định": [
    "hoài phú, hoài nhơn, bình định",
    "hoafi phus, hoafi nhown, bifnh ddijnh"
  ],
  "Hoài Sơn, Hoài Nhơn, Bình Định": [
    "hoài sơn, hoài nhơn, bình định",
    "hoafi sown, hoafi nhown, bifnh ddijnh"
  ],
  "Hoài Tân, Hoài Nhơn, Bình Định": [
    "hoài tân, hoài nhơn, bình định",
    "hoafi taan, hoafi nhown, bifnh ddijnh"
  ],
  "Hoàng Châu, Cát Hải, Hải Phòng": [
    "hoàng châu, cát hải, hải phòng",
    "hoafng chaau, cast hari, hari phofng"
  ],
  "Hoàng Giang, Nông Cống, Thanh Hóa": [
    "hoàng giang, nông cống, thanh hóa",
    "hoafng giang, noong coosng, thanh hosa"
  ],
  "Hoàng Thanh, Hiệp Hòa, Bắc Giang": [
    "hoàng thanh, hiệp hòa, bắc giang",
    "hoafng thanh, hieejp hofa, bawsc giang"
  ],
  "Hoàng Việt, Văn Lãng, Lạng Sơn": [
    "hoàng việt, văn lãng, lạng sơn",
    "hoafng vieejt, vawn laxng, lajng sown"
  ],
  "Hoằng Cát, Hoằng Hóa, Thanh Hóa": [
    "hoằng cát, hoằng hóa, thanh hóa",
    "hoawfng cast, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Lưu, Hoằng Hóa, Thanh Hóa": [
    "hoằng lưu, hoằng hóa, thanh hóa",
    "hoawfng luwu, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Phú, Hoằng Hóa, Thanh Hóa": [
    "hoằng phú, hoằng hóa, thanh hóa",
    "hoawfng phus, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Quý, Hoằng Hóa, Thanh Hóa": [
    "hoằng quý, hoằng hóa, thanh hóa",
    "hoawfng quys, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Sơn, Hoằng Hóa, Thanh Hóa": [
    "hoằng sơn, hoằng hóa, thanh hóa",
    "hoawfng sown, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Tân, Hoằng Hóa, Thanh Hóa": [
    "hoằng tân, hoằng hóa, thanh hóa",
    "hoawfng taan, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Đại, Thanh Hóa, Thanh Hóa": [
    "hoằng đại, thanh hóa, thanh hóa",
    "hoawfng ddaji, thanh hosa, thanh hosa"
  ],
  "Huổi Só, Tủa Chùa, Điện Biên": [
    "huổi só, tủa chùa, điện biên",
    "huoori sos, tura chufa, ddieejn bieen"
  ],
  "Hàm Ninh, Quảng Ninh, Quảng Bình": [
    "hàm ninh, quảng ninh, quảng bình",
    "hafm ninh, quarng ninh, quarng bifnh"
  ],
  "Hàng Trống, Hoàn Kiếm, Hà Nội": [
    "hàng trống, hoàn kiếm, hà nội",
    "hafng troosng, hoafn kieesm, haf nooji"
  ],
  "Hòa Khánh Tây, Đức Hòa, Long An": [
    "hòa khánh tây, đức hòa, long an",
    "hofa khasnh taay, dduwsc hofa, long an"
  ],
  "Hòa Lộc, Mỏ Cày Bắc, Bến Tre": [
    "hòa lộc, mỏ cày bắc, bến tre",
    "hofa loojc, mor cafy bawsc, beesn tre"
  ],
  "Hòa Mỹ Đông, Tây Hoà, Phú Yên": [
    "hòa mỹ đông, tây hoà, phú yên",
    "hofa myx ddoong, taay hoaf, phus yeen"
  ],
  "Hòa Mỹ, Phụng Hiệp, Hậu Giang": [
    "hòa mỹ, phụng hiệp, hậu giang",
    "hofa myx, phujng hieejp, haaju giang"
  ],
  "Hòa Phong, Krông Bông, Đắk Lắk": [
    "hòa phong, krông bông, đắk lắk",
    "hofa phong, kroong boong, ddawsk lawsk"
  ],
  "Hòa Quang Bắc, Phú Hoà, Phú Yên": [
    "hòa quang bắc, phú hoà, phú yên",
    "hofa quang bawsc, phus hoaf, phus yeen"
  ],
  "Hòa Thắng, Hữu Lũng, Lạng Sơn": [
    "hòa thắng, hữu lũng, lạng sơn",
    "hofa thawsng, huwxu luxng, lajng sown"
  ],
  "Hòa Tân, Châu Thành, Đồng Tháp": [
    "hòa tân, châu thành, đồng tháp",
    "hofa taan, chaau thafnh, ddoofng thasp"
  ],
  "Hòa Tịnh, Chợ Gạo, Tiền Giang": [
    "hòa tịnh, chợ gạo, tiền giang",
    "hofa tijnh, chowj gajo, tieefn giang"
  ],
  "Hòa Xuân Nam, Đông Hòa, Phú Yên": [
    "hòa xuân nam, đông hòa, phú yên",
    "hofa xuaan nam, ddoong hofa, phus yeen"
  ],
  "Hùng Cường, Hưng Yên, Hưng Yên": [
    "hùng cường, hưng yên, hưng yên",
    "hufng cuwowfng, huwng yeen, huwng yeen"
  ],
  "Hùng Sơn, Đại Từ, Thái Nguyên": [
    "hùng sơn, đại từ, thái nguyên",
    "hufng sown, ddaji tuwf, thasi nguyeen"
  ],
  "Hùng Thắng, Hạ Long, Quảng Ninh": [
    "hùng thắng, hạ long, quảng ninh",
    "hufng thawsng, haj long, quarng ninh"
  ],
  "Hùng Vương, Phúc Yên, Vĩnh Phúc": [
    "hùng vương, phúc yên, vĩnh phúc",
    "hufng vuwowng, phusc yeen, vixnh phusc"
  ],
  "Hưng Nghĩa, Hưng Nguyên, Nghệ An": [
    "hưng nghĩa, hưng nguyên, nghệ an",
    "huwng nghixa, huwng nguyeen, ngheej an"
  ],
  "Hưng Nhân, Vĩnh Bảo, Hải Phòng": [
    "hưng nhân, vĩnh bảo, hải phòng",
    "huwng nhaan, vixnh baro, hari phofng"
  ],
  "Hưng Phú, Phước Long, Bạc Liêu": [
    "hưng phú, phước long, bạc liêu",
    "huwng phus, phuwowsc long, bajc lieeu"
  ],
  "Hưng Thành, Hưng Nguyên, Nghệ An": [
    "hưng thành, hưng nguyên, nghệ an",
    "huwng thafnh, huwng nguyeen, ngheej an"
  ],
  "Hưng Thành, Vĩnh Lợi, Bạc Liêu": [
    "hưng thành, vĩnh lợi, bạc liêu",
    "huwng thafnh, vixnh lowji, bajc lieeu"
  ],
  "Hưng Thông, Hưng Nguyên, Nghệ An": [
    "hưng thông, hưng nguyên, nghệ an",
    "huwng thoong, huwng nguyeen, ngheej an"
  ],
  "Hưng Thịnh, Bảo Lạc, Cao Bằng": [
    "hưng thịnh, bảo lạc, cao bằng",
    "huwng thijnh, baro lajc, cao bawfng"
  ],
  "Hưng Đạo, Chí Linh, Hải Dương": [
    "hưng đạo, chí linh, hải dương",
    "huwng ddajo, chis linh, hari duwowng"
  ],
  "Hưng Đạo, Hưng Nguyên, Nghệ An": [
    "hưng đạo, hưng nguyên, nghệ an",
    "huwng ddajo, huwng nguyeen, ngheej an"
  ],
  "Hưng Đạo, Tứ Kỳ, Hải Dương": [
    "hưng đạo, tứ kỳ, hải dương",
    "huwng ddajo, tuws kyf, hari duwowng"
  ],
  "Hương Bình, Hương Khê, Hà Tĩnh": [
    "hương bình, hương khê, hà tĩnh",
    "huwowng bifnh, huwowng khee, haf tixnh"
  ],
  "Hương Giang, Hương Khê, Hà Tĩnh": [
    "hương giang, hương khê, hà tĩnh",
    "huwowng giang, huwowng khee, haf tixnh"
  ],
  "Hương Gián, Yên Dũng, Bắc Giang": [
    "hương gián, yên dũng, bắc giang",
    "huwowng giasn, yeen duxng, bawsc giang"
  ],
  "Hương Liên, Hương Khê, Hà Tĩnh": [
    "hương liên, hương khê, hà tĩnh",
    "huwowng lieen, huwowng khee, haf tixnh"
  ],
  "Hương Lâm, Hiệp Hòa, Bắc Giang": [
    "hương lâm, hiệp hòa, bắc giang",
    "huwowng laam, hieejp hofa, bawsc giang"
  ],
  "Hương Mỹ, Mỏ Cày Nam, Bến Tre": [
    "hương mỹ, mỏ cày nam, bến tre",
    "huwowng myx, mor cafy nam, beesn tre"
  ],
  "Hương Vĩnh, Hương Khê, Hà Tĩnh": [
    "hương vĩnh, hương khê, hà tĩnh",
    "huwowng vixnh, huwowng khee, haf tixnh"
  ],
  "Hương Xuân, Hương Khê, Hà Tĩnh": [
    "hương xuân, hương khê, hà tĩnh",
    "huwowng xuaan, huwowng khee, haf tixnh"
  ],
  "Hạ Bằng, Thạch Thất, Hà Nội": [
    "hạ bằng, thạch thất, hà nội",
    "haj bawfng, thajch thaast, haf nooji"
  ],
  "Hạnh Lâm, Thanh Chương, Nghệ An": [
    "hạnh lâm, thanh chương, nghệ an",
    "hajnh laam, thanh chuwowng, ngheej an"
  ],
  "Hạnh Phúc, Quảng Hòa, Cao Bằng": [
    "hạnh phúc, quảng hòa, cao bằng",
    "hajnh phusc, quarng hofa, cao bawfng"
  ],
  "Hải Chính, Hải Hậu, Nam Định": [
    "hải chính, hải hậu, nam định",
    "hari chisnh, hari haaju, nam ddijnh"
  ],
  "Hải Cảng, Qui Nhơn, Bình Định": [
    "hải cảng, qui nhơn, bình định",
    "hari carng, qui nhown, bifnh ddijnh"
  ],
  "Hải Khê, Hải Lăng, Quảng Trị": [
    "hải khê, hải lăng, quảng trị",
    "hari khee, hari lawng, quarng trij"
  ],
  "Hải Lâm, Hải Lăng, Quảng Trị": [
    "hải lâm, hải lăng, quảng trị",
    "hari laam, hari lawng, quarng trij"
  ],
  "Hải Lạng, Tiên Yên, Quảng Ninh": [
    "hải lạng, tiên yên, quảng ninh",
    "hari lajng, tieen yeen, quarng ninh"
  ],
  "Hải Ninh, Bắc Bình, Bình Thuận": [
    "hải ninh, bắc bình, bình thuận",
    "hari ninh, bawsc bifnh, bifnh thuaajn"
  ],
  "Hải Phú, Hải Lăng, Quảng Trị": [
    "hải phú, hải lăng, quảng trị",
    "hari phus, hari lawng, quarng trij"
  ],
  "Hải Sơn, Hải Lăng, Quảng Trị": [
    "hải sơn, hải lăng, quảng trị",
    "hari sown, hari lawng, quarng trij"
  ],
  "Hải Thượng, Tĩnh Gia, Thanh Hóa": [
    "hải thượng, tĩnh gia, thanh hóa",
    "hari thuwowjng, tixnh gia, thanh hosa"
  ],
  "Hải Tiến, Móng Cái, Quảng Ninh": [
    "hải tiến, móng cái, quảng ninh",
    "hari tieesn, mosng casi, quarng ninh"
  ],
  "Hải Đông, Hải Hậu, Nam Định": [
    "hải đông, hải hậu, nam định",
    "hari ddoong, hari haaju, nam ddijnh"
  ],
  "Hải Đông, Móng Cái, Quảng Ninh": [
    "hải đông, móng cái, quảng ninh",
    "hari ddoong, mosng casi, quarng ninh"
  ],
  "Hồ Thầu, Hoàng Su Phì, Hà Giang": [
    "hồ thầu, hoàng su phì, hà giang",
    "hoof thaafu, hoafng su phif, haf giang"
  ],
  "Hồ Thị Kỷ, Thới Bình, Cà Mau": [
    "hồ thị kỷ, thới bình, cà mau",
    "hoof thij kyr, thowsi bifnh, caf mau"
  ],
  "Hồng Dụ, Ninh Giang, Hải Dương": [
    "hồng dụ, ninh giang, hải dương",
    "hoofng duj, ninh giang, hari duwowng"
  ],
  "Hồng Hưng, Gia Lộc, Hải Dương": [
    "hồng hưng, gia lộc, hải dương",
    "hoofng huwng, gia loojc, hari duwowng"
  ],
  "Hồng Lạc, Thanh Hà, Hải Dương": [
    "hồng lạc, thanh hà, hải dương",
    "hoofng lajc, thanh haf, hari duwowng"
  ],
  "Hồng Phong, An Dương, Hải Phòng": [
    "hồng phong, an dương, hải phòng",
    "hoofng phong, an duwowng, hari phofng"
  ],
  "Hồng Phong, Chương Mỹ, Hà Nội": [
    "hồng phong, chương mỹ, hà nội",
    "hoofng phong, chuwowng myx, haf nooji"
  ],
  "Hồng Phong, Nam Sách, Hải Dương": [
    "hồng phong, nam sách, hải dương",
    "hoofng phong, nam sasch, hari duwowng"
  ],
  "Hồng Quang, Lâm Bình, Tuyên Quang": [
    "hồng quang, lâm bình, tuyên quang",
    "hoofng quang, laam bifnh, tuyeen quang"
  ],
  "Hồng Quang, Quảng Hòa, Cao Bằng": [
    "hồng quang, quảng hòa, cao bằng",
    "hoofng quang, quarng hofa, cao bawfng"
  ],
  "Hồng Thái, An Dương, Hải Phòng": [
    "hồng thái, an dương, hải phòng",
    "hoofng thasi, an duwowng, hari phofng"
  ],
  "Hồng Thái, Việt Yên, Bắc Giang": [
    "hồng thái, việt yên, bắc giang",
    "hoofng thasi, vieejt yeen, bawsc giang"
  ],
  "Hồng Vân, Thường Tín, Hà Nội": [
    "hồng vân, thường tín, hà nội",
    "hoofng vaan, thuwowfng tisn, haf nooji"
  ],
  "Hợp Hòa, Sơn Dương, Tuyên Quang": [
    "hợp hòa, sơn dương, tuyên quang",
    "howjp hofa, sown duwowng, tuyeen quang"
  ],
  "Hợp Thành, Triệu Sơn, Thanh Hóa": [
    "hợp thành, triệu sơn, thanh hóa",
    "howjp thafnh, trieeju sown, thanh hosa"
  ],
  "Hợp Tiến, Nam Sách, Hải Dương": [
    "hợp tiến, nam sách, hải dương",
    "howjp tieesn, nam sasch, hari duwowng"
  ],
  "Hợp Tiến, Triệu Sơn, Thanh Hóa": [
    "hợp tiến, triệu sơn, thanh hóa",
    "howjp tieesn, trieeju sown, thanh hosa"
  ],
  "Hợp Đức, Đồ Sơn, Hải Phòng": [
    "hợp đức, đồ sơn, hải phòng",
    "howjp dduwsc, ddoof sown, hari phofng"
  ],
  "Hữu Khánh, Lộc Bình, Lạng Sơn": [
    "hữu khánh, lộc bình, lạng sơn",
    "huwxu khasnh, loojc bifnh, lajng sown"
  ],
  "Hữu Sản, Sơn Động, Bắc Giang": [
    "hữu sản, sơn động, bắc giang",
    "huwxu sarn, sown ddoojng, bawsc giang"
  ],
  "Hữu Định, Châu Thành, Bến Tre": [
    "hữu định, châu thành, bến tre",
    "huwxu ddijnh, chaau thafnh, beesn tre"
  ],
  "Khao Mang, Mù Căng Chải, Yên Bái": [
    "khao mang, mù căng chải, yên bái",
    "khao mang, muf cawng chari, yeen basi"
  ],
  "Khe Sanh, Hướng Hóa, Quảng Trị": [
    "khe sanh, hướng hóa, quảng trị",
    "khe sanh, huwowsng hosa, quarng trij"
  ],
  "Khoái Châu, Khoái Châu, Hưng Yên": [
    "khoái châu, khoái châu, hưng yên",
    "khoasi chaau, khoasi chaau, huwng yeen"
  ],
  "Khánh Hải, Ninh Hải, Ninh Thuận": [
    "khánh hải, ninh hải, ninh thuận",
    "khasnh hari, ninh hari, ninh thuaajn"
  ],
  "Khánh Hồng, Yên Khánh, Ninh Bình": [
    "khánh hồng, yên khánh, ninh bình",
    "khasnh hoofng, yeen khasnh, ninh bifnh"
  ],
  "Khánh Nhạc, Yên Khánh, Ninh Bình": [
    "khánh nhạc, yên khánh, ninh bình",
    "khasnh nhajc, yeen khasnh, ninh bifnh"
  ],
  "Khánh Phú, Khánh Vĩnh, Khánh Hòa": [
    "khánh phú, khánh vĩnh, khánh hòa",
    "khasnh phus, khasnh vixnh, khasnh hofa"
  ],
  "Khánh Thành, Yên Khánh, Ninh Bình": [
    "khánh thành, yên khánh, ninh bình",
    "khasnh thafnh, yeen khasnh, ninh bifnh"
  ],
  "Khánh Thượng, Yên Mô, Ninh Bình": [
    "khánh thượng, yên mô, ninh bình",
    "khasnh thuwowjng, yeen moo, ninh bifnh"
  ],
  "Khánh Thủy, Yên Khánh, Ninh Bình": [
    "khánh thủy, yên khánh, ninh bình",
    "khasnh thury, yeen khasnh, ninh bifnh"
  ],
  "Khánh Xuân, Lộc Bình, Lạng Sơn": [
    "khánh xuân, lộc bình, lạng sơn",
    "khasnh xuaan, loojc bifnh, lajng sown"
  ],
  "Khánh Yên Trung, Văn Bàn, Lào Cai": [
    "khánh yên trung, văn bàn, lào cai",
    "khasnh yeen trung, vawn bafn, lafo cai"
  ],
  "Khôi Kỳ, Đại Từ, Thái Nguyên": [
    "khôi kỳ, đại từ, thái nguyên",
    "khooi kyf, ddaji tuwf, thasi nguyeen"
  ],
  "Khương Trung, Thanh Xuân, Hà Nội": [
    "khương trung, thanh xuân, hà nội",
    "khuwowng trung, thanh xuaan, haf nooji"
  ],
  "Kim Nọi, Mù Căng Chải, Yên Bái": [
    "kim nọi, mù căng chải, yên bái",
    "kim noji, muf cawng chari, yeen basi"
  ],
  "Kim Sơn, Đông Triều, Quảng Ninh": [
    "kim sơn, đông triều, quảng ninh",
    "kim sown, ddoong trieefu, quarng ninh"
  ],
  "Kim Thạch, Vĩnh Linh, Quảng Trị": [
    "kim thạch, vĩnh linh, quảng trị",
    "kim thajch, vixnh linh, quarng trij"
  ],
  "Kim Thủy, Lệ Thủy, Quảng Bình": [
    "kim thủy, lệ thủy, quảng bình",
    "kim thury, leej thury, quarng bifnh"
  ],
  "Kiên Mộc, Đình Lập, Lạng Sơn": [
    "kiên mộc, đình lập, lạng sơn",
    "kieen moojc, ddifnh laajp, lajng sown"
  ],
  "Kiên Đài, Chiêm Hóa, Tuyên Quang": [
    "kiên đài, chiêm hóa, tuyên quang",
    "kieen ddafi, chieem hosa, tuyeen quang"
  ],
  "Kênh Dương, Lê Chân, Hải Phòng": [
    "kênh dương, lê chân, hải phòng",
    "keenh duwowng, lee chaan, hari phofng"
  ],
  "Kẻ Sặt, Bình Giang, Hải Dương": [
    "kẻ sặt, bình giang, hải dương",
    "ker sawjt, bifnh giang, hari duwowng"
  ],
  "Lai Cách, Cẩm Giàng, Hải Dương": [
    "lai cách, cẩm giàng, hải dương",
    "lai casch, caarm giafng, hari duwowng"
  ],
  "Liên Giang, Đông Hưng, Thái Bình": [
    "liên giang, đông hưng, thái bình",
    "lieen giang, ddoong huwng, thasi bifnh"
  ],
  "Liên Hòa, Lập Thạch, Vĩnh Phúc": [
    "liên hòa, lập thạch, vĩnh phúc",
    "lieen hofa, laajp thajch, vixnh phusc"
  ],
  "Liên Hòa, Quảng Yên, Quảng Ninh": [
    "liên hòa, quảng yên, quảng ninh",
    "lieen hofa, quarng yeen, quarng ninh"
  ],
  "Liên Phương, Hưng Yên, Hưng Yên": [
    "liên phương, hưng yên, hưng yên",
    "lieen phuwowng, huwng yeen, huwng yeen"
  ],
  "Liên Trung, Đan Phượng, Hà Nội": [
    "liên trung, đan phượng, hà nội",
    "lieen trung, ddan phuwowjng, haf nooji"
  ],
  "Liên Vị, Quảng Yên, Quảng Ninh": [
    "liên vị, quảng yên, quảng ninh",
    "lieen vij, quarng yeen, quarng ninh"
  ],
  "Long Hà, Phú Riềng, Bình Phước": [
    "long hà, phú riềng, bình phước",
    "long haf, phus rieefng, bifnh phuwowsc"
  ],
  "Long Hòa, Cần Giờ, Hồ Chí Minh": [
    "long hòa, cần giờ, hồ chí minh",
    "long hofa, caafn giowf, hoof chis minh"
  ],
  "Long Hưng A, Lấp Vò, Đồng Tháp": [
    "long hưng a, lấp vò, đồng tháp",
    "long huwng a, laasp vof, ddoofng thasp"
  ],
  "Long Hưng B, Lấp Vò, Đồng Tháp": [
    "long hưng b, lấp vò, đồng tháp",
    "long huwng b, laasp vof, ddoofng thasp"
  ],
  "Long Hưng, Châu Thành, Tiền Giang": [
    "long hưng, châu thành, tiền giang",
    "long huwng, chaau thafnh, tieefn giang"
  ],
  "Long Thượng, Cần Giuộc, Long An": [
    "long thượng, cần giuộc, long an",
    "long thuwowjng, caafn giuoojc, long an"
  ],
  "Long Thạnh, Vĩnh Lợi, Bạc Liêu": [
    "long thạnh, vĩnh lợi, bạc liêu",
    "long thajnh, vixnh lowji, bajc lieeu"
  ],
  "Long Thọ, Nhơn Trạch, Đồng Nai": [
    "long thọ, nhơn trạch, đồng nai",
    "long thoj, nhown trajch, ddoofng nai"
  ],
  "Long Tuyền, Bình Thuỷ, Cần Thơ": [
    "long tuyền, bình thuỷ, cần thơ",
    "long tuyeefn, bifnh thuyr, caafn thow"
  ],
  "Lái Thiêu, Thuận An, Bình Dương": [
    "lái thiêu, thuận an, bình dương",
    "lasi thieeu, thuaajn an, bifnh duwowng"
  ],
  "Lê Lợi, Kiến Xương, Thái Bình": [
    "lê lợi, kiến xương, thái bình",
    "lee lowji, kieesn xuwowng, thasi bifnh"
  ],
  "Lùng Vai, Mường Khương, Lào Cai": [
    "lùng vai, mường khương, lào cai",
    "lufng vai, muwowfng khuwowng, lafo cai"
  ],
  "Lý Nhân, Vĩnh Tường, Vĩnh Phúc": [
    "lý nhân, vĩnh tường, vĩnh phúc",
    "lys nhaan, vixnh tuwowfng, vixnh phusc"
  ],
  "Lý Nhơn, Cần Giờ, Hồ Chí Minh": [
    "lý nhơn, cần giờ, hồ chí minh",
    "lys nhown, caafn giowf, hoof chis minh"
  ],
  "Lưu Nghiệp Anh, Trà Cú, Trà Vinh": [
    "lưu nghiệp anh, trà cú, trà vinh",
    "luwu nghieejp anh, traf cus, traf vinh"
  ],
  "Lương Hòa, Giồng Trôm, Bến Tre": [
    "lương hòa, giồng trôm, bến tre",
    "luwowng hofa, gioofng troom, beesn tre"
  ],
  "Lương Nghĩa, Long Mỹ, Hậu Giang": [
    "lương nghĩa, long mỹ, hậu giang",
    "luwowng nghixa, long myx, haaju giang"
  ],
  "Lương Phú, Giồng Trôm, Bến Tre": [
    "lương phú, giồng trôm, bến tre",
    "luwowng phus, gioofng troom, beesn tre"
  ],
  "Lương Sơn, Lương Sơn, Hoà Bình": [
    "lương sơn, lương sơn, hoà bình",
    "luwowng sown, luwowng sown, hoaf bifnh"
  ],
  "Lương Thượng, Na Rì, Bắc Kạn": [
    "lương thượng, na rì, bắc kạn",
    "luwowng thuwowjng, na rif, bawsc kajn"
  ],
  "Lạc Lương, Yên Thủy, Hoà Bình": [
    "lạc lương, yên thủy, hoà bình",
    "lajc luwowng, yeen thury, hoaf bifnh"
  ],
  "Lạc Thịnh, Yên Thủy, Hoà Bình": [
    "lạc thịnh, yên thủy, hoà bình",
    "lajc thijnh, yeen thury, hoaf bifnh"
  ],
  "Lạc Tánh, Tánh Linh, Bình Thuận": [
    "lạc tánh, tánh linh, bình thuận",
    "lajc tasnh, tasnh linh, bifnh thuaajn"
  ],
  "Lệ Viễn, Sơn Động, Bắc Giang": [
    "lệ viễn, sơn động, bắc giang",
    "leej vieexn, sown ddoojng, bawsc giang"
  ],
  "Lộc Châu, Bảo Lộc, Lâm Đồng": [
    "lộc châu, bảo lộc, lâm đồng",
    "loojc chaau, baro loojc, laam ddoofng"
  ],
  "Lộc Hòa, Lộc Ninh, Bình Phước": [
    "lộc hòa, lộc ninh, bình phước",
    "loojc hofa, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Ninh, Lộc Ninh, Bình Phước": [
    "lộc ninh, lộc ninh, bình phước",
    "loojc ninh, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Phát, Bảo Lộc, Lâm Đồng": [
    "lộc phát, bảo lộc, lâm đồng",
    "loojc phast, baro loojc, laam ddoofng"
  ],
  "Lộc Phú, Lộc Ninh, Bình Phước": [
    "lộc phú, lộc ninh, bình phước",
    "loojc phus, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Thanh, Bảo Lộc, Lâm Đồng": [
    "lộc thanh, bảo lộc, lâm đồng",
    "loojc thanh, baro loojc, laam ddoofng"
  ],
  "Lộc Thuận, Bình Đại, Bến Tre": [
    "lộc thuận, bình đại, bến tre",
    "loojc thuaajn, bifnh ddaji, beesn tre"
  ],
  "Lộc Thành, Bảo Lâm, Lâm Đồng": [
    "lộc thành, bảo lâm, lâm đồng",
    "loojc thafnh, baro laam, laam ddoofng"
  ],
  "Lộc Đức, Bảo Lâm, Lâm Đồng": [
    "lộc đức, bảo lâm, lâm đồng",
    "loojc dduwsc, baro laam, laam ddoofng"
  ],
  "Lục Hồn, Bình Liêu, Quảng Ninh": [
    "lục hồn, bình liêu, quảng ninh",
    "lujc hoofn, bifnh lieeu, quarng ninh"
  ],
  "Mai Thủy, Lệ Thủy, Quảng Bình": [
    "mai thủy, lệ thủy, quảng bình",
    "mai thury, leej thury, quarng bifnh"
  ],
  "Minh Hưng, Bù Đăng, Bình Phước": [
    "minh hưng, bù đăng, bình phước",
    "minh huwng, buf ddawng, bifnh phuwowsc"
  ],
  "Minh Khai, Bắc Từ Liêm, Hà Nội": [
    "minh khai, bắc từ liêm, hà nội",
    "minh khai, bawsc tuwf lieem, haf nooji"
  ],
  "Minh Khương, Hàm Yên, Tuyên Quang": [
    "minh khương, hàm yên, tuyên quang",
    "minh khuwowng, hafm yeen, tuyeen quang"
  ],
  "Minh Phương, Việt Trì, Phú Thọ": [
    "minh phương, việt trì, phú thọ",
    "minh phuwowng, vieejt trif, phus thoj"
  ],
  "Minh Phượng, Tiên Lữ, Hưng Yên": [
    "minh phượng, tiên lữ, hưng yên",
    "minh phuwowjng, tieen luwx, huwng yeen"
  ],
  "Minh Thanh, Sơn Dương, Tuyên Quang": [
    "minh thanh, sơn dương, tuyên quang",
    "minh thanh, sown duwowng, tuyeen quang"
  ],
  "Minh Tân, Kiến Thuỵ, Hải Phòng": [
    "minh tân, kiến thuỵ, hải phòng",
    "minh taan, kieesn thuyj, hari phofng"
  ],
  "Minh Tân, Kiến Xương, Thái Bình": [
    "minh tân, kiến xương, thái bình",
    "minh taan, kieesn xuwowng, thasi bifnh"
  ],
  "Minh Xuân, Tuyên Quang, Tuyên Quang": [
    "minh xuân, tuyên quang, tuyên quang",
    "minh xuaan, tuyeen quang, tuyeen quang"
  ],
  "Minh Đức, Phổ Yên, Thái Nguyên": [
    "minh đức, phổ yên, thái nguyên",
    "minh dduwsc, phoor yeen, thasi nguyeen"
  ],
  "Mường Chiên, Quỳnh Nhai, Sơn La": [
    "mường chiên, quỳnh nhai, sơn la",
    "muwowfng chieen, quyfnh nhai, sown la"
  ],
  "Mường Giàng, Quỳnh Nhai, Sơn La": [
    "mường giàng, quỳnh nhai, sơn la",
    "muwowfng giafng, quyfnh nhai, sown la"
  ],
  "Mường Nọc, Quế Phong, Nghệ An": [
    "mường nọc, quế phong, nghệ an",
    "muwowfng nojc, quees phong, ngheej an"
  ],
  "Mồ Dề, Mù Căng Chải, Yên Bái": [
    "mồ dề, mù căng chải, yên bái",
    "moof deef, muf cawng chari, yeen basi"
  ],
  "Mỹ Hoà Hưng, Long Xuyên, An Giang": [
    "mỹ hoà hưng, long xuyên, an giang",
    "myx hoaf huwng, long xuyeen, an giang"
  ],
  "Mỹ Hương, Lương Tài, Bắc Ninh": [
    "mỹ hương, lương tài, bắc ninh",
    "myx huwowng, luwowng tafi, bawsc ninh"
  ],
  "Mỹ Khánh, Phong Điền, Cần Thơ": [
    "mỹ khánh, phong điền, cần thơ",
    "myx khasnh, phong ddieefn, caafn thow"
  ],
  "Mỹ Lương, Chương Mỹ, Hà Nội": [
    "mỹ lương, chương mỹ, hà nội",
    "myx luwowng, chuwowng myx, haf nooji"
  ],
  "Mỹ Thanh, Bạch Thông, Bắc Kạn": [
    "mỹ thanh, bạch thông, bắc kạn",
    "myx thanh, bajch thoong, bawsc kajn"
  ],
  "Mỹ Thuận, Hòn Đất, Kiên Giang": [
    "mỹ thuận, hòn đất, kiên giang",
    "myx thuaajn, hofn ddaast, kieen giang"
  ],
  "Mỹ Thạnh, Giồng Trôm, Bến Tre": [
    "mỹ thạnh, giồng trôm, bến tre",
    "myx thajnh, gioofng troom, beesn tre"
  ],
  "Mỹ Thắng, Phù Mỹ, Bình Định": [
    "mỹ thắng, phù mỹ, bình định",
    "myx thawsng, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Xương, Cao Lãnh, Đồng Tháp": [
    "mỹ xương, cao lãnh, đồng tháp",
    "myx xuwowng, cao laxnh, ddoofng thasp"
  ],
  "Mỹ Đức, Đạ Tẻh, Lâm Đồng": [
    "mỹ đức, đạ tẻh, lâm đồng",
    "myx dduwsc, ddaj terh, laam ddoofng"
  ],
  "NT Trần Phú, Văn Chấn, Yên Bái": [
    "nt trần phú, văn chấn, yên bái",
    "nt traafn phus, vawn chaasn, yeen basi"
  ],
  "Na Tông, Điện Biên, Điện Biên": [
    "na tông, điện biên, điện biên",
    "na toong, ddieejn bieen, ddieejn bieen"
  ],
  "Nam Bình, Kiến Xương, Thái Bình": [
    "nam bình, kiến xương, thái bình",
    "nam bifnh, kieesn xuwowng, thasi bifnh"
  ],
  "Nam Chính, Đức Linh, Bình Thuận": [
    "nam chính, đức linh, bình thuận",
    "nam chisnh, dduwsc linh, bifnh thuaajn"
  ],
  "Nam Cát Tiên, Tân Phú, Đồng Nai": [
    "nam cát tiên, tân phú, đồng nai",
    "nam cast tieen, taan phus, ddoofng nai"
  ],
  "Nam Dương, Lục Ngạn, Bắc Giang": [
    "nam dương, lục ngạn, bắc giang",
    "nam duwowng, lujc ngajn, bawsc giang"
  ],
  "Nam Thắng, Tiền Hải, Thái Bình": [
    "nam thắng, tiền hải, thái bình",
    "nam thawsng, tieefn hari, thasi bifnh"
  ],
  "Nam Thịnh, Tiền Hải, Thái Bình": [
    "nam thịnh, tiền hải, thái bình",
    "nam thijnh, tieefn hari, thasi bifnh"
  ],
  "Nam Điền, Nghĩa Hưng, Nam Định": [
    "nam điền, nghĩa hưng, nam định",
    "nam ddieefn, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Hiếu, Nghĩa Đàn, Nghệ An": [
    "nghĩa hiếu, nghĩa đàn, nghệ an",
    "nghixa hieesu, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Hòa, Lạng Giang, Bắc Giang": [
    "nghĩa hòa, lạng giang, bắc giang",
    "nghixa hofa, lajng giang, bawsc giang"
  ],
  "Nghĩa Hòa, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa hòa, tư nghĩa, quảng ngãi",
    "nghixa hofa, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Hồng, Nghĩa Đàn, Nghệ An": [
    "nghĩa hồng, nghĩa đàn, nghệ an",
    "nghixa hoofng, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Khánh, Nghĩa Đàn, Nghệ An": [
    "nghĩa khánh, nghĩa đàn, nghệ an",
    "nghixa khasnh, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Kỳ, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa kỳ, tư nghĩa, quảng ngãi",
    "nghixa kyf, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Lâm, Nghĩa Hưng, Nam Định": [
    "nghĩa lâm, nghĩa hưng, nam định",
    "nghixa laam, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Lâm, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa lâm, tư nghĩa, quảng ngãi",
    "nghixa laam, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Minh, Nghĩa Hưng, Nam Định": [
    "nghĩa minh, nghĩa hưng, nam định",
    "nghixa minh, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Mỹ, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa mỹ, tư nghĩa, quảng ngãi",
    "nghixa myx, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Phú, Nghĩa Hưng, Nam Định": [
    "nghĩa phú, nghĩa hưng, nam định",
    "nghixa phus, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Sơn, Nghĩa Hưng, Nam Định": [
    "nghĩa sơn, nghĩa hưng, nam định",
    "nghixa sown, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Sơn, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa sơn, tư nghĩa, quảng ngãi",
    "nghixa sown, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Thuận, Quản Bạ, Hà Giang": [
    "nghĩa thuận, quản bạ, hà giang",
    "nghixa thuaajn, quarn baj, haf giang"
  ],
  "Nghĩa Thành, Nghĩa Đàn, Nghệ An": [
    "nghĩa thành, nghĩa đàn, nghệ an",
    "nghixa thafnh, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Trung, Gia Nghĩa, Đắk Nông": [
    "nghĩa trung, gia nghĩa, đắk nông",
    "nghixa trung, gia nghixa, ddawsk noong"
  ],
  "Nghĩa Trung, Việt Yên, Bắc Giang": [
    "nghĩa trung, việt yên, bắc giang",
    "nghixa trung, vieejt yeen, bawsc giang"
  ],
  "Nghĩa Tân, Nghĩa Hưng, Nam Định": [
    "nghĩa tân, nghĩa hưng, nam định",
    "nghixa taan, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Đức, Nghĩa Đàn, Nghệ An": [
    "nghĩa đức, nghĩa đàn, nghệ an",
    "nghixa dduwsc, nghixa ddafn, ngheej an"
  ],
  "Nguyên Xá, Đông Hưng, Thái Bình": [
    "nguyên xá, đông hưng, thái bình",
    "nguyeen xas, ddoong huwng, thasi bifnh"
  ],
  "Nguyễn Du, Hai Bà Trưng, Hà Nội": [
    "nguyễn du, hai bà trưng, hà nội",
    "nguyeexn du, hai baf truwng, haf nooji"
  ],
  "Nguyệt Hóa, Châu Thành, Trà Vinh": [
    "nguyệt hóa, châu thành, trà vinh",
    "nguyeejt hosa, chaau thafnh, traf vinh"
  ],
  "Ngãi Đăng, Mỏ Cày Nam, Bến Tre": [
    "ngãi đăng, mỏ cày nam, bến tre",
    "ngaxi ddawng, mor cafy nam, beesn tre"
  ],
  "Ngô Quyền, Bắc Giang, Bắc Giang": [
    "ngô quyền, bắc giang, bắc giang",
    "ngoo quyeefn, bawsc giang, bawsc giang"
  ],
  "Ngô Quyền, Nam Định, Nam Định": [
    "ngô quyền, nam định, nam định",
    "ngoo quyeefn, nam ddijnh, nam ddijnh"
  ],
  "Ngô Đồng, Giao Thủy, Nam Định": [
    "ngô đồng, giao thủy, nam định",
    "ngoo ddoofng, giao thury, nam ddijnh"
  ],
  "Ngũ Phụng, Phú Quí, Bình Thuận": [
    "ngũ phụng, phú quí, bình thuận",
    "ngux phujng, phus quis, bifnh thuaajn"
  ],
  "Ngũ Thái, Thuận Thành, Bắc Ninh": [
    "ngũ thái, thuận thành, bắc ninh",
    "ngux thasi, thuaajn thafnh, bawsc ninh"
  ],
  "Ngọc Côn, Trùng Khánh, Cao Bằng": [
    "ngọc côn, trùng khánh, cao bằng",
    "ngojc coon, trufng khasnh, cao bawfng"
  ],
  "Ngọc Khê, Trùng Khánh, Cao Bằng": [
    "ngọc khê, trùng khánh, cao bằng",
    "ngojc khee, trufng khasnh, cao bawfng"
  ],
  "Ngọc Liên, Ngọc Lặc, Thanh Hóa": [
    "ngọc liên, ngọc lặc, thanh hóa",
    "ngojc lieen, ngojc lawjc, thanh hosa"
  ],
  "Ngọc Lâm, Thanh Chương, Nghệ An": [
    "ngọc lâm, thanh chương, nghệ an",
    "ngojc laam, thanh chuwowng, ngheej an"
  ],
  "Ngọc Lặc, Ngọc Lặc, Thanh Hóa": [
    "ngọc lặc, ngọc lặc, thanh hóa",
    "ngojc lawjc, ngojc lawjc, thanh hosa"
  ],
  "Ngọc Sơn, Thanh Chương, Nghệ An": [
    "ngọc sơn, thanh chương, nghệ an",
    "ngojc sown, thanh chuwowng, ngheej an"
  ],
  "Ngọc Thiện, Tân Yên, Bắc Giang": [
    "ngọc thiện, tân yên, bắc giang",
    "ngojc thieejn, taan yeen, bawsc giang"
  ],
  "Ngọc Trung, Ngọc Lặc, Thanh Hóa": [
    "ngọc trung, ngọc lặc, thanh hóa",
    "ngojc trung, ngojc lawjc, thanh hosa"
  ],
  "Ngọc Đường, Hà Giang, Hà Giang": [
    "ngọc đường, hà giang, hà giang",
    "ngojc dduwowfng, haf giang, haf giang"
  ],
  "Ngọc Đồng, Yên Lập, Phú Thọ": [
    "ngọc đồng, yên lập, phú thọ",
    "ngojc ddoofng, yeen laajp, phus thoj"
  ],
  "Nhã Lộng, Phú Bình, Thái Nguyên": [
    "nhã lộng, phú bình, thái nguyên",
    "nhax loojng, phus bifnh, thasi nguyeen"
  ],
  "Nhơn Đức, Nhà Bè, Hồ Chí Minh": [
    "nhơn đức, nhà bè, hồ chí minh",
    "nhown dduwsc, nhaf bef, hoof chis minh"
  ],
  "Nhất Tiến, Bắc Sơn, Lạng Sơn": [
    "nhất tiến, bắc sơn, lạng sơn",
    "nhaast tieesn, bawsc sown, lajng sown"
  ],
  "Nhị Bình, Hóc Môn, Hồ Chí Minh": [
    "nhị bình, hóc môn, hồ chí minh",
    "nhij bifnh, hosc moon, hoof chis minh"
  ],
  "Nhị Long Phú, Càng Long, Trà Vinh": [
    "nhị long phú, càng long, trà vinh",
    "nhij long phus, cafng long, traf vinh"
  ],
  "Ninh Dương, Móng Cái, Quảng Ninh": [
    "ninh dương, móng cái, quảng ninh",
    "ninh duwowng, mosng casi, quarng ninh"
  ],
  "Ninh Gia, Đức Trọng, Lâm Đồng": [
    "ninh gia, đức trọng, lâm đồng",
    "ninh gia, dduwsc trojng, laam ddoofng"
  ],
  "Ninh Phước, Nông Sơn, Quảng Nam": [
    "ninh phước, nông sơn, quảng nam",
    "ninh phuwowsc, noong sown, quarng nam"
  ],
  "Ninh Thượng, Ninh Hòa, Khánh Hòa": [
    "ninh thượng, ninh hòa, khánh hòa",
    "ninh thuwowjng, ninh hofa, khasnh hofa"
  ],
  "Niệm Nghĩa, Lê Chân, Hải Phòng": [
    "niệm nghĩa, lê chân, hải phòng",
    "nieejm nghixa, lee chaan, hari phofng"
  ],
  "Nà Tòng, Tuần Giáo, Điện Biên": [
    "nà tòng, tuần giáo, điện biên",
    "naf tofng, tuaafn giaso, ddieejn bieen"
  ],
  "Nàng Đôn, Hoàng Su Phì, Hà Giang": [
    "nàng đôn, hoàng su phì, hà giang",
    "nafng ddoon, hoafng su phif, haf giang"
  ],
  "Nâm N'Jang, Đắk Song, Đắk Nông": [
    "nâm n'jang, đắk song, đắk nông",
    "naam n'jang, ddawsk song, ddawsk noong"
  ],
  "Nông Cống, Nông Cống, Thanh Hóa": [
    "nông cống, nông cống, thanh hóa",
    "noong coosng, noong coosng, thanh hosa"
  ],
  "Nấm Lư, Mường Khương, Lào Cai": [
    "nấm lư, mường khương, lào cai",
    "naasm luw, muwowfng khuwowng, lafo cai"
  ],
  "Nậm Có, Mù Căng Chải, Yên Bái": [
    "nậm có, mù căng chải, yên bái",
    "naajm cos, muf cawng chari, yeen basi"
  ],
  "Nậm Khòa, Hoàng Su Phì, Hà Giang": [
    "nậm khòa, hoàng su phì, hà giang",
    "naajm khofa, hoafng su phif, haf giang"
  ],
  "Nậm Khăn, Nậm Pồ, Điện Biên": [
    "nậm khăn, nậm pồ, điện biên",
    "naajm khawn, naajm poof, ddieejn bieen"
  ],
  "Nậm Nhừ, Nậm Pồ, Điện Biên": [
    "nậm nhừ, nậm pồ, điện biên",
    "naajm nhuwf, naajm poof, ddieejn bieen"
  ],
  "Pa Thơm, Điện Biên, Điện Biên": [
    "pa thơm, điện biên, điện biên",
    "pa thowm, ddieejn bieen, ddieejn bieen"
  ],
  "Phan Thanh, Bắc Bình, Bình Thuận": [
    "phan thanh, bắc bình, bình thuận",
    "phan thanh, bawsc bifnh, bifnh thuaajn"
  ],
  "Phong Châu, Trùng Khánh, Cao Bằng": [
    "phong châu, trùng khánh, cao bằng",
    "phong chaau, trufng khasnh, cao bawfng"
  ],
  "Phong Châu, Đông Hưng, Thái Bình": [
    "phong châu, đông hưng, thái bình",
    "phong chaau, ddoong huwng, thasi bifnh"
  ],
  "Phong Hóa, Tuyên Hóa, Quảng Bình": [
    "phong hóa, tuyên hóa, quảng bình",
    "phong hosa, tuyeen hosa, quarng bifnh"
  ],
  "Phong Nha, Bố Trạch, Quảng Bình": [
    "phong nha, bố trạch, quảng bình",
    "phong nha, boos trajch, quarng bifnh"
  ],
  "Phong Nậm, Trùng Khánh, Cao Bằng": [
    "phong nậm, trùng khánh, cao bằng",
    "phong naajm, trufng khasnh, cao bawfng"
  ],
  "Phong Thạnh A, Giá Rai, Bạc Liêu": [
    "phong thạnh a, giá rai, bạc liêu",
    "phong thajnh a, gias rai, bajc lieeu"
  ],
  "Phù Lưu Tế, Mỹ Đức, Hà Nội": [
    "phù lưu tế, mỹ đức, hà nội",
    "phuf luwu tees, myx dduwsc, haf nooji"
  ],
  "Phùng Giáo, Ngọc Lặc, Thanh Hóa": [
    "phùng giáo, ngọc lặc, thanh hóa",
    "phufng giaso, ngojc lawjc, thanh hosa"
  ],
  "Phùng Hưng, Khoái Châu, Hưng Yên": [
    "phùng hưng, khoái châu, hưng yên",
    "phufng huwng, khoasi chaau, huwng yeen"
  ],
  "Phú Bình, Huế, Thừa Thiên Huế": [
    "phú bình, huế, thừa thiên huế",
    "phus bifnh, huees, thuwfa thieen huees"
  ],
  "Phú Chánh, Tân Uyên, Bình Dương": [
    "phú chánh, tân uyên, bình dương",
    "phus chasnh, taan uyeen, bifnh duwowng"
  ],
  "Phú Cường, Cai Lậy, Tiền Giang": [
    "phú cường, cai lậy, tiền giang",
    "phus cuwowfng, cai laajy, tieefn giang"
  ],
  "Phú Hài, Phan Thiết, Bình Thuận": [
    "phú hài, phan thiết, bình thuận",
    "phus hafi, phan thieest, bifnh thuaajn"
  ],
  "Phú Hậu, Huế, Thừa Thiên Huế": [
    "phú hậu, huế, thừa thiên huế",
    "phus haaju, huees, thuwfa thieen huees"
  ],
  "Phú Hội, Huế, Thừa Thiên Huế": [
    "phú hội, huế, thừa thiên huế",
    "phus hooji, huees, thuwfa thieen huees"
  ],
  "Phú Hội, Nhơn Trạch, Đồng Nai": [
    "phú hội, nhơn trạch, đồng nai",
    "phus hooji, nhown trajch, ddoofng nai"
  ],
  "Phú Hữu, Nhơn Trạch, Đồng Nai": [
    "phú hữu, nhơn trạch, đồng nai",
    "phus huwxu, nhown trajch, ddoofng nai"
  ],
  "Phú Kiết, Chợ Gạo, Tiền Giang": [
    "phú kiết, chợ gạo, tiền giang",
    "phus kieest, chowj gajo, tieefn giang"
  ],
  "Phú Long, Châu Thành, Đồng Tháp": [
    "phú long, châu thành, đồng tháp",
    "phus long, chaau thafnh, ddoofng thasp"
  ],
  "Phú Lương, Lương Tài, Bắc Ninh": [
    "phú lương, lương tài, bắc ninh",
    "phus luwowng, luwowng tafi, bawsc ninh"
  ],
  "Phú Lạc, Đại Từ, Thái Nguyên": [
    "phú lạc, đại từ, thái nguyên",
    "phus lajc, ddaji tuwf, thasi nguyeen"
  ],
  "Phú Lộc, Krông Năng, Đắk Lắk": [
    "phú lộc, krông năng, đắk lắk",
    "phus loojc, kroong nawng, ddawsk lawsk"
  ],
  "Phú Lộc, Thạnh Trị, Sóc Trăng": [
    "phú lộc, thạnh trị, sóc trăng",
    "phus loojc, thajnh trij, sosc trawng"
  ],
  "Phú Lợi, Thanh Bình, Đồng Tháp": [
    "phú lợi, thanh bình, đồng tháp",
    "phus lowji, thanh bifnh, ddoofng thasp"
  ],
  "Phú Lợi, Định Quán, Đồng Nai": [
    "phú lợi, định quán, đồng nai",
    "phus lowji, ddijnh quasn, ddoofng nai"
  ],
  "Phú Mỹ, Tân Phước, Tiền Giang": [
    "phú mỹ, tân phước, tiền giang",
    "phus myx, taan phuwowsc, tieefn giang"
  ],
  "Phú Phong, Châu Thành, Tiền Giang": [
    "phú phong, châu thành, tiền giang",
    "phus phong, chaau thafnh, tieefn giang"
  ],
  "Phú Thuận, Quận 7, Hồ Chí Minh": [
    "phú thuận, quận 7, hồ chí minh",
    "phus thuaajn, quaajn 7, hoof chis minh"
  ],
  "Phú Tài, Phan Thiết, Bình Thuận": [
    "phú tài, phan thiết, bình thuận",
    "phus tafi, phan thieest, bifnh thuaajn"
  ],
  "Phú Xuân, Krông Năng, Đắk Lắk": [
    "phú xuân, krông năng, đắk lắk",
    "phus xuaan, kroong nawng, ddawsk lawsk"
  ],
  "Phú Xá, Thái Nguyên, Thái Nguyên": [
    "phú xá, thái nguyên, thái nguyên",
    "phus xas, thasi nguyeen, thasi nguyeen"
  ],
  "Phú Điền, Nam Sách, Hải Dương": [
    "phú điền, nam sách, hải dương",
    "phus ddieefn, nam sasch, hari duwowng"
  ],
  "Phú Đô, Phú Lương, Thái Nguyên": [
    "phú đô, phú lương, thái nguyên",
    "phus ddoo, phus luwowng, thasi nguyeen"
  ],
  "Phúc Chu, Định Hóa, Thái Nguyên": [
    "phúc chu, định hóa, thái nguyên",
    "phusc chu, ddijnh hosa, thasi nguyeen"
  ],
  "Phúc Thắng, Phúc Yên, Vĩnh Phúc": [
    "phúc thắng, phúc yên, vĩnh phúc",
    "phusc thawsng, phusc yeen, vixnh phusc"
  ],
  "Phúc Trạch, Hương Khê, Hà Tĩnh": [
    "phúc trạch, hương khê, hà tĩnh",
    "phusc trajch, huwowng khee, haf tixnh"
  ],
  "Phúc Đồng, Hương Khê, Hà Tĩnh": [
    "phúc đồng, hương khê, hà tĩnh",
    "phusc ddoofng, huwowng khee, haf tixnh"
  ],
  "Phương Giao, Võ Nhai, Thái Nguyên": [
    "phương giao, võ nhai, thái nguyên",
    "phuwowng giao, vox nhai, thasi nguyeen"
  ],
  "Phương Khoan, Sông Lô, Vĩnh Phúc": [
    "phương khoan, sông lô, vĩnh phúc",
    "phuwowng khoan, soong loo, vixnh phusc"
  ],
  "Phương Liên, Đống Đa, Hà Nội": [
    "phương liên, đống đa, hà nội",
    "phuwowng lieen, ddoosng dda, haf nooji"
  ],
  "Phương Liễu, Quế Võ, Bắc Ninh": [
    "phương liễu, quế võ, bắc ninh",
    "phuwowng lieexu, quees vox, bawsc ninh"
  ],
  "Phương Thiện, Hà Giang, Hà Giang": [
    "phương thiện, hà giang, hà giang",
    "phuwowng thieejn, haf giang, haf giang"
  ],
  "Phước Bình, Bác Ái, Ninh Thuận": [
    "phước bình, bác ái, ninh thuận",
    "phuwowsc bifnh, basc asi, ninh thuaajn"
  ],
  "Phước Hải, Nha Trang, Khánh Hòa": [
    "phước hải, nha trang, khánh hòa",
    "phuwowsc hari, nha trang, khasnh hofa"
  ],
  "Phước Hậu, Cần Giuộc, Long An": [
    "phước hậu, cần giuộc, long an",
    "phuwowsc haaju, caafn giuoojc, long an"
  ],
  "Phước Lại, Cần Giuộc, Long An": [
    "phước lại, cần giuộc, long an",
    "phuwowsc laji, caafn giuoojc, long an"
  ],
  "Phước Ninh, Nông Sơn, Quảng Nam": [
    "phước ninh, nông sơn, quảng nam",
    "phuwowsc ninh, noong sown, quarng nam"
  ],
  "Phước Thạnh, Gò Dầu, Tây Ninh": [
    "phước thạnh, gò dầu, tây ninh",
    "phuwowsc thajnh, gof daafu, taay ninh"
  ],
  "Phước Trung, Bác Ái, Ninh Thuận": [
    "phước trung, bác ái, ninh thuận",
    "phuwowsc trung, basc asi, ninh thuaajn"
  ],
  "Phước Trạch, Gò Dầu, Tây Ninh": [
    "phước trạch, gò dầu, tây ninh",
    "phuwowsc trajch, gof daafu, taay ninh"
  ],
  "Phước Tân, Biên Hòa, Đồng Nai": [
    "phước tân, biên hòa, đồng nai",
    "phuwowsc taan, bieen hofa, ddoofng nai"
  ],
  "Phước Vinh, Châu Thành, Tây Ninh": [
    "phước vinh, châu thành, tây ninh",
    "phuwowsc vinh, chaau thafnh, taay ninh"
  ],
  "Phước Vân, Cần Đước, Long An": [
    "phước vân, cần đước, long an",
    "phuwowsc vaan, caafn dduwowsc, long an"
  ],
  "Phường 01, Quận 3, Hồ Chí Minh": [
    "phường 01, quận 3, hồ chí minh",
    "phuwowfng 01, quaajn 3, hoof chis minh"
  ],
  "Phường 01, Quận 4, Hồ Chí Minh": [
    "phường 01, quận 4, hồ chí minh",
    "phuwowfng 01, quaajn 4, hoof chis minh"
  ],
  "Phường 01, Quận 5, Hồ Chí Minh": [
    "phường 01, quận 5, hồ chí minh",
    "phuwowfng 01, quaajn 5, hoof chis minh"
  ],
  "Phường 01, Quận 6, Hồ Chí Minh": [
    "phường 01, quận 6, hồ chí minh",
    "phuwowfng 01, quaajn 6, hoof chis minh"
  ],
  "Phường 01, Quận 8, Hồ Chí Minh": [
    "phường 01, quận 8, hồ chí minh",
    "phuwowfng 01, quaajn 8, hoof chis minh"
  ],
  "Phường 02, Quận 3, Hồ Chí Minh": [
    "phường 02, quận 3, hồ chí minh",
    "phuwowfng 02, quaajn 3, hoof chis minh"
  ],
  "Phường 02, Quận 4, Hồ Chí Minh": [
    "phường 02, quận 4, hồ chí minh",
    "phuwowfng 02, quaajn 4, hoof chis minh"
  ],
  "Phường 02, Quận 5, Hồ Chí Minh": [
    "phường 02, quận 5, hồ chí minh",
    "phuwowfng 02, quaajn 5, hoof chis minh"
  ],
  "Phường 02, Quận 6, Hồ Chí Minh": [
    "phường 02, quận 6, hồ chí minh",
    "phuwowfng 02, quaajn 6, hoof chis minh"
  ],
  "Phường 02, Quận 8, Hồ Chí Minh": [
    "phường 02, quận 8, hồ chí minh",
    "phuwowfng 02, quaajn 8, hoof chis minh"
  ],
  "Phường 03, Quận 3, Hồ Chí Minh": [
    "phường 03, quận 3, hồ chí minh",
    "phuwowfng 03, quaajn 3, hoof chis minh"
  ],
  "Phường 03, Quận 4, Hồ Chí Minh": [
    "phường 03, quận 4, hồ chí minh",
    "phuwowfng 03, quaajn 4, hoof chis minh"
  ],
  "Phường 03, Quận 5, Hồ Chí Minh": [
    "phường 03, quận 5, hồ chí minh",
    "phuwowfng 03, quaajn 5, hoof chis minh"
  ],
  "Phường 03, Quận 6, Hồ Chí Minh": [
    "phường 03, quận 6, hồ chí minh",
    "phuwowfng 03, quaajn 6, hoof chis minh"
  ],
  "Phường 03, Quận 8, Hồ Chí Minh": [
    "phường 03, quận 8, hồ chí minh",
    "phuwowfng 03, quaajn 8, hoof chis minh"
  ],
  "Phường 04, Quận 3, Hồ Chí Minh": [
    "phường 04, quận 3, hồ chí minh",
    "phuwowfng 04, quaajn 3, hoof chis minh"
  ],
  "Phường 04, Quận 4, Hồ Chí Minh": [
    "phường 04, quận 4, hồ chí minh",
    "phuwowfng 04, quaajn 4, hoof chis minh"
  ],
  "Phường 04, Quận 5, Hồ Chí Minh": [
    "phường 04, quận 5, hồ chí minh",
    "phuwowfng 04, quaajn 5, hoof chis minh"
  ],
  "Phường 04, Quận 6, Hồ Chí Minh": [
    "phường 04, quận 6, hồ chí minh",
    "phuwowfng 04, quaajn 6, hoof chis minh"
  ],
  "Phường 04, Quận 8, Hồ Chí Minh": [
    "phường 04, quận 8, hồ chí minh",
    "phuwowfng 04, quaajn 8, hoof chis minh"
  ],
  "Phường 05, Quận 3, Hồ Chí Minh": [
    "phường 05, quận 3, hồ chí minh",
    "phuwowfng 05, quaajn 3, hoof chis minh"
  ],
  "Phường 05, Quận 4, Hồ Chí Minh": [
    "phường 05, quận 4, hồ chí minh",
    "phuwowfng 05, quaajn 4, hoof chis minh"
  ],
  "Phường 05, Quận 5, Hồ Chí Minh": [
    "phường 05, quận 5, hồ chí minh",
    "phuwowfng 05, quaajn 5, hoof chis minh"
  ],
  "Phường 05, Quận 6, Hồ Chí Minh": [
    "phường 05, quận 6, hồ chí minh",
    "phuwowfng 05, quaajn 6, hoof chis minh"
  ],
  "Phường 05, Quận 8, Hồ Chí Minh": [
    "phường 05, quận 8, hồ chí minh",
    "phuwowfng 05, quaajn 8, hoof chis minh"
  ],
  "Phường 06, Quận 3, Hồ Chí Minh": [
    "phường 06, quận 3, hồ chí minh",
    "phuwowfng 06, quaajn 3, hoof chis minh"
  ],
  "Phường 06, Quận 4, Hồ Chí Minh": [
    "phường 06, quận 4, hồ chí minh",
    "phuwowfng 06, quaajn 4, hoof chis minh"
  ],
  "Phường 06, Quận 5, Hồ Chí Minh": [
    "phường 06, quận 5, hồ chí minh",
    "phuwowfng 06, quaajn 5, hoof chis minh"
  ],
  "Phường 06, Quận 6, Hồ Chí Minh": [
    "phường 06, quận 6, hồ chí minh",
    "phuwowfng 06, quaajn 6, hoof chis minh"
  ],
  "Phường 06, Quận 8, Hồ Chí Minh": [
    "phường 06, quận 8, hồ chí minh",
    "phuwowfng 06, quaajn 8, hoof chis minh"
  ],
  "Phường 07, Quận 3, Hồ Chí Minh": [
    "phường 07, quận 3, hồ chí minh",
    "phuwowfng 07, quaajn 3, hoof chis minh"
  ],
  "Phường 07, Quận 5, Hồ Chí Minh": [
    "phường 07, quận 5, hồ chí minh",
    "phuwowfng 07, quaajn 5, hoof chis minh"
  ],
  "Phường 07, Quận 6, Hồ Chí Minh": [
    "phường 07, quận 6, hồ chí minh",
    "phuwowfng 07, quaajn 6, hoof chis minh"
  ],
  "Phường 07, Quận 8, Hồ Chí Minh": [
    "phường 07, quận 8, hồ chí minh",
    "phuwowfng 07, quaajn 8, hoof chis minh"
  ],
  "Phường 08, Quận 3, Hồ Chí Minh": [
    "phường 08, quận 3, hồ chí minh",
    "phuwowfng 08, quaajn 3, hoof chis minh"
  ],
  "Phường 08, Quận 4, Hồ Chí Minh": [
    "phường 08, quận 4, hồ chí minh",
    "phuwowfng 08, quaajn 4, hoof chis minh"
  ],
  "Phường 08, Quận 5, Hồ Chí Minh": [
    "phường 08, quận 5, hồ chí minh",
    "phuwowfng 08, quaajn 5, hoof chis minh"
  ],
  "Phường 08, Quận 6, Hồ Chí Minh": [
    "phường 08, quận 6, hồ chí minh",
    "phuwowfng 08, quaajn 6, hoof chis minh"
  ],
  "Phường 08, Quận 8, Hồ Chí Minh": [
    "phường 08, quận 8, hồ chí minh",
    "phuwowfng 08, quaajn 8, hoof chis minh"
  ],
  "Phường 09, Quận 3, Hồ Chí Minh": [
    "phường 09, quận 3, hồ chí minh",
    "phuwowfng 09, quaajn 3, hoof chis minh"
  ],
  "Phường 09, Quận 4, Hồ Chí Minh": [
    "phường 09, quận 4, hồ chí minh",
    "phuwowfng 09, quaajn 4, hoof chis minh"
  ],
  "Phường 09, Quận 5, Hồ Chí Minh": [
    "phường 09, quận 5, hồ chí minh",
    "phuwowfng 09, quaajn 5, hoof chis minh"
  ],
  "Phường 09, Quận 6, Hồ Chí Minh": [
    "phường 09, quận 6, hồ chí minh",
    "phuwowfng 09, quaajn 6, hoof chis minh"
  ],
  "Phường 09, Quận 8, Hồ Chí Minh": [
    "phường 09, quận 8, hồ chí minh",
    "phuwowfng 09, quaajn 8, hoof chis minh"
  ],
  "Phường 1, Bảo Lộc, Lâm Đồng": [
    "phường 1, bảo lộc, lâm đồng",
    "phuwowfng 1, baro loojc, laam ddoofng"
  ],
  "Phường 1, Đông Hà, Quảng Trị": [
    "phường 1, đông hà, quảng trị",
    "phuwowfng 1, ddoong haf, quarng trij"
  ],
  "Phường 10, Quận 3, Hồ Chí Minh": [
    "phường 10, quận 3, hồ chí minh",
    "phuwowfng 10, quaajn 3, hoof chis minh"
  ],
  "Phường 10, Quận 4, Hồ Chí Minh": [
    "phường 10, quận 4, hồ chí minh",
    "phuwowfng 10, quaajn 4, hoof chis minh"
  ],
  "Phường 10, Quận 5, Hồ Chí Minh": [
    "phường 10, quận 5, hồ chí minh",
    "phuwowfng 10, quaajn 5, hoof chis minh"
  ],
  "Phường 10, Quận 6, Hồ Chí Minh": [
    "phường 10, quận 6, hồ chí minh",
    "phuwowfng 10, quaajn 6, hoof chis minh"
  ],
  "Phường 10, Quận 8, Hồ Chí Minh": [
    "phường 10, quận 8, hồ chí minh",
    "phuwowfng 10, quaajn 8, hoof chis minh"
  ],
  "Phường 10, Sóc Trăng, Sóc Trăng": [
    "phường 10, sóc trăng, sóc trăng",
    "phuwowfng 10, sosc trawng, sosc trawng"
  ],
  "Phường 10, Đà Lạt, Lâm Đồng": [
    "phường 10, đà lạt, lâm đồng",
    "phuwowfng 10, ddaf lajt, laam ddoofng"
  ],
  "Phường 11, Cao Lãnh, Đồng Tháp": [
    "phường 11, cao lãnh, đồng tháp",
    "phuwowfng 11, cao laxnh, ddoofng thasp"
  ],
  "Phường 11, Quận 3, Hồ Chí Minh": [
    "phường 11, quận 3, hồ chí minh",
    "phuwowfng 11, quaajn 3, hoof chis minh"
  ],
  "Phường 11, Quận 5, Hồ Chí Minh": [
    "phường 11, quận 5, hồ chí minh",
    "phuwowfng 11, quaajn 5, hoof chis minh"
  ],
  "Phường 11, Quận 6, Hồ Chí Minh": [
    "phường 11, quận 6, hồ chí minh",
    "phuwowfng 11, quaajn 6, hoof chis minh"
  ],
  "Phường 11, Quận 8, Hồ Chí Minh": [
    "phường 11, quận 8, hồ chí minh",
    "phuwowfng 11, quaajn 8, hoof chis minh"
  ],
  "Phường 11, Đà Lạt, Lâm Đồng": [
    "phường 11, đà lạt, lâm đồng",
    "phuwowfng 11, ddaf lajt, laam ddoofng"
  ],
  "Phường 12, Quận 3, Hồ Chí Minh": [
    "phường 12, quận 3, hồ chí minh",
    "phuwowfng 12, quaajn 3, hoof chis minh"
  ],
  "Phường 12, Quận 4, Hồ Chí Minh": [
    "phường 12, quận 4, hồ chí minh",
    "phuwowfng 12, quaajn 4, hoof chis minh"
  ],
  "Phường 12, Quận 5, Hồ Chí Minh": [
    "phường 12, quận 5, hồ chí minh",
    "phuwowfng 12, quaajn 5, hoof chis minh"
  ],
  "Phường 12, Quận 6, Hồ Chí Minh": [
    "phường 12, quận 6, hồ chí minh",
    "phuwowfng 12, quaajn 6, hoof chis minh"
  ],
  "Phường 12, Quận 8, Hồ Chí Minh": [
    "phường 12, quận 8, hồ chí minh",
    "phuwowfng 12, quaajn 8, hoof chis minh"
  ],
  "Phường 12, Đà Lạt, Lâm Đồng": [
    "phường 12, đà lạt, lâm đồng",
    "phuwowfng 12, ddaf lajt, laam ddoofng"
  ],
  "Phường 13, Quận 3, Hồ Chí Minh": [
    "phường 13, quận 3, hồ chí minh",
    "phuwowfng 13, quaajn 3, hoof chis minh"
  ],
  "Phường 13, Quận 4, Hồ Chí Minh": [
    "phường 13, quận 4, hồ chí minh",
    "phuwowfng 13, quaajn 4, hoof chis minh"
  ],
  "Phường 13, Quận 5, Hồ Chí Minh": [
    "phường 13, quận 5, hồ chí minh",
    "phuwowfng 13, quaajn 5, hoof chis minh"
  ],
  "Phường 13, Quận 6, Hồ Chí Minh": [
    "phường 13, quận 6, hồ chí minh",
    "phuwowfng 13, quaajn 6, hoof chis minh"
  ],
  "Phường 13, Quận 8, Hồ Chí Minh": [
    "phường 13, quận 8, hồ chí minh",
    "phuwowfng 13, quaajn 8, hoof chis minh"
  ],
  "Phường 14, Quận 3, Hồ Chí Minh": [
    "phường 14, quận 3, hồ chí minh",
    "phuwowfng 14, quaajn 3, hoof chis minh"
  ],
  "Phường 14, Quận 4, Hồ Chí Minh": [
    "phường 14, quận 4, hồ chí minh",
    "phuwowfng 14, quaajn 4, hoof chis minh"
  ],
  "Phường 14, Quận 5, Hồ Chí Minh": [
    "phường 14, quận 5, hồ chí minh",
    "phuwowfng 14, quaajn 5, hoof chis minh"
  ],
  "Phường 14, Quận 6, Hồ Chí Minh": [
    "phường 14, quận 6, hồ chí minh",
    "phuwowfng 14, quaajn 6, hoof chis minh"
  ],
  "Phường 14, Quận 8, Hồ Chí Minh": [
    "phường 14, quận 8, hồ chí minh",
    "phuwowfng 14, quaajn 8, hoof chis minh"
  ],
  "Phường 15, Quận 4, Hồ Chí Minh": [
    "phường 15, quận 4, hồ chí minh",
    "phuwowfng 15, quaajn 4, hoof chis minh"
  ],
  "Phường 15, Quận 5, Hồ Chí Minh": [
    "phường 15, quận 5, hồ chí minh",
    "phuwowfng 15, quaajn 5, hoof chis minh"
  ],
  "Phường 15, Quận 8, Hồ Chí Minh": [
    "phường 15, quận 8, hồ chí minh",
    "phuwowfng 15, quaajn 8, hoof chis minh"
  ],
  "Phường 16, Quận 4, Hồ Chí Minh": [
    "phường 16, quận 4, hồ chí minh",
    "phuwowfng 16, quaajn 4, hoof chis minh"
  ],
  "Phường 16, Quận 8, Hồ Chí Minh": [
    "phường 16, quận 8, hồ chí minh",
    "phuwowfng 16, quaajn 8, hoof chis minh"
  ],
  "Phường 18, Quận 4, Hồ Chí Minh": [
    "phường 18, quận 4, hồ chí minh",
    "phuwowfng 18, quaajn 4, hoof chis minh"
  ],
  "Phường 2, Bảo Lộc, Lâm Đồng": [
    "phường 2, bảo lộc, lâm đồng",
    "phuwowfng 2, baro loojc, laam ddoofng"
  ],
  "Phường 2, Đông Hà, Quảng Trị": [
    "phường 2, đông hà, quảng trị",
    "phuwowfng 2, ddoong haf, quarng trij"
  ],
  "Phường 3, Đông Hà, Quảng Trị": [
    "phường 3, đông hà, quảng trị",
    "phuwowfng 3, ddoong haf, quarng trij"
  ],
  "Phường 4, Đông Hà, Quảng Trị": [
    "phường 4, đông hà, quảng trị",
    "phuwowfng 4, ddoong haf, quarng trij"
  ],
  "Phường 5, Đông Hà, Quảng Trị": [
    "phường 5, đông hà, quảng trị",
    "phuwowfng 5, ddoong haf, quarng trij"
  ],
  "Phường 6, Gò Vấp, Hồ Chí Minh": [
    "phường 6, gò vấp, hồ chí minh",
    "phuwowfng 6, gof vaasp, hoof chis minh"
  ],
  "Phường 8, Gò Vấp, Hồ Chí Minh": [
    "phường 8, gò vấp, hồ chí minh",
    "phuwowfng 8, gof vaasp, hoof chis minh"
  ],
  "Phường 9, Gò Vấp, Hồ Chí Minh": [
    "phường 9, gò vấp, hồ chí minh",
    "phuwowfng 9, gof vaasp, hoof chis minh"
  ],
  "Phượng Cách, Quốc Oai, Hà Nội": [
    "phượng cách, quốc oai, hà nội",
    "phuwowjng casch, quoosc oai, haf nooji"
  ],
  "Phượng Nghi, Như Thanh, Thanh Hóa": [
    "phượng nghi, như thanh, thanh hóa",
    "phuwowjng nghi, nhuw thanh, thanh hosa"
  ],
  "Phạm Thái, Kinh Môn, Hải Dương": [
    "phạm thái, kinh môn, hải dương",
    "phajm thasi, kinh moon, hari duwowng"
  ],
  "Phố Huế, Hai Bà Trưng, Hà Nội": [
    "phố huế, hai bà trưng, hà nội",
    "phoos huees, hai baf truwng, haf nooji"
  ],
  "Phủ Lý, Phú Lương, Thái Nguyên": [
    "phủ lý, phú lương, thái nguyên",
    "phur lys, phus luwowng, thasi nguyeen"
  ],
  "Pom Lót, Điện Biên, Điện Biên": [
    "pom lót, điện biên, điện biên",
    "pom lost, ddieejn bieen, ddieejn bieen"
  ],
  "Pá Mỳ, Mường Nhé, Điện Biên": [
    "pá mỳ, mường nhé, điện biên",
    "pas myf, muwowfng nhes, ddieejn bieen"
  ],
  "Pú Nhung, Tuần Giáo, Điện Biên": [
    "pú nhung, tuần giáo, điện biên",
    "pus nhung, tuaafn giaso, ddieejn bieen"
  ],
  "Pơng Drang, Krông Búk, Đắk Lắk": [
    "pơng drang, krông búk, đắk lắk",
    "powng drang, kroong busk, ddawsk lawsk"
  ],
  "Quang Khải, Tứ Kỳ, Hải Dương": [
    "quang khải, tứ kỳ, hải dương",
    "quang khari, tuws kyf, hari duwowng"
  ],
  "Quang Phục, Tứ Kỳ, Hải Dương": [
    "quang phục, tứ kỳ, hải dương",
    "quang phujc, tuws kyf, hari duwowng"
  ],
  "Quang Sơn, Lập Thạch, Vĩnh Phúc": [
    "quang sơn, lập thạch, vĩnh phúc",
    "quang sown, laajp thajch, vixnh phusc"
  ],
  "Quang Thành, Kinh Môn, Hải Dương": [
    "quang thành, kinh môn, hải dương",
    "quang thafnh, kinh moon, hari duwowng"
  ],
  "Quang Trung, Trùng Khánh, Cao Bằng": [
    "quang trung, trùng khánh, cao bằng",
    "quang trung, trufng khasnh, cao bawfng"
  ],
  "Quyết Tiến, Quản Bạ, Hà Giang": [
    "quyết tiến, quản bạ, hà giang",
    "quyeest tieesn, quarn baj, haf giang"
  ],
  "Quán Toan, Hồng Bàng, Hải Phòng": [
    "quán toan, hồng bàng, hải phòng",
    "quasn toan, hoofng bafng, hari phofng"
  ],
  "Quê Mỹ Thạnh, Tân Trụ, Long An": [
    "quê mỹ thạnh, tân trụ, long an",
    "quee myx thajnh, taan truj, long an"
  ],
  "Quảng Bị, Chương Mỹ, Hà Nội": [
    "quảng bị, chương mỹ, hà nội",
    "quarng bij, chuwowng myx, haf nooji"
  ],
  "Quảng Hòa, Ba Đồn, Quảng Bình": [
    "quảng hòa, ba đồn, quảng bình",
    "quarng hofa, ba ddoofn, quarng bifnh"
  ],
  "Quảng Long, Ba Đồn, Quảng Bình": [
    "quảng long, ba đồn, quảng bình",
    "quarng long, ba ddoofn, quarng bifnh"
  ],
  "Quảng Lâm, Đầm Hà, Quảng Ninh": [
    "quảng lâm, đầm hà, quảng ninh",
    "quarng laam, ddaafm haf, quarng ninh"
  ],
  "Quảng Minh, Ba Đồn, Quảng Bình": [
    "quảng minh, ba đồn, quảng bình",
    "quarng minh, ba ddoofn, quarng bifnh"
  ],
  "Quảng Minh, Việt Yên, Bắc Giang": [
    "quảng minh, việt yên, bắc giang",
    "quarng minh, vieejt yeen, bawsc giang"
  ],
  "Quảng Nguyên, Xín Mần, Hà Giang": [
    "quảng nguyên, xín mần, hà giang",
    "quarng nguyeen, xisn maafn, haf giang"
  ],
  "Quảng Ngần, Vị Xuyên, Hà Giang": [
    "quảng ngần, vị xuyên, hà giang",
    "quarng ngaafn, vij xuyeen, haf giang"
  ],
  "Quảng Phong, Hải Hà, Quảng Ninh": [
    "quảng phong, hải hà, quảng ninh",
    "quarng phong, hari haf, quarng ninh"
  ],
  "Quảng Phú, Krông Nô, Đắk Nông": [
    "quảng phú, krông nô, đắk nông",
    "quarng phus, kroong noo, ddawsk noong"
  ],
  "Quảng Phú, Lương Tài, Bắc Ninh": [
    "quảng phú, lương tài, bắc ninh",
    "quarng phus, luwowng tafi, bawsc ninh"
  ],
  "Quảng Sơn, Ba Đồn, Quảng Bình": [
    "quảng sơn, ba đồn, quảng bình",
    "quarng sown, ba ddoofn, quarng bifnh"
  ],
  "Quảng Thành, Thanh Hóa, Thanh Hóa": [
    "quảng thành, thanh hóa, thanh hóa",
    "quarng thafnh, thanh hosa, thanh hosa"
  ],
  "Quảng Tiến, Sầm Sơn, Thanh Hóa": [
    "quảng tiến, sầm sơn, thanh hóa",
    "quarng tieesn, saafm sown, thanh hosa"
  ],
  "Quảng Tâm, Tuy Đức, Đắk Nông": [
    "quảng tâm, tuy đức, đắk nông",
    "quarng taam, tuy dduwsc, ddawsk noong"
  ],
  "Quảng Tân, Ba Đồn, Quảng Bình": [
    "quảng tân, ba đồn, quảng bình",
    "quarng taan, ba ddoofn, quarng bifnh"
  ],
  "Quảng Tân, Tuy Đức, Đắk Nông": [
    "quảng tân, tuy đức, đắk nông",
    "quarng taan, tuy dduwsc, ddawsk noong"
  ],
  "Quảng Tân, Đầm Hà, Quảng Ninh": [
    "quảng tân, đầm hà, quảng ninh",
    "quarng taan, ddaafm haf, quarng ninh"
  ],
  "Quảng Văn, Ba Đồn, Quảng Bình": [
    "quảng văn, ba đồn, quảng bình",
    "quarng vawn, ba ddoofn, quarng bifnh"
  ],
  "Quảng Đông, Thanh Hóa, Thanh Hóa": [
    "quảng đông, thanh hóa, thanh hóa",
    "quarng ddoong, thanh hosa, thanh hosa"
  ],
  "Quảng Đại, Sầm Sơn, Thanh Hóa": [
    "quảng đại, sầm sơn, thanh hóa",
    "quarng ddaji, saafm sown, thanh hosa"
  ],
  "Quất Lưu, Bình Xuyên, Vĩnh Phúc": [
    "quất lưu, bình xuyên, vĩnh phúc",
    "quaast luwu, bifnh xuyeen, vixnh phusc"
  ],
  "Quế Lưu, Hiệp Đức, Quảng Nam": [
    "quế lưu, hiệp đức, quảng nam",
    "quees luwu, hieejp dduwsc, quarng nam"
  ],
  "Quế Thuận, Quế Sơn, Quảng Nam": [
    "quế thuận, quế sơn, quảng nam",
    "quees thuaajn, quees sown, quarng nam"
  ],
  "Quế Xuân 1, Quế Sơn, Quảng Nam": [
    "quế xuân 1, quế sơn, quảng nam",
    "quees xuaan 1, quees sown, quarng nam"
  ],
  "Quế Xuân 2, Quế Sơn, Quảng Nam": [
    "quế xuân 2, quế sơn, quảng nam",
    "quees xuaan 2, quees sown, quarng nam"
  ],
  "Quới Thành, Châu Thành, Bến Tre": [
    "quới thành, châu thành, bến tre",
    "quowsi thafnh, chaau thafnh, beesn tre"
  ],
  "Quỳnh Châu, Quỳnh Lưu, Nghệ An": [
    "quỳnh châu, quỳnh lưu, nghệ an",
    "quyfnh chaau, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Giang, Quỳnh Lưu, Nghệ An": [
    "quỳnh giang, quỳnh lưu, nghệ an",
    "quyfnh giang, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Hưng, Quỳnh Lưu, Nghệ An": [
    "quỳnh hưng, quỳnh lưu, nghệ an",
    "quyfnh huwng, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Hậu, Quỳnh Lưu, Nghệ An": [
    "quỳnh hậu, quỳnh lưu, nghệ an",
    "quyfnh haaju, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Mai, Hai Bà Trưng, Hà Nội": [
    "quỳnh mai, hai bà trưng, hà nội",
    "quyfnh mai, hai baf truwng, haf nooji"
  ],
  "Quỳnh Thanh, Quỳnh Lưu, Nghệ An": [
    "quỳnh thanh, quỳnh lưu, nghệ an",
    "quyfnh thanh, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Thiện, Hoàng Mai, Nghệ An": [
    "quỳnh thiện, hoàng mai, nghệ an",
    "quyfnh thieejn, hoafng mai, ngheej an"
  ],
  "Quỳnh Thọ, Quỳnh Lưu, Nghệ An": [
    "quỳnh thọ, quỳnh lưu, nghệ an",
    "quyfnh thoj, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Đôi, Quỳnh Lưu, Nghệ An": [
    "quỳnh đôi, quỳnh lưu, nghệ an",
    "quyfnh ddooi, quyfnh luwu, ngheej an"
  ],
  "Rạch Sỏi, Rạch Giá, Kiên Giang": [
    "rạch sỏi, rạch giá, kiên giang",
    "rajch sori, rajch gias, kieen giang"
  ],
  "Rừng Thông, Đông Sơn, Thanh Hóa": [
    "rừng thông, đông sơn, thanh hóa",
    "ruwfng thoong, ddoong sown, thanh hosa"
  ],
  "Sa Lông, Mường Chà, Điện Biên": [
    "sa lông, mường chà, điện biên",
    "sa loong, muwowfng chaf, ddieejn bieen"
  ],
  "Sen Thủy, Lệ Thủy, Quảng Bình": [
    "sen thủy, lệ thủy, quảng bình",
    "sen thury, leej thury, quarng bifnh"
  ],
  "Si Pa Phìn, Nậm Pồ, Điện Biên": [
    "si pa phìn, nậm pồ, điện biên",
    "si pa phifn, naajm poof, ddieejn bieen"
  ],
  "Song Phương, Hoài Đức, Hà Nội": [
    "song phương, hoài đức, hà nội",
    "song phuwowng, hoafi dduwsc, haf nooji"
  ],
  "Suối Nho, Định Quán, Đồng Nai": [
    "suối nho, định quán, đồng nai",
    "suoosi nho, ddijnh quasn, ddoofng nai"
  ],
  "Suối Quyền, Văn Chấn, Yên Bái": [
    "suối quyền, văn chấn, yên bái",
    "suoosi quyeefn, vawn chaasn, yeen basi"
  ],
  "Sáng Nhè, Tủa Chùa, Điện Biên": [
    "sáng nhè, tủa chùa, điện biên",
    "sasng nhef, tura chufa, ddieejn bieen"
  ],
  "Sì Lở Lầu, Phong Thổ, Lai Châu": [
    "sì lở lầu, phong thổ, lai châu",
    "sif lowr laafu, phong thoor, lai chaau"
  ],
  "Sông Cầu, Khánh Vĩnh, Khánh Hòa": [
    "sông cầu, khánh vĩnh, khánh hòa",
    "soong caafu, khasnh vixnh, khasnh hofa"
  ],
  "Sông Lũy, Bắc Bình, Bình Thuận": [
    "sông lũy, bắc bình, bình thuận",
    "soong luxy, bawsc bifnh, bifnh thuaajn"
  ],
  "Sông Trà, Hiệp Đức, Quảng Nam": [
    "sông trà, hiệp đức, quảng nam",
    "soong traf, hieejp dduwsc, quarng nam"
  ],
  "Sông Trầu, Trảng Bom, Đồng Nai": [
    "sông trầu, trảng bom, đồng nai",
    "soong traafu, trarng bom, ddoofng nai"
  ],
  "Sơn Hải, Kiên Lương, Kiên Giang": [
    "sơn hải, kiên lương, kiên giang",
    "sown hari, kieen luwowng, kieen giang"
  ],
  "Sơn Phú, Định Hóa, Thái Nguyên": [
    "sơn phú, định hóa, thái nguyên",
    "sown phus, ddijnh hosa, thasi nguyeen"
  ],
  "Sơn Thành Tây, Tây Hoà, Phú Yên": [
    "sơn thành tây, tây hoà, phú yên",
    "sown thafnh taay, taay hoaf, phus yeen"
  ],
  "Sảng Tủng, Đồng Văn, Hà Giang": [
    "sảng tủng, đồng văn, hà giang",
    "sarng turng, ddoofng vawn, haf giang"
  ],
  "Sở Dầu, Hồng Bàng, Hải Phòng": [
    "sở dầu, hồng bàng, hải phòng",
    "sowr daafu, hoofng bafng, hari phofng"
  ],
  "Tam Giang Tây, Ngọc Hiển, Cà Mau": [
    "tam giang tây, ngọc hiển, cà mau",
    "tam giang taay, ngojc hieern, caf mau"
  ],
  "Tam Hiệp, Châu Thành, Tiền Giang": [
    "tam hiệp, châu thành, tiền giang",
    "tam hieejp, chaau thafnh, tieefn giang"
  ],
  "Tam Phú, Thủ Đức, Hồ Chí Minh": [
    "tam phú, thủ đức, hồ chí minh",
    "tam phus, thur dduwsc, hoof chis minh"
  ],
  "Tam Phúc, Vĩnh Tường, Vĩnh Phúc": [
    "tam phúc, vĩnh tường, vĩnh phúc",
    "tam phusc, vixnh tuwowfng, vixnh phusc"
  ],
  "Tam Xuân II, Núi Thành, Quảng Nam": [
    "tam xuân ii, núi thành, quảng nam",
    "tam xuaan ii, nusi thafnh, quarng nam"
  ],
  "Tam Đình, Tương Dương, Nghệ An": [
    "tam đình, tương dương, nghệ an",
    "tam ddifnh, tuwowng duwowng, ngheej an"
  ],
  "Thanh An, Dầu Tiếng, Bình Dương": [
    "thanh an, dầu tiếng, bình dương",
    "thanh an, daafu tieesng, bifnh duwowng"
  ],
  "Thanh An, Hớn Quản, Bình Phước": [
    "thanh an, hớn quản, bình phước",
    "thanh an, howsn quarn, bifnh phuwowsc"
  ],
  "Thanh An, Điện Biên, Điện Biên": [
    "thanh an, điện biên, điện biên",
    "thanh an, ddieejn bieen, ddieejn bieen"
  ],
  "Thanh Bình, Chợ Gạo, Tiền Giang": [
    "thanh bình, chợ gạo, tiền giang",
    "thanh bifnh, chowj gajo, tieefn giang"
  ],
  "Thanh Giang, Thanh Chương, Nghệ An": [
    "thanh giang, thanh chương, nghệ an",
    "thanh giang, thanh chuwowng, ngheej an"
  ],
  "Thanh Hòa, Bù Đốp, Bình Phước": [
    "thanh hòa, bù đốp, bình phước",
    "thanh hofa, buf ddoosp, bifnh phuwowsc"
  ],
  "Thanh Hóa, Tuyên Hóa, Quảng Bình": [
    "thanh hóa, tuyên hóa, quảng bình",
    "thanh hosa, tuyeen hosa, quarng bifnh"
  ],
  "Thanh Hải, Lục Ngạn, Bắc Giang": [
    "thanh hải, lục ngạn, bắc giang",
    "thanh hari, lujc ngajn, bawsc giang"
  ],
  "Thanh Hồng, Thanh Hà, Hải Dương": [
    "thanh hồng, thanh hà, hải dương",
    "thanh hoofng, thanh haf, hari duwowng"
  ],
  "Thanh Liên, Thanh Chương, Nghệ An": [
    "thanh liên, thanh chương, nghệ an",
    "thanh lieen, thanh chuwowng, ngheej an"
  ],
  "Thanh Lãng, Bình Xuyên, Vĩnh Phúc": [
    "thanh lãng, bình xuyên, vĩnh phúc",
    "thanh laxng, bifnh xuyeen, vixnh phusc"
  ],
  "Thanh Lĩnh, Thanh Chương, Nghệ An": [
    "thanh lĩnh, thanh chương, nghệ an",
    "thanh lixnh, thanh chuwowng, ngheej an"
  ],
  "Thanh Nhàn, Hai Bà Trưng, Hà Nội": [
    "thanh nhàn, hai bà trưng, hà nội",
    "thanh nhafn, hai baf truwng, haf nooji"
  ],
  "Thanh Phong, Thanh Chương, Nghệ An": [
    "thanh phong, thanh chương, nghệ an",
    "thanh phong, thanh chuwowng, ngheej an"
  ],
  "Thanh Phú Long, Châu Thành, Long An": [
    "thanh phú long, châu thành, long an",
    "thanh phus long, chaau thafnh, long an"
  ],
  "Thanh Phú, Bình Long, Bình Phước": [
    "thanh phú, bình long, bình phước",
    "thanh phus, bifnh long, bifnh phuwowsc"
  ],
  "Thanh Sơn, Định Quán, Đồng Nai": [
    "thanh sơn, định quán, đồng nai",
    "thanh sown, ddijnh quasn, ddoofng nai"
  ],
  "Thanh Thủy, Thanh Hà, Hải Dương": [
    "thanh thủy, thanh hà, hải dương",
    "thanh thury, thanh haf, hari duwowng"
  ],
  "Thanh Thủy, Thanh Thuỷ, Phú Thọ": [
    "thanh thủy, thanh thuỷ, phú thọ",
    "thanh thury, thanh thuyr, phus thoj"
  ],
  "Thanh Tiên, Thanh Chương, Nghệ An": [
    "thanh tiên, thanh chương, nghệ an",
    "thanh tieen, thanh chuwowng, ngheej an"
  ],
  "Thanh Tân, Mỏ Cày Bắc, Bến Tre": [
    "thanh tân, mỏ cày bắc, bến tre",
    "thanh taan, mor cafy bawsc, beesn tre"
  ],
  "Thanh Tùng, Thanh Chương, Nghệ An": [
    "thanh tùng, thanh chương, nghệ an",
    "thanh tufng, thanh chuwowng, ngheej an"
  ],
  "Thanh Xuân, Thanh Chương, Nghệ An": [
    "thanh xuân, thanh chương, nghệ an",
    "thanh xuaan, thanh chuwowng, ngheej an"
  ],
  "Thanh Điền, Châu Thành, Tây Ninh": [
    "thanh điền, châu thành, tây ninh",
    "thanh ddieefn, chaau thafnh, taay ninh"
  ],
  "Thiết Kế, Bá Thước, Thanh Hóa": [
    "thiết kế, bá thước, thanh hóa",
    "thieest kees, bas thuwowsc, thanh hosa"
  ],
  "Thiện Tân, Hữu Lũng, Lạng Sơn": [
    "thiện tân, hữu lũng, lạng sơn",
    "thieejn taan, huwxu luxng, lajng sown"
  ],
  "Thiện Tân, Vĩnh Cửu, Đồng Nai": [
    "thiện tân, vĩnh cửu, đồng nai",
    "thieejn taan, vixnh cuwru, ddoofng nai"
  ],
  "Thiệu Giao, Thiệu Hóa, Thanh Hóa": [
    "thiệu giao, thiệu hóa, thanh hóa",
    "thieeju giao, thieeju hosa, thanh hosa"
  ],
  "Thiệu Hòa, Thiệu Hóa, Thanh Hóa": [
    "thiệu hòa, thiệu hóa, thanh hóa",
    "thieeju hofa, thieeju hosa, thanh hosa"
  ],
  "Thiệu Hóa, Thiệu Hóa, Thanh Hóa": [
    "thiệu hóa, thiệu hóa, thanh hóa",
    "thieeju hosa, thieeju hosa, thanh hosa"
  ],
  "Thiệu Khánh, Thanh Hóa, Thanh Hóa": [
    "thiệu khánh, thanh hóa, thanh hóa",
    "thieeju khasnh, thanh hosa, thanh hosa"
  ],
  "Thiệu Long, Thiệu Hóa, Thanh Hóa": [
    "thiệu long, thiệu hóa, thanh hóa",
    "thieeju long, thieeju hosa, thanh hosa"
  ],
  "Thiệu Phú, Thiệu Hóa, Thanh Hóa": [
    "thiệu phú, thiệu hóa, thanh hóa",
    "thieeju phus, thieeju hosa, thanh hosa"
  ],
  "Thuần Lộc, Hậu Lộc, Thanh Hóa": [
    "thuần lộc, hậu lộc, thanh hóa",
    "thuaafn loojc, haaju loojc, thanh hosa"
  ],
  "Thuận Hà, Đắk Song, Đắk Nông": [
    "thuận hà, đắk song, đắk nông",
    "thuaajn haf, ddawsk song, ddawsk noong"
  ],
  "Thuận Lộc, Hồng Lĩnh, Hà Tĩnh": [
    "thuận lộc, hồng lĩnh, hà tĩnh",
    "thuaajn loojc, hoofng lixnh, haf tixnh"
  ],
  "Thuận Thành, Cần Giuộc, Long An": [
    "thuận thành, cần giuộc, long an",
    "thuaajn thafnh, caafn giuoojc, long an"
  ],
  "Thàng Tín, Hoàng Su Phì, Hà Giang": [
    "thàng tín, hoàng su phì, hà giang",
    "thafng tisn, hoafng su phif, haf giang"
  ],
  "Thành Công, Khoái Châu, Hưng Yên": [
    "thành công, khoái châu, hưng yên",
    "thafnh coong, khoasi chaau, huwng yeen"
  ],
  "Thái Bình, Đình Lập, Lạng Sơn": [
    "thái bình, đình lập, lạng sơn",
    "thasi bifnh, ddifnh laajp, lajng sown"
  ],
  "Thái Cường, Thạch An, Cao Bằng": [
    "thái cường, thạch an, cao bằng",
    "thasi cuwowfng, thajch an, cao bawfng"
  ],
  "Thái Giang, Thái Thụy, Thái Bình": [
    "thái giang, thái thụy, thái bình",
    "thasi giang, thasi thujy, thasi bifnh"
  ],
  "Thái Hòa, Bình Giang, Hải Dương": [
    "thái hòa, bình giang, hải dương",
    "thasi hofa, bifnh giang, hari duwowng"
  ],
  "Thái Hòa, Lập Thạch, Vĩnh Phúc": [
    "thái hòa, lập thạch, vĩnh phúc",
    "thasi hofa, laajp thajch, vixnh phusc"
  ],
  "Thái Hưng, Thái Thụy, Thái Bình": [
    "thái hưng, thái thụy, thái bình",
    "thasi huwng, thasi thujy, thasi bifnh"
  ],
  "Thái Long, Tuyên Quang, Tuyên Quang": [
    "thái long, tuyên quang, tuyên quang",
    "thasi long, tuyeen quang, tuyeen quang"
  ],
  "Thái Phúc, Thái Thụy, Thái Bình": [
    "thái phúc, thái thụy, thái bình",
    "thasi phusc, thasi thujy, thasi bifnh"
  ],
  "Thái Phương, Hưng Hà, Thái Bình": [
    "thái phương, hưng hà, thái bình",
    "thasi phuwowng, huwng haf, thasi bifnh"
  ],
  "Thái Thọ, Thái Thụy, Thái Bình": [
    "thái thọ, thái thụy, thái bình",
    "thasi thoj, thasi thujy, thasi bifnh"
  ],
  "Thái Đào, Lạng Giang, Bắc Giang": [
    "thái đào, lạng giang, bắc giang",
    "thasi ddafo, lajng giang, bawsc giang"
  ],
  "Thăng Bình, Nông Cống, Thanh Hóa": [
    "thăng bình, nông cống, thanh hóa",
    "thawng bifnh, noong coosng, thanh hosa"
  ],
  "Thăng Long, Đông Hưng, Thái Bình": [
    "thăng long, đông hưng, thái bình",
    "thawng long, ddoong huwng, thasi bifnh"
  ],
  "Thăng Thọ, Nông Cống, Thanh Hóa": [
    "thăng thọ, nông cống, thanh hóa",
    "thawng thoj, noong coosng, thanh hosa"
  ],
  "Thượng Giáp, Na Hang, Tuyên Quang": [
    "thượng giáp, na hang, tuyên quang",
    "thuwowjng giasp, na hang, tuyeen quang"
  ],
  "Thượng Hà, Bảo Lạc, Cao Bằng": [
    "thượng hà, bảo lạc, cao bằng",
    "thuwowjng haf, baro lajc, cao bawfng"
  ],
  "Thượng Kiệm, Kim Sơn, Ninh Bình": [
    "thượng kiệm, kim sơn, ninh bình",
    "thuwowjng kieejm, kim sown, ninh bifnh"
  ],
  "Thượng Long, Yên Lập, Phú Thọ": [
    "thượng long, yên lập, phú thọ",
    "thuwowjng long, yeen laajp, phus thoj"
  ],
  "Thượng Lâm, Mỹ Đức, Hà Nội": [
    "thượng lâm, mỹ đức, hà nội",
    "thuwowjng laam, myx dduwsc, haf nooji"
  ],
  "Thượng Ninh, Như Xuân, Thanh Hóa": [
    "thượng ninh, như xuân, thanh hóa",
    "thuwowjng ninh, nhuw xuaan, thanh hosa"
  ],
  "Thượng Nông, Na Hang, Tuyên Quang": [
    "thượng nông, na hang, tuyên quang",
    "thuwowjng noong, na hang, tuyeen quang"
  ],
  "Thượng Sơn, Vị Xuyên, Hà Giang": [
    "thượng sơn, vị xuyên, hà giang",
    "thuwowjng sown, vij xuyeen, haf giang"
  ],
  "Thượng Thanh, Long Biên, Hà Nội": [
    "thượng thanh, long biên, hà nội",
    "thuwowjng thanh, long bieen, haf nooji"
  ],
  "Thượng Ân, Ngân Sơn, Bắc Kạn": [
    "thượng ân, ngân sơn, bắc kạn",
    "thuwowjng aan, ngaan sown, bawsc kajn"
  ],
  "Thạch Khoán, Thanh Sơn, Phú Thọ": [
    "thạch khoán, thanh sơn, phú thọ",
    "thajch khoasn, thanh sown, phus thoj"
  ],
  "Thạch Ngọc, Thạch Hà, Hà Tĩnh": [
    "thạch ngọc, thạch hà, hà tĩnh",
    "thajch ngojc, thajch haf, haf tixnh"
  ],
  "Thạch Xá, Thạch Thất, Hà Nội": [
    "thạch xá, thạch thất, hà nội",
    "thajch xas, thajch thaast, haf nooji"
  ],
  "Thạch Đạn, Cao Lộc, Lạng Sơn": [
    "thạch đạn, cao lộc, lạng sơn",
    "thajch ddajn, cao loojc, lajng sown"
  ],
  "Thạnh Hoà, Thốt Nốt, Cần Thơ": [
    "thạnh hoà, thốt nốt, cần thơ",
    "thajnh hoaf, thoost noost, caafn thow"
  ],
  "Thạnh Hải, Thạnh Phú, Bến Tre": [
    "thạnh hải, thạnh phú, bến tre",
    "thajnh hari, thajnh phus, beesn tre"
  ],
  "Thạnh Lộc, Cai Lậy, Tiền Giang": [
    "thạnh lộc, cai lậy, tiền giang",
    "thajnh loojc, cai laajy, tieefn giang"
  ],
  "Thạnh Phong, Thạnh Phú, Bến Tre": [
    "thạnh phong, thạnh phú, bến tre",
    "thajnh phong, thajnh phus, beesn tre"
  ],
  "Thạnh Phú, Mỹ Xuyên, Sóc Trăng": [
    "thạnh phú, mỹ xuyên, sóc trăng",
    "thajnh phus, myx xuyeen, sosc trawng"
  ],
  "Thạnh Phú, Vĩnh Cửu, Đồng Nai": [
    "thạnh phú, vĩnh cửu, đồng nai",
    "thajnh phus, vixnh cuwru, ddoofng nai"
  ],
  "Thạnh Trị, Bình Đại, Bến Tre": [
    "thạnh trị, bình đại, bến tre",
    "thajnh trij, bifnh ddaji, beesn tre"
  ],
  "Thất Hùng, Kinh Môn, Hải Dương": [
    "thất hùng, kinh môn, hải dương",
    "thaast hufng, kinh moon, hari duwowng"
  ],
  "Thắng Quân, Yên Sơn, Tuyên Quang": [
    "thắng quân, yên sơn, tuyên quang",
    "thawsng quaan, yeen sown, tuyeen quang"
  ],
  "Thể Dục, Nguyên Bình, Cao Bằng": [
    "thể dục, nguyên bình, cao bằng",
    "theer dujc, nguyeen bifnh, cao bawfng"
  ],
  "Thịnh Long, Hải Hậu, Nam Định": [
    "thịnh long, hải hậu, nam định",
    "thijnh long, hari haaju, nam ddijnh"
  ],
  "Thịnh Thành, Yên Thành, Nghệ An": [
    "thịnh thành, yên thành, nghệ an",
    "thijnh thafnh, yeen thafnh, ngheej an"
  ],
  "Thọ Ngọc, Triệu Sơn, Thanh Hóa": [
    "thọ ngọc, triệu sơn, thanh hóa",
    "thoj ngojc, trieeju sown, thanh hosa"
  ],
  "Thọ Sơn, Bù Đăng, Bình Phước": [
    "thọ sơn, bù đăng, bình phước",
    "thoj sown, buf ddawng, bifnh phuwowsc"
  ],
  "Thọ Tiến, Triệu Sơn, Thanh Hóa": [
    "thọ tiến, triệu sơn, thanh hóa",
    "thoj tieesn, trieeju sown, thanh hosa"
  ],
  "Thọ Xuân, Đan Phượng, Hà Nội": [
    "thọ xuân, đan phượng, hà nội",
    "thoj xuaan, ddan phuwowjng, haf nooji"
  ],
  "Thọ Xương, Thọ Xuân, Thanh Hóa": [
    "thọ xương, thọ xuân, thanh hóa",
    "thoj xuwowng, thoj xuaan, thanh hosa"
  ],
  "Thống Nhất, Hòa Bình, Hoà Bình": [
    "thống nhất, hòa bình, hoà bình",
    "thoosng nhaast, hofa bifnh, hoaf bifnh"
  ],
  "Thống Nhất, Hưng Hà, Thái Bình": [
    "thống nhất, hưng hà, thái bình",
    "thoosng nhaast, huwng haf, thasi bifnh"
  ],
  "Thốt Nốt, Thốt Nốt, Cần Thơ": [
    "thốt nốt, thốt nốt, cần thơ",
    "thoost noost, thoost noost, caafn thow"
  ],
  "Thới Hòa, Bến Cát, Bình Dương": [
    "thới hòa, bến cát, bình dương",
    "thowsi hofa, beesn cast, bifnh duwowng"
  ],
  "Thới Thạnh, Thới Lai, Cần Thơ": [
    "thới thạnh, thới lai, cần thơ",
    "thowsi thajnh, thowsi lai, caafn thow"
  ],
  "Thục Luyện, Thanh Sơn, Phú Thọ": [
    "thục luyện, thanh sơn, phú thọ",
    "thujc luyeejn, thanh sown, phus thoj"
  ],
  "Thụy Dân, Thái Thụy, Thái Bình": [
    "thụy dân, thái thụy, thái bình",
    "thujy daan, thasi thujy, thasi bifnh"
  ],
  "Thụy Ninh, Thái Thụy, Thái Bình": [
    "thụy ninh, thái thụy, thái bình",
    "thujy ninh, thasi thujy, thasi bifnh"
  ],
  "Thụy Sơn, Thái Thụy, Thái Bình": [
    "thụy sơn, thái thụy, thái bình",
    "thujy sown, thasi thujy, thasi bifnh"
  ],
  "Thụy Văn, Thái Thụy, Thái Bình": [
    "thụy văn, thái thụy, thái bình",
    "thujy vawn, thasi thujy, thasi bifnh"
  ],
  "Thủ Thiêm, Quận 2, Hồ Chí Minh": [
    "thủ thiêm, quận 2, hồ chí minh",
    "thur thieem, quaajn 2, hoof chis minh"
  ],
  "Thừa Đức, Bình Đại, Bến Tre": [
    "thừa đức, bình đại, bến tre",
    "thuwfa dduwsc, bifnh ddaji, beesn tre"
  ],
  "Thừa Đức, Cẩm Mỹ, Đồng Nai": [
    "thừa đức, cẩm mỹ, đồng nai",
    "thuwfa dduwsc, caarm myx, ddoofng nai"
  ],
  "Tiên Hoàng, Cát Tiên, Lâm Đồng": [
    "tiên hoàng, cát tiên, lâm đồng",
    "tieen hoafng, cast tieen, laam ddoofng"
  ],
  "Tiên Hà, Tiên Phước, Quảng Nam": [
    "tiên hà, tiên phước, quảng nam",
    "tieen haf, tieen phuwowsc, quarng nam"
  ],
  "Tiên Lãng, Tiên Lãng, Hải Phòng": [
    "tiên lãng, tiên lãng, hải phòng",
    "tieen laxng, tieen laxng, hari phofng"
  ],
  "Tiên Lục, Lạng Giang, Bắc Giang": [
    "tiên lục, lạng giang, bắc giang",
    "tieen lujc, lajng giang, bawsc giang"
  ],
  "Tiên Lữ, Lập Thạch, Vĩnh Phúc": [
    "tiên lữ, lập thạch, vĩnh phúc",
    "tieen luwx, laajp thajch, vixnh phusc"
  ],
  "Tiên Phong, Phổ Yên, Thái Nguyên": [
    "tiên phong, phổ yên, thái nguyên",
    "tieen phong, phoor yeen, thasi nguyeen"
  ],
  "Tiên Thanh, Tiên Lãng, Hải Phòng": [
    "tiên thanh, tiên lãng, hải phòng",
    "tieen thanh, tieen laxng, hari phofng"
  ],
  "Tiên Thành, Quảng Hòa, Cao Bằng": [
    "tiên thành, quảng hòa, cao bằng",
    "tieen thafnh, quarng hofa, cao bawfng"
  ],
  "Tiến Nông, Triệu Sơn, Thanh Hóa": [
    "tiến nông, triệu sơn, thanh hóa",
    "tieesn noong, trieeju sown, thanh hosa"
  ],
  "Tiến Thủy, Quỳnh Lưu, Nghệ An": [
    "tiến thủy, quỳnh lưu, nghệ an",
    "tieesn thury, quyfnh luwu, ngheej an"
  ],
  "Tiền Phong, Thái Bình, Thái Bình": [
    "tiền phong, thái bình, thái bình",
    "tieefn phong, thasi bifnh, thasi bifnh"
  ],
  "Toàn Thắng, Kim Động, Hưng Yên": [
    "toàn thắng, kim động, hưng yên",
    "toafn thawsng, kim ddoojng, huwng yeen"
  ],
  "Triệu Lộc, Hậu Lộc, Thanh Hóa": [
    "triệu lộc, hậu lộc, thanh hóa",
    "trieeju loojc, haaju loojc, thanh hosa"
  ],
  "Triệu Sơn, Triệu Sơn, Thanh Hóa": [
    "triệu sơn, triệu sơn, thanh hóa",
    "trieeju sown, trieeju sown, thanh hosa"
  ],
  "Trung Bình, Trần Đề, Sóc Trăng": [
    "trung bình, trần đề, sóc trăng",
    "trung bifnh, traafn ddeef, sosc trawng"
  ],
  "Trung Chánh,  Vũng Liêm, Vĩnh Long": [
    "trung chánh,  vũng liêm, vĩnh long",
    "trung chasnh,  vuxng lieem, vixnh long"
  ],
  "Trung Châu, Đan Phượng, Hà Nội": [
    "trung châu, đan phượng, hà nội",
    "trung chaau, ddan phuwowjng, haf nooji"
  ],
  "Trung Chính, Lương Tài, Bắc Ninh": [
    "trung chính, lương tài, bắc ninh",
    "trung chisnh, luwowng tafi, bawsc ninh"
  ],
  "Trung Chính, Nông Cống, Thanh Hóa": [
    "trung chính, nông cống, thanh hóa",
    "trung chisnh, noong coosng, thanh hosa"
  ],
  "Trung Hiếu,  Vũng Liêm, Vĩnh Long": [
    "trung hiếu,  vũng liêm, vĩnh long",
    "trung hieesu,  vuxng lieem, vixnh long"
  ],
  "Trung Hiệp,  Vũng Liêm, Vĩnh Long": [
    "trung hiệp,  vũng liêm, vĩnh long",
    "trung hieejp,  vuxng lieem, vixnh long"
  ],
  "Trung Lương, Hồng Lĩnh, Hà Tĩnh": [
    "trung lương, hồng lĩnh, hà tĩnh",
    "trung luwowng, hoofng lixnh, haf tixnh"
  ],
  "Trung Lập, Vĩnh Bảo, Hải Phòng": [
    "trung lập, vĩnh bảo, hải phòng",
    "trung laajp, vixnh baro, hari phofng"
  ],
  "Trung Nghĩa,  Vũng Liêm, Vĩnh Long": [
    "trung nghĩa,  vũng liêm, vĩnh long",
    "trung nghixa,  vuxng lieem, vixnh long"
  ],
  "Trung Nguyên, Yên Lạc, Vĩnh Phúc": [
    "trung nguyên, yên lạc, vĩnh phúc",
    "trung nguyeen, yeen lajc, vixnh phusc"
  ],
  "Trung Nhứt, Thốt Nốt, Cần Thơ": [
    "trung nhứt, thốt nốt, cần thơ",
    "trung nhuwst, thoost noost, caafn thow"
  ],
  "Trung Phúc, Trùng Khánh, Cao Bằng": [
    "trung phúc, trùng khánh, cao bằng",
    "trung phusc, trufng khasnh, cao bawfng"
  ],
  "Trung Thành,  Vũng Liêm, Vĩnh Long": [
    "trung thành,  vũng liêm, vĩnh long",
    "trung thafnh,  vuxng lieem, vixnh long"
  ],
  "Trung Thành, Nông Cống, Thanh Hóa": [
    "trung thành, nông cống, thanh hóa",
    "trung thafnh, noong coosng, thanh hosa"
  ],
  "Trung Thượng, Quan Sơn, Thanh Hóa": [
    "trung thượng, quan sơn, thanh hóa",
    "trung thuwowjng, quan sown, thanh hosa"
  ],
  "Trung Yên, Sơn Dương, Tuyên Quang": [
    "trung yên, sơn dương, tuyên quang",
    "trung yeen, sown duwowng, tuyeen quang"
  ],
  "Trung Đông, Trực Ninh, Nam Định": [
    "trung đông, trực ninh, nam định",
    "trung ddoong, truwjc ninh, nam ddijnh"
  ],
  "Trà Bình, Trà Bồng, Quảng Ngãi": [
    "trà bình, trà bồng, quảng ngãi",
    "traf bifnh, traf boofng, quarng ngaxi"
  ],
  "Trà Giang, Bắc Trà My, Quảng Nam": [
    "trà giang, bắc trà my, quảng nam",
    "traf giang, bawsc traf my, quarng nam"
  ],
  "Trà Giang, Trà Bồng, Quảng Ngãi": [
    "trà giang, trà bồng, quảng ngãi",
    "traf giang, traf boofng, quarng ngaxi"
  ],
  "Trà Giác, Bắc Trà My, Quảng Nam": [
    "trà giác, bắc trà my, quảng nam",
    "traf giasc, bawsc traf my, quarng nam"
  ],
  "Trà Giáp, Bắc Trà My, Quảng Nam": [
    "trà giáp, bắc trà my, quảng nam",
    "traf giasp, bawsc traf my, quarng nam"
  ],
  "Trà Phong, Trà Bồng, Quảng Ngãi": [
    "trà phong, trà bồng, quảng ngãi",
    "traf phong, traf boofng, quarng ngaxi"
  ],
  "Trà Thanh, Trà Bồng, Quảng Ngãi": [
    "trà thanh, trà bồng, quảng ngãi",
    "traf thanh, traf boofng, quarng ngaxi"
  ],
  "Trà Xuân, Trà Bồng, Quảng Ngãi": [
    "trà xuân, trà bồng, quảng ngãi",
    "traf xuaan, traf boofng, quarng ngaxi"
  ],
  "Tràng Tiền, Hoàn Kiếm, Hà Nội": [
    "tràng tiền, hoàn kiếm, hà nội",
    "trafng tieefn, hoafn kieesm, haf nooji"
  ],
  "Trí Quả, Thuận Thành, Bắc Ninh": [
    "trí quả, thuận thành, bắc ninh",
    "tris quar, thuaajn thafnh, bawsc ninh"
  ],
  "Trùng Khánh, Văn Lãng, Lạng Sơn": [
    "trùng khánh, văn lãng, lạng sơn",
    "trufng khasnh, vawn laxng, lajng sown"
  ],
  "Trưng Trắc, Phúc Yên, Vĩnh Phúc": [
    "trưng trắc, phúc yên, vĩnh phúc",
    "truwng trawsc, phusc yeen, vixnh phusc"
  ],
  "Trường Hà, Hà Quảng, Cao Bằng": [
    "trường hà, hà quảng, cao bằng",
    "truwowfng haf, haf quarng, cao bawfng"
  ],
  "Trường Hòa, Hòa Thành, Tây Ninh": [
    "trường hòa, hòa thành, tây ninh",
    "truwowfng hofa, hofa thafnh, taay ninh"
  ],
  "Trường Sơn, Lục Nam, Bắc Giang": [
    "trường sơn, lục nam, bắc giang",
    "truwowfng sown, lujc nam, bawsc giang"
  ],
  "Trường Sơn, Sầm Sơn, Thanh Hóa": [
    "trường sơn, sầm sơn, thanh hóa",
    "truwowfng sown, saafm sown, thanh hosa"
  ],
  "Trường Thọ, An Lão, Hải Phòng": [
    "trường thọ, an lão, hải phòng",
    "truwowfng thoj, an laxo, hari phofng"
  ],
  "Trường Tây, Hòa Thành, Tây Ninh": [
    "trường tây, hòa thành, tây ninh",
    "truwowfng taay, hofa thafnh, taay ninh"
  ],
  "Trường Xuân, Tam Kỳ, Quảng Nam": [
    "trường xuân, tam kỳ, quảng nam",
    "truwowfng xuaan, tam kyf, quarng nam"
  ],
  "Trạm Hành, Đà Lạt, Lâm Đồng": [
    "trạm hành, đà lạt, lâm đồng",
    "trajm hafnh, ddaf lajt, laam ddoofng"
  ],
  "Trọng Hóa, Minh Hóa, Quảng Bình": [
    "trọng hóa, minh hóa, quảng bình",
    "trojng hosa, minh hosa, quarng bifnh"
  ],
  "Trực Hùng, Trực Ninh, Nam Định": [
    "trực hùng, trực ninh, nam định",
    "truwjc hufng, truwjc ninh, nam ddijnh"
  ],
  "Trực Hưng, Trực Ninh, Nam Định": [
    "trực hưng, trực ninh, nam định",
    "truwjc huwng, truwjc ninh, nam ddijnh"
  ],
  "Trực Khang, Trực Ninh, Nam Định": [
    "trực khang, trực ninh, nam định",
    "truwjc khang, truwjc ninh, nam ddijnh"
  ],
  "Trực Nội, Trực Ninh, Nam Định": [
    "trực nội, trực ninh, nam định",
    "truwjc nooji, truwjc ninh, nam ddijnh"
  ],
  "Trực Thanh, Trực Ninh, Nam Định": [
    "trực thanh, trực ninh, nam định",
    "truwjc thanh, truwjc ninh, nam ddijnh"
  ],
  "Trực Thái, Trực Ninh, Nam Định": [
    "trực thái, trực ninh, nam định",
    "truwjc thasi, truwjc ninh, nam ddijnh"
  ],
  "Tà Hine, Đức Trọng, Lâm Đồng": [
    "tà hine, đức trọng, lâm đồng",
    "taf hine, dduwsc trojng, laam ddoofng"
  ],
  "Tân Bình, Hiệp Đức, Quảng Nam": [
    "tân bình, hiệp đức, quảng nam",
    "taan bifnh, hieejp dduwsc, quarng nam"
  ],
  "Tân Bình, Mỏ Cày Bắc, Bến Tre": [
    "tân bình, mỏ cày bắc, bến tre",
    "taan bifnh, mor cafy bawsc, beesn tre"
  ],
  "Tân Bình, Thanh Bình, Đồng Tháp": [
    "tân bình, thanh bình, đồng tháp",
    "taan bifnh, thanh bifnh, ddoofng thasp"
  ],
  "Tân Hiệp, Hóc Môn, Hồ Chí Minh": [
    "tân hiệp, hóc môn, hồ chí minh",
    "taan hieejp, hosc moon, hoof chis minh"
  ],
  "Tân Hiệp, Phú Giáo, Bình Dương": [
    "tân hiệp, phú giáo, bình dương",
    "taan hieejp, phus giaso, bifnh duwowng"
  ],
  "Tân Hiệp, Tân Uyên, Bình Dương": [
    "tân hiệp, tân uyên, bình dương",
    "taan hieejp, taan uyeen, bifnh duwowng"
  ],
  "Tân Hoà, Châu Thành A, Hậu Giang": [
    "tân hoà, châu thành a, hậu giang",
    "taan hoaf, chaau thafnh a, haaju giang"
  ],
  "Tân Huề, Thanh Bình, Đồng Tháp": [
    "tân huề, thanh bình, đồng tháp",
    "taan hueef, thanh bifnh, ddoofng thasp"
  ],
  "Tân Khánh, Phú Bình, Thái Nguyên": [
    "tân khánh, phú bình, thái nguyên",
    "taan khasnh, phus bifnh, thasi nguyeen"
  ],
  "Tân Kiểng, Quận 7, Hồ Chí Minh": [
    "tân kiểng, quận 7, hồ chí minh",
    "taan kieerng, quaajn 7, hoof chis minh"
  ],
  "Tân Long, Phụng Hiệp, Hậu Giang": [
    "tân long, phụng hiệp, hậu giang",
    "taan long, phujng hieejp, haaju giang"
  ],
  "Tân Long, Đồng Hỷ, Thái Nguyên": [
    "tân long, đồng hỷ, thái nguyên",
    "taan long, ddoofng hyr, thasi nguyeen"
  ],
  "Tân Minh, Tràng Định, Lạng Sơn": [
    "tân minh, tràng định, lạng sơn",
    "taan minh, trafng ddijnh, lajng sown"
  ],
  "Tân Mỹ Hà, Hương Sơn, Hà Tĩnh": [
    "tân mỹ hà, hương sơn, hà tĩnh",
    "taan myx haf, huwowng sown, haf tixnh"
  ],
  "Tân Ninh, Quảng Ninh, Quảng Bình": [
    "tân ninh, quảng ninh, quảng bình",
    "taan ninh, quarng ninh, quarng bifnh"
  ],
  "Tân Phú, Châu Thành, Đồng Tháp": [
    "tân phú, châu thành, đồng tháp",
    "taan phus, chaau thafnh, ddoofng thasp"
  ],
  "Tân Phú, Vĩnh Tường, Vĩnh Phúc": [
    "tân phú, vĩnh tường, vĩnh phúc",
    "taan phus, vixnh tuwowfng, vixnh phusc"
  ],
  "Tân Phước, Lai Vung, Đồng Tháp": [
    "tân phước, lai vung, đồng tháp",
    "taan phuwowsc, lai vung, ddoofng thasp"
  ],
  "Tân Quang, Sông Công, Thái Nguyên": [
    "tân quang, sông công, thái nguyên",
    "taan quang, soong coong, thasi nguyeen"
  ],
  "Tân Quang, Tuyên Quang, Tuyên Quang": [
    "tân quang, tuyên quang, tuyên quang",
    "taan quang, tuyeen quang, tuyeen quang"
  ],
  "Tân Quy Tây, Sa Đéc, Đồng Tháp": [
    "tân quy tây, sa đéc, đồng tháp",
    "taan quy taay, sa ddesc, ddoofng thasp"
  ],
  "Tân Thanh, Sơn Dương, Tuyên Quang": [
    "tân thanh, sơn dương, tuyên quang",
    "taan thanh, sown duwowng, tuyeen quang"
  ],
  "Tân Thành, Phú Bình, Thái Nguyên": [
    "tân thành, phú bình, thái nguyên",
    "taan thafnh, phus bifnh, thasi nguyeen"
  ],
  "Tân Thành, Tân Phú, Hồ Chí Minh": [
    "tân thành, tân phú, hồ chí minh",
    "taan thafnh, taan phus, hoof chis minh"
  ],
  "Tân Thái, Đại Từ, Thái Nguyên": [
    "tân thái, đại từ, thái nguyên",
    "taan thasi, ddaji tuwf, thasi nguyeen"
  ],
  "Tân Thắng, Hàm Tân, Bình Thuận": [
    "tân thắng, hàm tân, bình thuận",
    "taan thawsng, hafm taan, bifnh thuaajn"
  ],
  "Tân Thới, Phong Điền, Cần Thơ": [
    "tân thới, phong điền, cần thơ",
    "taan thowsi, phong ddieefn, caafn thow"
  ],
  "Tân Tiến, Hoàng Su Phì, Hà Giang": [
    "tân tiến, hoàng su phì, hà giang",
    "taan tieesn, hoafng su phif, haf giang"
  ],
  "Tân Trào, Sơn Dương, Tuyên Quang": [
    "tân trào, sơn dương, tuyên quang",
    "taan trafo, sown duwowng, tuyeen quang"
  ],
  "Tân Tạo, Bình Tân, Hồ Chí Minh": [
    "tân tạo, bình tân, hồ chí minh",
    "taan tajo, bifnh taan, hoof chis minh"
  ],
  "Tân Yên, Tràng Định, Lạng Sơn": [
    "tân yên, tràng định, lạng sơn",
    "taan yeen, trafng ddijnh, lajng sown"
  ],
  "Tân Định, Quận 1, Hồ Chí Minh": [
    "tân định, quận 1, hồ chí minh",
    "taan ddijnh, quaajn 1, hoof chis minh"
  ],
  "Tân Đức, Phú Bình, Thái Nguyên": [
    "tân đức, phú bình, thái nguyên",
    "taan dduwsc, phus bifnh, thasi nguyeen"
  ],
  "Tây Lộc, Huế, Thừa Thiên Huế": [
    "tây lộc, huế, thừa thiên huế",
    "taay loojc, huees, thuwfa thieen huees"
  ],
  "Tây Sơn, Kiến Xương, Thái Bình": [
    "tây sơn, kiến xương, thái bình",
    "taay sown, kieesn xuwowng, thasi bifnh"
  ],
  "Tây Thuận, Tây Sơn, Bình Định": [
    "tây thuận, tây sơn, bình định",
    "taay thuaajn, taay sown, bifnh ddijnh"
  ],
  "Tây Tiến, Tiền Hải, Thái Bình": [
    "tây tiến, tiền hải, thái bình",
    "taay tieesn, tieefn hari, thasi bifnh"
  ],
  "Tông Qua Lìn, Phong Thổ, Lai Châu": [
    "tông qua lìn, phong thổ, lai châu",
    "toong qua lifn, phong thoor, lai chaau"
  ],
  "Tăng Tiến, Việt Yên, Bắc Giang": [
    "tăng tiến, việt yên, bắc giang",
    "tawng tieesn, vieejt yeen, bawsc giang"
  ],
  "Tường Thượng, Phù Yên, Sơn La": [
    "tường thượng, phù yên, sơn la",
    "tuwowfng thuwowjng, phuf yeen, sown la"
  ],
  "Tạ An Khương, Đầm Dơi, Cà Mau": [
    "tạ an khương, đầm dơi, cà mau",
    "taj an khuwowng, ddaafm dowi, caf mau"
  ],
  "Tả Phìn, Tủa Chùa, Điện Biên": [
    "tả phìn, tủa chùa, điện biên",
    "tar phifn, tura chufa, ddieejn bieen"
  ],
  "Tế Thắng, Nông Cống, Thanh Hóa": [
    "tế thắng, nông cống, thanh hóa",
    "tees thawsng, noong coosng, thanh hosa"
  ],
  "Tịnh Hà, Sơn Tịnh, Quảng Ngãi": [
    "tịnh hà, sơn tịnh, quảng ngãi",
    "tijnh haf, sown tijnh, quarng ngaxi"
  ],
  "Tự Nhiên, Thường Tín, Hà Nội": [
    "tự nhiên, thường tín, hà nội",
    "tuwj nhieen, thuwowfng tisn, haf nooji"
  ],
  "Uyên Hưng, Tân Uyên, Bình Dương": [
    "uyên hưng, tân uyên, bình dương",
    "uyeen huwng, taan uyeen, bifnh duwowng"
  ],
  "Vi Hương, Bạch Thông, Bắc Kạn": [
    "vi hương, bạch thông, bắc kạn",
    "vi huwowng, bajch thoong, bawsc kajn"
  ],
  "Viên Bình, Trần Đề, Sóc Trăng": [
    "viên bình, trần đề, sóc trăng",
    "vieen bifnh, traafn ddeef, sosc trawng"
  ],
  "Việt Cường, Yên Mỹ, Hưng Yên": [
    "việt cường, yên mỹ, hưng yên",
    "vieejt cuwowfng, yeen myx, huwng yeen"
  ],
  "Việt Hùng, Trực Ninh, Nam Định": [
    "việt hùng, trực ninh, nam định",
    "vieejt hufng, truwjc ninh, nam ddijnh"
  ],
  "Việt Hải, Cát Hải, Hải Phòng": [
    "việt hải, cát hải, hải phòng",
    "vieejt hari, cast hari, hari phofng"
  ],
  "Vàng Đán, Nậm Pồ, Điện Biên": [
    "vàng đán, nậm pồ, điện biên",
    "vafng ddasn, naajm poof, ddieejn bieen"
  ],
  "Vân Khánh Tây, An Minh, Kiên Giang": [
    "vân khánh tây, an minh, kiên giang",
    "vaan khasnh taay, an minh, kieen giang"
  ],
  "Vô Tranh, Phú Lương, Thái Nguyên": [
    "vô tranh, phú lương, thái nguyên",
    "voo tranh, phus luwowng, thasi nguyeen"
  ],
  "Văn Hán, Đồng Hỷ, Thái Nguyên": [
    "văn hán, đồng hỷ, thái nguyên",
    "vawn hasn, ddoofng hyr, thasi nguyeen"
  ],
  "Văn Quán, Lập Thạch, Vĩnh Phúc": [
    "văn quán, lập thạch, vĩnh phúc",
    "vawn quasn, laajp thajch, vixnh phusc"
  ],
  "Vĩnh Bình, Vĩnh Thạnh, Cần Thơ": [
    "vĩnh bình, vĩnh thạnh, cần thơ",
    "vixnh bifnh, vixnh thajnh, caafn thow"
  ],
  "Vĩnh Bảo, Vĩnh Bảo, Hải Phòng": [
    "vĩnh bảo, vĩnh bảo, hải phòng",
    "vixnh baro, vixnh baro, hari phofng"
  ],
  "Vĩnh Giang, Vĩnh Linh, Quảng Trị": [
    "vĩnh giang, vĩnh linh, quảng trị",
    "vixnh giang, vixnh linh, quarng trij"
  ],
  "Vĩnh Hiệp, Rạch Giá, Kiên Giang": [
    "vĩnh hiệp, rạch giá, kiên giang",
    "vixnh hieejp, rajch gias, kieen giang"
  ],
  "Vĩnh Hiệp, Vĩnh Châu, Sóc Trăng": [
    "vĩnh hiệp, vĩnh châu, sóc trăng",
    "vixnh hieejp, vixnh chaau, sosc trawng"
  ],
  "Vĩnh Hậu A, Hoà Bình, Bạc Liêu": [
    "vĩnh hậu a, hoà bình, bạc liêu",
    "vixnh haaju a, hoaf bifnh, bajc lieeu"
  ],
  "Vĩnh Lộc, Chiêm Hóa, Tuyên Quang": [
    "vĩnh lộc, chiêm hóa, tuyên quang",
    "vixnh loojc, chieem hosa, tuyeen quang"
  ],
  "Vĩnh Ninh, Huế, Thừa Thiên Huế": [
    "vĩnh ninh, huế, thừa thiên huế",
    "vixnh ninh, huees, thuwfa thieen huees"
  ],
  "Vĩnh Phong, Vĩnh Bảo, Hải Phòng": [
    "vĩnh phong, vĩnh bảo, hải phòng",
    "vixnh phong, vixnh baro, hari phofng"
  ],
  "Vĩnh Phương, Nha Trang, Khánh Hòa": [
    "vĩnh phương, nha trang, khánh hòa",
    "vixnh phuwowng, nha trang, khasnh hofa"
  ],
  "Vĩnh Phước, Nha Trang, Khánh Hòa": [
    "vĩnh phước, nha trang, khánh hòa",
    "vixnh phuwowsc, nha trang, khasnh hofa"
  ],
  "Vĩnh Thái, Vĩnh Linh, Quảng Trị": [
    "vĩnh thái, vĩnh linh, quảng trị",
    "vixnh thasi, vixnh linh, quarng trij"
  ],
  "Vĩnh Thông, Rạch Giá, Kiên Giang": [
    "vĩnh thông, rạch giá, kiên giang",
    "vixnh thoong, rajch gias, kieen giang"
  ],
  "Vĩnh Thịnh, Hoà Bình, Bạc Liêu": [
    "vĩnh thịnh, hoà bình, bạc liêu",
    "vixnh thijnh, hoaf bifnh, bajc lieeu"
  ],
  "Vĩnh Thịnh, Vĩnh Lộc, Thanh Hóa": [
    "vĩnh thịnh, vĩnh lộc, thanh hóa",
    "vixnh thijnh, vixnh loojc, thanh hosa"
  ],
  "Vĩnh Thực, Móng Cái, Quảng Ninh": [
    "vĩnh thực, móng cái, quảng ninh",
    "vixnh thuwjc, mosng casi, quarng ninh"
  ],
  "Vĩnh Trinh, Vĩnh Thạnh, Cần Thơ": [
    "vĩnh trinh, vĩnh thạnh, cần thơ",
    "vixnh trinh, vixnh thajnh, caafn thow"
  ],
  "Vĩnh Trại, Lạng Sơn, Lạng Sơn": [
    "vĩnh trại, lạng sơn, lạng sơn",
    "vixnh traji, lajng sown, lajng sown"
  ],
  "Vĩnh Tường, Long Mỹ, Hậu Giang": [
    "vĩnh tường, long mỹ, hậu giang",
    "vixnh tuwowfng, long myx, haaju giang"
  ],
  "Vĩnh Viễn A, Long Mỹ, Hậu Giang": [
    "vĩnh viễn a, long mỹ, hậu giang",
    "vixnh vieexn a, long myx, haaju giang"
  ],
  "Vũ Bình, Kiến Xương, Thái Bình": [
    "vũ bình, kiến xương, thái bình",
    "vux bifnh, kieesn xuwowng, thasi bifnh"
  ],
  "Vũ Công, Kiến Xương, Thái Bình": [
    "vũ công, kiến xương, thái bình",
    "vux coong, kieesn xuwowng, thasi bifnh"
  ],
  "Vũ Muộn, Bạch Thông, Bắc Kạn": [
    "vũ muộn, bạch thông, bắc kạn",
    "vux muoojn, bajch thoong, bawsc kajn"
  ],
  "Vũ Trung, Kiến Xương, Thái Bình": [
    "vũ trung, kiến xương, thái bình",
    "vux trung, kieesn xuwowng, thasi bifnh"
  ],
  "Vạn Lương, Vạn Ninh, Khánh Hòa": [
    "vạn lương, vạn ninh, khánh hòa",
    "vajn luwowng, vajn ninh, khasnh hofa"
  ],
  "Vạn Mỹ, Ngô Quyền, Hải Phòng": [
    "vạn mỹ, ngô quyền, hải phòng",
    "vajn myx, ngoo quyeefn, hari phofng"
  ],
  "Vạn Phái, Phổ Yên, Thái Nguyên": [
    "vạn phái, phổ yên, thái nguyên",
    "vajn phasi, phoor yeen, thasi nguyeen"
  ],
  "Vạn Phúc, Ninh Giang, Hải Dương": [
    "vạn phúc, ninh giang, hải dương",
    "vajn phusc, ninh giang, hari duwowng"
  ],
  "Vạn Thạnh, Vạn Ninh, Khánh Hòa": [
    "vạn thạnh, vạn ninh, khánh hòa",
    "vajn thajnh, vajn ninh, khasnh hofa"
  ],
  "Vạn Thắng, Vạn Ninh, Khánh Hòa": [
    "vạn thắng, vạn ninh, khánh hòa",
    "vajn thawsng, vajn ninh, khasnh hofa"
  ],
  "Vị Thắng, Vị Thuỷ, Hậu Giang": [
    "vị thắng, vị thuỷ, hậu giang",
    "vij thawsng, vij thuyr, haaju giang"
  ],
  "Vụ Bổn, Krông Pắc, Đắk Lắk": [
    "vụ bổn, krông pắc, đắk lắk",
    "vuj boorn, kroong pawsc, ddawsk lawsk"
  ],
  "Xuân Cao, Thường Xuân, Thanh Hóa": [
    "xuân cao, thường xuân, thanh hóa",
    "xuaan cao, thuwowfng xuaan, thanh hosa"
  ],
  "Xuân Hiệp, Xuân Lộc, Đồng Nai": [
    "xuân hiệp, xuân lộc, đồng nai",
    "xuaan hieejp, xuaan loojc, ddoofng nai"
  ],
  "Xuân Hòa, Lập Thạch, Vĩnh Phúc": [
    "xuân hòa, lập thạch, vĩnh phúc",
    "xuaan hofa, laajp thajch, vixnh phusc"
  ],
  "Xuân Lâm, Thuận Thành, Bắc Ninh": [
    "xuân lâm, thuận thành, bắc ninh",
    "xuaan laam, thuaajn thafnh, bawsc ninh"
  ],
  "Xuân Lôi, Lập Thạch, Vĩnh Phúc": [
    "xuân lôi, lập thạch, vĩnh phúc",
    "xuaan looi, laajp thajch, vixnh phusc"
  ],
  "Xuân Lương, Yên Thế, Bắc Giang": [
    "xuân lương, yên thế, bắc giang",
    "xuaan luwowng, yeen thees, bawsc giang"
  ],
  "Xuân Lạc, Chợ Đồn, Bắc Kạn": [
    "xuân lạc, chợ đồn, bắc kạn",
    "xuaan lajc, chowj ddoofn, bawsc kajn"
  ],
  "Xuân Nội, Trùng Khánh, Cao Bằng": [
    "xuân nội, trùng khánh, cao bằng",
    "xuaan nooji, trufng khasnh, cao bawfng"
  ],
  "Xuân Phú, Huế, Thừa Thiên Huế": [
    "xuân phú, huế, thừa thiên huế",
    "xuaan phus, huees, thuwfa thieen huees"
  ],
  "Xuân Phương, Sông Cầu, Phú Yên": [
    "xuân phương, sông cầu, phú yên",
    "xuaan phuwowng, soong caafu, phus yeen"
  ],
  "Xuân Quang, Chiêm Hóa, Tuyên Quang": [
    "xuân quang, chiêm hóa, tuyên quang",
    "xuaan quang, chieem hosa, tuyeen quang"
  ],
  "Xuân Thành, Xuân Lộc, Đồng Nai": [
    "xuân thành, xuân lộc, đồng nai",
    "xuaan thafnh, xuaan loojc, ddoofng nai"
  ],
  "Yên Giang, Quảng Yên, Quảng Ninh": [
    "yên giang, quảng yên, quảng ninh",
    "yeen giang, quarng yeen, quarng ninh"
  ],
  "Yên Hải, Quảng Yên, Quảng Ninh": [
    "yên hải, quảng yên, quảng ninh",
    "yeen hari, quarng yeen, quarng ninh"
  ],
  "Yên Khương, Lang Chánh, Thanh Hóa": [
    "yên khương, lang chánh, thanh hóa",
    "yeen khuwowng, lang chasnh, thanh hosa"
  ],
  "Yên Lãng, Đại Từ, Thái Nguyên": [
    "yên lãng, đại từ, thái nguyên",
    "yeen laxng, ddaji tuwf, thasi nguyeen"
  ],
  "Yên Ninh, Phú Lương, Thái Nguyên": [
    "yên ninh, phú lương, thái nguyên",
    "yeen ninh, phus luwowng, thasi nguyeen"
  ],
  "Yên Phương, Yên Lạc, Vĩnh Phúc": [
    "yên phương, yên lạc, vĩnh phúc",
    "yeen phuwowng, yeen lajc, vixnh phusc"
  ],
  "Yên Thịnh, Hữu Lũng, Lạng Sơn": [
    "yên thịnh, hữu lũng, lạng sơn",
    "yeen thijnh, huwxu luxng, lajng sown"
  ],
  "Yên Thịnh, Yên Định, Thanh Hóa": [
    "yên thịnh, yên định, thanh hóa",
    "yeen thijnh, yeen ddijnh, thanh hosa"
  ],
  "Yên Tĩnh, Tương Dương, Nghệ An": [
    "yên tĩnh, tương dương, nghệ an",
    "yeen tixnh, tuwowng duwowng, ngheej an"
  ],
  "Yên Định, Hải Hậu, Nam Định": [
    "yên định, hải hậu, nam định",
    "yeen ddijnh, hari haaju, nam ddijnh"
  ],
  "Ái Tử, Triệu Phong, Quảng Trị": [
    "ái tử, triệu phong, quảng trị",
    "asi tuwr, trieeju phong, quarng trij"
  ],
  "Ô Chợ Dừa, Đống Đa, Hà Nội": [
    "ô chợ dừa, đống đa, hà nội",
    "oo chowj duwfa, ddoosng dda, haf nooji"
  ],
  "Đa Kia, Bù Gia Mập, Bình Phước": [
    "đa kia, bù gia mập, bình phước",
    "dda kia, buf gia maajp, bifnh phuwowsc"
  ],
  "Đa Quyn, Đức Trọng, Lâm Đồng": [
    "đa quyn, đức trọng, lâm đồng",
    "dda quyn, dduwsc trojng, laam ddoofng"
  ],
  "Đak Ơ, Bù Gia Mập, Bình Phước": [
    "đak ơ, bù gia mập, bình phước",
    "ddak ow, buf gia maajp, bifnh phuwowsc"
  ],
  "Đan Phượng, Lâm Hà, Lâm Đồng": [
    "đan phượng, lâm hà, lâm đồng",
    "ddan phuwowjng, laam haf, laam ddoofng"
  ],
  "Điêu Lương, Cẩm Khê, Phú Thọ": [
    "điêu lương, cẩm khê, phú thọ",
    "ddieeu luwowng, caarm khee, phus thoj"
  ],
  "Điềm Hy, Châu Thành, Tiền Giang": [
    "điềm hy, châu thành, tiền giang",
    "ddieefm hy, chaau thafnh, tieefn giang"
  ],
  "Điền Hạ, Bá Thước, Thanh Hóa": [
    "điền hạ, bá thước, thanh hóa",
    "ddieefn haj, bas thuwowsc, thanh hosa"
  ],
  "Đoàn Kết, Buôn Hồ, Đắk Lắk": [
    "đoàn kết, buôn hồ, đắk lắk",
    "ddoafn keest, buoon hoof, ddawsk lawsk"
  ],
  "Đình Chu, Lập Thạch, Vĩnh Phúc": [
    "đình chu, lập thạch, vĩnh phúc",
    "ddifnh chu, laajp thajch, vixnh phusc"
  ],
  "Đình Phùng, Bảo Lạc, Cao Bằng": [
    "đình phùng, bảo lạc, cao bằng",
    "ddifnh phufng, baro lajc, cao bawfng"
  ],
  "Đông Các, Đông Hưng, Thái Bình": [
    "đông các, đông hưng, thái bình",
    "ddoong casc, ddoong huwng, thasi bifnh"
  ],
  "Đông Cương, Thanh Hóa, Thanh Hóa": [
    "đông cương, thanh hóa, thanh hóa",
    "ddoong cuwowng, thanh hosa, thanh hosa"
  ],
  "Đông Hoàng, Đông Sơn, Thanh Hóa": [
    "đông hoàng, đông sơn, thanh hóa",
    "ddoong hoafng, ddoong sown, thanh hosa"
  ],
  "Đông Hà, Đức Linh, Bình Thuận": [
    "đông hà, đức linh, bình thuận",
    "ddoong haf, dduwsc linh, bifnh thuaajn"
  ],
  "Đông Hương, Thanh Hóa, Thanh Hóa": [
    "đông hương, thanh hóa, thanh hóa",
    "ddoong huwowng, thanh hosa, thanh hosa"
  ],
  "Đông Hải 1, Hải An, Hải Phòng": [
    "đông hải 1, hải an, hải phòng",
    "ddoong hari 1, hari an, hari phofng"
  ],
  "Đông Hải 2, Hải An, Hải Phòng": [
    "đông hải 2, hải an, hải phòng",
    "ddoong hari 2, hari an, hari phofng"
  ],
  "Đông Hải, Tiên Yên, Quảng Ninh": [
    "đông hải, tiên yên, quảng ninh",
    "ddoong hari, tieen yeen, quarng ninh"
  ],
  "Đông Kinh, Đông Hưng, Thái Bình": [
    "đông kinh, đông hưng, thái bình",
    "ddoong kinh, ddoong huwng, thasi bifnh"
  ],
  "Đông Kết, Khoái Châu, Hưng Yên": [
    "đông kết, khoái châu, hưng yên",
    "ddoong keest, khoasi chaau, huwng yeen"
  ],
  "Đông Long, Tiền Hải, Thái Bình": [
    "đông long, tiền hải, thái bình",
    "ddoong long, tieefn hari, thasi bifnh"
  ],
  "Đông Lâm, Tiền Hải, Thái Bình": [
    "đông lâm, tiền hải, thái bình",
    "ddoong laam, tieefn hari, thasi bifnh"
  ],
  "Đông Lễ, Đông Hà, Quảng Trị": [
    "đông lễ, đông hà, quảng trị",
    "ddoong leex, ddoong haf, quarng trij"
  ],
  "Đông Mai, Quảng Yên, Quảng Ninh": [
    "đông mai, quảng yên, quảng ninh",
    "ddoong mai, quarng yeen, quarng ninh"
  ],
  "Đông Minh, Tiền Hải, Thái Bình": [
    "đông minh, tiền hải, thái bình",
    "ddoong minh, tieefn hari, thasi bifnh"
  ],
  "Đông Phú, Châu Thành, Hậu Giang": [
    "đông phú, châu thành, hậu giang",
    "ddoong phus, chaau thafnh, haaju giang"
  ],
  "Đông Quan, Đông Hưng, Thái Bình": [
    "đông quan, đông hưng, thái bình",
    "ddoong quan, ddoong huwng, thasi bifnh"
  ],
  "Đông Quí, Tiền Hải, Thái Bình": [
    "đông quí, tiền hải, thái bình",
    "ddoong quis, tieefn hari, thasi bifnh"
  ],
  "Đông Sơn, Đông Hưng, Thái Bình": [
    "đông sơn, đông hưng, thái bình",
    "ddoong sown, ddoong huwng, thasi bifnh"
  ],
  "Đông Thuận, Bình Minh, Vĩnh Long": [
    "đông thuận, bình minh, vĩnh long",
    "ddoong thuaajn, bifnh minh, vixnh long"
  ],
  "Đông Thuận, Thới Lai, Cần Thơ": [
    "đông thuận, thới lai, cần thơ",
    "ddoong thuaajn, thowsi lai, caafn thow"
  ],
  "Đông Thạnh, Bình Minh, Vĩnh Long": [
    "đông thạnh, bình minh, vĩnh long",
    "ddoong thajnh, bifnh minh, vixnh long"
  ],
  "Đông Thạnh, Cần Giuộc, Long An": [
    "đông thạnh, cần giuộc, long an",
    "ddoong thajnh, caafn giuoojc, long an"
  ],
  "Đông Thắng, Cờ Đỏ, Cần Thơ": [
    "đông thắng, cờ đỏ, cần thơ",
    "ddoong thawsng, cowf ddor, caafn thow"
  ],
  "Đông Thọ, Thái Bình, Thái Bình": [
    "đông thọ, thái bình, thái bình",
    "ddoong thoj, thasi bifnh, thasi bifnh"
  ],
  "Đông Tiến, Đông Sơn, Thanh Hóa": [
    "đông tiến, đông sơn, thanh hóa",
    "ddoong tieesn, ddoong sown, thanh hosa"
  ],
  "Đông Trà, Tiền Hải, Thái Bình": [
    "đông trà, tiền hải, thái bình",
    "ddoong traf, tieefn hari, thasi bifnh"
  ],
  "Đông Tân, Đông Hưng, Thái Bình": [
    "đông tân, đông hưng, thái bình",
    "ddoong taan, ddoong huwng, thasi bifnh"
  ],
  "Đông Tảo, Khoái Châu, Hưng Yên": [
    "đông tảo, khoái châu, hưng yên",
    "ddoong taro, khoasi chaau, huwng yeen"
  ],
  "Đông Vinh, Đông Hưng, Thái Bình": [
    "đông vinh, đông hưng, thái bình",
    "ddoong vinh, ddoong huwng, thasi bifnh"
  ],
  "Đăk R'Moan, Gia Nghĩa, Đắk Nông": [
    "đăk r'moan, gia nghĩa, đắk nông",
    "ddawk r'moan, gia nghixa, ddawsk noong"
  ],
  "Đăng Hà, Bù Đăng, Bình Phước": [
    "đăng hà, bù đăng, bình phước",
    "ddawng haf, buf ddawng, bifnh phuwowsc"
  ],
  "Đường Hoa, Hải Hà, Quảng Ninh": [
    "đường hoa, hải hà, quảng ninh",
    "dduwowfng hoa, hari haf, quarng ninh"
  ],
  "Đường Hồng, Bắc Mê, Hà Giang": [
    "đường hồng, bắc mê, hà giang",
    "dduwowfng hoofng, bawsc mee, haf giang"
  ],
  "Đạ Sar, Lạc Dương, Lâm Đồng": [
    "đạ sar, lạc dương, lâm đồng",
    "ddaj sar, lajc duwowng, laam ddoofng"
  ],
  "Đạ Tẻh, Đạ Tẻh, Lâm Đồng": [
    "đạ tẻh, đạ tẻh, lâm đồng",
    "ddaj terh, ddaj terh, laam ddoofng"
  ],
  "Đạ Tồn, Đạ Huoai, Lâm Đồng": [
    "đạ tồn, đạ huoai, lâm đồng",
    "ddaj toofn, ddaj huoai, laam ddoofng"
  ],
  "Đại Bình, Đầm Hà, Quảng Ninh": [
    "đại bình, đầm hà, quảng ninh",
    "ddaji bifnh, ddaafm haf, quarng ninh"
  ],
  "Đại Bản, An Dương, Hải Phòng": [
    "đại bản, an dương, hải phòng",
    "ddaji barn, an duwowng, hari phofng"
  ],
  "Đại Cường, Ứng Hòa, Hà Nội": [
    "đại cường, ứng hòa, hà nội",
    "ddaji cuwowfng, uwsng hofa, haf nooji"
  ],
  "Đại Dực, Tiên Yên, Quảng Ninh": [
    "đại dực, tiên yên, quảng ninh",
    "ddaji duwjc, tieen yeen, quarng ninh"
  ],
  "Đại Hòa, Đại Lộc, Quảng Nam": [
    "đại hòa, đại lộc, quảng nam",
    "ddaji hofa, ddaji loojc, quarng nam"
  ],
  "Đại Hưng, Khoái Châu, Hưng Yên": [
    "đại hưng, khoái châu, hưng yên",
    "ddaji huwng, khoasi chaau, huwng yeen"
  ],
  "Đại Hợp, Tứ Kỳ, Hải Dương": [
    "đại hợp, tứ kỳ, hải dương",
    "ddaji howjp, tuws kyf, hari duwowng"
  ],
  "Đại Lào, Bảo Lộc, Lâm Đồng": [
    "đại lào, bảo lộc, lâm đồng",
    "ddaji lafo, baro loojc, laam ddoofng"
  ],
  "Đại Lâm, Lạng Giang, Bắc Giang": [
    "đại lâm, lạng giang, bắc giang",
    "ddaji laam, lajng giang, bawsc giang"
  ],
  "Đại Minh, Đại Lộc, Quảng Nam": [
    "đại minh, đại lộc, quảng nam",
    "ddaji minh, ddaji loojc, quarng nam"
  ],
  "Đại Mỗ, Nam Từ Liêm, Hà Nội": [
    "đại mỗ, nam từ liêm, hà nội",
    "ddaji moox, nam tuwf lieem, haf nooji"
  ],
  "Đại Phước, Càng Long, Trà Vinh": [
    "đại phước, càng long, trà vinh",
    "ddaji phuwowsc, cafng long, traf vinh"
  ],
  "Đại Sơn, Sơn Động, Bắc Giang": [
    "đại sơn, sơn động, bắc giang",
    "ddaji sown, sown ddoojng, bawsc giang"
  ],
  "Đại Sơn, Đại Lộc, Quảng Nam": [
    "đại sơn, đại lộc, quảng nam",
    "ddaji sown, ddaji loojc, quarng nam"
  ],
  "Đại Thành, Ngã Bảy, Hậu Giang": [
    "đại thành, ngã bảy, hậu giang",
    "ddaji thafnh, ngax bary, haaju giang"
  ],
  "Đại Thắng, Phú Xuyên, Hà Nội": [
    "đại thắng, phú xuyên, hà nội",
    "ddaji thawsng, phus xuyeen, haf nooji"
  ],
  "Đại Tân, Đại Lộc, Quảng Nam": [
    "đại tân, đại lộc, quảng nam",
    "ddaji taan, ddaji loojc, quarng nam"
  ],
  "Đại Tập, Khoái Châu, Hưng Yên": [
    "đại tập, khoái châu, hưng yên",
    "ddaji taajp, khoasi chaau, huwng yeen"
  ],
  "Đại Đình, Tam Đảo, Vĩnh Phúc": [
    "đại đình, tam đảo, vĩnh phúc",
    "ddaji ddifnh, tam ddaro, vixnh phusc"
  ],
  "Đạo Thạnh, Mỹ Tho, Tiền Giang": [
    "đạo thạnh, mỹ tho, tiền giang",
    "ddajo thajnh, myx tho, tieefn giang"
  ],
  "Đạo Viện, Yên Sơn, Tuyên Quang": [
    "đạo viện, yên sơn, tuyên quang",
    "ddajo vieejn, yeen sown, tuyeen quang"
  ],
  "Đản Ván, Hoàng Su Phì, Hà Giang": [
    "đản ván, hoàng su phì, hà giang",
    "ddarn vasn, hoafng su phif, haf giang"
  ],
  "Đắc Sơn, Phổ Yên, Thái Nguyên": [
    "đắc sơn, phổ yên, thái nguyên",
    "ddawsc sown, phoor yeen, thasi nguyeen"
  ],
  "Đắk Gằn, Đắk Mil, Đắk Nông": [
    "đắk gằn, đắk mil, đắk nông",
    "ddawsk gawfn, ddawsk mil, ddawsk noong"
  ],
  "Đắk Hòa, Đắk Song, Đắk Nông": [
    "đắk hòa, đắk song, đắk nông",
    "ddawsk hofa, ddawsk song, ddawsk noong"
  ],
  "Đắk Môl, Đắk Song, Đắk Nông": [
    "đắk môl, đắk song, đắk nông",
    "ddawsk mool, ddawsk song, ddawsk noong"
  ],
  "Đắk Plao, Đăk Glong, Đắk Nông": [
    "đắk plao, đăk glong, đắk nông",
    "ddawsk plao, ddawk glong, ddawsk noong"
  ],
  "Đắk Rơ Ông, Tu Mơ Rông, Kon Tum": [
    "đắk rơ ông, tu mơ rông, kon tum",
    "ddawsk row oong, tu mow roong, kon tum"
  ],
  "Đắk Sắk, Đắk Mil, Đắk Nông": [
    "đắk sắk, đắk mil, đắk nông",
    "ddawsk sawsk, ddawsk mil, ddawsk noong"
  ],
  "Đắk Tờ Kan, Tu Mơ Rông, Kon Tum": [
    "đắk tờ kan, tu mơ rông, kon tum",
    "ddawsk towf kan, tu mow roong, kon tum"
  ],
  "Định Hòa, Yên Định, Thanh Hóa": [
    "định hòa, yên định, thanh hóa",
    "ddijnh hofa, yeen ddijnh, thanh hosa"
  ],
  "Định Long, Yên Định, Thanh Hóa": [
    "định long, yên định, thanh hóa",
    "ddijnh long, yeen ddijnh, thanh hosa"
  ],
  "Định Thành, Thoại Sơn, An Giang": [
    "định thành, thoại sơn, an giang",
    "ddijnh thafnh, thoaji sown, an giang"
  ],
  "Định Trung, Bình Đại, Bến Tre": [
    "định trung, bình đại, bến tre",
    "ddijnh trung, bifnh ddaji, beesn tre"
  ],
  "Định Trung, Vĩnh Yên, Vĩnh Phúc": [
    "định trung, vĩnh yên, vĩnh phúc",
    "ddijnh trung, vixnh yeen, vixnh phusc"
  ],
  "Định Tân, Yên Định, Thanh Hóa": [
    "định tân, yên định, thanh hóa",
    "ddijnh taan, yeen ddijnh, thanh hosa"
  ],
  "Định Yên, Lấp Vò, Đồng Tháp": [
    "định yên, lấp vò, đồng tháp",
    "ddijnh yeen, laasp vof, ddoofng thasp"
  ],
  "Đồng Bài, Cát Hải, Hải Phòng": [
    "đồng bài, cát hải, hải phòng",
    "ddoofng bafi, cast hari, hari phofng"
  ],
  "Đồng Hướng, Kim Sơn, Ninh Bình": [
    "đồng hướng, kim sơn, ninh bình",
    "ddoofng huwowsng, kim sown, ninh bifnh"
  ],
  "Đồng Kho, Tánh Linh, Bình Thuận": [
    "đồng kho, tánh linh, bình thuận",
    "ddoofng kho, tasnh linh, bifnh thuaajn"
  ],
  "Đồng Lạc, Yên Thế, Bắc Giang": [
    "đồng lạc, yên thế, bắc giang",
    "ddoofng lajc, yeen thees, bawsc giang"
  ],
  "Đồng Lộc, Hậu Lộc, Thanh Hóa": [
    "đồng lộc, hậu lộc, thanh hóa",
    "ddoofng loojc, haaju loojc, thanh hosa"
  ],
  "Đồng Nguyên, Từ Sơn, Bắc Ninh": [
    "đồng nguyên, từ sơn, bắc ninh",
    "ddoofng nguyeen, tuwf sown, bawsc ninh"
  ],
  "Đồng Phú, Chương Mỹ, Hà Nội": [
    "đồng phú, chương mỹ, hà nội",
    "ddoofng phus, chuwowng myx, haf nooji"
  ],
  "Đồng Phúc, Yên Dũng, Bắc Giang": [
    "đồng phúc, yên dũng, bắc giang",
    "ddoofng phusc, yeen duxng, bawsc giang"
  ],
  "Đồng Sơn, Bắc Giang, Bắc Giang": [
    "đồng sơn, bắc giang, bắc giang",
    "ddoofng sown, bawsc giang, bawsc giang"
  ],
  "Đồng Thanh, Kim Động, Hưng Yên": [
    "đồng thanh, kim động, hưng yên",
    "ddoofng thanh, kim ddoojng, huwng yeen"
  ],
  "Đồng Thành, Yên Thành, Nghệ An": [
    "đồng thành, yên thành, nghệ an",
    "ddoofng thafnh, yeen thafnh, ngheej an"
  ],
  "Đồng Tiến, Bắc Quang, Hà Giang": [
    "đồng tiến, bắc quang, hà giang",
    "ddoofng tieesn, bawsc quang, haf giang"
  ],
  "Đồng Tiến, Hòa Bình, Hoà Bình": [
    "đồng tiến, hòa bình, hoà bình",
    "ddoofng tieesn, hofa bifnh, hoaf bifnh"
  ],
  "Đồng Tâm, Chợ Mới, Bắc Kạn": [
    "đồng tâm, chợ mới, bắc kạn",
    "ddoofng taam, chowj mowsi, bawsc kajn"
  ],
  "Đồng Tâm, Lạc Thủy, Hoà Bình": [
    "đồng tâm, lạc thủy, hoà bình",
    "ddoofng taam, lajc thury, hoaf bifnh"
  ],
  "Đồng Tân, Hiệp Hòa, Bắc Giang": [
    "đồng tân, hiệp hòa, bắc giang",
    "ddoofng taan, hieejp hofa, bawsc giang"
  ],
  "Đồng Tân, Hữu Lũng, Lạng Sơn": [
    "đồng tân, hữu lũng, lạng sơn",
    "ddoofng taan, huwxu luxng, lajng sown"
  ],
  "Đồng Xuân, Hoàn Kiếm, Hà Nội": [
    "đồng xuân, hoàn kiếm, hà nội",
    "ddoofng xuaan, hoafn kieesm, haf nooji"
  ],
  "Đồng Xuân, Phúc Yên, Vĩnh Phúc": [
    "đồng xuân, phúc yên, vĩnh phúc",
    "ddoofng xuaan, phusc yeen, vixnh phusc"
  ],
  "Đồng Đăng, Cao Lộc, Lạng Sơn": [
    "đồng đăng, cao lộc, lạng sơn",
    "ddoofng ddawng, cao loojc, lajng sown"
  ],
  "Độc Lập, Quảng Hòa, Cao Bằng": [
    "độc lập, quảng hòa, cao bằng",
    "ddoojc laajp, quarng hofa, cao bawfng"
  ],
  "Đức Hòa Hạ, Đức Hòa, Long An": [
    "đức hòa hạ, đức hòa, long an",
    "dduwsc hofa haj, dduwsc hofa, long an"
  ],
  "Đức Lạng, Đức Thọ, Hà Tĩnh": [
    "đức lạng, đức thọ, hà tĩnh",
    "dduwsc lajng, dduwsc thoj, haf tixnh"
  ],
  "Đức Phú, Tánh Linh, Bình Thuận": [
    "đức phú, tánh linh, bình thuận",
    "dduwsc phus, tasnh linh, bifnh thuaajn"
  ],
  "Đức Phổ, Cát Tiên, Lâm Đồng": [
    "đức phổ, cát tiên, lâm đồng",
    "dduwsc phoor, cast tieen, laam ddoofng"
  ],
  "Đức Thắng, Tiên Lữ, Hưng Yên": [
    "đức thắng, tiên lữ, hưng yên",
    "dduwsc thawsng, tieen luwx, huwng yeen"
  ],
  "Đức Xuân, Bắc Kạn, Bắc Kạn": [
    "đức xuân, bắc kạn, bắc kạn",
    "dduwsc xuaan, bawsc kajn, bawsc kajn"
  ],
  "An Bình A, Hồng Ngự, Đồng Tháp": [
    "an bình a, hồng ngự, đồng tháp",
    "an bifnh a, hoofng nguwj, ddoofng thasp"
  ],
  "An Bình B, Hồng Ngự, Đồng Tháp": [
    "an bình b, hồng ngự, đồng tháp",
    "an bifnh b, hoofng nguwj, ddoofng thasp"
  ],
  "An Hải Đông, Sơn Trà, Đà Nẵng": [
    "an hải đông, sơn trà, đà nẵng",
    "an hari ddoong, sown traf, ddaf nawxng"
  ],
  "An Lạc Thôn, Kế Sách, Sóc Trăng": [
    "an lạc thôn, kế sách, sóc trăng",
    "an lajc thoon, kees sasch, sosc trawng"
  ],
  "An Nhơn Tây, Củ Chi, Hồ Chí Minh": [
    "an nhơn tây, củ chi, hồ chí minh",
    "an nhown taay, cur chi, hoof chis minh"
  ],
  "An Phước, Tân Hồng, Đồng Tháp": [
    "an phước, tân hồng, đồng tháp",
    "an phuwowsc, taan hoofng, ddoofng thasp"
  ],
  "An Thái Đông, Cái Bè, Tiền Giang": [
    "an thái đông, cái bè, tiền giang",
    "an thasi ddoong, casi bef, tieefn giang"
  ],
  "An Thạnh 1, Cù Lao Dung, Sóc Trăng": [
    "an thạnh 1, cù lao dung, sóc trăng",
    "an thajnh 1, cuf lao dung, sosc trawng"
  ],
  "An Thạnh 2, Cù Lao Dung, Sóc Trăng": [
    "an thạnh 2, cù lao dung, sóc trăng",
    "an thajnh 2, cuf lao dung, sosc trawng"
  ],
  "An Thạnh 3, Cù Lao Dung, Sóc Trăng": [
    "an thạnh 3, cù lao dung, sóc trăng",
    "an thajnh 3, cuf lao dung, sosc trawng"
  ],
  "An Thạnh Trung, Chợ Mới, An Giang": [
    "an thạnh trung, chợ mới, an giang",
    "an thajnh trung, chowj mowsi, an giang"
  ],
  "An Thạnh, Hồng Ngự, Đồng Tháp": [
    "an thạnh, hồng ngự, đồng tháp",
    "an thajnh, hoofng nguwj, ddoofng thasp"
  ],
  "An Trạch A, Đông Hải, Bạc Liêu": [
    "an trạch a, đông hải, bạc liêu",
    "an trajch a, ddoong hari, bajc lieeu"
  ],
  "An Tường, Tuyên Quang, Tuyên Quang": [
    "an tường, tuyên quang, tuyên quang",
    "an tuwowfng, tuyeen quang, tuyeen quang"
  ],
  "Ba Tầng, Hướng Hóa, Quảng Trị": [
    "ba tầng, hướng hóa, quảng trị",
    "ba taafng, huwowsng hosa, quarng trij"
  ],
  "Buôn Trấp, Krông A Na, Đắk Lắk": [
    "buôn trấp, krông a na, đắk lắk",
    "buoon traasp, kroong a na, ddawsk lawsk"
  ],
  "Bàn Giản, Lập Thạch, Vĩnh Phúc": [
    "bàn giản, lập thạch, vĩnh phúc",
    "bafn giarn, laajp thajch, vixnh phusc"
  ],
  "Bách Quang, Sông Công, Thái Nguyên": [
    "bách quang, sông công, thái nguyên",
    "basch quang, soong coong, thasi nguyeen"
  ],
  "Bát Mọt, Thường Xuân, Thanh Hóa": [
    "bát mọt, thường xuân, thanh hóa",
    "bast mojt, thuwowfng xuaan, thanh hosa"
  ],
  "Bình Chánh, Bình Sơn, Quảng Ngãi": [
    "bình chánh, bình sơn, quảng ngãi",
    "bifnh chasnh, bifnh sown, quarng ngaxi"
  ],
  "Bình Chánh, Thăng Bình, Quảng Nam": [
    "bình chánh, thăng bình, quảng nam",
    "bifnh chasnh, thawng bifnh, quarng nam"
  ],
  "Bình Dương, Phù Mỹ, Bình Định": [
    "bình dương, phù mỹ, bình định",
    "bifnh duwowng, phuf myx, bifnh ddijnh"
  ],
  "Bình Hiệp, Bình Sơn, Quảng Ngãi": [
    "bình hiệp, bình sơn, quảng ngãi",
    "bifnh hieejp, bifnh sown, quarng ngaxi"
  ],
  "Bình Hòa Bắc, Đức Huệ, Long An": [
    "bình hòa bắc, đức huệ, long an",
    "bifnh hofa bawsc, dduwsc hueej, long an"
  ],
  "Bình Hòa Hưng, Đức Huệ, Long An": [
    "bình hòa hưng, đức huệ, long an",
    "bifnh hofa huwng, dduwsc hueej, long an"
  ],
  "Bình Khánh , Mỏ Cày Nam, Bến Tre": [
    "bình khánh , mỏ cày nam, bến tre",
    "bifnh khasnh , mor cafy nam, beesn tre"
  ],
  "Bình Minh, Kiến Xương, Thái Bình": [
    "bình minh, kiến xương, thái bình",
    "bifnh minh, kieesn xuwowng, thasi bifnh"
  ],
  "Bình Phục, Thăng Bình, Quảng Nam": [
    "bình phục, thăng bình, quảng nam",
    "bifnh phujc, thawng bifnh, quarng nam"
  ],
  "Bình Thanh , Bình Sơn, Quảng Ngãi": [
    "bình thanh , bình sơn, quảng ngãi",
    "bifnh thanh , bifnh sown, quarng ngaxi"
  ],
  "Bình Thuận, Buôn Hồ, Đắk Lắk": [
    "bình thuận, buôn hồ, đắk lắk",
    "bifnh thuaajn, buoon hoof, ddawsk lawsk"
  ],
  "Bình Thuận, Hải Châu, Đà Nẵng": [
    "bình thuận, hải châu, đà nẵng",
    "bifnh thuaajn, hari chaau, ddaf nawxng"
  ],
  "Bình Thuận, Quận 7, Hồ Chí Minh": [
    "bình thuận, quận 7, hồ chí minh",
    "bifnh thuaajn, quaajn 7, hoof chis minh"
  ],
  "Bình Thuận, Tây Sơn, Bình Định": [
    "bình thuận, tây sơn, bình định",
    "bifnh thuaajn, taay sown, bifnh ddijnh"
  ],
  "Bình Thạnh, Cao Lãnh, Đồng Tháp": [
    "bình thạnh, cao lãnh, đồng tháp",
    "bifnh thajnh, cao laxnh, ddoofng thasp"
  ],
  "Bình Thạnh, Tuy Phong, Bình Thuận": [
    "bình thạnh, tuy phong, bình thuận",
    "bifnh thajnh, tuy phong, bifnh thuaajn"
  ],
  "Bình Trinh Đông, Tân Trụ, Long An": [
    "bình trinh đông, tân trụ, long an",
    "bifnh trinh ddoong, taan truj, long an"
  ],
  "Bình Trị, Kiên Lương, Kiên Giang": [
    "bình trị, kiên lương, kiên giang",
    "bifnh trij, kieen luwowng, kieen giang"
  ],
  "Bình Tấn, Thanh Bình, Đồng Tháp": [
    "bình tấn, thanh bình, đồng tháp",
    "bifnh taasn, thanh bifnh, ddoofng thasp"
  ],
  "Bình Yên, Định Hóa, Thái Nguyên": [
    "bình yên, định hóa, thái nguyên",
    "bifnh yeen, ddijnh hosa, thasi nguyeen"
  ],
  "Bình Đông, Bình Sơn, Quảng Ngãi": [
    "bình đông, bình sơn, quảng ngãi",
    "bifnh ddoong, bifnh sown, quarng ngaxi"
  ],
  "Bình Định, Lương Tài, Bắc Ninh": [
    "bình định, lương tài, bắc ninh",
    "bifnh ddijnh, luwowng tafi, bawsc ninh"
  ],
  "Bích Động, Việt Yên, Bắc Giang": [
    "bích động, việt yên, bắc giang",
    "bisch ddoojng, vieejt yeen, bawsc giang"
  ],
  "Búng Tàu, Phụng Hiệp, Hậu Giang": [
    "búng tàu, phụng hiệp, hậu giang",
    "busng tafu, phujng hieejp, haaju giang"
  ],
  "Bạch Đằng, Hạ Long, Quảng Ninh": [
    "bạch đằng, hạ long, quảng ninh",
    "bajch ddawfng, haj long, quarng ninh"
  ],
  "Bản Luốc, Hoàng Su Phì, Hà Giang": [
    "bản luốc, hoàng su phì, hà giang",
    "barn luoosc, hoafng su phif, haf giang"
  ],
  "Bản Nhùng, Hoàng Su Phì, Hà Giang": [
    "bản nhùng, hoàng su phì, hà giang",
    "barn nhufng, hoafng su phif, haf giang"
  ],
  "Bản Phùng, Hoàng Su Phì, Hà Giang": [
    "bản phùng, hoàng su phì, hà giang",
    "barn phufng, hoafng su phif, haf giang"
  ],
  "Bảo Linh, Định Hóa, Thái Nguyên": [
    "bảo linh, định hóa, thái nguyên",
    "baro linh, ddijnh hosa, thasi nguyeen"
  ],
  "Bần Yên Nhân, Mỹ Hào, Hưng Yên": [
    "bần yên nhân, mỹ hào, hưng yên",
    "baafn yeen nhaan, myx hafo, huwng yeen"
  ],
  "Bắc Bình, Lập Thạch, Vĩnh Phúc": [
    "bắc bình, lập thạch, vĩnh phúc",
    "bawsc bifnh, laajp thajch, vixnh phusc"
  ],
  "Bắc Lý, Đồng Hới, Quảng Bình": [
    "bắc lý, đồng hới, quảng bình",
    "bawsc lys, ddoofng howsi, quarng bifnh"
  ],
  "Bắc Sơn, Thuận Bắc, Ninh Thuận": [
    "bắc sơn, thuận bắc, ninh thuận",
    "bawsc sown, thuaajn bawsc, ninh thuaajn"
  ],
  "Bằng Lãng, Chợ Đồn, Bắc Kạn": [
    "bằng lãng, chợ đồn, bắc kạn",
    "bawfng laxng, chowj ddoofn, bawsc kajn"
  ],
  "Bằng Lũng, Chợ Đồn, Bắc Kạn": [
    "bằng lũng, chợ đồn, bắc kạn",
    "bawfng luxng, chowj ddoofn, bawsc kajn"
  ],
  "Bằng Phúc, Chợ Đồn, Bắc Kạn": [
    "bằng phúc, chợ đồn, bắc kạn",
    "bawfng phusc, chowj ddoofn, bawsc kajn"
  ],
  "Bồng Sơn, Hoài Nhơn, Bình Định": [
    "bồng sơn, hoài nhơn, bình định",
    "boofng sown, hoafi nhown, bifnh ddijnh"
  ],
  "Cam Hiệp Bắc, Cam Lâm, Khánh Hòa": [
    "cam hiệp bắc, cam lâm, khánh hòa",
    "cam hieejp bawsc, cam laam, khasnh hofa"
  ],
  "Cam Hải Đông, Cam Lâm, Khánh Hòa": [
    "cam hải đông, cam lâm, khánh hòa",
    "cam hari ddoong, cam laam, khasnh hofa"
  ],
  "Cam Thành Bắc, Cam Lâm, Khánh Hòa": [
    "cam thành bắc, cam lâm, khánh hòa",
    "cam thafnh bawsc, cam laam, khasnh hofa"
  ],
  "Cam Thịnh Tây, Cam Ranh, Khánh Hòa": [
    "cam thịnh tây, cam ranh, khánh hòa",
    "cam thijnh taay, cam ranh, khasnh hofa"
  ],
  "Cao Chương, Trùng Khánh, Cao Bằng": [
    "cao chương, trùng khánh, cao bằng",
    "cao chuwowng, trufng khasnh, cao bawfng"
  ],
  "Cao Nhân, Thuỷ Nguyên, Hải Phòng": [
    "cao nhân, thuỷ nguyên, hải phòng",
    "cao nhaan, thuyr nguyeen, hari phofng"
  ],
  "Cao Quảng, Tuyên Hóa, Quảng Bình": [
    "cao quảng, tuyên hóa, quảng bình",
    "cao quarng, tuyeen hosa, quarng bifnh"
  ],
  "Cao Đại, Vĩnh Tường, Vĩnh Phúc": [
    "cao đại, vĩnh tường, vĩnh phúc",
    "cao ddaji, vixnh tuwowfng, vixnh phusc"
  ],
  "Chi Thiết, Sơn Dương, Tuyên Quang": [
    "chi thiết, sơn dương, tuyên quang",
    "chi thieest, sown duwowng, tuyeen quang"
  ],
  "Chiến Thắng, Chi Lăng, Lạng Sơn": [
    "chiến thắng, chi lăng, lạng sơn",
    "chieesn thawsng, chi lawng, lajng sown"
  ],
  "Chà Là, Dương Minh Châu, Tây Ninh": [
    "chà là, dương minh châu, tây ninh",
    "chaf laf, duwowng minh chaau, taay ninh"
  ],
  "Châu Hưng A, Vĩnh Lợi, Bạc Liêu": [
    "châu hưng a, vĩnh lợi, bạc liêu",
    "chaau huwng a, vixnh lowji, bajc lieeu"
  ],
  "Châu Hưng, Thạnh Trị, Sóc Trăng": [
    "châu hưng, thạnh trị, sóc trăng",
    "chaau huwng, thajnh trij, sosc trawng"
  ],
  "Châu Thành, Châu Thành, Sóc Trăng": [
    "châu thành, châu thành, sóc trăng",
    "chaau thafnh, chaau thafnh, sosc trawng"
  ],
  "Chợ Lầu, Bắc Bình, Bình Thuận": [
    "chợ lầu, bắc bình, bình thuận",
    "chowj laafu, bawsc bifnh, bifnh thuaajn"
  ],
  "Cái Tắc, Châu Thành A, Hậu Giang": [
    "cái tắc, châu thành a, hậu giang",
    "casi tawsc, chaau thafnh a, haaju giang"
  ],
  "Cát Tường, Phù Cát, Bình Định": [
    "cát tường, phù cát, bình định",
    "cast tuwowfng, phuf cast, bifnh ddijnh"
  ],
  "Cây Thị, Đồng Hỷ, Thái Nguyên": [
    "cây thị, đồng hỷ, thái nguyên",
    "caay thij, ddoofng hyr, thasi nguyeen"
  ],
  "Cù Lao Dung, Cù Lao Dung, Sóc Trăng": [
    "cù lao dung, cù lao dung, sóc trăng",
    "cuf lao dung, cuf lao dung, sosc trawng"
  ],
  "Cúc Đường, Võ Nhai, Thái Nguyên": [
    "cúc đường, võ nhai, thái nguyên",
    "cusc dduwowfng, vox nhai, thasi nguyeen"
  ],
  "Cấp Tiến, Tiên Lãng, Hải Phòng": [
    "cấp tiến, tiên lãng, hải phòng",
    "caasp tieesn, tieen laxng, hari phofng"
  ],
  "Cần Kiệm, Thạch Thất, Hà Nội": [
    "cần kiệm, thạch thất, hà nội",
    "caafn kieejm, thajch thaast, haf nooji"
  ],
  "Cần Đước, Cần Đước, Long An": [
    "cần đước, cần đước, long an",
    "caafn dduwowsc, caafn dduwowsc, long an"
  ],
  "Cầu Diễn, Nam Từ Liêm, Hà Nội": [
    "cầu diễn, nam từ liêm, hà nội",
    "caafu dieexn, nam tuwf lieem, haf nooji"
  ],
  "Cẩm Lương, Cẩm Thủy, Thanh Hóa": [
    "cẩm lương, cẩm thủy, thanh hóa",
    "caarm luwowng, caarm thury, thanh hosa"
  ],
  "Cẩm Thành, Cẩm Phả, Quảng Ninh": [
    "cẩm thành, cẩm phả, quảng ninh",
    "caarm thafnh, caarm phar, quarng ninh"
  ],
  "Cẩm Thạch, Cẩm Thủy, Thanh Hóa": [
    "cẩm thạch, cẩm thủy, thanh hóa",
    "caarm thajch, caarm thury, thanh hosa"
  ],
  "Cẩm Thủy, Cẩm Phả, Quảng Ninh": [
    "cẩm thủy, cẩm phả, quảng ninh",
    "caarm thury, caarm phar, quarng ninh"
  ],
  "Cẩm Văn, Cẩm Giàng, Hải Dương": [
    "cẩm văn, cẩm giàng, hải dương",
    "caarm vawn, caarm giafng, hari duwowng"
  ],
  "Cẩm Đông, Cẩm Phả, Quảng Ninh": [
    "cẩm đông, cẩm phả, quảng ninh",
    "caarm ddoong, caarm phar, quarng ninh"
  ],
  "Cổ Lũng, Phú Lương, Thái Nguyên": [
    "cổ lũng, phú lương, thái nguyên",
    "coor luxng, phus luwowng, thasi nguyeen"
  ],
  "Cộng Hòa, Quảng Yên, Quảng Ninh": [
    "cộng hòa, quảng yên, quảng ninh",
    "coojng hofa, quarng yeen, quarng ninh"
  ],
  "Cửa Dương, Phú Quốc, Kiên Giang": [
    "cửa dương, phú quốc, kiên giang",
    "cuwra duwowng, phus quoosc, kieen giang"
  ],
  "Cự Nẫm, Bố Trạch, Quảng Bình": [
    "cự nẫm, bố trạch, quảng bình",
    "cuwj naaxm, boos trajch, quarng bifnh"
  ],
  "Diên Khánh, Diên Khánh, Khánh Hòa": [
    "diên khánh, diên khánh, khánh hòa",
    "dieen khasnh, dieen khasnh, khasnh hofa"
  ],
  "Diêu Trì, Tuy Phước, Bình Định": [
    "diêu trì, tuy phước, bình định",
    "dieeu trif, tuy phuwowsc, bifnh ddijnh"
  ],
  "Diễn Nguyên, Diễn Châu, Nghệ An": [
    "diễn nguyên, diễn châu, nghệ an",
    "dieexn nguyeen, dieexn chaau, ngheej an"
  ],
  "Diễn Quảng, Diễn Châu, Nghệ An": [
    "diễn quảng, diễn châu, nghệ an",
    "dieexn quarng, dieexn chaau, ngheej an"
  ],
  "Diễn Thịnh, Diễn Châu, Nghệ An": [
    "diễn thịnh, diễn châu, nghệ an",
    "dieexn thijnh, dieexn chaau, ngheej an"
  ],
  "Diễn Đồng, Diễn Châu, Nghệ An": [
    "diễn đồng, diễn châu, nghệ an",
    "dieexn ddoofng, dieexn chaau, ngheej an"
  ],
  "Duyên Thái, Thường Tín, Hà Nội": [
    "duyên thái, thường tín, hà nội",
    "duyeen thasi, thuwowfng tisn, haf nooji"
  ],
  "Dũng Tiến, Thường Tín, Hà Nội": [
    "dũng tiến, thường tín, hà nội",
    "duxng tieesn, thuwowfng tisn, haf nooji"
  ],
  "Dũng Tiến, Vĩnh Bảo, Hải Phòng": [
    "dũng tiến, vĩnh bảo, hải phòng",
    "duxng tieesn, vixnh baro, hari phofng"
  ],
  "Dương Hưu, Sơn Động, Bắc Giang": [
    "dương hưu, sơn động, bắc giang",
    "duwowng huwu, sown ddoojng, bawsc giang"
  ],
  "Dương Liễu, Hoài Đức, Hà Nội": [
    "dương liễu, hoài đức, hà nội",
    "duwowng lieexu, hoafi dduwsc, haf nooji"
  ],
  "Dương Quang, Bắc Kạn, Bắc Kạn": [
    "dương quang, bắc kạn, bắc kạn",
    "duwowng quang, bawsc kajn, bawsc kajn"
  ],
  "Ghềnh Ráng, Qui Nhơn, Bình Định": [
    "ghềnh ráng, qui nhơn, bình định",
    "gheefnh rasng, qui nhown, bifnh ddijnh"
  ],
  "Gia Kiệm, Thống Nhất, Đồng Nai": [
    "gia kiệm, thống nhất, đồng nai",
    "gia kieejm, thoosng nhaast, ddoofng nai"
  ],
  "Gia Sàng, Thái Nguyên, Thái Nguyên": [
    "gia sàng, thái nguyên, thái nguyên",
    "gia safng, thasi nguyeen, thasi nguyeen"
  ],
  "Gia Tân 1, Thống Nhất, Đồng Nai": [
    "gia tân 1, thống nhất, đồng nai",
    "gia taan 1, thoosng nhaast, ddoofng nai"
  ],
  "Gia Tân 2, Thống Nhất, Đồng Nai": [
    "gia tân 2, thống nhất, đồng nai",
    "gia taan 2, thoosng nhaast, ddoofng nai"
  ],
  "Gia Tân 3, Thống Nhất, Đồng Nai": [
    "gia tân 3, thống nhất, đồng nai",
    "gia taan 3, thoosng nhaast, ddoofng nai"
  ],
  "Giang Điền, Trảng Bom, Đồng Nai": [
    "giang điền, trảng bom, đồng nai",
    "giang ddieefn, trarng bom, ddoofng nai"
  ],
  "Giàng Chu Phìn, Mèo Vạc, Hà Giang": [
    "giàng chu phìn, mèo vạc, hà giang",
    "giafng chu phifn, mefo vajc, haf giang"
  ],
  "Giồng Trôm, Giồng Trôm, Bến Tre": [
    "giồng trôm, giồng trôm, bến tre",
    "gioofng troom, gioofng troom, beesn tre"
  ],
  "Hiến Thành, Kinh Môn, Hải Dương": [
    "hiến thành, kinh môn, hải dương",
    "hieesn thafnh, kinh moon, hari duwowng"
  ],
  "Hiếu Nghĩa,  Vũng Liêm, Vĩnh Long": [
    "hiếu nghĩa,  vũng liêm, vĩnh long",
    "hieesu nghixa,  vuxng lieem, vixnh long"
  ],
  "Hiếu Thành,  Vũng Liêm, Vĩnh Long": [
    "hiếu thành,  vũng liêm, vĩnh long",
    "hieesu thafnh,  vuxng lieem, vixnh long"
  ],
  "Hiền Giang, Thường Tín, Hà Nội": [
    "hiền giang, thường tín, hà nội",
    "hieefn giang, thuwowfng tisn, haf nooji"
  ],
  "Hiệp An, Đức Trọng, Lâm Đồng": [
    "hiệp an, đức trọng, lâm đồng",
    "hieejp an, dduwsc trojng, laam ddoofng"
  ],
  "Hiệp Hòa, Hiệp Đức, Quảng Nam": [
    "hiệp hòa, hiệp đức, quảng nam",
    "hieejp hofa, hieejp dduwsc, quarng nam"
  ],
  "Hiệp Hòa, Quảng Yên, Quảng Ninh": [
    "hiệp hòa, quảng yên, quảng ninh",
    "hieejp hofa, quarng yeen, quarng ninh"
  ],
  "Hiệp Lực, Ninh Giang, Hải Dương": [
    "hiệp lực, ninh giang, hải dương",
    "hieejp luwjc, ninh giang, hari duwowng"
  ],
  "Hiệp Thành, Bạc Liêu, Bạc Liêu": [
    "hiệp thành, bạc liêu, bạc liêu",
    "hieejp thafnh, bajc lieeu, bajc lieeu"
  ],
  "Hiệp Thạnh, Duyên Hải, Trà Vinh": [
    "hiệp thạnh, duyên hải, trà vinh",
    "hieejp thajnh, duyeen hari, traf vinh"
  ],
  "Hoà Nghĩa, Dương Kinh, Hải Phòng": [
    "hoà nghĩa, dương kinh, hải phòng",
    "hoaf nghixa, duwowng kinh, hari phofng"
  ],
  "Hoà Quý, Ngũ Hành Sơn, Đà Nẵng": [
    "hoà quý, ngũ hành sơn, đà nẵng",
    "hoaf quys, ngux hafnh sown, ddaf nawxng"
  ],
  "Hoài Châu, Hoài Nhơn, Bình Định": [
    "hoài châu, hoài nhơn, bình định",
    "hoafi chaau, hoafi nhown, bifnh ddijnh"
  ],
  "Hoài Hải, Hoài Nhơn, Bình Định": [
    "hoài hải, hoài nhơn, bình định",
    "hoafi hari, hoafi nhown, bifnh ddijnh"
  ],
  "Hoài Hảo, Hoài Nhơn, Bình Định": [
    "hoài hảo, hoài nhơn, bình định",
    "hoafi haro, hoafi nhown, bifnh ddijnh"
  ],
  "Hoài Thanh, Hoài Nhơn, Bình Định": [
    "hoài thanh, hoài nhơn, bình định",
    "hoafi thanh, hoafi nhown, bifnh ddijnh"
  ],
  "Hoài Xuân, Hoài Nhơn, Bình Định": [
    "hoài xuân, hoài nhơn, bình định",
    "hoafi xuaan, hoafi nhown, bifnh ddijnh"
  ],
  "Hoàn Lão, Bố Trạch, Quảng Bình": [
    "hoàn lão, bố trạch, quảng bình",
    "hoafn laxo, boos trajch, quarng bifnh"
  ],
  "Hoàng Diệu, Chương Mỹ, Hà Nội": [
    "hoàng diệu, chương mỹ, hà nội",
    "hoafng dieeju, chuwowng myx, haf nooji"
  ],
  "Hoàng Diệu, Gia Lộc, Hải Dương": [
    "hoàng diệu, gia lộc, hải dương",
    "hoafng dieeju, gia loojc, hari duwowng"
  ],
  "Hoàng Diệu, Thái Bình, Thái Bình": [
    "hoàng diệu, thái bình, thái bình",
    "hoafng dieeju, thasi bifnh, thasi bifnh"
  ],
  "Hoàng Tiến, Chí Linh, Hải Dương": [
    "hoàng tiến, chí linh, hải dương",
    "hoafng tieesn, chis linh, hari duwowng"
  ],
  "Hoàng Tân, Quảng Yên, Quảng Ninh": [
    "hoàng tân, quảng yên, quảng ninh",
    "hoafng taan, quarng yeen, quarng ninh"
  ],
  "Hoằng Châu, Hoằng Hóa, Thanh Hóa": [
    "hoằng châu, hoằng hóa, thanh hóa",
    "hoawfng chaau, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Giang, Hoằng Hóa, Thanh Hóa": [
    "hoằng giang, hoằng hóa, thanh hóa",
    "hoawfng giang, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Hải, Hoằng Hóa, Thanh Hóa": [
    "hoằng hải, hoằng hóa, thanh hóa",
    "hoawfng hari, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Hợp, Hoằng Hóa, Thanh Hóa": [
    "hoằng hợp, hoằng hóa, thanh hóa",
    "hoawfng howjp, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Lộc, Hoằng Hóa, Thanh Hóa": [
    "hoằng lộc, hoằng hóa, thanh hóa",
    "hoawfng loojc, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Phong, Hoằng Hóa, Thanh Hóa": [
    "hoằng phong, hoằng hóa, thanh hóa",
    "hoawfng phong, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Phụ, Hoằng Hóa, Thanh Hóa": [
    "hoằng phụ, hoằng hóa, thanh hóa",
    "hoawfng phuj, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Quỳ, Hoằng Hóa, Thanh Hóa": [
    "hoằng quỳ, hoằng hóa, thanh hóa",
    "hoawfng quyf, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Thanh, Hoằng Hóa, Thanh Hóa": [
    "hoằng thanh, hoằng hóa, thanh hóa",
    "hoawfng thanh, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Thái, Hoằng Hóa, Thanh Hóa": [
    "hoằng thái, hoằng hóa, thanh hóa",
    "hoawfng thasi, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Trinh, Hoằng Hóa, Thanh Hóa": [
    "hoằng trinh, hoằng hóa, thanh hóa",
    "hoawfng trinh, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Trung, Hoằng Hóa, Thanh Hóa": [
    "hoằng trung, hoằng hóa, thanh hóa",
    "hoawfng trung, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Xuân, Hoằng Hóa, Thanh Hóa": [
    "hoằng xuân, hoằng hóa, thanh hóa",
    "hoawfng xuaan, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Yến, Hoằng Hóa, Thanh Hóa": [
    "hoằng yến, hoằng hóa, thanh hóa",
    "hoawfng yeesn, hoawfng hosa, thanh hosa"
  ],
  "Hua Thanh, Điện Biên, Điện Biên": [
    "hua thanh, điện biên, điện biên",
    "hua thanh, ddieejn bieen, ddieejn bieen"
  ],
  "Hành Minh, Nghĩa Hành, Quảng Ngãi": [
    "hành minh, nghĩa hành, quảng ngãi",
    "hafnh minh, nghixa hafnh, quarng ngaxi"
  ],
  "Hòa Bình, Kiến Xương, Thái Bình": [
    "hòa bình, kiến xương, thái bình",
    "hofa bifnh, kieesn xuwowng, thasi bifnh"
  ],
  "Hòa Bình, Đồng Hỷ, Thái Nguyên": [
    "hòa bình, đồng hỷ, thái nguyên",
    "hofa bifnh, ddoofng hyr, thasi nguyeen"
  ],
  "Hòa Hiệp Nam, Đông Hòa, Phú Yên": [
    "hòa hiệp nam, đông hòa, phú yên",
    "hofa hieejp nam, ddoong hofa, phus yeen"
  ],
  "Hòa Thành, Krông Bông, Đắk Lắk": [
    "hòa thành, krông bông, đắk lắk",
    "hofa thafnh, kroong boong, ddawsk lawsk"
  ],
  "Hòa Thạnh, Tân Phú, Hồ Chí Minh": [
    "hòa thạnh, tân phú, hồ chí minh",
    "hofa thajnh, taan phus, hoof chis minh"
  ],
  "Hòa Tiến, Krông Pắc, Đắk Lắk": [
    "hòa tiến, krông pắc, đắk lắk",
    "hofa tieesn, kroong pawsc, ddawsk lawsk"
  ],
  "Hòa Xuân Tây, Đông Hòa, Phú Yên": [
    "hòa xuân tây, đông hòa, phú yên",
    "hofa xuaan taay, ddoong hofa, phus yeen"
  ],
  "Hòa Đông, Krông Pắc, Đắk Lắk": [
    "hòa đông, krông pắc, đắk lắk",
    "hofa ddoong, kroong pawsc, ddawsk lawsk"
  ],
  "Hòa Định Tây, Phú Hoà, Phú Yên": [
    "hòa định tây, phú hoà, phú yên",
    "hofa ddijnh taay, phus hoaf, phus yeen"
  ],
  "Hòa Định, Chợ Gạo, Tiền Giang": [
    "hòa định, chợ gạo, tiền giang",
    "hofa ddijnh, chowj gajo, tieefn giang"
  ],
  "Hòn Nghệ, Kiên Lương, Kiên Giang": [
    "hòn nghệ, kiên lương, kiên giang",
    "hofn ngheej, kieen luwowng, kieen giang"
  ],
  "Hóa Trung, Đồng Hỷ, Thái Nguyên": [
    "hóa trung, đồng hỷ, thái nguyên",
    "hosa trung, ddoofng hyr, thasi nguyeen"
  ],
  "Hùng Sơn, Tràng Định, Lạng Sơn": [
    "hùng sơn, tràng định, lạng sơn",
    "hufng sown, trafng ddijnh, lajng sown"
  ],
  "Hùng Tiến, Vĩnh Bảo, Hải Phòng": [
    "hùng tiến, vĩnh bảo, hải phòng",
    "hufng tieesn, vixnh baro, hari phofng"
  ],
  "Húc Động, Bình Liêu, Quảng Ninh": [
    "húc động, bình liêu, quảng ninh",
    "husc ddoojng, bifnh lieeu, quarng ninh"
  ],
  "Hưng Long, Phan Thiết, Bình Thuận": [
    "hưng long, phan thiết, bình thuận",
    "huwng long, phan thieest, bifnh thuaajn"
  ],
  "Hưng Lợi, Thạnh Trị, Sóc Trăng": [
    "hưng lợi, thạnh trị, sóc trăng",
    "huwng lowji, thajnh trij, sosc trawng"
  ],
  "Hưng Nguyên, Hưng Nguyên, Nghệ An": [
    "hưng nguyên, hưng nguyên, nghệ an",
    "huwng nguyeen, huwng nguyeen, ngheej an"
  ],
  "Hưng Thuận, Trảng Bàng, Tây Ninh": [
    "hưng thuận, trảng bàng, tây ninh",
    "huwng thuaajn, trarng bafng, taay ninh"
  ],
  "Hưng Thịnh, Hưng Nguyên, Nghệ An": [
    "hưng thịnh, hưng nguyên, nghệ an",
    "huwng thijnh, huwng nguyeen, ngheej an"
  ],
  "Hưng Thịnh, Trảng Bom, Đồng Nai": [
    "hưng thịnh, trảng bom, đồng nai",
    "huwng thijnh, trarng bom, ddoofng nai"
  ],
  "Hưng Đạo, Nguyên Bình, Cao Bằng": [
    "hưng đạo, nguyên bình, cao bằng",
    "huwng ddajo, nguyeen bifnh, cao bawfng"
  ],
  "Hương Canh, Bình Xuyên, Vĩnh Phúc": [
    "hương canh, bình xuyên, vĩnh phúc",
    "huwowng canh, bifnh xuyeen, vixnh phusc"
  ],
  "Hương Sơ, Huế, Thừa Thiên Huế": [
    "hương sơ, huế, thừa thiên huế",
    "huwowng sow, huees, thuwfa thieen huees"
  ],
  "Hương Sơn, Bình Xuyên, Vĩnh Phúc": [
    "hương sơn, bình xuyên, vĩnh phúc",
    "huwowng sown, bifnh xuyeen, vixnh phusc"
  ],
  "Hương Sơn, Lạng Giang, Bắc Giang": [
    "hương sơn, lạng giang, bắc giang",
    "huwowng sown, lajng giang, bawsc giang"
  ],
  "Hương Sơn, Phú Bình, Thái Nguyên": [
    "hương sơn, phú bình, thái nguyên",
    "huwowng sown, phus bifnh, thasi nguyeen"
  ],
  "Hương Thủy, Hương Khê, Hà Tĩnh": [
    "hương thủy, hương khê, hà tĩnh",
    "huwowng thury, huwowng khee, haf tixnh"
  ],
  "Hải Hưng, Hải Lăng, Quảng Trị": [
    "hải hưng, hải lăng, quảng trị",
    "hari huwng, hari lawng, quarng trij"
  ],
  "Hải Ninh, Quảng Ninh, Quảng Bình": [
    "hải ninh, quảng ninh, quảng bình",
    "hari ninh, quarng ninh, quarng bifnh"
  ],
  "Hải Phong, Hải Lăng, Quảng Trị": [
    "hải phong, hải lăng, quảng trị",
    "hari phong, hari lawng, quarng trij"
  ],
  "Hải Phú, Bố Trạch, Quảng Bình": [
    "hải phú, bố trạch, quảng bình",
    "hari phus, boos trajch, quarng bifnh"
  ],
  "Hải Quế, Hải Lăng, Quảng Trị": [
    "hải quế, hải lăng, quảng trị",
    "hari quees, hari lawng, quarng trij"
  ],
  "Hải Triều, Hải Hậu, Nam Định": [
    "hải triều, hải hậu, nam định",
    "hari trieefu, hari haaju, nam ddijnh"
  ],
  "Hảo Đước, Châu Thành, Tây Ninh": [
    "hảo đước, châu thành, tây ninh",
    "haro dduwowsc, chaau thafnh, taay ninh"
  ],
  "Hậu Mỹ Phú, Cái Bè, Tiền Giang": [
    "hậu mỹ phú, cái bè, tiền giang",
    "haaju myx phus, casi bef, tieefn giang"
  ],
  "Hồ Bốn, Mù Căng Chải, Yên Bái": [
    "hồ bốn, mù căng chải, yên bái",
    "hoof boosn, muf cawng chari, yeen basi"
  ],
  "Hồng Dũng, Thái Thụy, Thái Bình": [
    "hồng dũng, thái thụy, thái bình",
    "hoofng duxng, thasi thujy, thasi bifnh"
  ],
  "Hồng Giang, Lục Ngạn, Bắc Giang": [
    "hồng giang, lục ngạn, bắc giang",
    "hoofng giang, lujc ngajn, bawsc giang"
  ],
  "Hồng Giang, Đông Hưng, Thái Bình": [
    "hồng giang, đông hưng, thái bình",
    "hoofng giang, ddoong huwng, thasi bifnh"
  ],
  "Hồng Khê, Bình Giang, Hải Dương": [
    "hồng khê, bình giang, hải dương",
    "hoofng khee, bifnh giang, hari duwowng"
  ],
  "Hồng Phong, Ninh Giang, Hải Dương": [
    "hồng phong, ninh giang, hải dương",
    "hoofng phong, ninh giang, hari duwowng"
  ],
  "Hồng Phúc, Ninh Giang, Hải Dương": [
    "hồng phúc, ninh giang, hải dương",
    "hoofng phusc, ninh giang, hari duwowng"
  ],
  "Hồng Tiến, Khoái Châu, Hưng Yên": [
    "hồng tiến, khoái châu, hưng yên",
    "hoofng tieesn, khoasi chaau, huwng yeen"
  ],
  "Hội Nghĩa, Tân Uyên, Bình Dương": [
    "hội nghĩa, tân uyên, bình dương",
    "hooji nghixa, taan uyeen, bifnh duwowng"
  ],
  "Hợp Thắng, Triệu Sơn, Thanh Hóa": [
    "hợp thắng, triệu sơn, thanh hóa",
    "howjp thawsng, trieeju sown, thanh hosa"
  ],
  "Hợp Thịnh, Hiệp Hòa, Bắc Giang": [
    "hợp thịnh, hiệp hòa, bắc giang",
    "howjp thijnh, hieejp hofa, bawsc giang"
  ],
  "Hợp Thịnh, Tam Dương, Vĩnh Phúc": [
    "hợp thịnh, tam dương, vĩnh phúc",
    "howjp thijnh, tam duwowng, vixnh phusc"
  ],
  "Hợp Tiến, Đông Hưng, Thái Bình": [
    "hợp tiến, đông hưng, thái bình",
    "howjp tieesn, ddoong huwng, thasi bifnh"
  ],
  "Hợp Đồng, Chương Mỹ, Hà Nội": [
    "hợp đồng, chương mỹ, hà nội",
    "howjp ddoofng, chuwowng myx, haf nooji"
  ],
  "Hữu Bằng, Thạch Thất, Hà Nội": [
    "hữu bằng, thạch thất, hà nội",
    "huwxu bawfng, thajch thaast, haf nooji"
  ],
  "KRông Búk, Krông Pắc, Đắk Lắk": [
    "krông búk, krông pắc, đắk lắk",
    "kroong busk, kroong pawsc, ddawsk lawsk"
  ],
  "Khánh Bình, Khánh Vĩnh, Khánh Hòa": [
    "khánh bình, khánh vĩnh, khánh hòa",
    "khasnh bifnh, khasnh vixnh, khasnh hofa"
  ],
  "Khánh Bình, Tân Uyên, Bình Dương": [
    "khánh bình, tân uyên, bình dương",
    "khasnh bifnh, taan uyeen, bifnh duwowng"
  ],
  "Khánh Thiện, Yên Khánh, Ninh Bình": [
    "khánh thiện, yên khánh, ninh bình",
    "khasnh thieejn, yeen khasnh, ninh bifnh"
  ],
  "Khánh Trung, Khánh Vĩnh, Khánh Hòa": [
    "khánh trung, khánh vĩnh, khánh hòa",
    "khasnh trung, khasnh vixnh, khasnh hofa"
  ],
  "Khánh Vĩnh Yên, Can Lộc, Hà Tĩnh": [
    "khánh vĩnh yên, can lộc, hà tĩnh",
    "khasnh vixnh yeen, can loojc, haf tixnh"
  ],
  "Khánh Vĩnh, Khánh Vĩnh, Khánh Hòa": [
    "khánh vĩnh, khánh vĩnh, khánh hòa",
    "khasnh vixnh, khasnh vixnh, khasnh hofa"
  ],
  "Khâm Thành, Trùng Khánh, Cao Bằng": [
    "khâm thành, trùng khánh, cao bằng",
    "khaam thafnh, trufng khasnh, cao bawfng"
  ],
  "Khương Đình, Thanh Xuân, Hà Nội": [
    "khương đình, thanh xuân, hà nội",
    "khuwowng ddifnh, thanh xuaan, haf nooji"
  ],
  "Kinh Cùng, Phụng Hiệp, Hậu Giang": [
    "kinh cùng, phụng hiệp, hậu giang",
    "kinh cufng, phujng hieejp, haaju giang"
  ],
  "Kiên Bình, Kiên Lương, Kiên Giang": [
    "kiên bình, kiên lương, kiên giang",
    "kieen bifnh, kieen luwowng, kieen giang"
  ],
  "Kiên Thành, Lục Ngạn, Bắc Giang": [
    "kiên thành, lục ngạn, bắc giang",
    "kieen thafnh, lujc ngajn, bawsc giang"
  ],
  "Kiến Thiết, Yên Sơn, Tuyên Quang": [
    "kiến thiết, yên sơn, tuyên quang",
    "kieesn thieest, yeen sown, tuyeen quang"
  ],
  "Krông Klang, Đa Krông, Quảng Trị": [
    "krông klang, đa krông, quảng trị",
    "kroong klang, dda kroong, quarng trij"
  ],
  "Krông Kmar, Krông Bông, Đắk Lắk": [
    "krông kmar, krông bông, đắk lắk",
    "kroong kmar, kroong boong, ddawsk lawsk"
  ],
  "Kỳ Sơn, Thuỷ Nguyên, Hải Phòng": [
    "kỳ sơn, thuỷ nguyên, hải phòng",
    "kyf sown, thuyr nguyeen, hari phofng"
  ],
  "Kỳ Thượng, Hạ Long, Quảng Ninh": [
    "kỳ thượng, hạ long, quảng ninh",
    "kyf thuwowjng, haj long, quarng ninh"
  ],
  "Lao Bảo, Hướng Hóa, Quảng Trị": [
    "lao bảo, hướng hóa, quảng trị",
    "lao baro, huwowsng hosa, quarng trij"
  ],
  "Lao Chải, Mù Căng Chải, Yên Bái": [
    "lao chải, mù căng chải, yên bái",
    "lao chari, muf cawng chari, yeen basi"
  ],
  "Linh Sơn, Thái Nguyên, Thái Nguyên": [
    "linh sơn, thái nguyên, thái nguyên",
    "linh sown, thasi nguyeen, thasi nguyeen"
  ],
  "Linh Trường, Gio Linh, Quảng Trị": [
    "linh trường, gio linh, quảng trị",
    "linh truwowfng, gio linh, quarng trij"
  ],
  "Linh Tây, Thủ Đức, Hồ Chí Minh": [
    "linh tây, thủ đức, hồ chí minh",
    "linh taay, thur dduwsc, hoof chis minh"
  ],
  "Liên Hương, Tuy Phong, Bình Thuận": [
    "liên hương, tuy phong, bình thuận",
    "lieen huwowng, tuy phong, bifnh thuaajn"
  ],
  "Liên Hồng, Đan Phượng, Hà Nội": [
    "liên hồng, đan phượng, hà nội",
    "lieen hoofng, ddan phuwowjng, haf nooji"
  ],
  "Liêng Srônh, Đam Rông, Lâm Đồng": [
    "liêng srônh, đam rông, lâm đồng",
    "lieeng sroonh, ddam roong, laam ddoofng"
  ],
  "Liễn Sơn, Lập Thạch, Vĩnh Phúc": [
    "liễn sơn, lập thạch, vĩnh phúc",
    "lieexn sown, laajp thajch, vixnh phusc"
  ],
  "Liễu Đề, Nghĩa Hưng, Nam Định": [
    "liễu đề, nghĩa hưng, nam định",
    "lieexu ddeef, nghixa huwng, nam ddijnh"
  ],
  "Long Hoà, Dầu Tiếng, Bình Dương": [
    "long hoà, dầu tiếng, bình dương",
    "long hoaf, daafu tieesng, bifnh duwowng"
  ],
  "Long Nguyên, Bàu Bàng, Bình Dương": [
    "long nguyên, bàu bàng, bình dương",
    "long nguyeen, bafu bafng, bifnh duwowng"
  ],
  "Long Phước, Long Thành, Đồng Nai": [
    "long phước, long thành, đồng nai",
    "long phuwowsc, long thafnh, ddoofng nai"
  ],
  "Long Phước, Quận 9, Hồ Chí Minh": [
    "long phước, quận 9, hồ chí minh",
    "long phuwowsc, quaajn 9, hoof chis minh"
  ],
  "Long Thành Nam, Hòa Thành, Tây Ninh": [
    "long thành nam, hòa thành, tây ninh",
    "long thafnh nam, hofa thafnh, taay ninh"
  ],
  "Long Tân, Dầu Tiếng, Bình Dương": [
    "long tân, dầu tiếng, bình dương",
    "long taan, daafu tieesng, bifnh duwowng"
  ],
  "Long Tân, Phú Riềng, Bình Phước": [
    "long tân, phú riềng, bình phước",
    "long taan, phus rieefng, bifnh phuwowsc"
  ],
  "Long Xuyên, Bình Giang, Hải Dương": [
    "long xuyên, bình giang, hải dương",
    "long xuyeen, bifnh giang, hari duwowng"
  ],
  "Long Điền, Đông Hải, Bạc Liêu": [
    "long điền, đông hải, bạc liêu",
    "long ddieefn, ddoong hari, bajc lieeu"
  ],
  "Láng Thượng, Đống Đa, Hà Nội": [
    "láng thượng, đống đa, hà nội",
    "lasng thuwowjng, ddoosng dda, haf nooji"
  ],
  "Lâm Kiết, Thạnh Trị, Sóc Trăng": [
    "lâm kiết, thạnh trị, sóc trăng",
    "laam kieest, thajnh trij, sosc trawng"
  ],
  "Lâm Thủy, Lệ Thủy, Quảng Bình": [
    "lâm thủy, lệ thủy, quảng bình",
    "laam thury, leej thury, quarng bifnh"
  ],
  "Lâu Thượng, Võ Nhai, Thái Nguyên": [
    "lâu thượng, võ nhai, thái nguyên",
    "laau thuwowjng, vox nhai, thasi nguyeen"
  ],
  "Lê Hồng, Thanh Miện, Hải Dương": [
    "lê hồng, thanh miện, hải dương",
    "lee hoofng, thanh mieejn, hari duwowng"
  ],
  "Lình Huỳnh, Hòn Đất, Kiên Giang": [
    "lình huỳnh, hòn đất, kiên giang",
    "lifnh huyfnh, hofn ddaast, kieen giang"
  ],
  "Lý Thái Tổ, Hoàn Kiếm, Hà Nội": [
    "lý thái tổ, hoàn kiếm, hà nội",
    "lys thasi toor, hoafn kieesm, haf nooji"
  ],
  "Lăng Hiếu, Trùng Khánh, Cao Bằng": [
    "lăng hiếu, trùng khánh, cao bằng",
    "lawng hieesu, trufng khasnh, cao bawfng"
  ],
  "Lũng Hoà, Vĩnh Tường, Vĩnh Phúc": [
    "lũng hoà, vĩnh tường, vĩnh phúc",
    "luxng hoaf, vixnh tuwowfng, vixnh phusc"
  ],
  "Lưu Kiền, Tương Dương, Nghệ An": [
    "lưu kiền, tương dương, nghệ an",
    "luwu kieefn, tuwowng duwowng, ngheej an"
  ],
  "Lưu Kỳ, Thuỷ Nguyên, Hải Phòng": [
    "lưu kỳ, thuỷ nguyên, hải phòng",
    "luwu kyf, thuyr nguyeen, hari phofng"
  ],
  "Lưu Vĩnh Sơn, Thạch Hà, Hà Tĩnh": [
    "lưu vĩnh sơn, thạch hà, hà tĩnh",
    "luwu vixnh sown, thajch haf, haf tixnh"
  ],
  "Lương Bằng, Kim Động, Hưng Yên": [
    "lương bằng, kim động, hưng yên",
    "luwowng bawfng, kim ddoojng, huwng yeen"
  ],
  "Lương Hoà A, Châu Thành, Trà Vinh": [
    "lương hoà a, châu thành, trà vinh",
    "luwowng hoaf a, chaau thafnh, traf vinh"
  ],
  "Lương Nội, Bá Thước, Thanh Hóa": [
    "lương nội, bá thước, thanh hóa",
    "luwowng nooji, bas thuwowsc, thanh hosa"
  ],
  "Lương Phong, Hiệp Hòa, Bắc Giang": [
    "lương phong, hiệp hòa, bắc giang",
    "luwowng phong, hieejp hofa, bawsc giang"
  ],
  "Lương Phú, Phú Bình, Thái Nguyên": [
    "lương phú, phú bình, thái nguyên",
    "luwowng phus, phus bifnh, thasi nguyeen"
  ],
  "Lương Thông, Hà Quảng, Cao Bằng": [
    "lương thông, hà quảng, cao bằng",
    "luwowng thoong, haf quarng, cao bawfng"
  ],
  "Lương Thịnh, Trấn Yên, Yên Bái": [
    "lương thịnh, trấn yên, yên bái",
    "luwowng thijnh, traasn yeen, yeen basi"
  ],
  "Lương Trung, Bá Thước, Thanh Hóa": [
    "lương trung, bá thước, thanh hóa",
    "luwowng trung, bas thuwowsc, thanh hosa"
  ],
  "Lạc Lâm, Đơn Dương, Lâm Đồng": [
    "lạc lâm, đơn dương, lâm đồng",
    "lajc laam, ddown duwowng, laam ddoofng"
  ],
  "Lạc Viên, Ngô Quyền, Hải Phòng": [
    "lạc viên, ngô quyền, hải phòng",
    "lajc vieen, ngoo quyeefn, hari phofng"
  ],
  "Lạch Tray, Ngô Quyền, Hải Phòng": [
    "lạch tray, ngô quyền, hải phòng",
    "lajch tray, ngoo quyeefn, hari phofng"
  ],
  "Lộc Hưng, Lộc Ninh, Bình Phước": [
    "lộc hưng, lộc ninh, bình phước",
    "loojc huwng, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Quang, Lộc Ninh, Bình Phước": [
    "lộc quang, lộc ninh, bình phước",
    "loojc quang, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Quảng, Bảo Lâm, Lâm Đồng": [
    "lộc quảng, bảo lâm, lâm đồng",
    "loojc quarng, baro laam, laam ddoofng"
  ],
  "Lộc Thái, Lộc Ninh, Bình Phước": [
    "lộc thái, lộc ninh, bình phước",
    "loojc thasi, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Thắng, Bảo Lâm, Lâm Đồng": [
    "lộc thắng, bảo lâm, lâm đồng",
    "loojc thawsng, baro laam, laam ddoofng"
  ],
  "Lộc Thịnh, Ngọc Lặc, Thanh Hóa": [
    "lộc thịnh, ngọc lặc, thanh hóa",
    "loojc thijnh, ngojc lawjc, thanh hosa"
  ],
  "Lộc Tiến, Bảo Lộc, Lâm Đồng": [
    "lộc tiến, bảo lộc, lâm đồng",
    "loojc tieesn, baro loojc, laam ddoofng"
  ],
  "Lộc Tấn, Lộc Ninh, Bình Phước": [
    "lộc tấn, lộc ninh, bình phước",
    "loojc taasn, loojc ninh, bifnh phuwowsc"
  ],
  "Lục Bình, Bạch Thông, Bắc Kạn": [
    "lục bình, bạch thông, bắc kạn",
    "lujc bifnh, bajch thoong, bawsc kajn"
  ],
  "Lục Sỹ Thành, Trà Ôn, Vĩnh Long": [
    "lục sỹ thành, trà ôn, vĩnh long",
    "lujc syx thafnh, traf oon, vixnh long"
  ],
  "Ma Đa Guôi, Đạ Huoai, Lâm Đồng": [
    "ma đa guôi, đạ huoai, lâm đồng",
    "ma dda guooi, ddaj huoai, laam ddoofng"
  ],
  "Minh Hoà, Dầu Tiếng, Bình Dương": [
    "minh hoà, dầu tiếng, bình dương",
    "minh hoaf, daafu tieesng, bifnh duwowng"
  ],
  "Minh Long, Chơn Thành, Bình Phước": [
    "minh long, chơn thành, bình phước",
    "minh long, chown thafnh, bifnh phuwowsc"
  ],
  "Minh Lương, Châu Thành, Kiên Giang": [
    "minh lương, châu thành, kiên giang",
    "minh luwowng, chaau thafnh, kieen giang"
  ],
  "Minh Lập, Đồng Hỷ, Thái Nguyên": [
    "minh lập, đồng hỷ, thái nguyên",
    "minh laajp, ddoofng hyr, thasi nguyeen"
  ],
  "Minh Quang, Kiến Xương, Thái Bình": [
    "minh quang, kiến xương, thái bình",
    "minh quang, kieesn xuwowng, thasi bifnh"
  ],
  "Minh Thành, Quảng Yên, Quảng Ninh": [
    "minh thành, quảng yên, quảng ninh",
    "minh thafnh, quarng yeen, quarng ninh"
  ],
  "Minh Tiến, Đại Từ, Thái Nguyên": [
    "minh tiến, đại từ, thái nguyên",
    "minh tieesn, ddaji tuwf, thasi nguyeen"
  ],
  "Minh Tâm, Hớn Quản, Bình Phước": [
    "minh tâm, hớn quản, bình phước",
    "minh taam, howsn quarn, bifnh phuwowsc"
  ],
  "Minh Tân, Dầu Tiếng, Bình Dương": [
    "minh tân, dầu tiếng, bình dương",
    "minh taan, daafu tieesng, bifnh duwowng"
  ],
  "Minh Tân, Thuỷ Nguyên, Hải Phòng": [
    "minh tân, thuỷ nguyên, hải phòng",
    "minh taan, thuyr nguyeen, hari phofng"
  ],
  "Mong Thọ A, Châu Thành, Kiên Giang": [
    "mong thọ a, châu thành, kiên giang",
    "mong thoj a, chaau thafnh, kieen giang"
  ],
  "Mong Thọ B, Châu Thành, Kiên Giang": [
    "mong thọ b, châu thành, kiên giang",
    "mong thoj b, chaau thafnh, kieen giang"
  ],
  "Mùn Chung, Tuần Giáo, Điện Biên": [
    "mùn chung, tuần giáo, điện biên",
    "mufn chung, tuaafn giaso, ddieejn bieen"
  ],
  "Mường Lý, Mường Lát, Thanh Hóa": [
    "mường lý, mường lát, thanh hóa",
    "muwowfng lys, muwowfng last, thanh hosa"
  ],
  "Mộ Đức, Mộ Đức, Quảng Ngãi": [
    "mộ đức, mộ đức, quảng ngãi",
    "mooj dduwsc, mooj dduwsc, quarng ngaxi"
  ],
  "Mỹ Hòa, Tháp Mười, Đồng Tháp": [
    "mỹ hòa, tháp mười, đồng tháp",
    "myx hofa, thasp muwowfi, ddoofng thasp"
  ],
  "Mỹ Hạnh Bắc, Đức Hòa, Long An": [
    "mỹ hạnh bắc, đức hòa, long an",
    "myx hajnh bawsc, dduwsc hofa, long an"
  ],
  "Mỹ Long Bắc, Cầu Ngang, Trà Vinh": [
    "mỹ long bắc, cầu ngang, trà vinh",
    "myx long bawsc, caafu ngang, traf vinh"
  ],
  "Mỹ Phước, Hòn Đất, Kiên Giang": [
    "mỹ phước, hòn đất, kiên giang",
    "myx phuwowsc, hofn ddaast, kieen giang"
  ],
  "Mỹ Quý Đông, Đức Huệ, Long An": [
    "mỹ quý đông, đức huệ, long an",
    "myx quys ddoong, dduwsc hueej, long an"
  ],
  "Mỹ Quý, Tháp Mười, Đồng Tháp": [
    "mỹ quý, tháp mười, đồng tháp",
    "myx quys, thasp muwowfi, ddoofng thasp"
  ],
  "Mỹ Thủy, Lệ Thủy, Quảng Bình": [
    "mỹ thủy, lệ thủy, quảng bình",
    "myx thury, leej thury, quarng bifnh"
  ],
  "Nam Cường, Chợ Đồn, Bắc Kạn": [
    "nam cường, chợ đồn, bắc kạn",
    "nam cuwowfng, chowj ddoofn, bawsc kajn"
  ],
  "Nam Cường, Tiền Hải, Thái Bình": [
    "nam cường, tiền hải, thái bình",
    "nam cuwowfng, tieefn hari, thasi bifnh"
  ],
  "Nghi Công Bắc, Nghi Lộc, Nghệ An": [
    "nghi công bắc, nghi lộc, nghệ an",
    "nghi coong bawsc, nghi loojc, ngheej an"
  ],
  "Nghĩa An, Quảng Ngãi, Quảng Ngãi": [
    "nghĩa an, quảng ngãi, quảng ngãi",
    "nghixa an, quarng ngaxi, quarng ngaxi"
  ],
  "Nghĩa Bình, Nghĩa Hưng, Nam Định": [
    "nghĩa bình, nghĩa hưng, nam định",
    "nghixa bifnh, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Châu, Nghĩa Hưng, Nam Định": [
    "nghĩa châu, nghĩa hưng, nam định",
    "nghixa chaau, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Hùng, Nghĩa Hưng, Nam Định": [
    "nghĩa hùng, nghĩa hưng, nam định",
    "nghixa hufng, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Hưng, Lạng Giang, Bắc Giang": [
    "nghĩa hưng, lạng giang, bắc giang",
    "nghixa huwng, lajng giang, bawsc giang"
  ],
  "Nghĩa Hải, Nghĩa Hưng, Nam Định": [
    "nghĩa hải, nghĩa hưng, nam định",
    "nghixa hari, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Lạc, Nghĩa Hưng, Nam Định": [
    "nghĩa lạc, nghĩa hưng, nam định",
    "nghixa lajc, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Lợi, Nghĩa Hưng, Nam Định": [
    "nghĩa lợi, nghĩa hưng, nam định",
    "nghixa lowji, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Phong, Nghĩa Hưng, Nam Định": [
    "nghĩa phong, nghĩa hưng, nam định",
    "nghixa phong, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Phương, Lục Nam, Bắc Giang": [
    "nghĩa phương, lục nam, bắc giang",
    "nghixa phuwowng, lujc nam, bawsc giang"
  ],
  "Nghĩa Thành, Gia Nghĩa, Đắk Nông": [
    "nghĩa thành, gia nghĩa, đắk nông",
    "nghixa thafnh, gia nghixa, ddawsk noong"
  ],
  "Nghĩa Thái, Nghĩa Hưng, Nam Định": [
    "nghĩa thái, nghĩa hưng, nam định",
    "nghixa thasi, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Thịnh, Nghĩa Đàn, Nghệ An": [
    "nghĩa thịnh, nghĩa đàn, nghệ an",
    "nghixa thijnh, nghixa ddafn, ngheej an"
  ],
  "Nghĩa Trung, Nghĩa Hưng, Nam Định": [
    "nghĩa trung, nghĩa hưng, nam định",
    "nghixa trung, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Trung, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa trung, tư nghĩa, quảng ngãi",
    "nghixa trung, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Đức, Gia Nghĩa, Đắk Nông": [
    "nghĩa đức, gia nghĩa, đắk nông",
    "nghixa dduwsc, gia nghixa, ddawsk noong"
  ],
  "Nguyên Giáp, Tứ Kỳ, Hải Dương": [
    "nguyên giáp, tứ kỳ, hải dương",
    "nguyeen giasp, tuws kyf, hari duwowng"
  ],
  "Nguyệt Ấn, Ngọc Lặc, Thanh Hóa": [
    "nguyệt ấn, ngọc lặc, thanh hóa",
    "nguyeejt aasn, ngojc lawjc, thanh hosa"
  ],
  "Ngũ Hùng, Thanh Miện, Hải Dương": [
    "ngũ hùng, thanh miện, hải dương",
    "ngux hufng, thanh mieejn, hari duwowng"
  ],
  "Ngũ Kiên, Vĩnh Tường, Vĩnh Phúc": [
    "ngũ kiên, vĩnh tường, vĩnh phúc",
    "ngux kieen, vixnh tuwowfng, vixnh phusc"
  ],
  "Ngũ Lão, Thuỷ Nguyên, Hải Phòng": [
    "ngũ lão, thuỷ nguyên, hải phòng",
    "ngux laxo, thuyr nguyeen, hari phofng"
  ],
  "Ngũ Phúc, Kiến Thuỵ, Hải Phòng": [
    "ngũ phúc, kiến thuỵ, hải phòng",
    "ngux phusc, kieesn thuyj, hari phofng"
  ],
  "Ngũ Đoan, Kiến Thuỵ, Hải Phòng": [
    "ngũ đoan, kiến thuỵ, hải phòng",
    "ngux ddoan, kieesn thuyj, hari phofng"
  ],
  "Ngọc Hội, Chiêm Hóa, Tuyên Quang": [
    "ngọc hội, chiêm hóa, tuyên quang",
    "ngojc hooji, chieem hosa, tuyeen quang"
  ],
  "Ngọc Lương, Yên Thủy, Hoà Bình": [
    "ngọc lương, yên thủy, hoà bình",
    "ngojc luwowng, yeen thury, hoaf bifnh"
  ],
  "Ngọc Mỹ, Lập Thạch, Vĩnh Phúc": [
    "ngọc mỹ, lập thạch, vĩnh phúc",
    "ngojc myx, laajp thajch, vixnh phusc"
  ],
  "Ngọc Phái, Chợ Đồn, Bắc Kạn": [
    "ngọc phái, chợ đồn, bắc kạn",
    "ngojc phasi, chowj ddoofn, bawsc kajn"
  ],
  "Ngọc Xuyên, Đồ Sơn, Hải Phòng": [
    "ngọc xuyên, đồ sơn, hải phòng",
    "ngojc xuyeen, ddoof sown, hari phofng"
  ],
  "Ngọc Đông, Mỹ Xuyên, Sóc Trăng": [
    "ngọc đông, mỹ xuyên, sóc trăng",
    "ngojc ddoong, myx xuyeen, sosc trawng"
  ],
  "Ngọc Động, Hà Quảng, Cao Bằng": [
    "ngọc động, hà quảng, cao bằng",
    "ngojc ddoojng, haf quarng, cao bawfng"
  ],
  "Nha Bích, Chơn Thành, Bình Phước": [
    "nha bích, chơn thành, bình phước",
    "nha bisch, chown thafnh, bifnh phuwowsc"
  ],
  "Nhân Cơ, Đắk R'Lấp, Đắk Nông": [
    "nhân cơ, đắk r'lấp, đắk nông",
    "nhaan cow, ddawsk r'laasp, ddawsk noong"
  ],
  "Nhơn Hòa Lập, Tân Thạnh, Long An": [
    "nhơn hòa lập, tân thạnh, long an",
    "nhown hofa laajp, taan thajnh, long an"
  ],
  "Nhơn Nghĩa, Phong Điền, Cần Thơ": [
    "nhơn nghĩa, phong điền, cần thơ",
    "nhown nghixa, phong ddieefn, caafn thow"
  ],
  "Nhật Tiến, Hữu Lũng, Lạng Sơn": [
    "nhật tiến, hữu lũng, lạng sơn",
    "nhaajt tieesn, huwxu luxng, lajng sown"
  ],
  "Nhị Bình, Châu Thành, Tiền Giang": [
    "nhị bình, châu thành, tiền giang",
    "nhij bifnh, chaau thafnh, tieefn giang"
  ],
  "Nhị Trường, Cầu Ngang, Trà Vinh": [
    "nhị trường, cầu ngang, trà vinh",
    "nhij truwowfng, caafu ngang, traf vinh"
  ],
  "Ninh Cường, Trực Ninh, Nam Định": [
    "ninh cường, trực ninh, nam định",
    "ninh cuwowfng, truwjc ninh, nam ddijnh"
  ],
  "Ninh Loan, Đức Trọng, Lâm Đồng": [
    "ninh loan, đức trọng, lâm đồng",
    "ninh loan, dduwsc trojng, laam ddoofng"
  ],
  "Ninh Quới A, Hồng Dân, Bạc Liêu": [
    "ninh quới a, hồng dân, bạc liêu",
    "ninh quowsi a, hoofng daan, bajc lieeu"
  ],
  "Núa Ngam, Điện Biên, Điện Biên": [
    "núa ngam, điện biên, điện biên",
    "nusa ngam, ddieejn bieen, ddieejn bieen"
  ],
  "Nậm Dịch, Hoàng Su Phì, Hà Giang": [
    "nậm dịch, hoàng su phì, hà giang",
    "naajm dijch, hoafng su phif, haf giang"
  ],
  "Nậm Kè, Mường Nhé, Điện Biên": [
    "nậm kè, mường nhé, điện biên",
    "naajm kef, muwowfng nhes, ddieejn bieen"
  ],
  "Nậm Vì, Mường Nhé, Điện Biên": [
    "nậm vì, mường nhé, điện biên",
    "naajm vif, muwowfng nhes, ddieejn bieen"
  ],
  "Phan Chu Trinh, Hoàn Kiếm, Hà Nội": [
    "phan chu trinh, hoàn kiếm, hà nội",
    "phan chu trinh, hoafn kieesm, haf nooji"
  ],
  "Phan Hiệp, Bắc Bình, Bình Thuận": [
    "phan hiệp, bắc bình, bình thuận",
    "phan hieejp, bawsc bifnh, bifnh thuaajn"
  ],
  "Phan Tiến, Bắc Bình, Bình Thuận": [
    "phan tiến, bắc bình, bình thuận",
    "phan tieesn, bawsc bifnh, bifnh thuaajn"
  ],
  "Phong Cốc, Quảng Yên, Quảng Ninh": [
    "phong cốc, quảng yên, quảng ninh",
    "phong coosc, quarng yeen, quarng ninh"
  ],
  "Phong Hải, Quảng Yên, Quảng Ninh": [
    "phong hải, quảng yên, quảng ninh",
    "phong hari, quarng yeen, quarng ninh"
  ],
  "Phì Điền, Lục Ngạn, Bắc Giang": [
    "phì điền, lục ngạn, bắc giang",
    "phif ddieefn, lujc ngajn, bawsc giang"
  ],
  "Phù Ninh, Thuỷ Nguyên, Hải Phòng": [
    "phù ninh, thuỷ nguyên, hải phòng",
    "phuf ninh, thuyr nguyeen, hari phofng"
  ],
  "Phú An, Phú Vang, Thừa Thiên Huế": [
    "phú an, phú vang, thừa thiên huế",
    "phus an, phus vang, thuwfa thieen huees"
  ],
  "Phú Cường, Tam Nông, Đồng Tháp": [
    "phú cường, tam nông, đồng tháp",
    "phus cuwowfng, tam noong, ddoofng thasp"
  ],
  "Phú Hiệp, Huế, Thừa Thiên Huế": [
    "phú hiệp, huế, thừa thiên huế",
    "phus hieejp, huees, thuwfa thieen huees"
  ],
  "Phú Hựu, Châu Thành, Đồng Tháp": [
    "phú hựu, châu thành, đồng tháp",
    "phus huwju, chaau thafnh, ddoofng thasp"
  ],
  "Phú Lương, Đông Hưng, Thái Bình": [
    "phú lương, đông hưng, thái bình",
    "phus luwowng, ddoong huwng, thasi bifnh"
  ],
  "Phú Ngãi Trị, Châu Thành, Long An": [
    "phú ngãi trị, châu thành, long an",
    "phus ngaxi trij, chaau thafnh, long an"
  ],
  "Phú Ngọc, Định Quán, Đồng Nai": [
    "phú ngọc, định quán, đồng nai",
    "phus ngojc, ddijnh quasn, ddoofng nai"
  ],
  "Phú Nhuận, Lục Ngạn, Bắc Giang": [
    "phú nhuận, lục ngạn, bắc giang",
    "phus nhuaajn, lujc ngajn, bawsc giang"
  ],
  "Phú Thành A, Tam Nông, Đồng Tháp": [
    "phú thành a, tam nông, đồng tháp",
    "phus thafnh a, tam noong, ddoofng thasp"
  ],
  "Phú Thành B, Tam Nông, Đồng Tháp": [
    "phú thành b, tam nông, đồng tháp",
    "phus thafnh b, tam noong, ddoofng thasp"
  ],
  "Phú Thượng, Võ Nhai, Thái Nguyên": [
    "phú thượng, võ nhai, thái nguyên",
    "phus thuwowjng, vox nhai, thasi nguyeen"
  ],
  "Phú Thạnh, Tân Phú, Hồ Chí Minh": [
    "phú thạnh, tân phú, hồ chí minh",
    "phus thajnh, taan phus, hoof chis minh"
  ],
  "Phú Thủy, Lệ Thủy, Quảng Bình": [
    "phú thủy, lệ thủy, quảng bình",
    "phus thury, leej thury, quarng bifnh"
  ],
  "Phú Trinh, Phan Thiết, Bình Thuận": [
    "phú trinh, phan thiết, bình thuận",
    "phus trinh, phan thieest, bifnh thuaajn"
  ],
  "Phú Xuyên, Đại Từ, Thái Nguyên": [
    "phú xuyên, đại từ, thái nguyên",
    "phus xuyeen, ddaji tuwf, thasi nguyeen"
  ],
  "Phú Đông, Nhơn Trạch, Đồng Nai": [
    "phú đông, nhơn trạch, đồng nai",
    "phus ddoong, nhown trajch, ddoofng nai"
  ],
  "Phú Đức, Bình Long, Bình Phước": [
    "phú đức, bình long, bình phước",
    "phus dduwsc, bifnh long, bifnh phuwowsc"
  ],
  "Phúc Hà, Thái Nguyên, Thái Nguyên": [
    "phúc hà, thái nguyên, thái nguyên",
    "phusc haf, thasi nguyeen, thasi nguyeen"
  ],
  "Phúc Thịnh, Ngọc Lặc, Thanh Hóa": [
    "phúc thịnh, ngọc lặc, thanh hóa",
    "phusc thijnh, ngojc lawjc, thanh hosa"
  ],
  "Phúc Ứng, Sơn Dương, Tuyên Quang": [
    "phúc ứng, sơn dương, tuyên quang",
    "phusc uwsng, sown duwowng, tuyeen quang"
  ],
  "Phương Liệt, Thanh Xuân, Hà Nội": [
    "phương liệt, thanh xuân, hà nội",
    "phuwowng lieejt, thanh xuaan, haf nooji"
  ],
  "Phương Thạnh, Càng Long, Trà Vinh": [
    "phương thạnh, càng long, trà vinh",
    "phuwowng thajnh, cafng long, traf vinh"
  ],
  "Phương Tiến, Vị Xuyên, Hà Giang": [
    "phương tiến, vị xuyên, hà giang",
    "phuwowng tieesn, vij xuyeen, haf giang"
  ],
  "Phương Trà, Cao Lãnh, Đồng Tháp": [
    "phương trà, cao lãnh, đồng tháp",
    "phuwowng traf, cao laxnh, ddoofng thasp"
  ],
  "Phước An, Krông Pắc, Đắk Lắk": [
    "phước an, krông pắc, đắk lắk",
    "phuwowsc an, kroong pawsc, ddawsk lawsk"
  ],
  "Phước An, Nhơn Trạch, Đồng Nai": [
    "phước an, nhơn trạch, đồng nai",
    "phuwowsc an, nhown trajch, ddoofng nai"
  ],
  "Phước Chính, Bác Ái, Ninh Thuận": [
    "phước chính, bác ái, ninh thuận",
    "phuwowsc chisnh, basc asi, ninh thuaajn"
  ],
  "Phước Hà, Thuận Nam, Ninh Thuận": [
    "phước hà, thuận nam, ninh thuận",
    "phuwowsc haf, thuaajn nam, ninh thuaajn"
  ],
  "Phước Hảo, Châu Thành, Trà Vinh": [
    "phước hảo, châu thành, trà vinh",
    "phuwowsc haro, chaau thafnh, traf vinh"
  ],
  "Phước Long, Giồng Trôm, Bến Tre": [
    "phước long, giồng trôm, bến tre",
    "phuwowsc long, gioofng troom, beesn tre"
  ],
  "Phước Mỹ, Qui Nhơn, Bình Định": [
    "phước mỹ, qui nhơn, bình định",
    "phuwowsc myx, qui nhown, bifnh ddijnh"
  ],
  "Phước Nam, Thuận Nam, Ninh Thuận": [
    "phước nam, thuận nam, ninh thuận",
    "phuwowsc nam, thuaajn nam, ninh thuaajn"
  ],
  "Phước Ninh, Hải Châu, Đà Nẵng": [
    "phước ninh, hải châu, đà nẵng",
    "phuwowsc ninh, hari chaau, ddaf nawxng"
  ],
  "Phước Thành, Bác Ái, Ninh Thuận": [
    "phước thành, bác ái, ninh thuận",
    "phuwowsc thafnh, basc asi, ninh thuaajn"
  ],
  "Phước Tiến, Bác Ái, Ninh Thuận": [
    "phước tiến, bác ái, ninh thuận",
    "phuwowsc tieesn, basc asi, ninh thuaajn"
  ],
  "Phước Tiến, Nha Trang, Khánh Hòa": [
    "phước tiến, nha trang, khánh hòa",
    "phuwowsc tieesn, nha trang, khasnh hofa"
  ],
  "Phước Đại, Bác Ái, Ninh Thuận": [
    "phước đại, bác ái, ninh thuận",
    "phuwowsc ddaji, basc asi, ninh thuaajn"
  ],
  "Phường 01, Gò Vấp, Hồ Chí Minh": [
    "phường 01, gò vấp, hồ chí minh",
    "phuwowfng 01, gof vaasp, hoof chis minh"
  ],
  "Phường 01, Quận 10, Hồ Chí Minh": [
    "phường 01, quận 10, hồ chí minh",
    "phuwowfng 01, quaajn 10, hoof chis minh"
  ],
  "Phường 01, Quận 11, Hồ Chí Minh": [
    "phường 01, quận 11, hồ chí minh",
    "phuwowfng 01, quaajn 11, hoof chis minh"
  ],
  "Phường 02, Quận 10, Hồ Chí Minh": [
    "phường 02, quận 10, hồ chí minh",
    "phuwowfng 02, quaajn 10, hoof chis minh"
  ],
  "Phường 02, Quận 11, Hồ Chí Minh": [
    "phường 02, quận 11, hồ chí minh",
    "phuwowfng 02, quaajn 11, hoof chis minh"
  ],
  "Phường 03, Gò Vấp, Hồ Chí Minh": [
    "phường 03, gò vấp, hồ chí minh",
    "phuwowfng 03, gof vaasp, hoof chis minh"
  ],
  "Phường 03, Quận 10, Hồ Chí Minh": [
    "phường 03, quận 10, hồ chí minh",
    "phuwowfng 03, quaajn 10, hoof chis minh"
  ],
  "Phường 03, Quận 11, Hồ Chí Minh": [
    "phường 03, quận 11, hồ chí minh",
    "phuwowfng 03, quaajn 11, hoof chis minh"
  ],
  "Phường 04, Gò Vấp, Hồ Chí Minh": [
    "phường 04, gò vấp, hồ chí minh",
    "phuwowfng 04, gof vaasp, hoof chis minh"
  ],
  "Phường 04, Quận 10, Hồ Chí Minh": [
    "phường 04, quận 10, hồ chí minh",
    "phuwowfng 04, quaajn 10, hoof chis minh"
  ],
  "Phường 04, Quận 11, Hồ Chí Minh": [
    "phường 04, quận 11, hồ chí minh",
    "phuwowfng 04, quaajn 11, hoof chis minh"
  ],
  "Phường 05, Gò Vấp, Hồ Chí Minh": [
    "phường 05, gò vấp, hồ chí minh",
    "phuwowfng 05, gof vaasp, hoof chis minh"
  ],
  "Phường 05, Quận 10, Hồ Chí Minh": [
    "phường 05, quận 10, hồ chí minh",
    "phuwowfng 05, quaajn 10, hoof chis minh"
  ],
  "Phường 05, Quận 11, Hồ Chí Minh": [
    "phường 05, quận 11, hồ chí minh",
    "phuwowfng 05, quaajn 11, hoof chis minh"
  ],
  "Phường 06, Quận 10, Hồ Chí Minh": [
    "phường 06, quận 10, hồ chí minh",
    "phuwowfng 06, quaajn 10, hoof chis minh"
  ],
  "Phường 06, Quận 11, Hồ Chí Minh": [
    "phường 06, quận 11, hồ chí minh",
    "phuwowfng 06, quaajn 11, hoof chis minh"
  ],
  "Phường 07, Gò Vấp, Hồ Chí Minh": [
    "phường 07, gò vấp, hồ chí minh",
    "phuwowfng 07, gof vaasp, hoof chis minh"
  ],
  "Phường 07, Quận 10, Hồ Chí Minh": [
    "phường 07, quận 10, hồ chí minh",
    "phuwowfng 07, quaajn 10, hoof chis minh"
  ],
  "Phường 07, Quận 11, Hồ Chí Minh": [
    "phường 07, quận 11, hồ chí minh",
    "phuwowfng 07, quaajn 11, hoof chis minh"
  ],
  "Phường 08, Quận 10, Hồ Chí Minh": [
    "phường 08, quận 10, hồ chí minh",
    "phuwowfng 08, quaajn 10, hoof chis minh"
  ],
  "Phường 08, Quận 11, Hồ Chí Minh": [
    "phường 08, quận 11, hồ chí minh",
    "phuwowfng 08, quaajn 11, hoof chis minh"
  ],
  "Phường 09, Quận 10, Hồ Chí Minh": [
    "phường 09, quận 10, hồ chí minh",
    "phuwowfng 09, quaajn 10, hoof chis minh"
  ],
  "Phường 09, Quận 11, Hồ Chí Minh": [
    "phường 09, quận 11, hồ chí minh",
    "phuwowfng 09, quaajn 11, hoof chis minh"
  ],
  "Phường 10, Gò Vấp, Hồ Chí Minh": [
    "phường 10, gò vấp, hồ chí minh",
    "phuwowfng 10, gof vaasp, hoof chis minh"
  ],
  "Phường 10, Quận 10, Hồ Chí Minh": [
    "phường 10, quận 10, hồ chí minh",
    "phuwowfng 10, quaajn 10, hoof chis minh"
  ],
  "Phường 10, Quận 11, Hồ Chí Minh": [
    "phường 10, quận 11, hồ chí minh",
    "phuwowfng 10, quaajn 11, hoof chis minh"
  ],
  "Phường 11, Gò Vấp, Hồ Chí Minh": [
    "phường 11, gò vấp, hồ chí minh",
    "phuwowfng 11, gof vaasp, hoof chis minh"
  ],
  "Phường 11, Quận 10, Hồ Chí Minh": [
    "phường 11, quận 10, hồ chí minh",
    "phuwowfng 11, quaajn 10, hoof chis minh"
  ],
  "Phường 11, Quận 11, Hồ Chí Minh": [
    "phường 11, quận 11, hồ chí minh",
    "phuwowfng 11, quaajn 11, hoof chis minh"
  ],
  "Phường 12, Gò Vấp, Hồ Chí Minh": [
    "phường 12, gò vấp, hồ chí minh",
    "phuwowfng 12, gof vaasp, hoof chis minh"
  ],
  "Phường 12, Quận 10, Hồ Chí Minh": [
    "phường 12, quận 10, hồ chí minh",
    "phuwowfng 12, quaajn 10, hoof chis minh"
  ],
  "Phường 12, Quận 11, Hồ Chí Minh": [
    "phường 12, quận 11, hồ chí minh",
    "phuwowfng 12, quaajn 11, hoof chis minh"
  ],
  "Phường 13, Gò Vấp, Hồ Chí Minh": [
    "phường 13, gò vấp, hồ chí minh",
    "phuwowfng 13, gof vaasp, hoof chis minh"
  ],
  "Phường 13, Quận 10, Hồ Chí Minh": [
    "phường 13, quận 10, hồ chí minh",
    "phuwowfng 13, quaajn 10, hoof chis minh"
  ],
  "Phường 13, Quận 11, Hồ Chí Minh": [
    "phường 13, quận 11, hồ chí minh",
    "phuwowfng 13, quaajn 11, hoof chis minh"
  ],
  "Phường 14, Gò Vấp, Hồ Chí Minh": [
    "phường 14, gò vấp, hồ chí minh",
    "phuwowfng 14, gof vaasp, hoof chis minh"
  ],
  "Phường 14, Quận 10, Hồ Chí Minh": [
    "phường 14, quận 10, hồ chí minh",
    "phuwowfng 14, quaajn 10, hoof chis minh"
  ],
  "Phường 14, Quận 11, Hồ Chí Minh": [
    "phường 14, quận 11, hồ chí minh",
    "phuwowfng 14, quaajn 11, hoof chis minh"
  ],
  "Phường 15, Gò Vấp, Hồ Chí Minh": [
    "phường 15, gò vấp, hồ chí minh",
    "phuwowfng 15, gof vaasp, hoof chis minh"
  ],
  "Phường 15, Quận 10, Hồ Chí Minh": [
    "phường 15, quận 10, hồ chí minh",
    "phuwowfng 15, quaajn 10, hoof chis minh"
  ],
  "Phường 15, Quận 11, Hồ Chí Minh": [
    "phường 15, quận 11, hồ chí minh",
    "phuwowfng 15, quaajn 11, hoof chis minh"
  ],
  "Phường 16, Gò Vấp, Hồ Chí Minh": [
    "phường 16, gò vấp, hồ chí minh",
    "phuwowfng 16, gof vaasp, hoof chis minh"
  ],
  "Phường 16, Quận 11, Hồ Chí Minh": [
    "phường 16, quận 11, hồ chí minh",
    "phuwowfng 16, quaajn 11, hoof chis minh"
  ],
  "Phường 17, Gò Vấp, Hồ Chí Minh": [
    "phường 17, gò vấp, hồ chí minh",
    "phuwowfng 17, gof vaasp, hoof chis minh"
  ],
  "Phượng Dực, Phú Xuyên, Hà Nội": [
    "phượng dực, phú xuyên, hà nội",
    "phuwowjng duwjc, phus xuyeen, haf nooji"
  ],
  "Phượng Lâu, Việt Trì, Phú Thọ": [
    "phượng lâu, việt trì, phú thọ",
    "phuwowjng laau, vieejt trif, phus thoj"
  ],
  "Phạm Kha, Thanh Miện, Hải Dương": [
    "phạm kha, thanh miện, hải dương",
    "phajm kha, thanh mieejn, hari duwowng"
  ],
  "Phạm Trấn, Gia Lộc, Hải Dương": [
    "phạm trấn, gia lộc, hải dương",
    "phajm traasn, gia loojc, hari duwowng"
  ],
  "Phồn Xương, Yên Thế, Bắc Giang": [
    "phồn xương, yên thế, bắc giang",
    "phoofn xuwowng, yeen thees, bawsc giang"
  ],
  "Phổ Hòa, Đức Phổ, Quảng Ngãi": [
    "phổ hòa, đức phổ, quảng ngãi",
    "phoor hofa, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Minh, Đức Phổ, Quảng Ngãi": [
    "phổ minh, đức phổ, quảng ngãi",
    "phoor minh, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Ninh, Đức Phổ, Quảng Ngãi": [
    "phổ ninh, đức phổ, quảng ngãi",
    "phoor ninh, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Vinh, Đức Phổ, Quảng Ngãi": [
    "phổ vinh, đức phổ, quảng ngãi",
    "phoor vinh, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Văn, Đức Phổ, Quảng Ngãi": [
    "phổ văn, đức phổ, quảng ngãi",
    "phoor vawn, dduwsc phoor, quarng ngaxi"
  ],
  "Phục Linh, Đại Từ, Thái Nguyên": [
    "phục linh, đại từ, thái nguyên",
    "phujc linh, ddaji tuwf, thasi nguyeen"
  ],
  "Phụng Châu, Chương Mỹ, Hà Nội": [
    "phụng châu, chương mỹ, hà nội",
    "phujng chaau, chuwowng myx, haf nooji"
  ],
  "Pá Ma Pha Khinh, Quỳnh Nhai, Sơn La": [
    "pá ma pha khinh, quỳnh nhai, sơn la",
    "pas ma pha khinh, quyfnh nhai, sown la"
  ],
  "Quang Minh, Kiến Xương, Thái Bình": [
    "quang minh, kiến xương, thái bình",
    "quang minh, kieesn xuwowng, thasi bifnh"
  ],
  "Quang Phục, Tiên Lãng, Hải Phòng": [
    "quang phục, tiên lãng, hải phòng",
    "quang phujc, tieen laxng, hari phofng"
  ],
  "Quang Sơn, Đồng Hỷ, Thái Nguyên": [
    "quang sơn, đồng hỷ, thái nguyên",
    "quang sown, ddoofng hyr, thasi nguyeen"
  ],
  "Quang Thành, Nguyên Bình, Cao Bằng": [
    "quang thành, nguyên bình, cao bằng",
    "quang thafnh, nguyeen bifnh, cao bawfng"
  ],
  "Quyết Chiến, Tân Lạc, Hoà Bình": [
    "quyết chiến, tân lạc, hoà bình",
    "quyeest chieesn, taan lajc, hoaf bifnh"
  ],
  "Quyết Thắng, Lạc Sơn, Hoà Bình": [
    "quyết thắng, lạc sơn, hoà bình",
    "quyeest thawsng, lajc sown, hoaf bifnh"
  ],
  "Quài Cang, Tuần Giáo, Điện Biên": [
    "quài cang, tuần giáo, điện biên",
    "quafi cang, tuaafn giaso, ddieejn bieen"
  ],
  "Quài Nưa, Tuần Giáo, Điện Biên": [
    "quài nưa, tuần giáo, điện biên",
    "quafi nuwa, tuaafn giaso, ddieejn bieen"
  ],
  "Quài Tở, Tuần Giáo, Điện Biên": [
    "quài tở, tuần giáo, điện biên",
    "quafi towr, tuaafn giaso, ddieejn bieen"
  ],
  "Quán Hàu, Quảng Ninh, Quảng Bình": [
    "quán hàu, quảng ninh, quảng bình",
    "quasn hafu, quarng ninh, quarng bifnh"
  ],
  "Quảng Chính, Hải Hà, Quảng Ninh": [
    "quảng chính, hải hà, quảng ninh",
    "quarng chisnh, hari haf, quarng ninh"
  ],
  "Quảng Hiệp, Cư M'gar, Đắk Lắk": [
    "quảng hiệp, cư m'gar, đắk lắk",
    "quarng hieejp, cuw m'gar, ddawsk lawsk"
  ],
  "Quảng Hoà, Đăk Glong, Đắk Nông": [
    "quảng hoà, đăk glong, đắk nông",
    "quarng hoaf, ddawk glong, ddawsk noong"
  ],
  "Quảng Hưng, Quảng Hòa, Cao Bằng": [
    "quảng hưng, quảng hòa, cao bằng",
    "quarng huwng, quarng hofa, cao bawfng"
  ],
  "Quảng Hải, Ba Đồn, Quảng Bình": [
    "quảng hải, ba đồn, quảng bình",
    "quarng hari, ba ddoofn, quarng bifnh"
  ],
  "Quảng Khê, Đăk Glong, Đắk Nông": [
    "quảng khê, đăk glong, đắk nông",
    "quarng khee, ddawk glong, ddawsk noong"
  ],
  "Quảng Lạc, Lạng Sơn, Lạng Sơn": [
    "quảng lạc, lạng sơn, lạng sơn",
    "quarng lajc, lajng sown, lajng sown"
  ],
  "Quảng Lộc, Ba Đồn, Quảng Bình": [
    "quảng lộc, ba đồn, quảng bình",
    "quarng loojc, ba ddoofn, quarng bifnh"
  ],
  "Quảng Ngãi, Cát Tiên, Lâm Đồng": [
    "quảng ngãi, cát tiên, lâm đồng",
    "quarng ngaxi, cast tieen, laam ddoofng"
  ],
  "Quảng Phong, Ba Đồn, Quảng Bình": [
    "quảng phong, ba đồn, quảng bình",
    "quarng phong, ba ddoofn, quarng bifnh"
  ],
  "Quảng Phúc, Ba Đồn, Quảng Bình": [
    "quảng phúc, ba đồn, quảng bình",
    "quarng phusc, ba ddoofn, quarng bifnh"
  ],
  "Quảng Sơn, Đăk Glong, Đắk Nông": [
    "quảng sơn, đăk glong, đắk nông",
    "quarng sown, ddawk glong, ddawsk noong"
  ],
  "Quảng Thành, Hải Hà, Quảng Ninh": [
    "quảng thành, hải hà, quảng ninh",
    "quarng thafnh, hari haf, quarng ninh"
  ],
  "Quảng Thắng, Thanh Hóa, Thanh Hóa": [
    "quảng thắng, thanh hóa, thanh hóa",
    "quarng thawsng, thanh hosa, thanh hosa"
  ],
  "Quảng Thịnh, Thanh Hóa, Thanh Hóa": [
    "quảng thịnh, thanh hóa, thanh hóa",
    "quarng thijnh, thanh hosa, thanh hosa"
  ],
  "Quảng Thọ, Ba Đồn, Quảng Bình": [
    "quảng thọ, ba đồn, quảng bình",
    "quarng thoj, ba ddoofn, quarng bifnh"
  ],
  "Quảng Tiên, Ba Đồn, Quảng Bình": [
    "quảng tiên, ba đồn, quảng bình",
    "quarng tieen, ba ddoofn, quarng bifnh"
  ],
  "Quảng Tiến, Cư M'gar, Đắk Lắk": [
    "quảng tiến, cư m'gar, đắk lắk",
    "quarng tieesn, cuw m'gar, ddawsk lawsk"
  ],
  "Quảng Trung, Ba Đồn, Quảng Bình": [
    "quảng trung, ba đồn, quảng bình",
    "quarng trung, ba ddoofn, quarng bifnh"
  ],
  "Quảng Uyên, Quảng Hòa, Cao Bằng": [
    "quảng uyên, quảng hòa, cao bằng",
    "quarng uyeen, quarng hofa, cao bawfng"
  ],
  "Quảng Đức, Hải Hà, Quảng Ninh": [
    "quảng đức, hải hà, quảng ninh",
    "quarng dduwsc, hari haf, quarng ninh"
  ],
  "Quế Thọ, Hiệp Đức, Quảng Nam": [
    "quế thọ, hiệp đức, quảng nam",
    "quees thoj, hieejp dduwsc, quarng nam"
  ],
  "Quốc Toản, Quảng Hòa, Cao Bằng": [
    "quốc toản, quảng hòa, cao bằng",
    "quoosc toarn, quarng hofa, cao bawfng"
  ],
  "Quốc Tuấn, An Dương, Hải Phòng": [
    "quốc tuấn, an dương, hải phòng",
    "quoosc tuaasn, an duwowng, hari phofng"
  ],
  "Quốc Tuấn, Nam Sách, Hải Dương": [
    "quốc tuấn, nam sách, hải dương",
    "quoosc tuaasn, nam sasch, hari duwowng"
  ],
  "Quới Điền, Thạnh Phú, Bến Tre": [
    "quới điền, thạnh phú, bến tre",
    "quowsi ddieefn, thajnh phus, beesn tre"
  ],
  "Quỳnh Bảng, Quỳnh Lưu, Nghệ An": [
    "quỳnh bảng, quỳnh lưu, nghệ an",
    "quyfnh barng, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Diễn, Quỳnh Lưu, Nghệ An": [
    "quỳnh diễn, quỳnh lưu, nghệ an",
    "quyfnh dieexn, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Hoa, Quỳnh Phụ, Thái Bình": [
    "quỳnh hoa, quỳnh phụ, thái bình",
    "quyfnh hoa, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Hồng, Quỳnh Lưu, Nghệ An": [
    "quỳnh hồng, quỳnh lưu, nghệ an",
    "quyfnh hoofng, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Lôi, Hai Bà Trưng, Hà Nội": [
    "quỳnh lôi, hai bà trưng, hà nội",
    "quyfnh looi, hai baf truwng, haf nooji"
  ],
  "Quỳnh Nghĩa, Quỳnh Lưu, Nghệ An": [
    "quỳnh nghĩa, quỳnh lưu, nghệ an",
    "quyfnh nghixa, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Ngọc, Quỳnh Lưu, Nghệ An": [
    "quỳnh ngọc, quỳnh lưu, nghệ an",
    "quyfnh ngojc, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Phương, Hoàng Mai, Nghệ An": [
    "quỳnh phương, hoàng mai, nghệ an",
    "quyfnh phuwowng, hoafng mai, ngheej an"
  ],
  "Quỳnh Xá, Quỳnh Phụ, Thái Bình": [
    "quỳnh xá, quỳnh phụ, thái bình",
    "quyfnh xas, quyfnh phuj, thasi bifnh"
  ],
  "Quỹ Nhất, Nghĩa Hưng, Nam Định": [
    "quỹ nhất, nghĩa hưng, nam định",
    "quyx nhaast, nghixa huwng, nam ddijnh"
  ],
  "Sam Mứn, Điện Biên, Điện Biên": [
    "sam mứn, điện biên, điện biên",
    "sam muwsn, ddieejn bieen, ddieejn bieen"
  ],
  "Sin Suối Hồ, Phong Thổ, Lai Châu": [
    "sin suối hồ, phong thổ, lai châu",
    "sin suoosi hoof, phong thoor, lai chaau"
  ],
  "Song Liễu, Thuận Thành, Bắc Ninh": [
    "song liễu, thuận thành, bắc ninh",
    "song lieexu, thuaajn thafnh, bawsc ninh"
  ],
  "Suối Tiên, Diên Khánh, Khánh Hòa": [
    "suối tiên, diên khánh, khánh hòa",
    "suoosi tieen, dieen khasnh, khasnh hofa"
  ],
  "Sông Bình, Bắc Bình, Bình Thuận": [
    "sông bình, bắc bình, bình thuận",
    "soong bifnh, bawsc bifnh, bifnh thuaajn"
  ],
  "Sông Khoai, Quảng Yên, Quảng Ninh": [
    "sông khoai, quảng yên, quảng ninh",
    "soong khoai, quarng yeen, quarng ninh"
  ],
  "Sông Đà, Mường Lay, Điện Biên": [
    "sông đà, mường lay, điện biên",
    "soong ddaf, muwowfng lay, ddieejn bieen"
  ],
  "Sùng Nhơn, Đức Linh, Bình Thuận": [
    "sùng nhơn, đức linh, bình thuận",
    "sufng nhown, dduwsc linh, bifnh thuaajn"
  ],
  "Sơn Lộc, Bố Trạch, Quảng Bình": [
    "sơn lộc, bố trạch, quảng bình",
    "sown loojc, boos trajch, quarng bifnh"
  ],
  "Sơn Thượng, Sơn Hà, Quảng Ngãi": [
    "sơn thượng, sơn hà, quảng ngãi",
    "sown thuwowjng, sown haf, quarng ngaxi"
  ],
  "Sơn Thủy, Lệ Thủy, Quảng Bình": [
    "sơn thủy, lệ thủy, quảng bình",
    "sown thury, leej thury, quarng bifnh"
  ],
  "Sơn Trường, Hương Sơn, Hà Tĩnh": [
    "sơn trường, hương sơn, hà tĩnh",
    "sown truwowfng, huwowng sown, haf tixnh"
  ],
  "Sơn Đông, Lập Thạch, Vĩnh Phúc": [
    "sơn đông, lập thạch, vĩnh phúc",
    "sown ddoong, laajp thajch, vixnh phusc"
  ],
  "Tam Anh Bắc, Núi Thành, Quảng Nam": [
    "tam anh bắc, núi thành, quảng nam",
    "tam anh bawsc, nusi thafnh, quarng nam"
  ],
  "Tam Bình, Thủ Đức, Hồ Chí Minh": [
    "tam bình, thủ đức, hồ chí minh",
    "tam bifnh, thur dduwsc, hoof chis minh"
  ],
  "Tam Cường, Vĩnh Bảo, Hải Phòng": [
    "tam cường, vĩnh bảo, hải phòng",
    "tam cuwowfng, vixnh baro, hari phofng"
  ],
  "Tam Hưng, Thuỷ Nguyên, Hải Phòng": [
    "tam hưng, thuỷ nguyên, hải phòng",
    "tam huwng, thuyr nguyeen, hari phofng"
  ],
  "Tam Mỹ Tây, Núi Thành, Quảng Nam": [
    "tam mỹ tây, núi thành, quảng nam",
    "tam myx taay, nusi thafnh, quarng nam"
  ],
  "Tam Đường, Tam Đường, Lai Châu": [
    "tam đường, tam đường, lai châu",
    "tam dduwowfng, tam dduwowfng, lai chaau"
  ],
  "Thanh Bình, Bù Đốp, Bình Phước": [
    "thanh bình, bù đốp, bình phước",
    "thanh bifnh, buf ddoosp, bifnh phuwowsc"
  ],
  "Thanh Bình, Thanh Bình, Đồng Tháp": [
    "thanh bình, thanh bình, đồng tháp",
    "thanh bifnh, thanh bifnh, ddoofng thasp"
  ],
  "Thanh Luận, Sơn Động, Bắc Giang": [
    "thanh luận, sơn động, bắc giang",
    "thanh luaajn, sown ddoojng, bawsc giang"
  ],
  "Thanh Ngọc, Thanh Chương, Nghệ An": [
    "thanh ngọc, thanh chương, nghệ an",
    "thanh ngojc, thanh chuwowng, ngheej an"
  ],
  "Thanh Sơn, Kiến Thuỵ, Hải Phòng": [
    "thanh sơn, kiến thuỵ, hải phòng",
    "thanh sown, kieesn thuyj, hari phofng"
  ],
  "Thanh Thịnh, Chợ Mới, Bắc Kạn": [
    "thanh thịnh, chợ mới, bắc kạn",
    "thanh thijnh, chowj mowsi, bawsc kajn"
  ],
  "Thanh Thủy, Thanh Chương, Nghệ An": [
    "thanh thủy, thanh chương, nghệ an",
    "thanh thury, thanh chuwowng, ngheej an"
  ],
  "Thanh Tân, Kiến Xương, Thái Bình": [
    "thanh tân, kiến xương, thái bình",
    "thanh taan, kieesn xuwowng, thasi bifnh"
  ],
  "Thanh Xuân Nam, Thanh Xuân, Hà Nội": [
    "thanh xuân nam, thanh xuân, hà nội",
    "thanh xuaan nam, thanh xuaan, haf nooji"
  ],
  "Thanh Đức, Thanh Chương, Nghệ An": [
    "thanh đức, thanh chương, nghệ an",
    "thanh dduwsc, thanh chuwowng, ngheej an"
  ],
  "Thiết Ống, Bá Thước, Thanh Hóa": [
    "thiết ống, bá thước, thanh hóa",
    "thieest oosng, bas thuwowsc, thanh hosa"
  ],
  "Thiện Kế, Bình Xuyên, Vĩnh Phúc": [
    "thiện kế, bình xuyên, vĩnh phúc",
    "thieejn kees, bifnh xuyeen, vixnh phusc"
  ],
  "Thiện Mỹ, Châu Thành, Sóc Trăng": [
    "thiện mỹ, châu thành, sóc trăng",
    "thieejn myx, chaau thafnh, sosc trawng"
  ],
  "Thiện Phiến, Tiên Lữ, Hưng Yên": [
    "thiện phiến, tiên lữ, hưng yên",
    "thieejn phieesn, tieen luwx, huwng yeen"
  ],
  "Thiện Thuật, Bình Gia, Lạng Sơn": [
    "thiện thuật, bình gia, lạng sơn",
    "thieejn thuaajt, bifnh gia, lajng sown"
  ],
  "Thiệu Công, Thiệu Hóa, Thanh Hóa": [
    "thiệu công, thiệu hóa, thanh hóa",
    "thieeju coong, thieeju hosa, thanh hosa"
  ],
  "Thiệu Dương, Thanh Hóa, Thanh Hóa": [
    "thiệu dương, thanh hóa, thanh hóa",
    "thieeju duwowng, thanh hosa, thanh hosa"
  ],
  "Thiệu Giang, Thiệu Hóa, Thanh Hóa": [
    "thiệu giang, thiệu hóa, thanh hóa",
    "thieeju giang, thieeju hosa, thanh hosa"
  ],
  "Thiệu Hợp, Thiệu Hóa, Thanh Hóa": [
    "thiệu hợp, thiệu hóa, thanh hóa",
    "thieeju howjp, thieeju hosa, thanh hosa"
  ],
  "Thiệu Phúc, Thiệu Hóa, Thanh Hóa": [
    "thiệu phúc, thiệu hóa, thanh hóa",
    "thieeju phusc, thieeju hosa, thanh hosa"
  ],
  "Thiệu Quang, Thiệu Hóa, Thanh Hóa": [
    "thiệu quang, thiệu hóa, thanh hóa",
    "thieeju quang, thieeju hosa, thanh hosa"
  ],
  "Thiệu Toán, Thiệu Hóa, Thanh Hóa": [
    "thiệu toán, thiệu hóa, thanh hóa",
    "thieeju toasn, thieeju hosa, thanh hosa"
  ],
  "Thiệu Trung, Thiệu Hóa, Thanh Hóa": [
    "thiệu trung, thiệu hóa, thanh hóa",
    "thieeju trung, thieeju hosa, thanh hosa"
  ],
  "Thiệu Viên, Thiệu Hóa, Thanh Hóa": [
    "thiệu viên, thiệu hóa, thanh hóa",
    "thieeju vieen, thieeju hosa, thanh hosa"
  ],
  "Thiệu Vận, Thiệu Hóa, Thanh Hóa": [
    "thiệu vận, thiệu hóa, thanh hóa",
    "thieeju vaajn, thieeju hosa, thanh hosa"
  ],
  "Thuần Hưng, Khoái Châu, Hưng Yên": [
    "thuần hưng, khoái châu, hưng yên",
    "thuaafn huwng, khoasi chaau, huwng yeen"
  ],
  "Thuận Giao, Thuận An, Bình Dương": [
    "thuận giao, thuận an, bình dương",
    "thuaajn giao, thuaajn an, bifnh duwowng"
  ],
  "Thuận Hòa, Châu Thành, Sóc Trăng": [
    "thuận hòa, châu thành, sóc trăng",
    "thuaajn hofa, chaau thafnh, sosc trawng"
  ],
  "Thuận Hưng, Thốt Nốt, Cần Thơ": [
    "thuận hưng, thốt nốt, cần thơ",
    "thuaajn huwng, thoost noost, caafn thow"
  ],
  "Thành Công, Nguyên Bình, Cao Bằng": [
    "thành công, nguyên bình, cao bằng",
    "thafnh coong, nguyeen bifnh, cao bawfng"
  ],
  "Thành Công, Phổ Yên, Thái Nguyên": [
    "thành công, phổ yên, thái nguyên",
    "thafnh coong, phoor yeen, thasi nguyeen"
  ],
  "Thành Long, Thạch Thành, Thanh Hóa": [
    "thành long, thạch thành, thanh hóa",
    "thafnh long, thajch thafnh, thanh hosa"
  ],
  "Thành Minh, Thạch Thành, Thanh Hóa": [
    "thành minh, thạch thành, thanh hóa",
    "thafnh minh, thajch thafnh, thanh hosa"
  ],
  "Thành Mỹ, Thạch Thành, Thanh Hóa": [
    "thành mỹ, thạch thành, thanh hóa",
    "thafnh myx, thajch thafnh, thanh hosa"
  ],
  "Thành Phước, Bình Minh, Vĩnh Long": [
    "thành phước, bình minh, vĩnh long",
    "thafnh phuwowsc, bifnh minh, vixnh long"
  ],
  "Thành Triệu, Châu Thành, Bến Tre": [
    "thành triệu, châu thành, bến tre",
    "thafnh trieeju, chaau thafnh, beesn tre"
  ],
  "Thành Tâm, Thạch Thành, Thanh Hóa": [
    "thành tâm, thạch thành, thanh hóa",
    "thafnh taam, thajch thafnh, thanh hosa"
  ],
  "Thành Tân, Thạch Thành, Thanh Hóa": [
    "thành tân, thạch thành, thanh hóa",
    "thafnh taan, thajch thafnh, thanh hosa"
  ],
  "Thành Vinh, Thạch Thành, Thanh Hóa": [
    "thành vinh, thạch thành, thanh hóa",
    "thafnh vinh, thajch thafnh, thanh hosa"
  ],
  "Thành Yên, Thạch Thành, Thanh Hóa": [
    "thành yên, thạch thành, thanh hóa",
    "thafnh yeen, thajch thafnh, thanh hosa"
  ],
  "Thái Bình Trung, Vĩnh Hưng, Long An": [
    "thái bình trung, vĩnh hưng, long an",
    "thasi bifnh trung, vixnh huwng, long an"
  ],
  "Thái Học, Bình Giang, Hải Dương": [
    "thái học, bình giang, hải dương",
    "thasi hojc, bifnh giang, hari duwowng"
  ],
  "Thái Thịnh, Kinh Môn, Hải Dương": [
    "thái thịnh, kinh môn, hải dương",
    "thasi thijnh, kinh moon, hari duwowng"
  ],
  "Thái Xuyên, Thái Thụy, Thái Bình": [
    "thái xuyên, thái thụy, thái bình",
    "thasi xuyeen, thasi thujy, thasi bifnh"
  ],
  "Thượng Bình, Bắc Quang, Hà Giang": [
    "thượng bình, bắc quang, hà giang",
    "thuwowjng bifnh, bawsc quang, haf giang"
  ],
  "Thượng Cốc, Lạc Sơn, Hoà Bình": [
    "thượng cốc, lạc sơn, hoà bình",
    "thuwowjng coosc, lajc sown, hoaf bifnh"
  ],
  "Thượng Cốc, Phúc Thọ, Hà Nội": [
    "thượng cốc, phúc thọ, hà nội",
    "thuwowjng coosc, phusc thoj, haf nooji"
  ],
  "Thượng Cửu, Thanh Sơn, Phú Thọ": [
    "thượng cửu, thanh sơn, phú thọ",
    "thuwowjng cuwru, thanh sown, phus thoj"
  ],
  "Thượng Lan, Việt Yên, Bắc Giang": [
    "thượng lan, việt yên, bắc giang",
    "thuwowjng lan, vieejt yeen, bawsc giang"
  ],
  "Thượng Nung, Võ Nhai, Thái Nguyên": [
    "thượng nung, võ nhai, thái nguyên",
    "thuwowjng nung, vox nhai, thasi nguyeen"
  ],
  "Thượng Phùng, Mèo Vạc, Hà Giang": [
    "thượng phùng, mèo vạc, hà giang",
    "thuwowjng phufng, mefo vajc, haf giang"
  ],
  "Thượng Quan, Ngân Sơn, Bắc Kạn": [
    "thượng quan, ngân sơn, bắc kạn",
    "thuwowjng quan, ngaan sown, bawsc kajn"
  ],
  "Thượng Sơn, Đô Lương, Nghệ An": [
    "thượng sơn, đô lương, nghệ an",
    "thuwowjng sown, ddoo luwowng, ngheej an"
  ],
  "Thạch Hoà, Thạch Thất, Hà Nội": [
    "thạch hoà, thạch thất, hà nội",
    "thajch hoaf, thajch thaast, haf nooji"
  ],
  "Thạch Lương, Nghĩa Lộ, Yên Bái": [
    "thạch lương, nghĩa lộ, yên bái",
    "thajch luwowng, nghixa looj, yeen basi"
  ],
  "Thạch Lập, Ngọc Lặc, Thanh Hóa": [
    "thạch lập, ngọc lặc, thanh hóa",
    "thajch laajp, ngojc lawjc, thanh hosa"
  ],
  "Thạch Thang, Hải Châu, Đà Nẵng": [
    "thạch thang, hải châu, đà nẵng",
    "thajch thang, hari chaau, ddaf nawxng"
  ],
  "Thạch Thắng, Thạch Hà, Hà Tĩnh": [
    "thạch thắng, thạch hà, hà tĩnh",
    "thajch thawsng, thajch haf, haf tixnh"
  ],
  "Thạnh An, Cần Giờ, Hồ Chí Minh": [
    "thạnh an, cần giờ, hồ chí minh",
    "thajnh an, caafn giowf, hoof chis minh"
  ],
  "Thạnh Hưng, Kiến Tường, Long An": [
    "thạnh hưng, kiến tường, long an",
    "thajnh huwng, kieesn tuwowfng, long an"
  ],
  "Thạnh Mỹ Tây, Châu Phú, An Giang": [
    "thạnh mỹ tây, châu phú, an giang",
    "thajnh myx taay, chaau phus, an giang"
  ],
  "Thạnh Mỹ, Vĩnh Thạnh, Cần Thơ": [
    "thạnh mỹ, vĩnh thạnh, cần thơ",
    "thajnh myx, vixnh thajnh, caafn thow"
  ],
  "Thạnh Phước, Thạnh Hóa, Long An": [
    "thạnh phước, thạnh hóa, long an",
    "thajnh phuwowsc, thajnh hosa, long an"
  ],
  "Thạnh Trị, Kiến Tường, Long An": [
    "thạnh trị, kiến tường, long an",
    "thajnh trij, kieesn tuwowfng, long an"
  ],
  "Thạnh Trị, Tân Hiệp, Kiên Giang": [
    "thạnh trị, tân hiệp, kiên giang",
    "thajnh trij, taan hieejp, kieen giang"
  ],
  "Thắng Hải, Hàm Tân, Bình Thuận": [
    "thắng hải, hàm tân, bình thuận",
    "thawsng hari, hafm taan, bifnh thuaajn"
  ],
  "Thọ Xương, Bắc Giang, Bắc Giang": [
    "thọ xương, bắc giang, bắc giang",
    "thoj xuwowng, bawsc giang, bawsc giang"
  ],
  "Thống Kênh, Gia Lộc, Hải Dương": [
    "thống kênh, gia lộc, hải dương",
    "thoosng keenh, gia loojc, hari duwowng"
  ],
  "Thống Nhất, Biên Hòa, Đồng Nai": [
    "thống nhất, biên hòa, đồng nai",
    "thoosng nhaast, bieen hofa, ddoofng nai"
  ],
  "Thống Nhất, Hạ Long, Quảng Ninh": [
    "thống nhất, hạ long, quảng ninh",
    "thoosng nhaast, haj long, quarng ninh"
  ],
  "Thổ Tang, Vĩnh Tường, Vĩnh Phúc": [
    "thổ tang, vĩnh tường, vĩnh phúc",
    "thoor tang, vixnh tuwowfng, vixnh phusc"
  ],
  "Thới Thuận, Bình Đại, Bến Tre": [
    "thới thuận, bình đại, bến tre",
    "thowsi thuaajn, bifnh ddaji, beesn tre"
  ],
  "Thới Thạnh, Thạnh Phú, Bến Tre": [
    "thới thạnh, thạnh phú, bến tre",
    "thowsi thajnh, thajnh phus, beesn tre"
  ],
  "Thụy Bình, Thái Thụy, Thái Bình": [
    "thụy bình, thái thụy, thái bình",
    "thujy bifnh, thasi thujy, thasi bifnh"
  ],
  "Thụy Hưng, Thái Thụy, Thái Bình": [
    "thụy hưng, thái thụy, thái bình",
    "thujy huwng, thasi thujy, thasi bifnh"
  ],
  "Thụy Hải, Thái Thụy, Thái Bình": [
    "thụy hải, thái thụy, thái bình",
    "thujy hari, thasi thujy, thasi bifnh"
  ],
  "Thụy Liên, Thái Thụy, Thái Bình": [
    "thụy liên, thái thụy, thái bình",
    "thujy lieen, thasi thujy, thasi bifnh"
  ],
  "Thụy Phong, Thái Thụy, Thái Bình": [
    "thụy phong, thái thụy, thái bình",
    "thujy phong, thasi thujy, thasi bifnh"
  ],
  "Thụy Thanh, Thái Thụy, Thái Bình": [
    "thụy thanh, thái thụy, thái bình",
    "thujy thanh, thasi thujy, thasi bifnh"
  ],
  "Thụy Xuân, Thái Thụy, Thái Bình": [
    "thụy xuân, thái thụy, thái bình",
    "thujy xuaan, thasi thujy, thasi bifnh"
  ],
  "Thủy An, Đông Triều, Quảng Ninh": [
    "thủy an, đông triều, quảng ninh",
    "thury an, ddoong trieefu, quarng ninh"
  ],
  "Tiên Hội, Đại Từ, Thái Nguyên": [
    "tiên hội, đại từ, thái nguyên",
    "tieen hooji, ddaji tuwf, thasi nguyeen"
  ],
  "Tiên Kỳ, Tiên Phước, Quảng Nam": [
    "tiên kỳ, tiên phước, quảng nam",
    "tieen kyf, tieen phuwowsc, quarng nam"
  ],
  "Tiên Mỹ, Tiên Phước, Quảng Nam": [
    "tiên mỹ, tiên phước, quảng nam",
    "tieen myx, tieen phuwowsc, quarng nam"
  ],
  "Tiên Sơn, Tiên Phước, Quảng Nam": [
    "tiên sơn, tiên phước, quảng nam",
    "tieen sown, tieen phuwowsc, quarng nam"
  ],
  "Tiên Động, Tứ Kỳ, Hải Dương": [
    "tiên động, tứ kỳ, hải dương",
    "tieen ddoojng, tuws kyf, hari duwowng"
  ],
  "Tiến Hóa, Tuyên Hóa, Quảng Bình": [
    "tiến hóa, tuyên hóa, quảng bình",
    "tieesn hosa, tuyeen hosa, quarng bifnh"
  ],
  "Tiến Thắng, Yên Thế, Bắc Giang": [
    "tiến thắng, yên thế, bắc giang",
    "tieesn thawsng, yeen thees, bawsc giang"
  ],
  "Tiến Xuân, Thạch Thất, Hà Nội": [
    "tiến xuân, thạch thất, hà nội",
    "tieesn xuaan, thajch thaast, haf nooji"
  ],
  "Tiền Hải, Tiền Hải, Thái Bình": [
    "tiền hải, tiền hải, thái bình",
    "tieefn hari, tieefn hari, thasi bifnh"
  ],
  "Tiền Phong, Thường Tín, Hà Nội": [
    "tiền phong, thường tín, hà nội",
    "tieefn phong, thuwowfng tisn, haf nooji"
  ],
  "Tiền Phong, Vĩnh Bảo, Hải Phòng": [
    "tiền phong, vĩnh bảo, hải phòng",
    "tieefn phong, vixnh baro, hari phofng"
  ],
  "Toàn Thắng, Gia Lộc, Hải Dương": [
    "toàn thắng, gia lộc, hải dương",
    "toafn thawsng, gia loojc, hari duwowng"
  ],
  "Tri Phương, Trùng Khánh, Cao Bằng": [
    "tri phương, trùng khánh, cao bằng",
    "tri phuwowng, trufng khasnh, cao bawfng"
  ],
  "Trung Chánh, Hóc Môn, Hồ Chí Minh": [
    "trung chánh, hóc môn, hồ chí minh",
    "trung chasnh, hosc moon, hoof chis minh"
  ],
  "Trung Hà, Thuỷ Nguyên, Hải Phòng": [
    "trung hà, thuỷ nguyên, hải phòng",
    "trung haf, thuyr nguyeen, hari phofng"
  ],
  "Trung Sơn Trầm, Sơn Tây, Hà Nội": [
    "trung sơn trầm, sơn tây, hà nội",
    "trung sown traafm, sown taay, haf nooji"
  ],
  "Trung Thành, Phổ Yên, Thái Nguyên": [
    "trung thành, phổ yên, thái nguyên",
    "trung thafnh, phoor yeen, thasi nguyeen"
  ],
  "Trà Giang, Kiến Xương, Thái Bình": [
    "trà giang, kiến xương, thái bình",
    "traf giang, kieesn xuwowng, thasi bifnh"
  ],
  "Trà Hiệp, Trà Bồng, Quảng Ngãi": [
    "trà hiệp, trà bồng, quảng ngãi",
    "traf hieejp, traf boofng, quarng ngaxi"
  ],
  "Trà Thủy, Trà Bồng, Quảng Ngãi": [
    "trà thủy, trà bồng, quảng ngãi",
    "traf thury, traf boofng, quarng ngaxi"
  ],
  "Trà Đông, Bắc Trà My, Quảng Nam": [
    "trà đông, bắc trà my, quảng nam",
    "traf ddoong, bawsc traf my, quarng nam"
  ],
  "Trà Đốc, Bắc Trà My, Quảng Nam": [
    "trà đốc, bắc trà my, quảng nam",
    "traf ddoosc, bawsc traf my, quarng nam"
  ],
  "Tràng An, Đông Triều, Quảng Ninh": [
    "tràng an, đông triều, quảng ninh",
    "trafng an, ddoong trieefu, quarng ninh"
  ],
  "Tràng Đà, Tuyên Quang, Tuyên Quang": [
    "tràng đà, tuyên quang, tuyên quang",
    "trafng ddaf, tuyeen quang, tuyeen quang"
  ],
  "Trưng Vương, Uông Bí, Quảng Ninh": [
    "trưng vương, uông bí, quảng ninh",
    "truwng vuwowng, uoong bis, quarng ninh"
  ],
  "Trưng Vương, Việt Trì, Phú Thọ": [
    "trưng vương, việt trì, phú thọ",
    "truwng vuwowng, vieejt trif, phus thoj"
  ],
  "Trường Giang, Lục Nam, Bắc Giang": [
    "trường giang, lục nam, bắc giang",
    "truwowfng giang, lujc nam, bawsc giang"
  ],
  "Trường Sa, Trường Sa, Khánh Hòa": [
    "trường sa, trường sa, khánh hòa",
    "truwowfng sa, truwowfng sa, khasnh hofa"
  ],
  "Trường Sơn, Đức Thọ, Hà Tĩnh": [
    "trường sơn, đức thọ, hà tĩnh",
    "truwowfng sown, dduwsc thoj, haf tixnh"
  ],
  "Trường Thi, Nam Định, Nam Định": [
    "trường thi, nam định, nam định",
    "truwowfng thi, nam ddijnh, nam ddijnh"
  ],
  "Trường Thành, An Lão, Hải Phòng": [
    "trường thành, an lão, hải phòng",
    "truwowfng thafnh, an laxo, hari phofng"
  ],
  "Trường Thọ, Cầu Ngang, Trà Vinh": [
    "trường thọ, cầu ngang, trà vinh",
    "truwowfng thoj, caafu ngang, traf vinh"
  ],
  "Trường Xuân, Thới Lai, Cần Thơ": [
    "trường xuân, thới lai, cần thơ",
    "truwowfng xuaan, thowsi lai, caafn thow"
  ],
  "Trại Cau, Đồng Hỷ, Thái Nguyên": [
    "trại cau, đồng hỷ, thái nguyên",
    "traji cau, ddoofng hyr, thasi nguyeen"
  ],
  "Trạm Lộ, Thuận Thành, Bắc Ninh": [
    "trạm lộ, thuận thành, bắc ninh",
    "trajm looj, thuaajn thafnh, bawsc ninh"
  ],
  "Trảng Bàng, Trảng Bàng, Tây Ninh": [
    "trảng bàng, trảng bàng, tây ninh",
    "trarng bafng, trarng bafng, taay ninh"
  ],
  "Trần Hưng Đạo, Lý Nhân, Hà Nam": [
    "trần hưng đạo, lý nhân, hà nam",
    "traafn huwng ddajo, lys nhaan, haf nam"
  ],
  "Trần Hưng Đạo, Phủ Lý, Hà Nam": [
    "trần hưng đạo, phủ lý, hà nam",
    "traafn huwng ddajo, phur lys, haf nam"
  ],
  "Trần Đề, Trần Đề, Sóc Trăng": [
    "trần đề, trần đề, sóc trăng",
    "traafn ddeef, traafn ddeef, sosc trawng"
  ],
  "Trọng Quan, Đông Hưng, Thái Bình": [
    "trọng quan, đông hưng, thái bình",
    "trojng quan, ddoong huwng, thasi bifnh"
  ],
  "Trực Chính, Trực Ninh, Nam Định": [
    "trực chính, trực ninh, nam định",
    "truwjc chisnh, truwjc ninh, nam ddijnh"
  ],
  "Trực Tuấn, Trực Ninh, Nam Định": [
    "trực tuấn, trực ninh, nam định",
    "truwjc tuaasn, truwjc ninh, nam ddijnh"
  ],
  "Trực Đại, Trực Ninh, Nam Định": [
    "trực đại, trực ninh, nam định",
    "truwjc ddaji, truwjc ninh, nam ddijnh"
  ],
  "Trực Đạo, Trực Ninh, Nam Định": [
    "trực đạo, trực ninh, nam định",
    "truwjc ddajo, truwjc ninh, nam ddijnh"
  ],
  "Tuyên Bình Tây, Vĩnh Hưng, Long An": [
    "tuyên bình tây, vĩnh hưng, long an",
    "tuyeen bifnh taay, vixnh huwng, long an"
  ],
  "Tuân Tức, Thạnh Trị, Sóc Trăng": [
    "tuân tức, thạnh trị, sóc trăng",
    "tuaan tuwsc, thajnh trij, sosc trawng"
  ],
  "Tà Năng, Đức Trọng, Lâm Đồng": [
    "tà năng, đức trọng, lâm đồng",
    "taf nawng, dduwsc trojng, laam ddoofng"
  ],
  "Tân An Hội, Củ Chi, Hồ Chí Minh": [
    "tân an hội, củ chi, hồ chí minh",
    "taan an hooji, cur chi, hoof chis minh"
  ],
  "Tân An Thạnh, Bình Tân, Vĩnh Long": [
    "tân an thạnh, bình tân, vĩnh long",
    "taan an thajnh, bifnh taan, vixnh long"
  ],
  "Tân An, Buôn Ma Thuột, Đắk Lắk": [
    "tân an, buôn ma thuột, đắk lắk",
    "taan an, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Tân Bình, Châu Thành, Đồng Tháp": [
    "tân bình, châu thành, đồng tháp",
    "taan bifnh, chaau thafnh, ddoofng thasp"
  ],
  "Tân Bình, Phụng Hiệp, Hậu Giang": [
    "tân bình, phụng hiệp, hậu giang",
    "taan bifnh, phujng hieejp, haaju giang"
  ],
  "Tân Hiệp A, Tân Hiệp, Kiên Giang": [
    "tân hiệp a, tân hiệp, kiên giang",
    "taan hieejp a, taan hieejp, kieen giang"
  ],
  "Tân Hiệp B, Tân Hiệp, Kiên Giang": [
    "tân hiệp b, tân hiệp, kiên giang",
    "taan hieejp b, taan hieejp, kieen giang"
  ],
  "Tân Hiệp, Châu Thành, Tiền Giang": [
    "tân hiệp, châu thành, tiền giang",
    "taan hieejp, chaau thafnh, tieefn giang"
  ],
  "Tân Hòa, Đồng Phú, Bình Phước": [
    "tân hòa, đồng phú, bình phước",
    "taan hofa, ddoofng phus, bifnh phuwowsc"
  ],
  "Tân Hương, Ninh Giang, Hải Dương": [
    "tân hương, ninh giang, hải dương",
    "taan huwowng, ninh giang, hari duwowng"
  ],
  "Tân Hương, Phổ Yên, Thái Nguyên": [
    "tân hương, phổ yên, thái nguyên",
    "taan huwowng, phoor yeen, thasi nguyeen"
  ],
  "Tân Hồng, Bình Giang, Hải Dương": [
    "tân hồng, bình giang, hải dương",
    "taan hoofng, bifnh giang, hari duwowng"
  ],
  "Tân Hội, Hồng Ngự, Đồng Tháp": [
    "tân hội, hồng ngự, đồng tháp",
    "taan hooji, hoofng nguwj, ddoofng thasp"
  ],
  "Tân Khai, Hớn Quản, Bình Phước": [
    "tân khai, hớn quản, bình phước",
    "taan khai, howsn quarn, bifnh phuwowsc"
  ],
  "Tân Long Hội, Mang Thít, Vĩnh Long": [
    "tân long hội, mang thít, vĩnh long",
    "taan long hooji, mang thist, vixnh long"
  ],
  "Tân Long, Hướng Hóa, Quảng Trị": [
    "tân long, hướng hóa, quảng trị",
    "taan long, huwowsng hosa, quarng trij"
  ],
  "Tân Long, Thái Nguyên, Thái Nguyên": [
    "tân long, thái nguyên, thái nguyên",
    "taan long, thasi nguyeen, thasi nguyeen"
  ],
  "Tân Lộc Bắc, Thới Bình, Cà Mau": [
    "tân lộc bắc, thới bình, cà mau",
    "taan loojc bawsc, thowsi bifnh, caf mau"
  ],
  "Tân Lợi, Đồng Hỷ, Thái Nguyên": [
    "tân lợi, đồng hỷ, thái nguyên",
    "taan lowji, ddoofng hyr, thasi nguyeen"
  ],
  "Tân Phong, Kiến Thuỵ, Hải Phòng": [
    "tân phong, kiến thuỵ, hải phòng",
    "taan phong, kieesn thuyj, hari phofng"
  ],
  "Tân Phong, Quảng Xương, Thanh Hóa": [
    "tân phong, quảng xương, thanh hóa",
    "taan phong, quarng xuwowng, thanh hosa"
  ],
  "Tân Phú, Đồng Phú, Bình Phước": [
    "tân phú, đồng phú, bình phước",
    "taan phus, ddoofng phus, bifnh phuwowsc"
  ],
  "Tân Phương, Thanh Thuỷ, Phú Thọ": [
    "tân phương, thanh thuỷ, phú thọ",
    "taan phuwowng, thanh thuyr, phus thoj"
  ],
  "Tân Phước Tây, Tân Trụ, Long An": [
    "tân phước tây, tân trụ, long an",
    "taan phuwowsc taay, taan truj, long an"
  ],
  "Tân Quan, Hớn Quản, Bình Phước": [
    "tân quan, hớn quản, bình phước",
    "taan quan, howsn quarn, bifnh phuwowsc"
  ],
  "Tân Quới, Thanh Bình, Đồng Tháp": [
    "tân quới, thanh bình, đồng tháp",
    "taan quowsi, thanh bifnh, ddoofng thasp"
  ],
  "Tân Thành, Bù Đốp, Bình Phước": [
    "tân thành, bù đốp, bình phước",
    "taan thafnh, buf ddoosp, bifnh phuwowsc"
  ],
  "Tân Thành, Dương Kinh, Hải Phòng": [
    "tân thành, dương kinh, hải phòng",
    "taan thafnh, duwowng kinh, hari phofng"
  ],
  "Tân Thịnh, Chiêm Hóa, Tuyên Quang": [
    "tân thịnh, chiêm hóa, tuyên quang",
    "taan thijnh, chieem hosa, tuyeen quang"
  ],
  "Tân Thủy, Lệ Thủy, Quảng Bình": [
    "tân thủy, lệ thủy, quảng bình",
    "taan thury, leej thury, quarng bifnh"
  ],
  "Tân Tiến, Bù Đốp, Bình Phước": [
    "tân tiến, bù đốp, bình phước",
    "taan tieesn, buf ddoosp, bifnh phuwowsc"
  ],
  "Tân Tiến, Krông Pắc, Đắk Lắk": [
    "tân tiến, krông pắc, đắk lắk",
    "taan tieesn, kroong pawsc, ddawsk lawsk"
  ],
  "Tân Trào, Kiến Thuỵ, Hải Phòng": [
    "tân trào, kiến thuỵ, hải phòng",
    "taan trafo, kieesn thuyj, hari phofng"
  ],
  "Tân Trào, Thanh Miện, Hải Dương": [
    "tân trào, thanh miện, hải dương",
    "taan trafo, thanh mieejn, hari duwowng"
  ],
  "Tân Túc, Bình Chánh, Hồ Chí Minh": [
    "tân túc, bình chánh, hồ chí minh",
    "taan tusc, bifnh chasnh, hoof chis minh"
  ],
  "Tân Việt, Bình Giang, Hải Dương": [
    "tân việt, bình giang, hải dương",
    "taan vieejt, bifnh giang, hari duwowng"
  ],
  "Tân Định, Bến Cát, Bình Dương": [
    "tân định, bến cát, bình dương",
    "taan ddijnh, beesn cast, bifnh duwowng"
  ],
  "Tây Lương, Tiền Hải, Thái Bình": [
    "tây lương, tiền hải, thái bình",
    "taay luwowng, tieefn hari, thasi bifnh"
  ],
  "Tây Thạnh, Tân Phú, Hồ Chí Minh": [
    "tây thạnh, tân phú, hồ chí minh",
    "taay thajnh, taan phus, hoof chis minh"
  ],
  "Tây Tựu, Bắc Từ Liêm, Hà Nội": [
    "tây tựu, bắc từ liêm, hà nội",
    "taay tuwju, bawsc tuwf lieem, haf nooji"
  ],
  "Tú Thịnh, Sơn Dương, Tuyên Quang": [
    "tú thịnh, sơn dương, tuyên quang",
    "tus thijnh, sown duwowng, tuyeen quang"
  ],
  "Túc Trưng, Định Quán, Đồng Nai": [
    "túc trưng, định quán, đồng nai",
    "tusc truwng, ddijnh quasn, ddoofng nai"
  ],
  "Tượng Sơn, Nông Cống, Thanh Hóa": [
    "tượng sơn, nông cống, thanh hóa",
    "tuwowjng sown, noong coosng, thanh hosa"
  ],
  "Tượng Văn, Nông Cống, Thanh Hóa": [
    "tượng văn, nông cống, thanh hóa",
    "tuwowjng vawn, noong coosng, thanh hosa"
  ],
  "Tằng Loỏng, Bảo Thắng, Lào Cai": [
    "tằng loỏng, bảo thắng, lào cai",
    "tawfng loorng, baro thawsng, lafo cai"
  ],
  "Tịnh An, Quảng Ngãi, Quảng Ngãi": [
    "tịnh an, quảng ngãi, quảng ngãi",
    "tijnh an, quarng ngaxi, quarng ngaxi"
  ],
  "Tịnh Minh, Sơn Tịnh, Quảng Ngãi": [
    "tịnh minh, sơn tịnh, quảng ngãi",
    "tijnh minh, sown tijnh, quarng ngaxi"
  ],
  "Tịnh Sơn, Sơn Tịnh, Quảng Ngãi": [
    "tịnh sơn, sơn tịnh, quảng ngãi",
    "tijnh sown, sown tijnh, quarng ngaxi"
  ],
  "Tịnh Thới, Cao Lãnh, Đồng Tháp": [
    "tịnh thới, cao lãnh, đồng tháp",
    "tijnh thowsi, cao laxnh, ddoofng thasp"
  ],
  "Tịnh Trà, Sơn Tịnh, Quảng Ngãi": [
    "tịnh trà, sơn tịnh, quảng ngãi",
    "tijnh traf, sown tijnh, quarng ngaxi"
  ],
  "Tốt Động, Chương Mỹ, Hà Nội": [
    "tốt động, chương mỹ, hà nội",
    "toost ddoojng, chuwowng myx, haf nooji"
  ],
  "Tủa Chùa, Tủa Chùa, Điện Biên": [
    "tủa chùa, tủa chùa, điện biên",
    "tura chufa, tura chufa, ddieejn bieen"
  ],
  "Tủa Sín Chải, Sìn Hồ, Lai Châu": [
    "tủa sín chải, sìn hồ, lai châu",
    "tura sisn chari, sifn hoof, lai chaau"
  ],
  "Tứ Minh, Hải Dương, Hải Dương": [
    "tứ minh, hải dương, hải dương",
    "tuws minh, hari duwowng, hari duwowng"
  ],
  "Tự An, Buôn Ma Thuột, Đắk Lắk": [
    "tự an, buôn ma thuột, đắk lắk",
    "tuwj an, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Vinh An, Phú Vang, Thừa Thiên Huế": [
    "vinh an, phú vang, thừa thiên huế",
    "vinh an, phus vang, thuwfa thieen huees"
  ],
  "Viên An Đông, Ngọc Hiển, Cà Mau": [
    "viên an đông, ngọc hiển, cà mau",
    "vieen an ddoong, ngojc hieern, caf mau"
  ],
  "Việt Cường, Trấn Yên, Yên Bái": [
    "việt cường, trấn yên, yên bái",
    "vieejt cuwowfng, traasn yeen, yeen basi"
  ],
  "Việt Hồng, Thanh Hà, Hải Dương": [
    "việt hồng, thanh hà, hải dương",
    "vieejt hoofng, thanh haf, hari duwowng"
  ],
  "Việt Tiến, Việt Yên, Bắc Giang": [
    "việt tiến, việt yên, bắc giang",
    "vieejt tieesn, vieejt yeen, bawsc giang"
  ],
  "Vàng Ma Chải, Phong Thổ, Lai Châu": [
    "vàng ma chải, phong thổ, lai châu",
    "vafng ma chari, phong thoor, lai chaau"
  ],
  "Vân Trục, Lập Thạch, Vĩnh Phúc": [
    "vân trục, lập thạch, vĩnh phúc",
    "vaan trujc, laajp thajch, vixnh phusc"
  ],
  "Vân Xuân, Vĩnh Tường, Vĩnh Phúc": [
    "vân xuân, vĩnh tường, vĩnh phúc",
    "vaan xuaan, vixnh tuwowfng, vixnh phusc"
  ],
  "Văn Lăng, Đồng Hỷ, Thái Nguyên": [
    "văn lăng, đồng hỷ, thái nguyên",
    "vawn lawng, ddoofng hyr, thasi nguyeen"
  ],
  "Vĩnh Chấp, Vĩnh Linh, Quảng Trị": [
    "vĩnh chấp, vĩnh linh, quảng trị",
    "vixnh chaasp, vixnh linh, quarng trij"
  ],
  "Vĩnh Hưng A, Vĩnh Lợi, Bạc Liêu": [
    "vĩnh hưng a, vĩnh lợi, bạc liêu",
    "vixnh huwng a, vixnh lowji, bajc lieeu"
  ],
  "Vĩnh Hưng, Bình Giang, Hải Dương": [
    "vĩnh hưng, bình giang, hải dương",
    "vixnh huwng, bifnh giang, hari duwowng"
  ],
  "Vĩnh Kim, Vĩnh Thạnh, Bình Định": [
    "vĩnh kim, vĩnh thạnh, bình định",
    "vixnh kim, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Lộc A, Hồng Dân, Bạc Liêu": [
    "vĩnh lộc a, hồng dân, bạc liêu",
    "vixnh loojc a, hoofng daan, bajc lieeu"
  ],
  "Vĩnh Lợi, Sơn Dương, Tuyên Quang": [
    "vĩnh lợi, sơn dương, tuyên quang",
    "vixnh lowji, sown duwowng, tuyeen quang"
  ],
  "Vĩnh Lợi, Thạnh Trị, Sóc Trăng": [
    "vĩnh lợi, thạnh trị, sóc trăng",
    "vixnh lowji, thajnh trij, sosc trawng"
  ],
  "Vĩnh Ninh, Quảng Ninh, Quảng Bình": [
    "vĩnh ninh, quảng ninh, quảng bình",
    "vixnh ninh, quarng ninh, quarng bifnh"
  ],
  "Vĩnh Ninh, Vĩnh Tường, Vĩnh Phúc": [
    "vĩnh ninh, vĩnh tường, vĩnh phúc",
    "vixnh ninh, vixnh tuwowfng, vixnh phusc"
  ],
  "Vĩnh Phong, Vĩnh Thuận, Kiên Giang": [
    "vĩnh phong, vĩnh thuận, kiên giang",
    "vixnh phong, vixnh thuaajn, kieen giang"
  ],
  "Vĩnh Phước A, Gò Quao, Kiên Giang": [
    "vĩnh phước a, gò quao, kiên giang",
    "vixnh phuwowsc a, gof quao, kieen giang"
  ],
  "Vĩnh Phước B, Gò Quao, Kiên Giang": [
    "vĩnh phước b, gò quao, kiên giang",
    "vixnh phuwowsc b, gof quao, kieen giang"
  ],
  "Vĩnh Sơn, Vĩnh Tường, Vĩnh Phúc": [
    "vĩnh sơn, vĩnh tường, vĩnh phúc",
    "vixnh sown, vixnh tuwowfng, vixnh phusc"
  ],
  "Vĩnh Thanh, Nhơn Trạch, Đồng Nai": [
    "vĩnh thanh, nhơn trạch, đồng nai",
    "vixnh thanh, nhown trajch, ddoofng nai"
  ],
  "Vĩnh Thanh, Phước Long, Bạc Liêu": [
    "vĩnh thanh, phước long, bạc liêu",
    "vixnh thanh, phuwowsc long, bajc lieeu"
  ],
  "Vĩnh Thạnh, Lấp Vò, Đồng Tháp": [
    "vĩnh thạnh, lấp vò, đồng tháp",
    "vixnh thajnh, laasp vof, ddoofng thasp"
  ],
  "Vĩnh Thủy, Vĩnh Linh, Quảng Trị": [
    "vĩnh thủy, vĩnh linh, quảng trị",
    "vixnh thury, vixnh linh, quarng trij"
  ],
  "Vĩnh Tiến, Vĩnh Bảo, Hải Phòng": [
    "vĩnh tiến, vĩnh bảo, hải phòng",
    "vixnh tieesn, vixnh baro, hari phofng"
  ],
  "Vĩnh Trường, Nha Trang, Khánh Hòa": [
    "vĩnh trường, nha trang, khánh hòa",
    "vixnh truwowfng, nha trang, khasnh hofa"
  ],
  "Vĩnh Trạch, Bạc Liêu, Bạc Liêu": [
    "vĩnh trạch, bạc liêu, bạc liêu",
    "vixnh trajch, bajc lieeu, bajc lieeu"
  ],
  "Vạn Hương, Đồ Sơn, Hải Phòng": [
    "vạn hương, đồ sơn, hải phòng",
    "vajn huwowng, ddoof sown, hari phofng"
  ],
  "Vạn Ninh, Quảng Ninh, Quảng Bình": [
    "vạn ninh, quảng ninh, quảng bình",
    "vajn ninh, quarng ninh, quarng bifnh"
  ],
  "Vạn Phước, Vạn Ninh, Khánh Hòa": [
    "vạn phước, vạn ninh, khánh hòa",
    "vajn phuwowsc, vajn ninh, khasnh hofa"
  ],
  "Vạn Thiện, Nông Cống, Thanh Hóa": [
    "vạn thiện, nông cống, thanh hóa",
    "vajn thieejn, noong coosng, thanh hosa"
  ],
  "Vạn Thắng, Nông Cống, Thanh Hóa": [
    "vạn thắng, nông cống, thanh hóa",
    "vajn thawsng, noong coosng, thanh hosa"
  ],
  "Vạn Thọ, Đại Từ, Thái Nguyên": [
    "vạn thọ, đại từ, thái nguyên",
    "vajn thoj, ddaji tuwf, thasi nguyeen"
  ],
  "Xuân Dương, Lộc Bình, Lạng Sơn": [
    "xuân dương, lộc bình, lạng sơn",
    "xuaan duwowng, loojc bifnh, lajng sown"
  ],
  "Xuân Lẹ, Thường Xuân, Thanh Hóa": [
    "xuân lẹ, thường xuân, thanh hóa",
    "xuaan lej, thuwowfng xuaan, thanh hosa"
  ],
  "Xuân Ninh, Quảng Ninh, Quảng Bình": [
    "xuân ninh, quảng ninh, quảng bình",
    "xuaan ninh, quarng ninh, quarng bifnh"
  ],
  "Xuân Quang 1, Đồng Xuân, Phú Yên": [
    "xuân quang 1, đồng xuân, phú yên",
    "xuaan quang 1, ddoofng xuaan, phus yeen"
  ],
  "Xuân Quang 2, Đồng Xuân, Phú Yên": [
    "xuân quang 2, đồng xuân, phú yên",
    "xuaan quang 2, ddoofng xuaan, phus yeen"
  ],
  "Xuân Quang 3, Đồng Xuân, Phú Yên": [
    "xuân quang 3, đồng xuân, phú yên",
    "xuaan quang 3, ddoofng xuaan, phus yeen"
  ],
  "Xuân Thịnh, Triệu Sơn, Thanh Hóa": [
    "xuân thịnh, triệu sơn, thanh hóa",
    "xuaan thijnh, trieeju sown, thanh hosa"
  ],
  "Xuân Đông, Chợ Gạo, Tiền Giang": [
    "xuân đông, chợ gạo, tiền giang",
    "xuaan ddoong, chowj gajo, tieefn giang"
  ],
  "Xuân Định, Xuân Lộc, Đồng Nai": [
    "xuân định, xuân lộc, đồng nai",
    "xuaan ddijnh, xuaan loojc, ddoofng nai"
  ],
  "Xín Chải, Tủa Chùa, Điện Biên": [
    "xín chải, tủa chùa, điện biên",
    "xisn chari, tura chufa, ddieejn bieen"
  ],
  "Xương Giang, Bắc Giang, Bắc Giang": [
    "xương giang, bắc giang, bắc giang",
    "xuwowng giang, bawsc giang, bawsc giang"
  ],
  "Xương Lâm, Lạng Giang, Bắc Giang": [
    "xương lâm, lạng giang, bắc giang",
    "xuwowng laam, lajng giang, bawsc giang"
  ],
  "Xương Thịnh, Cẩm Khê, Phú Thọ": [
    "xương thịnh, cẩm khê, phú thọ",
    "xuwowng thijnh, caarm khee, phus thoj"
  ],
  "Yên Bình, Vĩnh Tường, Vĩnh Phúc": [
    "yên bình, vĩnh tường, vĩnh phúc",
    "yeen bifnh, vixnh tuwowfng, vixnh phusc"
  ],
  "Yên Lạc, Phú Lương, Thái Nguyên": [
    "yên lạc, phú lương, thái nguyên",
    "yeen lajc, phus luwowng, thasi nguyeen"
  ],
  "Yên Lập, Vĩnh Tường, Vĩnh Phúc": [
    "yên lập, vĩnh tường, vĩnh phúc",
    "yeen laajp, vixnh tuwowfng, vixnh phusc"
  ],
  "Yên Nguyên, Chiêm Hóa, Tuyên Quang": [
    "yên nguyên, chiêm hóa, tuyên quang",
    "yeen nguyeen, chieem hosa, tuyeen quang"
  ],
  "Yên Nhân, Thường Xuân, Thanh Hóa": [
    "yên nhân, thường xuân, thanh hóa",
    "yeen nhaan, thuwowfng xuaan, thanh hosa"
  ],
  "Yên Thịnh, Chợ Đồn, Bắc Kạn": [
    "yên thịnh, chợ đồn, bắc kạn",
    "yeen thijnh, chowj ddoofn, bawsc kajn"
  ],
  "Yên Vượng, Hữu Lũng, Lạng Sơn": [
    "yên vượng, hữu lũng, lạng sơn",
    "yeen vuwowjng, huwxu luxng, lajng sown"
  ],
  "Yên Định, Sơn Động, Bắc Giang": [
    "yên định, sơn động, bắc giang",
    "yeen ddijnh, sown ddoojng, bawsc giang"
  ],
  "Yên Đổ, Phú Lương, Thái Nguyên": [
    "yên đổ, phú lương, thái nguyên",
    "yeen ddoor, phus luwowng, thasi nguyeen"
  ],
  "Ái Thượng, Bá Thước, Thanh Hóa": [
    "ái thượng, bá thước, thanh hóa",
    "asi thuwowjng, bas thuwowsc, thanh hosa"
  ],
  "Đinh Trang Hòa, Di Linh, Lâm Đồng": [
    "đinh trang hòa, di linh, lâm đồng",
    "ddinh trang hofa, di linh, laam ddoofng"
  ],
  "Điền Quang, Bá Thước, Thanh Hóa": [
    "điền quang, bá thước, thanh hóa",
    "ddieefn quang, bas thuwowsc, thanh hosa"
  ],
  "Điền Trung, Bá Thước, Thanh Hóa": [
    "điền trung, bá thước, thanh hóa",
    "ddieefn trung, bas thuwowsc, thanh hosa"
  ],
  "Điện Hòa, Điện Bàn, Quảng Nam": [
    "điện hòa, điện bàn, quảng nam",
    "ddieejn hofa, ddieejn bafn, quarng nam"
  ],
  "Điện Minh, Điện Bàn, Quảng Nam": [
    "điện minh, điện bàn, quảng nam",
    "ddieejn minh, ddieejn bafn, quarng nam"
  ],
  "Đoàn Kết, Vân Đồn, Quảng Ninh": [
    "đoàn kết, vân đồn, quảng ninh",
    "ddoafn keest, vaan ddoofn, quarng ninh"
  ],
  "Đoàn Kết, Đạ Huoai, Lâm Đồng": [
    "đoàn kết, đạ huoai, lâm đồng",
    "ddoafn keest, ddaj huoai, laam ddoofng"
  ],
  "Đoàn Lập, Tiên Lãng, Hải Phòng": [
    "đoàn lập, tiên lãng, hải phòng",
    "ddoafn laajp, tieen laxng, hari phofng"
  ],
  "Đoàn Xá, Kiến Thuỵ, Hải Phòng": [
    "đoàn xá, kiến thuỵ, hải phòng",
    "ddoafn xas, kieesn thuyj, hari phofng"
  ],
  "Đà Loan, Đức Trọng, Lâm Đồng": [
    "đà loan, đức trọng, lâm đồng",
    "ddaf loan, dduwsc trojng, laam ddoofng"
  ],
  "Đài Xuyên, Vân Đồn, Quảng Ninh": [
    "đài xuyên, vân đồn, quảng ninh",
    "ddafi xuyeen, vaan ddoofn, quarng ninh"
  ],
  "Đàm Thuỷ, Trùng Khánh, Cao Bằng": [
    "đàm thuỷ, trùng khánh, cao bằng",
    "ddafm thuyr, trufng khasnh, cao bawfng"
  ],
  "Đình Lập, Đình Lập, Lạng Sơn": [
    "đình lập, đình lập, lạng sơn",
    "ddifnh laajp, ddifnh laajp, lajng sown"
  ],
  "Đình Phong, Trùng Khánh, Cao Bằng": [
    "đình phong, trùng khánh, cao bằng",
    "ddifnh phong, trufng khasnh, cao bawfng"
  ],
  "Đình Tổ, Thuận Thành, Bắc Ninh": [
    "đình tổ, thuận thành, bắc ninh",
    "ddifnh toor, thuaajn thafnh, bawsc ninh"
  ],
  "Đô Lương, Đông Hưng, Thái Bình": [
    "đô lương, đông hưng, thái bình",
    "ddoo luwowng, ddoong huwng, thasi bifnh"
  ],
  "Đôn Phong, Bạch Thông, Bắc Kạn": [
    "đôn phong, bạch thông, bắc kạn",
    "ddoon phong, bajch thoong, bawsc kajn"
  ],
  "Đôn Thuận, Trảng Bàng, Tây Ninh": [
    "đôn thuận, trảng bàng, tây ninh",
    "ddoon thuaajn, trarng bafng, taay ninh"
  ],
  "Đông Giang, Đông Hà, Quảng Trị": [
    "đông giang, đông hà, quảng trị",
    "ddoong giang, ddoong haf, quarng trij"
  ],
  "Đông Hòa, Châu Thành, Tiền Giang": [
    "đông hòa, châu thành, tiền giang",
    "ddoong hofa, chaau thafnh, tieefn giang"
  ],
  "Đông Hưng, Tiên Lãng, Hải Phòng": [
    "đông hưng, tiên lãng, hải phòng",
    "ddoong huwng, tieen laxng, hari phofng"
  ],
  "Đông Hưng, Đông Hưng, Thái Bình": [
    "đông hưng, đông hưng, thái bình",
    "ddoong huwng, ddoong huwng, thasi bifnh"
  ],
  "Đông Hợp, Đông Hưng, Thái Bình": [
    "đông hợp, đông hưng, thái bình",
    "ddoong howjp, ddoong huwng, thasi bifnh"
  ],
  "Đông Khê, Ngô Quyền, Hải Phòng": [
    "đông khê, ngô quyền, hải phòng",
    "ddoong khee, ngoo quyeefn, hari phofng"
  ],
  "Đông Phong, Tiền Hải, Thái Bình": [
    "đông phong, tiền hải, thái bình",
    "ddoong phong, tieefn hari, thasi bifnh"
  ],
  "Đông Quang, Đông Hưng, Thái Bình": [
    "đông quang, đông hưng, thái bình",
    "ddoong quang, ddoong huwng, thasi bifnh"
  ],
  "Đông Thanh, Đông Hà, Quảng Trị": [
    "đông thanh, đông hà, quảng trị",
    "ddoong thanh, ddoong haf, quarng trij"
  ],
  "Đông Thịnh, Đông Sơn, Thanh Hóa": [
    "đông thịnh, đông sơn, thanh hóa",
    "ddoong thijnh, ddoong sown, thanh hosa"
  ],
  "Đông Trung, Tiền Hải, Thái Bình": [
    "đông trung, tiền hải, thái bình",
    "ddoong trung, tieefn hari, thasi bifnh"
  ],
  "Đông Xuân, Đông Hưng, Thái Bình": [
    "đông xuân, đông hưng, thái bình",
    "ddoong xuaan, ddoong huwng, thasi bifnh"
  ],
  "Đạ M' Rong, Đam Rông, Lâm Đồng": [
    "đạ m' rong, đam rông, lâm đồng",
    "ddaj m' rong, ddam roong, laam ddoofng"
  ],
  "Đạ Nhim, Lạc Dương, Lâm Đồng": [
    "đạ nhim, lạc dương, lâm đồng",
    "ddaj nhim, lajc duwowng, laam ddoofng"
  ],
  "Đạ Ròn, Đơn Dương, Lâm Đồng": [
    "đạ ròn, đơn dương, lâm đồng",
    "ddaj rofn, ddown duwowng, laam ddoofng"
  ],
  "Đại Hà, Kiến Thuỵ, Hải Phòng": [
    "đại hà, kiến thuỵ, hải phòng",
    "ddaji haf, kieesn thuyj, hari phofng"
  ],
  "Đại Hưng, Đại Lộc, Quảng Nam": [
    "đại hưng, đại lộc, quảng nam",
    "ddaji huwng, ddaji loojc, quarng nam"
  ],
  "Đại Lãnh, Đại Lộc, Quảng Nam": [
    "đại lãnh, đại lộc, quảng nam",
    "ddaji laxnh, ddaji loojc, quarng nam"
  ],
  "Đại Phong, Đại Lộc, Quảng Nam": [
    "đại phong, đại lộc, quảng nam",
    "ddaji phong, ddaji loojc, quarng nam"
  ],
  "Đại Phú, Sơn Dương, Tuyên Quang": [
    "đại phú, sơn dương, tuyên quang",
    "ddaji phus, sown duwowng, tuyeen quang"
  ],
  "Đại Quang, Đại Lộc, Quảng Nam": [
    "đại quang, đại lộc, quảng nam",
    "ddaji quang, ddaji loojc, quarng nam"
  ],
  "Đại Sảo, Chợ Đồn, Bắc Kạn": [
    "đại sảo, chợ đồn, bắc kạn",
    "ddaji saro, chowj ddoofn, bawsc kajn"
  ],
  "Đại Thành, Hiệp Hòa, Bắc Giang": [
    "đại thành, hiệp hòa, bắc giang",
    "ddaji thafnh, hieejp hofa, bawsc giang"
  ],
  "Đại Thắng, Vụ Bản, Nam Định": [
    "đại thắng, vụ bản, nam định",
    "ddaji thawsng, vuj barn, nam ddijnh"
  ],
  "Đại Ân 1, Cù Lao Dung, Sóc Trăng": [
    "đại ân 1, cù lao dung, sóc trăng",
    "ddaji aan 1, cuf lao dung, sosc trawng"
  ],
  "Đại Điền, Thạnh Phú, Bến Tre": [
    "đại điền, thạnh phú, bến tre",
    "ddaji ddieefn, thajnh phus, beesn tre"
  ],
  "Đạt Hiếu, Buôn Hồ, Đắk Lắk": [
    "đạt hiếu, buôn hồ, đắk lắk",
    "ddajt hieesu, buoon hoof, ddawsk lawsk"
  ],
  "Đắk R'Tíh, Tuy Đức, Đắk Nông": [
    "đắk r'tíh, tuy đức, đắk nông",
    "ddawsk r'tish, tuy dduwsc, ddawsk noong"
  ],
  "Đắk Ru, Đắk R'Lấp, Đắk Nông": [
    "đắk ru, đắk r'lấp, đắk nông",
    "ddawsk ru, ddawsk r'laasp, ddawsk noong"
  ],
  "Định Bình, Yên Định, Thanh Hóa": [
    "định bình, yên định, thanh hóa",
    "ddijnh bifnh, yeen ddijnh, thanh hosa"
  ],
  "Định Công, Yên Định, Thanh Hóa": [
    "định công, yên định, thanh hóa",
    "ddijnh coong, yeen ddijnh, thanh hosa"
  ],
  "Định Hưng, Yên Định, Thanh Hóa": [
    "định hưng, yên định, thanh hóa",
    "ddijnh huwng, yeen ddijnh, thanh hosa"
  ],
  "Định Hải, Yên Định, Thanh Hóa": [
    "định hải, yên định, thanh hóa",
    "ddijnh hari, yeen ddijnh, thanh hosa"
  ],
  "Định Liên, Yên Định, Thanh Hóa": [
    "định liên, yên định, thanh hóa",
    "ddijnh lieen, yeen ddijnh, thanh hosa"
  ],
  "Định Tăng, Yên Định, Thanh Hóa": [
    "định tăng, yên định, thanh hóa",
    "ddijnh tawng, yeen ddijnh, thanh hosa"
  ],
  "Đống Mác, Hai Bà Trưng, Hà Nội": [
    "đống mác, hai bà trưng, hà nội",
    "ddoosng masc, hai baf truwng, haf nooji"
  ],
  "Đồng Bục, Lộc Bình, Lạng Sơn": [
    "đồng bục, lộc bình, lạng sơn",
    "ddoofng bujc, loojc bifnh, lajng sown"
  ],
  "Đồng Khởi, Châu Thành, Tây Ninh": [
    "đồng khởi, châu thành, tây ninh",
    "ddoofng khowri, chaau thafnh, taay ninh"
  ],
  "Đồng Lê, Tuyên Hóa, Quảng Bình": [
    "đồng lê, tuyên hóa, quảng bình",
    "ddoofng lee, tuyeen hosa, quarng bifnh"
  ],
  "Đồng Lương, Cẩm Khê, Phú Thọ": [
    "đồng lương, cẩm khê, phú thọ",
    "ddoofng luwowng, caarm khee, phus thoj"
  ],
  "Đồng Lạc, Chí Linh, Hải Dương": [
    "đồng lạc, chí linh, hải dương",
    "ddoofng lajc, chis linh, hari duwowng"
  ],
  "Đồng Lạc, Chương Mỹ, Hà Nội": [
    "đồng lạc, chương mỹ, hà nội",
    "ddoofng lajc, chuwowng myx, haf nooji"
  ],
  "Đồng Lạc, Nam Sách, Hải Dương": [
    "đồng lạc, nam sách, hải dương",
    "ddoofng lajc, nam sasch, hari duwowng"
  ],
  "Đồng Lợi, Triệu Sơn, Thanh Hóa": [
    "đồng lợi, triệu sơn, thanh hóa",
    "ddoofng lowji, trieeju sown, thanh hosa"
  ],
  "Đồng Minh, Vĩnh Bảo, Hải Phòng": [
    "đồng minh, vĩnh bảo, hải phòng",
    "ddoofng minh, vixnh baro, hari phofng"
  ],
  "Đồng Nai, Bù Đăng, Bình Phước": [
    "đồng nai, bù đăng, bình phước",
    "ddoofng nai, buf ddawng, bifnh phuwowsc"
  ],
  "Đồng Quang, Gia Lộc, Hải Dương": [
    "đồng quang, gia lộc, hải dương",
    "ddoofng quang, gia loojc, hari duwowng"
  ],
  "Đồng Ruộng, Đà Bắc, Hoà Bình": [
    "đồng ruộng, đà bắc, hoà bình",
    "ddoofng ruoojng, ddaf bawsc, hoaf bifnh"
  ],
  "Đồng Thái, An Dương, Hải Phòng": [
    "đồng thái, an dương, hải phòng",
    "ddoofng thasi, an duwowng, hari phofng"
  ],
  "Đồng Thịnh, Sông Lô, Vĩnh Phúc": [
    "đồng thịnh, sông lô, vĩnh phúc",
    "ddoofng thijnh, soong loo, vixnh phusc"
  ],
  "Đồng Thịnh, Yên Lập, Phú Thọ": [
    "đồng thịnh, yên lập, phú thọ",
    "ddoofng thijnh, yeen laajp, phus thoj"
  ],
  "Đồng Tiến, Yên Thế, Bắc Giang": [
    "đồng tiến, yên thế, bắc giang",
    "ddoofng tieesn, yeen thees, bawsc giang"
  ],
  "Đồng Trung, Thanh Thuỷ, Phú Thọ": [
    "đồng trung, thanh thuỷ, phú thọ",
    "ddoofng trung, thanh thuyr, phus thoj"
  ],
  "Đồng Tâm, Bình Liêu, Quảng Ninh": [
    "đồng tâm, bình liêu, quảng ninh",
    "ddoofng taam, bifnh lieeu, quarng ninh"
  ],
  "Đồng Tâm, Hai Bà Trưng, Hà Nội": [
    "đồng tâm, hai bà trưng, hà nội",
    "ddoofng taam, hai baf truwng, haf nooji"
  ],
  "Đồng Tâm, Ninh Giang, Hải Dương": [
    "đồng tâm, ninh giang, hải dương",
    "ddoofng taam, ninh giang, hari duwowng"
  ],
  "Đồng Tĩnh, Tam Dương, Vĩnh Phúc": [
    "đồng tĩnh, tam dương, vĩnh phúc",
    "ddoofng tixnh, tam duwowng, vixnh phusc"
  ],
  "Đồng Việt, Yên Dũng, Bắc Giang": [
    "đồng việt, yên dũng, bắc giang",
    "ddoofng vieejt, yeen duxng, bawsc giang"
  ],
  "Đồng Văn, Bình Liêu, Quảng Ninh": [
    "đồng văn, bình liêu, quảng ninh",
    "ddoofng vawn, bifnh lieeu, quarng ninh"
  ],
  "Đồng Văn, Thanh Chương, Nghệ An": [
    "đồng văn, thanh chương, nghệ an",
    "ddoofng vawn, thanh chuwowng, ngheej an"
  ],
  "Đức Bình, Tánh Linh, Bình Thuận": [
    "đức bình, tánh linh, bình thuận",
    "dduwsc bifnh, tasnh linh, bifnh thuaajn"
  ],
  "Đức Hòa, Mộ Đức, Quảng Ngãi": [
    "đức hòa, mộ đức, quảng ngãi",
    "dduwsc hofa, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Hóa, Tuyên Hóa, Quảng Bình": [
    "đức hóa, tuyên hóa, quảng bình",
    "dduwsc hosa, tuyeen hosa, quarng bifnh"
  ],
  "Đức Lân, Mộ Đức, Quảng Ngãi": [
    "đức lân, mộ đức, quảng ngãi",
    "dduwsc laan, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Lập Hạ, Đức Hòa, Long An": [
    "đức lập hạ, đức hòa, long an",
    "dduwsc laajp haj, dduwsc hofa, long an"
  ],
  "Đức Minh, Mộ Đức, Quảng Ngãi": [
    "đức minh, mộ đức, quảng ngãi",
    "dduwsc minh, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Mạnh, Đắk Mil, Đắk Nông": [
    "đức mạnh, đắk mil, đắk nông",
    "dduwsc majnh, ddawsk mil, ddawsk noong"
  ],
  "Đức Phú, Mộ Đức, Quảng Ngãi": [
    "đức phú, mộ đức, quảng ngãi",
    "dduwsc phus, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Thuận, Hồng Lĩnh, Hà Tĩnh": [
    "đức thuận, hồng lĩnh, hà tĩnh",
    "dduwsc thuaajn, hoofng lixnh, haf tixnh"
  ],
  "Đức Tài, Đức Linh, Bình Thuận": [
    "đức tài, đức linh, bình thuận",
    "dduwsc tafi, dduwsc linh, bifnh thuaajn"
  ],
  "Đức Tân, Mộ Đức, Quảng Ngãi": [
    "đức tân, mộ đức, quảng ngãi",
    "dduwsc taan, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Tín, Đức Linh, Bình Thuận": [
    "đức tín, đức linh, bình thuận",
    "dduwsc tisn, dduwsc linh, bifnh thuaajn"
  ],
  "Đức Xuyên, Krông Nô, Đắk Nông": [
    "đức xuyên, krông nô, đắk nông",
    "dduwsc xuyeen, kroong noo, ddawsk noong"
  ],
  "Đức Đồng, Đức Thọ, Hà Tĩnh": [
    "đức đồng, đức thọ, hà tĩnh",
    "dduwsc ddoofng, dduwsc thoj, haf tixnh"
  ],
  "An Hòa Thịnh, Hương Sơn, Hà Tĩnh": [
    "an hòa thịnh, hương sơn, hà tĩnh",
    "an hofa thijnh, huwowng sown, haf tixnh"
  ],
  "An Tường, Vĩnh Tường, Vĩnh Phúc": [
    "an tường, vĩnh tường, vĩnh phúc",
    "an tuwowfng, vixnh tuwowfng, vixnh phusc"
  ],
  "Ba Cụm Bắc, Khánh Sơn, Khánh Hòa": [
    "ba cụm bắc, khánh sơn, khánh hòa",
    "ba cujm bawsc, khasnh sown, khasnh hofa"
  ],
  "Bàu Hàm 2, Thống Nhất, Đồng Nai": [
    "bàu hàm 2, thống nhất, đồng nai",
    "bafu hafm 2, thoosng nhaast, ddoofng nai"
  ],
  "Bát Đại Sơn, Quản Bạ, Hà Giang": [
    "bát đại sơn, quản bạ, hà giang",
    "bast ddaji sown, quarn baj, haf giang"
  ],
  "Bình Chuẩn, Thuận An, Bình Dương": [
    "bình chuẩn, thuận an, bình dương",
    "bifnh chuaarn, thuaajn an, bifnh duwowng"
  ],
  "Bình Dương, Bình Sơn, Quảng Ngãi": [
    "bình dương, bình sơn, quảng ngãi",
    "bifnh duwowng, bifnh sown, quarng ngaxi"
  ],
  "Bình Dương, Thăng Bình, Quảng Nam": [
    "bình dương, thăng bình, quảng nam",
    "bifnh duwowng, thawng bifnh, quarng nam"
  ],
  "Bình Hàn, Hải Dương, Hải Dương": [
    "bình hàn, hải dương, hải dương",
    "bifnh hafn, hari duwowng, hari duwowng"
  ],
  "Bình Hưng, Phan Thiết, Bình Thuận": [
    "bình hưng, phan thiết, bình thuận",
    "bifnh huwng, phan thieest, bifnh thuaajn"
  ],
  "Bình Khê, Đông Triều, Quảng Ninh": [
    "bình khê, đông triều, quảng ninh",
    "bifnh khee, ddoong trieefu, quarng ninh"
  ],
  "Bình Nguyên, Bình Sơn, Quảng Ngãi": [
    "bình nguyên, bình sơn, quảng ngãi",
    "bifnh nguyeen, bifnh sown, quarng ngaxi"
  ],
  "Bình Nguyên, Thăng Bình, Quảng Nam": [
    "bình nguyên, thăng bình, quảng nam",
    "bifnh nguyeen, thawng bifnh, quarng nam"
  ],
  "Bình Nhì, Gò Công Tây, Tiền Giang": [
    "bình nhì, gò công tây, tiền giang",
    "bifnh nhif, gof coong taay, tieefn giang"
  ],
  "Bình Phong Thạnh, Mộc Hóa, Long An": [
    "bình phong thạnh, mộc hóa, long an",
    "bifnh phong thajnh, moojc hosa, long an"
  ],
  "Bình Phú, Gò Công Tây, Tiền Giang": [
    "bình phú, gò công tây, tiền giang",
    "bifnh phus, gof coong taay, tieefn giang"
  ],
  "Bình Sơn, Phú Riềng, Bình Phước": [
    "bình sơn, phú riềng, bình phước",
    "bifnh sown, phus rieefng, bifnh phuwowsc"
  ],
  "Bình Thanh, Kiến Xương, Thái Bình": [
    "bình thanh, kiến xương, thái bình",
    "bifnh thanh, kieesn xuwowng, thasi bifnh"
  ],
  "Bình Thuận, Bình Sơn, Quảng Ngãi": [
    "bình thuận, bình sơn, quảng ngãi",
    "bifnh thuaajn, bifnh sown, quarng ngaxi"
  ],
  "Bình Thành, Thanh Bình, Đồng Tháp": [
    "bình thành, thanh bình, đồng tháp",
    "bifnh thafnh, thanh bifnh, ddoofng thasp"
  ],
  "Bình Thạnh, Bình Sơn, Quảng Ngãi": [
    "bình thạnh, bình sơn, quảng ngãi",
    "bifnh thajnh, bifnh sown, quarng ngaxi"
  ],
  "Bình Triều, Thăng Bình, Quảng Nam": [
    "bình triều, thăng bình, quảng nam",
    "bifnh trieefu, thawng bifnh, quarng nam"
  ],
  "Bình Trưng, Châu Thành, Tiền Giang": [
    "bình trưng, châu thành, tiền giang",
    "bifnh truwng, chaau thafnh, tieefn giang"
  ],
  "Bình Tân, Gò Công Tây, Tiền Giang": [
    "bình tân, gò công tây, tiền giang",
    "bifnh taan, gof coong taay, tieefn giang"
  ],
  "Bình Tân, Phú Riềng, Bình Phước": [
    "bình tân, phú riềng, bình phước",
    "bifnh taan, phus rieefng, bifnh phuwowsc"
  ],
  "Bình Tường, Tây Sơn, Bình Định": [
    "bình tường, tây sơn, bình định",
    "bifnh tuwowfng, taay sown, bifnh ddijnh"
  ],
  "Bình Xuyên, Bình Giang, Hải Dương": [
    "bình xuyên, bình giang, hải dương",
    "bifnh xuyeen, bifnh giang, hari duwowng"
  ],
  "Bình Đức, Châu Thành, Tiền Giang": [
    "bình đức, châu thành, tiền giang",
    "bifnh dduwsc, chaau thafnh, tieefn giang"
  ],
  "Búng Lao, Mường Ảng, Điện Biên": [
    "búng lao, mường ảng, điện biên",
    "busng lao, muwowfng arng, ddieejn bieen"
  ],
  "Bạch Đằng, Kinh Môn, Hải Dương": [
    "bạch đằng, kinh môn, hải dương",
    "bajch ddawfng, kinh moon, hari duwowng"
  ],
  "Bản Lầu, Mường Khương, Lào Cai": [
    "bản lầu, mường khương, lào cai",
    "barn laafu, muwowfng khuwowng, lafo cai"
  ],
  "Bảo Ninh, Đồng Hới, Quảng Bình": [
    "bảo ninh, đồng hới, quảng bình",
    "baro ninh, ddoofng howsi, quarng bifnh"
  ],
  "Bảy Ngàn, Châu Thành A, Hậu Giang": [
    "bảy ngàn, châu thành a, hậu giang",
    "bary ngafn, chaau thafnh a, haaju giang"
  ],
  "Bắc Phong, Thuận Bắc, Ninh Thuận": [
    "bắc phong, thuận bắc, ninh thuận",
    "bawsc phong, thuaajn bawsc, ninh thuaajn"
  ],
  "Bắc Ruộng, Tánh Linh, Bình Thuận": [
    "bắc ruộng, tánh linh, bình thuận",
    "bawsc ruoojng, tasnh linh, bifnh thuaajn"
  ],
  "Cam Phước Tây, Cam Lâm, Khánh Hòa": [
    "cam phước tây, cam lâm, khánh hòa",
    "cam phuwowsc taay, cam laam, khasnh hofa"
  ],
  "Cao Ngạn, Thái Nguyên, Thái Nguyên": [
    "cao ngạn, thái nguyên, thái nguyên",
    "cao ngajn, thasi nguyeen, thasi nguyeen"
  ],
  "Cao Thắng, Thanh Miện, Hải Dương": [
    "cao thắng, thanh miện, hải dương",
    "cao thawsng, thanh mieejn, hari duwowng"
  ],
  "Chiến Phố, Hoàng Su Phì, Hà Giang": [
    "chiến phố, hoàng su phì, hà giang",
    "chieesn phoos, hoafng su phif, haf giang"
  ],
  "Chiến Thắng, Bắc Sơn, Lạng Sơn": [
    "chiến thắng, bắc sơn, lạng sơn",
    "chieesn thawsng, bawsc sown, lajng sown"
  ],
  "Chùa Hang, Thái Nguyên, Thái Nguyên": [
    "chùa hang, thái nguyên, thái nguyên",
    "chufa hang, thasi nguyeen, thasi nguyeen"
  ],
  "Chế Tạo, Mù Căng Chải, Yên Bái": [
    "chế tạo, mù căng chải, yên bái",
    "chees tajo, muf cawng chari, yeen basi"
  ],
  "Chợ Chùa, Nghĩa Hành, Quảng Ngãi": [
    "chợ chùa, nghĩa hành, quảng ngãi",
    "chowj chufa, nghixa hafnh, quarng ngaxi"
  ],
  "Công Hải, Thuận Bắc, Ninh Thuận": [
    "công hải, thuận bắc, ninh thuận",
    "coong hari, thuaajn bawsc, ninh thuaajn"
  ],
  "Cường Thịnh, Trấn Yên, Yên Bái": [
    "cường thịnh, trấn yên, yên bái",
    "cuwowfng thijnh, traasn yeen, yeen basi"
  ],
  "Cấp Tiến, Sơn Dương, Tuyên Quang": [
    "cấp tiến, sơn dương, tuyên quang",
    "caasp tieesn, sown duwowng, tuyeen quang"
  ],
  "Cầu Đất, Ngô Quyền, Hải Phòng": [
    "cầu đất, ngô quyền, hải phòng",
    "caafu ddaast, ngoo quyeefn, hari phofng"
  ],
  "Cẩm Giang, Cẩm Giàng, Hải Dương": [
    "cẩm giang, cẩm giàng, hải dương",
    "caarm giang, caarm giafng, hari duwowng"
  ],
  "Cẩm Giàng, Bạch Thông, Bắc Kạn": [
    "cẩm giàng, bạch thông, bắc kạn",
    "caarm giafng, bajch thoong, bawsc kajn"
  ],
  "Cẩm Hưng, Cẩm Giàng, Hải Dương": [
    "cẩm hưng, cẩm giàng, hải dương",
    "caarm huwng, caarm giafng, hari duwowng"
  ],
  "Cẩm Nhượng, Cẩm Xuyên, Hà Tĩnh": [
    "cẩm nhượng, cẩm xuyên, hà tĩnh",
    "caarm nhuwowjng, caarm xuyeen, haf tixnh"
  ],
  "Cẩm Phúc, Cẩm Giàng, Hải Dương": [
    "cẩm phúc, cẩm giàng, hải dương",
    "caarm phusc, caarm giafng, hari duwowng"
  ],
  "Cẩm Thạch, Cẩm Phả, Quảng Ninh": [
    "cẩm thạch, cẩm phả, quảng ninh",
    "caarm thajch, caarm phar, quarng ninh"
  ],
  "Cẩm Thịnh, Cẩm Phả, Quảng Ninh": [
    "cẩm thịnh, cẩm phả, quảng ninh",
    "caarm thijnh, caarm phar, quarng ninh"
  ],
  "Cộng Hiền, Vĩnh Bảo, Hải Phòng": [
    "cộng hiền, vĩnh bảo, hải phòng",
    "coojng hieefn, vixnh baro, hari phofng"
  ],
  "Diêm Điền, Thái Thụy, Thái Bình": [
    "diêm điền, thái thụy, thái bình",
    "dieem ddieefn, thasi thujy, thasi bifnh"
  ],
  "Diên Thạnh, Diên Khánh, Khánh Hòa": [
    "diên thạnh, diên khánh, khánh hòa",
    "dieen thajnh, dieen khasnh, khasnh hofa"
  ],
  "Diên Điền, Diên Khánh, Khánh Hòa": [
    "diên điền, diên khánh, khánh hòa",
    "dieen ddieefn, dieen khasnh, khasnh hofa"
  ],
  "Diên Đồng, Diên Khánh, Khánh Hòa": [
    "diên đồng, diên khánh, khánh hòa",
    "dieen ddoofng, dieen khasnh, khasnh hofa"
  ],
  "Dư Hàng Kênh, Lê Chân, Hải Phòng": [
    "dư hàng kênh, lê chân, hải phòng",
    "duw hafng keenh, lee chaan, hari phofng"
  ],
  "Dương Hòa, Kiên Lương, Kiên Giang": [
    "dương hòa, kiên lương, kiên giang",
    "duwowng hofa, kieen luwowng, kieen giang"
  ],
  "Dương Phúc, Thái Thụy, Thái Bình": [
    "dương phúc, thái thụy, thái bình",
    "duwowng phusc, thasi thujy, thasi bifnh"
  ],
  "Dương Đông, Phú Quốc, Kiên Giang": [
    "dương đông, phú quốc, kiên giang",
    "duwowng ddoong, phus quoosc, kieen giang"
  ],
  "Dầu Giây, Thống Nhất, Đồng Nai": [
    "dầu giây, thống nhất, đồng nai",
    "daafu giaay, thoosng nhaast, ddoofng nai"
  ],
  "Gia Xuyên, Hải Dương, Hải Dương": [
    "gia xuyên, hải dương, hải dương",
    "gia xuyeen, hari duwowng, hari duwowng"
  ],
  "Gia Đức, Thuỷ Nguyên, Hải Phòng": [
    "gia đức, thuỷ nguyên, hải phòng",
    "gia dduwsc, thuyr nguyeen, hari phofng"
  ],
  "Giang Sơn Tây, Đô Lương, Nghệ An": [
    "giang sơn tây, đô lương, nghệ an",
    "giang sown taay, ddoo luwowng, ngheej an"
  ],
  "Giang Tiên, Phú Lương, Thái Nguyên": [
    "giang tiên, phú lương, thái nguyên",
    "giang tieen, phus luwowng, thasi nguyeen"
  ],
  "Hiếu Phụng,  Vũng Liêm, Vĩnh Long": [
    "hiếu phụng,  vũng liêm, vĩnh long",
    "hieesu phujng,  vuxng lieem, vixnh long"
  ],
  "Hiếu Thuận,  Vũng Liêm, Vĩnh Long": [
    "hiếu thuận,  vũng liêm, vĩnh long",
    "hieesu thuaajn,  vuxng lieem, vixnh long"
  ],
  "Hiền Ninh, Quảng Ninh, Quảng Bình": [
    "hiền ninh, quảng ninh, quảng bình",
    "hieefn ninh, quarng ninh, quarng bifnh"
  ],
  "Hiền Thành, Vĩnh Linh, Quảng Trị": [
    "hiền thành, vĩnh linh, quảng trị",
    "hieefn thafnh, vixnh linh, quarng trij"
  ],
  "Hiệp Cường, Kim Động, Hưng Yên": [
    "hiệp cường, kim động, hưng yên",
    "hieejp cuwowfng, kim ddoojng, huwng yeen"
  ],
  "Hiệp Mỹ Tây, Cầu Ngang, Trà Vinh": [
    "hiệp mỹ tây, cầu ngang, trà vinh",
    "hieejp myx taay, caafu ngang, traf vinh"
  ],
  "Hiệp Thành, Quận 12, Hồ Chí Minh": [
    "hiệp thành, quận 12, hồ chí minh",
    "hieejp thafnh, quaajn 12, hoof chis minh"
  ],
  "Hoà Bình, Thuỷ Nguyên, Hải Phòng": [
    "hoà bình, thuỷ nguyên, hải phòng",
    "hoaf bifnh, thuyr nguyeen, hari phofng"
  ],
  "Hoà Hải, Ngũ Hành Sơn, Đà Nẵng": [
    "hoà hải, ngũ hành sơn, đà nẵng",
    "hoaf hari, ngux hafnh sown, ddaf nawxng"
  ],
  "Hoà Lợi, Giồng Riềng, Kiên Giang": [
    "hoà lợi, giồng riềng, kiên giang",
    "hoaf lowji, gioofng rieefng, kieen giang"
  ],
  "Hoài Đức, Hoài Nhơn, Bình Định": [
    "hoài đức, hoài nhơn, bình định",
    "hoafi dduwsc, hoafi nhown, bifnh ddijnh"
  ],
  "Hoàng Lương, Hiệp Hòa, Bắc Giang": [
    "hoàng lương, hiệp hòa, bắc giang",
    "hoafng luwowng, hieejp hofa, bawsc giang"
  ],
  "Hoàng Nông, Đại Từ, Thái Nguyên": [
    "hoàng nông, đại từ, thái nguyên",
    "hoafng noong, ddaji tuwf, thasi nguyeen"
  ],
  "Hoàng Văn Thụ, Hoàng Mai, Hà Nội": [
    "hoàng văn thụ, hoàng mai, hà nội",
    "hoafng vawn thuj, hoafng mai, haf nooji"
  ],
  "Hoàng Đồng, Lạng Sơn, Lạng Sơn": [
    "hoàng đồng, lạng sơn, lạng sơn",
    "hoafng ddoofng, lajng sown, lajng sown"
  ],
  "Hoằng Ngọc, Hoằng Hóa, Thanh Hóa": [
    "hoằng ngọc, hoằng hóa, thanh hóa",
    "hoawfng ngojc, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Thành, Hoằng Hóa, Thanh Hóa": [
    "hoằng thành, hoằng hóa, thanh hóa",
    "hoawfng thafnh, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Tiến, Hoằng Hóa, Thanh Hóa": [
    "hoằng tiến, hoằng hóa, thanh hóa",
    "hoawfng tieesn, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Xuyên, Hoằng Hóa, Thanh Hóa": [
    "hoằng xuyên, hoằng hóa, thanh hóa",
    "hoawfng xuyeen, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Đông, Hoằng Hóa, Thanh Hóa": [
    "hoằng đông, hoằng hóa, thanh hóa",
    "hoawfng ddoong, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Đạo, Hoằng Hóa, Thanh Hóa": [
    "hoằng đạo, hoằng hóa, thanh hóa",
    "hoawfng ddajo, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Đạt, Hoằng Hóa, Thanh Hóa": [
    "hoằng đạt, hoằng hóa, thanh hóa",
    "hoawfng ddajt, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Đức, Hoằng Hóa, Thanh Hóa": [
    "hoằng đức, hoằng hóa, thanh hóa",
    "hoawfng dduwsc, hoawfng hosa, thanh hosa"
  ],
  "Huyền Tụng, Bắc Kạn, Bắc Kạn": [
    "huyền tụng, bắc kạn, bắc kạn",
    "huyeefn tujng, bawsc kajn, bawsc kajn"
  ],
  "Huổi Mí, Mường Chà, Điện Biên": [
    "huổi mí, mường chà, điện biên",
    "huoori mis, muwowfng chaf, ddieejn bieen"
  ],
  "Hàm Tiến, Phan Thiết, Bình Thuận": [
    "hàm tiến, phan thiết, bình thuận",
    "hafm tieesn, phan thieest, bifnh thuaajn"
  ],
  "Hành Dũng, Nghĩa Hành, Quảng Ngãi": [
    "hành dũng, nghĩa hành, quảng ngãi",
    "hafnh duxng, nghixa hafnh, quarng ngaxi"
  ],
  "Hành Nhân, Nghĩa Hành, Quảng Ngãi": [
    "hành nhân, nghĩa hành, quảng ngãi",
    "hafnh nhaan, nghixa hafnh, quarng ngaxi"
  ],
  "Hành Trung, Nghĩa Hành, Quảng Ngãi": [
    "hành trung, nghĩa hành, quảng ngãi",
    "hafnh trung, nghixa hafnh, quarng ngaxi"
  ],
  "Hòa Hưng, Giồng Riềng, Kiên Giang": [
    "hòa hưng, giồng riềng, kiên giang",
    "hofa huwng, gioofng rieefng, kieen giang"
  ],
  "Hòa Khánh Đông, Đức Hòa, Long An": [
    "hòa khánh đông, đức hòa, long an",
    "hofa khasnh ddoong, dduwsc hofa, long an"
  ],
  "Hòa Thắng, Bắc Bình, Bình Thuận": [
    "hòa thắng, bắc bình, bình thuận",
    "hofa thawsng, bawsc bifnh, bifnh thuaajn"
  ],
  "Hòa Thọ Tây, Cẩm Lệ, Đà Nẵng": [
    "hòa thọ tây, cẩm lệ, đà nẵng",
    "hofa thoj taay, caarm leej, ddaf nawxng"
  ],
  "Hòa Tân Đông, Đông Hòa, Phú Yên": [
    "hòa tân đông, đông hòa, phú yên",
    "hofa taan ddoong, ddoong hofa, phus yeen"
  ],
  "Hòa Điền, Kiên Lương, Kiên Giang": [
    "hòa điền, kiên lương, kiên giang",
    "hofa ddieefn, kieen luwowng, kieen giang"
  ],
  "Hùng Thắng, Tiên Lãng, Hải Phòng": [
    "hùng thắng, tiên lãng, hải phòng",
    "hufng thawsng, tieen laxng, hari phofng"
  ],
  "Hưng Long, Bình Chánh, Hồ Chí Minh": [
    "hưng long, bình chánh, hồ chí minh",
    "huwng long, bifnh chasnh, hoof chis minh"
  ],
  "Hưng Lộc, Thống Nhất, Đồng Nai": [
    "hưng lộc, thống nhất, đồng nai",
    "huwng loojc, thoosng nhaast, ddoofng nai"
  ],
  "Hưng Thành, Tuyên Quang, Tuyên Quang": [
    "hưng thành, tuyên quang, tuyên quang",
    "huwng thafnh, tuyeen quang, tuyeen quang"
  ],
  "Hưng Thủy, Lệ Thủy, Quảng Bình": [
    "hưng thủy, lệ thủy, quảng bình",
    "huwng thury, leej thury, quarng bifnh"
  ],
  "Hưng Đạo, Dương Kinh, Hải Phòng": [
    "hưng đạo, dương kinh, hải phòng",
    "huwng ddajo, duwowng kinh, hari phofng"
  ],
  "Hưng Định, Thuận An, Bình Dương": [
    "hưng định, thuận an, bình dương",
    "huwng ddijnh, thuaajn an, bifnh duwowng"
  ],
  "Hương Hóa, Tuyên Hóa, Quảng Bình": [
    "hương hóa, tuyên hóa, quảng bình",
    "huwowng hosa, tuyeen hosa, quarng bifnh"
  ],
  "Hương Long, Huế, Thừa Thiên Huế": [
    "hương long, huế, thừa thiên huế",
    "huwowng long, huees, thuwfa thieen huees"
  ],
  "Hương Lạc, Lạng Giang, Bắc Giang": [
    "hương lạc, lạng giang, bắc giang",
    "huwowng lajc, lajng giang, bawsc giang"
  ],
  "Hương Trà, Trà Bồng, Quảng Ngãi": [
    "hương trà, trà bồng, quảng ngãi",
    "huwowng traf, traf boofng, quarng ngaxi"
  ],
  "Hương Trạch, Hương Khê, Hà Tĩnh": [
    "hương trạch, hương khê, hà tĩnh",
    "huwowng trajch, huwowng khee, haf tixnh"
  ],
  "Hải Chánh, Hải Lăng, Quảng Trị": [
    "hải chánh, hải lăng, quảng trị",
    "hari chasnh, hari lawng, quarng trij"
  ],
  "Hải Châu  I, Hải Châu, Đà Nẵng": [
    "hải châu  i, hải châu, đà nẵng",
    "hari chaau  i, hari chaau, ddaf nawxng"
  ],
  "Hải Châu II, Hải Châu, Đà Nẵng": [
    "hải châu ii, hải châu, đà nẵng",
    "hari chaau ii, hari chaau, ddaf nawxng"
  ],
  "Hải Cường, Hải Hậu, Nam Định": [
    "hải cường, hải hậu, nam định",
    "hari cuwowfng, hari haaju, nam ddijnh"
  ],
  "Hải Lệ, Quảng Trị, Quảng Trị": [
    "hải lệ, quảng trị, quảng trị",
    "hari leej, quarng trij, quarng trij"
  ],
  "Hải Phương, Hải Hậu, Nam Định": [
    "hải phương, hải hậu, nam định",
    "hari phuwowng, hari haaju, nam ddijnh"
  ],
  "Hải Thành, Dương Kinh, Hải Phòng": [
    "hải thành, dương kinh, hải phòng",
    "hari thafnh, duwowng kinh, hari phofng"
  ],
  "Hải Tân, Hải Dương, Hải Dương": [
    "hải tân, hải dương, hải dương",
    "hari taan, hari duwowng, hari duwowng"
  ],
  "Hậu Mỹ Trinh, Cái Bè, Tiền Giang": [
    "hậu mỹ trinh, cái bè, tiền giang",
    "haaju myx trinh, casi bef, tieefn giang"
  ],
  "Hồng Bạch, Đông Hưng, Thái Bình": [
    "hồng bạch, đông hưng, thái bình",
    "hoofng bajch, ddoong huwng, thasi bifnh"
  ],
  "Hồng Lạc, Sơn Dương, Tuyên Quang": [
    "hồng lạc, sơn dương, tuyên quang",
    "hoofng lajc, sown duwowng, tuyeen quang"
  ],
  "Hồng Phong, Bắc Bình, Bình Thuận": [
    "hồng phong, bắc bình, bình thuận",
    "hoofng phong, bawsc bifnh, bifnh thuaajn"
  ],
  "Hồng Phương, Yên Lạc, Vĩnh Phúc": [
    "hồng phương, yên lạc, vĩnh phúc",
    "hoofng phuwowng, yeen lajc, vixnh phusc"
  ],
  "Hồng Thuận, Giao Thủy, Nam Định": [
    "hồng thuận, giao thủy, nam định",
    "hoofng thuaajn, giao thury, nam ddijnh"
  ],
  "Hồng Thái, Bắc Bình, Bình Thuận": [
    "hồng thái, bắc bình, bình thuận",
    "hoofng thasi, bawsc bifnh, bifnh thuaajn"
  ],
  "Hồng Tiến, Phổ Yên, Thái Nguyên": [
    "hồng tiến, phổ yên, thái nguyên",
    "hoofng tieesn, phoor yeen, thasi nguyeen"
  ],
  "Hồng Việt, Đông Hưng, Thái Bình": [
    "hồng việt, đông hưng, thái bình",
    "hoofng vieejt, ddoong huwng, thasi bifnh"
  ],
  "Hồng Đức, Ninh Giang, Hải Dương": [
    "hồng đức, ninh giang, hải dương",
    "hoofng dduwsc, ninh giang, hari duwowng"
  ],
  "Hợp Thành, Sơn Dương, Tuyên Quang": [
    "hợp thành, sơn dương, tuyên quang",
    "howjp thafnh, sown duwowng, tuyeen quang"
  ],
  "Hữu Đạo, Châu Thành, Tiền Giang": [
    "hữu đạo, châu thành, tiền giang",
    "huwxu ddajo, chaau thafnh, tieefn giang"
  ],
  "Khe Tre, Nam Đông, Thừa Thiên Huế": [
    "khe tre, nam đông, thừa thiên huế",
    "khe tre, nam ddoong, thuwfa thieen huees"
  ],
  "Khuyến Nông, Triệu Sơn, Thanh Hóa": [
    "khuyến nông, triệu sơn, thanh hóa",
    "khuyeesn noong, trieeju sown, thanh hosa"
  ],
  "Khuê Mỹ, Ngũ Hành Sơn, Đà Nẵng": [
    "khuê mỹ, ngũ hành sơn, đà nẵng",
    "khuee myx, ngux hafnh sown, ddaf nawxng"
  ],
  "Khánh Cường, Yên Khánh, Ninh Bình": [
    "khánh cường, yên khánh, ninh bình",
    "khasnh cuwowfng, yeen khasnh, ninh bifnh"
  ],
  "Khánh Hiệp, Khánh Vĩnh, Khánh Hòa": [
    "khánh hiệp, khánh vĩnh, khánh hòa",
    "khasnh hieejp, khasnh vixnh, khasnh hofa"
  ],
  "Khánh Long, Tràng Định, Lạng Sơn": [
    "khánh long, tràng định, lạng sơn",
    "khasnh long, trafng ddijnh, lajng sown"
  ],
  "Khánh Thành, Khánh Vĩnh, Khánh Hòa": [
    "khánh thành, khánh vĩnh, khánh hòa",
    "khasnh thafnh, khasnh vixnh, khasnh hofa"
  ],
  "Khánh Đông, Khánh Vĩnh, Khánh Hòa": [
    "khánh đông, khánh vĩnh, khánh hòa",
    "khasnh ddoong, khasnh vixnh, khasnh hofa"
  ],
  "Khâm Đức, Phước Sơn, Quảng Nam": [
    "khâm đức, phước sơn, quảng nam",
    "khaam dduwsc, phuwowsc sown, quarng nam"
  ],
  "Khởi Nghĩa, Tiên Lãng, Hải Phòng": [
    "khởi nghĩa, tiên lãng, hải phòng",
    "khowri nghixa, tieen laxng, hari phofng"
  ],
  "Kim Song Trường, Can Lộc, Hà Tĩnh": [
    "kim song trường, can lộc, hà tĩnh",
    "kim song truwowfng, can loojc, haf tixnh"
  ],
  "Kim Đồng, Tràng Định, Lạng Sơn": [
    "kim đồng, tràng định, lạng sơn",
    "kim ddoofng, trafng ddijnh, lajng sown"
  ],
  "Kiến Giang, Lệ Thủy, Quảng Bình": [
    "kiến giang, lệ thủy, quảng bình",
    "kieesn giang, leej thury, quarng bifnh"
  ],
  "Kiến Quốc, Ninh Giang, Hải Dương": [
    "kiến quốc, ninh giang, hải dương",
    "kieesn quoosc, ninh giang, hari duwowng"
  ],
  "Krông Năng, Krông Năng, Đắk Lắk": [
    "krông năng, krông năng, đắk lắk",
    "kroong nawng, kroong nawng, ddawsk lawsk"
  ],
  "Linh Thông, Định Hóa, Thái Nguyên": [
    "linh thông, định hóa, thái nguyên",
    "linh thoong, ddijnh hosa, thasi nguyeen"
  ],
  "Linh Trung, Thủ Đức, Hồ Chí Minh": [
    "linh trung, thủ đức, hồ chí minh",
    "linh trung, thur dduwsc, hoof chis minh"
  ],
  "Linh Xuân, Thủ Đức, Hồ Chí Minh": [
    "linh xuân, thủ đức, hồ chí minh",
    "linh xuaan, thur dduwsc, hoof chis minh"
  ],
  "Liên Khê, Thuỷ Nguyên, Hải Phòng": [
    "liên khê, thuỷ nguyên, hải phòng",
    "lieen khee, thuyr nguyeen, hari phofng"
  ],
  "Liên Mạc, Bắc Từ Liêm, Hà Nội": [
    "liên mạc, bắc từ liêm, hà nội",
    "lieen majc, bawsc tuwf lieem, haf nooji"
  ],
  "Liên Thủy, Lệ Thủy, Quảng Bình": [
    "liên thủy, lệ thủy, quảng bình",
    "lieen thury, leej thury, quarng bifnh"
  ],
  "Long Bình Tân, Biên Hòa, Đồng Nai": [
    "long bình tân, biên hòa, đồng nai",
    "long bifnh taan, bieen hofa, ddoofng nai"
  ],
  "Long Bình, Gò Công Tây, Tiền Giang": [
    "long bình, gò công tây, tiền giang",
    "long bifnh, gof coong taay, tieefn giang"
  ],
  "Long Bình, Phú Riềng, Bình Phước": [
    "long bình, phú riềng, bình phước",
    "long bifnh, phus rieefng, bifnh phuwowsc"
  ],
  "Long Hưng, Phú Riềng, Bình Phước": [
    "long hưng, phú riềng, bình phước",
    "long huwng, phus rieefng, bifnh phuwowsc"
  ],
  "Long Hựu Tây, Cần Đước, Long An": [
    "long hựu tây, cần đước, long an",
    "long huwju taay, caafn dduwowsc, long an"
  ],
  "Long Trường, Quận 9, Hồ Chí Minh": [
    "long trường, quận 9, hồ chí minh",
    "long truwowfng, quaajn 9, hoof chis minh"
  ],
  "Long Vĩnh, Gò Công Tây, Tiền Giang": [
    "long vĩnh, gò công tây, tiền giang",
    "long vixnh, gof coong taay, tieefn giang"
  ],
  "Long Định, Châu Thành, Tiền Giang": [
    "long định, châu thành, tiền giang",
    "long ddijnh, chaau thafnh, tieefn giang"
  ],
  "Luận Khê, Thường Xuân, Thanh Hóa": [
    "luận khê, thường xuân, thanh hóa",
    "luaajn khee, thuwowfng xuaan, thanh hosa"
  ],
  "Lý Trạch, Bố Trạch, Quảng Bình": [
    "lý trạch, bố trạch, quảng bình",
    "lys trajch, boos trajch, quarng bifnh"
  ],
  "Lương Quới, Giồng Trôm, Bến Tre": [
    "lương quới, giồng trôm, bến tre",
    "luwowng quowsi, gioofng troom, beesn tre"
  ],
  "Lương Sơn, Bắc Bình, Bình Thuận": [
    "lương sơn, bắc bình, bình thuận",
    "luwowng sown, bawsc bifnh, bifnh thuaajn"
  ],
  "Lương Sơn, Sông Công, Thái Nguyên": [
    "lương sơn, sông công, thái nguyên",
    "luwowng sown, soong coong, thasi nguyeen"
  ],
  "Lạc Xuân, Đơn Dương, Lâm Đồng": [
    "lạc xuân, đơn dương, lâm đồng",
    "lajc xuaan, ddown duwowng, laam ddoofng"
  ],
  "Lả Nhì Thàng, Phong Thổ, Lai Châu": [
    "lả nhì thàng, phong thổ, lai châu",
    "lar nhif thafng, phong thoor, lai chaau"
  ],
  "Lập Lễ, Thuỷ Nguyên, Hải Phòng": [
    "lập lễ, thuỷ nguyên, hải phòng",
    "laajp leex, thuyr nguyeen, hari phofng"
  ],
  "Lộc Hiệp, Lộc Ninh, Bình Phước": [
    "lộc hiệp, lộc ninh, bình phước",
    "loojc hieejp, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Khánh, Lộc Ninh, Bình Phước": [
    "lộc khánh, lộc ninh, bình phước",
    "loojc khasnh, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Ninh, Đồng Hới, Quảng Bình": [
    "lộc ninh, đồng hới, quảng bình",
    "loojc ninh, ddoofng howsi, quarng bifnh"
  ],
  "Lộc Thành, Lộc Ninh, Bình Phước": [
    "lộc thành, lộc ninh, bình phước",
    "loojc thafnh, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Thủy, Lệ Thủy, Quảng Bình": [
    "lộc thủy, lệ thủy, quảng bình",
    "loojc thury, leej thury, quarng bifnh"
  ],
  "Lộc Vượng, Nam Định, Nam Định": [
    "lộc vượng, nam định, nam định",
    "loojc vuwowjng, nam ddijnh, nam ddijnh"
  ],
  "Lợi Hải, Thuận Bắc, Ninh Thuận": [
    "lợi hải, thuận bắc, ninh thuận",
    "lowji hari, thuaajn bawsc, ninh thuaajn"
  ],
  "Minh Cường, Thường Tín, Hà Nội": [
    "minh cường, thường tín, hà nội",
    "minh cuwowfng, thuwowfng tisn, haf nooji"
  ],
  "Minh Hưng, Chơn Thành, Bình Phước": [
    "minh hưng, chơn thành, bình phước",
    "minh huwng, chown thafnh, bifnh phuwowsc"
  ],
  "Minh Lập, Chơn Thành, Bình Phước": [
    "minh lập, chơn thành, bình phước",
    "minh laajp, chown thafnh, bifnh phuwowsc"
  ],
  "Mão Điền, Thuận Thành, Bắc Ninh": [
    "mão điền, thuận thành, bắc ninh",
    "maxo ddieefn, thuaajn thafnh, bawsc ninh"
  ],
  "Mông Dương, Cẩm Phả, Quảng Ninh": [
    "mông dương, cẩm phả, quảng ninh",
    "moong duwowng, caarm phar, quarng ninh"
  ],
  "Mường Khiêng, Thuận Châu, Sơn La": [
    "mường khiêng, thuận châu, sơn la",
    "muwowfng khieeng, thuaajn chaau, sown la"
  ],
  "Mường Lát, Mường Lát, Thanh Hóa": [
    "mường lát, mường lát, thanh hóa",
    "muwowfng last, muwowfng last, thanh hosa"
  ],
  "Mạo Khê, Đông Triều, Quảng Ninh": [
    "mạo khê, đông triều, quảng ninh",
    "majo khee, ddoong trieefu, quarng ninh"
  ],
  "Một Ngàn, Châu Thành A, Hậu Giang": [
    "một ngàn, châu thành a, hậu giang",
    "moojt ngafn, chaau thafnh a, haaju giang"
  ],
  "Mỹ Hội Đông, Chợ Mới, An Giang": [
    "mỹ hội đông, chợ mới, an giang",
    "myx hooji ddoong, chowj mowsi, an giang"
  ],
  "Mỹ Phú Đông, Thoại Sơn, An Giang": [
    "mỹ phú đông, thoại sơn, an giang",
    "myx phus ddoong, thoaji sown, an giang"
  ],
  "Mỹ Phước, Bến Cát, Bình Dương": [
    "mỹ phước, bến cát, bình dương",
    "myx phuwowsc, beesn cast, bifnh duwowng"
  ],
  "Mỹ Thành Nam, Cai Lậy, Tiền Giang": [
    "mỹ thành nam, cai lậy, tiền giang",
    "myx thafnh nam, cai laajy, tieefn giang"
  ],
  "Mỹ Thạnh Tây, Đức Huệ, Long An": [
    "mỹ thạnh tây, đức huệ, long an",
    "myx thajnh taay, dduwsc hueej, long an"
  ],
  "Mỹ Đình 1, Nam Từ Liêm, Hà Nội": [
    "mỹ đình 1, nam từ liêm, hà nội",
    "myx ddifnh 1, nam tuwf lieem, haf nooji"
  ],
  "Mỹ Đình 2, Nam Từ Liêm, Hà Nội": [
    "mỹ đình 2, nam từ liêm, hà nội",
    "myx ddifnh 2, nam tuwf lieem, haf nooji"
  ],
  "Mỹ Đức Tây, Cái Bè, Tiền Giang": [
    "mỹ đức tây, cái bè, tiền giang",
    "myx dduwsc taay, casi bef, tieefn giang"
  ],
  "N.T Phong Hải, Bảo Thắng, Lào Cai": [
    "n.t phong hải, bảo thắng, lào cai",
    "n.t phong hari, baro thawsng, lafo cai"
  ],
  "NT Lệ Ninh, Lệ Thủy, Quảng Bình": [
    "nt lệ ninh, lệ thủy, quảng bình",
    "nt leej ninh, leej thury, quarng bifnh"
  ],
  "Nam Thái Sơn, Hòn Đất, Kiên Giang": [
    "nam thái sơn, hòn đất, kiên giang",
    "nam thasi sown, hofn ddaast, kieen giang"
  ],
  "Nam Trạch, Bố Trạch, Quảng Bình": [
    "nam trạch, bố trạch, quảng bình",
    "nam trajch, boos trajch, quarng bifnh"
  ],
  "Nghinh Tường, Võ Nhai, Thái Nguyên": [
    "nghinh tường, võ nhai, thái nguyên",
    "nghinh tuwowfng, vox nhai, thasi nguyeen"
  ],
  "Nghĩa Bình, Bù Đăng, Bình Phước": [
    "nghĩa bình, bù đăng, bình phước",
    "nghixa bifnh, buf ddawng, bifnh phuwowsc"
  ],
  "Nghĩa Hiệp, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa hiệp, tư nghĩa, quảng ngãi",
    "nghixa hieejp, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Hà, Quảng Ngãi, Quảng Ngãi": [
    "nghĩa hà, quảng ngãi, quảng ngãi",
    "nghixa haf, quarng ngaxi, quarng ngaxi"
  ],
  "Nghĩa Hồng, Nghĩa Hưng, Nam Định": [
    "nghĩa hồng, nghĩa hưng, nam định",
    "nghixa hoofng, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Thành, Nghĩa Hưng, Nam Định": [
    "nghĩa thành, nghĩa hưng, nam định",
    "nghixa thafnh, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Trung, Bù Đăng, Bình Phước": [
    "nghĩa trung, bù đăng, bình phước",
    "nghixa trung, buf ddawng, bifnh phuwowsc"
  ],
  "Nghị Đức, Tánh Linh, Bình Thuận": [
    "nghị đức, tánh linh, bình thuận",
    "nghij dduwsc, tasnh linh, bifnh thuaajn"
  ],
  "Nguyên Bình, Nguyên Bình, Cao Bằng": [
    "nguyên bình, nguyên bình, cao bằng",
    "nguyeen bifnh, nguyeen bifnh, cao bawfng"
  ],
  "Nguyệt Đức, Yên Lạc, Vĩnh Phúc": [
    "nguyệt đức, yên lạc, vĩnh phúc",
    "nguyeejt dduwsc, yeen lajc, vixnh phusc"
  ],
  "Ngân Thủy, Lệ Thủy, Quảng Bình": [
    "ngân thủy, lệ thủy, quảng bình",
    "ngaan thury, leej thury, quarng bifnh"
  ],
  "Ngư Thủy , Lệ Thủy, Quảng Bình": [
    "ngư thủy , lệ thủy, quảng bình",
    "nguw thury , leej thury, quarng bifnh"
  ],
  "Ngọc Vừng, Vân Đồn, Quảng Ninh": [
    "ngọc vừng, vân đồn, quảng ninh",
    "ngojc vuwfng, vaan ddoofn, quarng ninh"
  ],
  "Ngọc Động, Quảng Hòa, Cao Bằng": [
    "ngọc động, quảng hòa, cao bằng",
    "ngojc ddoojng, quarng hofa, cao bawfng"
  ],
  "Nhuận Đức, Củ Chi, Hồ Chí Minh": [
    "nhuận đức, củ chi, hồ chí minh",
    "nhuaajn dduwsc, cur chi, hoof chis minh"
  ],
  "Nhuế Dương, Khoái Châu, Hưng Yên": [
    "nhuế dương, khoái châu, hưng yên",
    "nhuees duwowng, khoasi chaau, huwng yeen"
  ],
  "Nông Tiến, Tuyên Quang, Tuyên Quang": [
    "nông tiến, tuyên quang, tuyên quang",
    "noong tieesn, tuyeen quang, tuyeen quang"
  ],
  "Núi Đèo, Thuỷ Nguyên, Hải Phòng": [
    "núi đèo, thuỷ nguyên, hải phòng",
    "nusi ddefo, thuyr nguyeen, hari phofng"
  ],
  "Núi Đối, Kiến Thuỵ, Hải Phòng": [
    "núi đối, kiến thuỵ, hải phòng",
    "nusi ddoosi, kieesn thuyj, hari phofng"
  ],
  "Nậm Nèn, Mường Chà, Điện Biên": [
    "nậm nèn, mường chà, điện biên",
    "naajm nefn, muwowfng chaf, ddieejn bieen"
  ],
  "Phan Rí Cửa, Tuy Phong, Bình Thuận": [
    "phan rí cửa, tuy phong, bình thuận",
    "phan ris cuwra, tuy phong, bifnh thuaajn"
  ],
  "Phan Thiết, Tuyên Quang, Tuyên Quang": [
    "phan thiết, tuyên quang, tuyên quang",
    "phan thieest, tuyeen quang, tuyeen quang"
  ],
  "Phan Điền, Bắc Bình, Bình Thuận": [
    "phan điền, bắc bình, bình thuận",
    "phan ddieefn, bawsc bifnh, bifnh thuaajn"
  ],
  "Phong Lạc, Trần Văn Thời, Cà Mau": [
    "phong lạc, trần văn thời, cà mau",
    "phong lajc, traafn vawn thowfi, caf mau"
  ],
  "Phong Nẫm, Phan Thiết, Bình Thuận": [
    "phong nẫm, phan thiết, bình thuận",
    "phong naaxm, phan thieest, bifnh thuaajn"
  ],
  "Phong Phú, Bình Chánh, Hồ Chí Minh": [
    "phong phú, bình chánh, hồ chí minh",
    "phong phus, bifnh chasnh, hoof chis minh"
  ],
  "Phong Thịnh, Thanh Chương, Nghệ An": [
    "phong thịnh, thanh chương, nghệ an",
    "phong thijnh, thanh chuwowng, ngheej an"
  ],
  "Phong Thủy, Lệ Thủy, Quảng Bình": [
    "phong thủy, lệ thủy, quảng bình",
    "phong thury, leej thury, quarng bifnh"
  ],
  "Phong Điền, Phong Điền, Cần Thơ": [
    "phong điền, phong điền, cần thơ",
    "phong ddieefn, phong ddieefn, caafn thow"
  ],
  "Phong Đông, Vĩnh Thuận, Kiên Giang": [
    "phong đông, vĩnh thuận, kiên giang",
    "phong ddoong, vixnh thuaajn, kieen giang"
  ],
  "Phu Luông, Điện Biên, Điện Biên": [
    "phu luông, điện biên, điện biên",
    "phu luoong, ddieejn bieen, ddieejn bieen"
  ],
  "Phùng Chí Kiên, Mỹ Hào, Hưng Yên": [
    "phùng chí kiên, mỹ hào, hưng yên",
    "phufng chis kieen, myx hafo, huwng yeen"
  ],
  "Phú Diễn, Bắc Từ Liêm, Hà Nội": [
    "phú diễn, bắc từ liêm, hà nội",
    "phus dieexn, bawsc tuwf lieem, haf nooji"
  ],
  "Phú Gia, Phú Vang, Thừa Thiên Huế": [
    "phú gia, phú vang, thừa thiên huế",
    "phus gia, phus vang, thuwfa thieen huees"
  ],
  "Phú Hải, Đồng Hới, Quảng Bình": [
    "phú hải, đồng hới, quảng bình",
    "phus hari, ddoofng howsi, quarng bifnh"
  ],
  "Phú Hội, Đức Trọng, Lâm Đồng": [
    "phú hội, đức trọng, lâm đồng",
    "phus hooji, dduwsc trojng, laam ddoofng"
  ],
  "Phú Lương, Sơn Dương, Tuyên Quang": [
    "phú lương, sơn dương, tuyên quang",
    "phus luwowng, sown duwowng, tuyeen quang"
  ],
  "Phú Nhuận, Huế, Thừa Thiên Huế": [
    "phú nhuận, huế, thừa thiên huế",
    "phus nhuaajn, huees, thuwfa thieen huees"
  ],
  "Phú Thuận, Huế, Thừa Thiên Huế": [
    "phú thuận, huế, thừa thiên huế",
    "phus thuaajn, huees, thuwfa thieen huees"
  ],
  "Phú Thạnh, Nhơn Trạch, Đồng Nai": [
    "phú thạnh, nhơn trạch, đồng nai",
    "phus thajnh, nhown trajch, ddoofng nai"
  ],
  "Phú Thịnh, Bình Long, Bình Phước": [
    "phú thịnh, bình long, bình phước",
    "phus thijnh, bifnh long, bifnh phuwowsc"
  ],
  "Phú Thịnh, Đại Từ, Thái Nguyên": [
    "phú thịnh, đại từ, thái nguyên",
    "phus thijnh, ddaji tuwf, thasi nguyeen"
  ],
  "Phú Thủy, Phan Thiết, Bình Thuận": [
    "phú thủy, phan thiết, bình thuận",
    "phus thury, phan thieest, bifnh thuaajn"
  ],
  "Phú Tiến, Định Hóa, Thái Nguyên": [
    "phú tiến, định hóa, thái nguyên",
    "phus tieesn, ddijnh hosa, thasi nguyeen"
  ],
  "Phú Trung, Phú Riềng, Bình Phước": [
    "phú trung, phú riềng, bình phước",
    "phus trung, phus rieefng, bifnh phuwowsc"
  ],
  "Phú Văn, Bù Gia Mập, Bình Phước": [
    "phú văn, bù gia mập, bình phước",
    "phus vawn, buf gia maajp, bifnh phuwowsc"
  ],
  "Phú Đa, Phú Vang, Thừa Thiên Huế": [
    "phú đa, phú vang, thừa thiên huế",
    "phus dda, phus vang, thuwfa thieen huees"
  ],
  "Phú Đình, Định Hóa, Thái Nguyên": [
    "phú đình, định hóa, thái nguyên",
    "phus ddifnh, ddijnh hosa, thasi nguyeen"
  ],
  "Phúc Thuận, Phổ Yên, Thái Nguyên": [
    "phúc thuận, phổ yên, thái nguyên",
    "phusc thuaajn, phoor yeen, thasi nguyeen"
  ],
  "Phúc Thắng, Nghĩa Hưng, Nam Định": [
    "phúc thắng, nghĩa hưng, nam định",
    "phusc thawsng, nghixa huwng, nam ddijnh"
  ],
  "Phúc Thịnh, Chiêm Hóa, Tuyên Quang": [
    "phúc thịnh, chiêm hóa, tuyên quang",
    "phusc thijnh, chieem hosa, tuyeen quang"
  ],
  "Phương Canh, Nam Từ Liêm, Hà Nội": [
    "phương canh, nam từ liêm, hà nội",
    "phuwowng canh, nam tuwf lieem, haf nooji"
  ],
  "Phương Chiểu, Hưng Yên, Hưng Yên": [
    "phương chiểu, hưng yên, hưng yên",
    "phuwowng chieeru, huwng yeen, huwng yeen"
  ],
  "Phương Hải, Ninh Hải, Ninh Thuận": [
    "phương hải, ninh hải, ninh thuận",
    "phuwowng hari, ninh hari, ninh thuaajn"
  ],
  "Phương Đông, Uông Bí, Quảng Ninh": [
    "phương đông, uông bí, quảng ninh",
    "phuwowng ddoong, uoong bis, quarng ninh"
  ],
  "Phước An, Tuy Phước, Bình Định": [
    "phước an, tuy phước, bình định",
    "phuwowsc an, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Bình, Long Thành, Đồng Nai": [
    "phước bình, long thành, đồng nai",
    "phuwowsc bifnh, long thafnh, ddoofng nai"
  ],
  "Phước Bình, Quận 9, Hồ Chí Minh": [
    "phước bình, quận 9, hồ chí minh",
    "phuwowsc bifnh, quaajn 9, hoof chis minh"
  ],
  "Phước Bình, Trảng Bàng, Tây Ninh": [
    "phước bình, trảng bàng, tây ninh",
    "phuwowsc bifnh, trarng bafng, taay ninh"
  ],
  "Phước Chỉ, Trảng Bàng, Tây Ninh": [
    "phước chỉ, trảng bàng, tây ninh",
    "phuwowsc chir, trarng bafng, taay ninh"
  ],
  "Phước Cát , Cát Tiên, Lâm Đồng": [
    "phước cát , cát tiên, lâm đồng",
    "phuwowsc cast , cast tieen, laam ddoofng"
  ],
  "Phước Dinh, Thuận Nam, Ninh Thuận": [
    "phước dinh, thuận nam, ninh thuận",
    "phuwowsc dinh, thuaajn nam, ninh thuaajn"
  ],
  "Phước Gia, Hiệp Đức, Quảng Nam": [
    "phước gia, hiệp đức, quảng nam",
    "phuwowsc gia, hieejp dduwsc, quarng nam"
  ],
  "Phước Hoà, Phú Giáo, Bình Dương": [
    "phước hoà, phú giáo, bình dương",
    "phuwowsc hoaf, phus giaso, bifnh duwowng"
  ],
  "Phước Kim, Phước Sơn, Quảng Nam": [
    "phước kim, phước sơn, quảng nam",
    "phuwowsc kim, phuwowsc sown, quarng nam"
  ],
  "Phước Lộc, Nhà Bè, Hồ Chí Minh": [
    "phước lộc, nhà bè, hồ chí minh",
    "phuwowsc loojc, nhaf bef, hoof chis minh"
  ],
  "Phước Minh, Thuận Nam, Ninh Thuận": [
    "phước minh, thuận nam, ninh thuận",
    "phuwowsc minh, thuaajn nam, ninh thuaajn"
  ],
  "Phước Ninh, Thuận Nam, Ninh Thuận": [
    "phước ninh, thuận nam, ninh thuận",
    "phuwowsc ninh, thuaajn nam, ninh thuaajn"
  ],
  "Phước Sang, Phú Giáo, Bình Dương": [
    "phước sang, phú giáo, bình dương",
    "phuwowsc sang, phus giaso, bifnh duwowng"
  ],
  "Phước Thái, Long Thành, Đồng Nai": [
    "phước thái, long thành, đồng nai",
    "phuwowsc thasi, long thafnh, ddoofng nai"
  ],
  "Phước Thạnh, Mỹ Tho, Tiền Giang": [
    "phước thạnh, mỹ tho, tiền giang",
    "phuwowsc thajnh, myx tho, tieefn giang"
  ],
  "Phước Thắng, Bác Ái, Ninh Thuận": [
    "phước thắng, bác ái, ninh thuận",
    "phuwowsc thawsng, basc asi, ninh thuaajn"
  ],
  "Phước Thể, Tuy Phong, Bình Thuận": [
    "phước thể, tuy phong, bình thuận",
    "phuwowsc theer, tuy phong, bifnh thuaajn"
  ],
  "Phước Đông, Cần Đước, Long An": [
    "phước đông, cần đước, long an",
    "phuwowsc ddoong, caafn dduwowsc, long an"
  ],
  "Phước Đồng, Nha Trang, Khánh Hòa": [
    "phước đồng, nha trang, khánh hòa",
    "phuwowsc ddoofng, nha trang, khasnh hofa"
  ],
  "Phường 01, Tân Bình, Hồ Chí Minh": [
    "phường 01, tân bình, hồ chí minh",
    "phuwowfng 01, taan bifnh, hoof chis minh"
  ],
  "Phường 02, Tân Bình, Hồ Chí Minh": [
    "phường 02, tân bình, hồ chí minh",
    "phuwowfng 02, taan bifnh, hoof chis minh"
  ],
  "Phường 03, Tân Bình, Hồ Chí Minh": [
    "phường 03, tân bình, hồ chí minh",
    "phuwowfng 03, taan bifnh, hoof chis minh"
  ],
  "Phường 04, Tân Bình, Hồ Chí Minh": [
    "phường 04, tân bình, hồ chí minh",
    "phuwowfng 04, taan bifnh, hoof chis minh"
  ],
  "Phường 05, Tân Bình, Hồ Chí Minh": [
    "phường 05, tân bình, hồ chí minh",
    "phuwowfng 05, taan bifnh, hoof chis minh"
  ],
  "Phường 06, Tân Bình, Hồ Chí Minh": [
    "phường 06, tân bình, hồ chí minh",
    "phuwowfng 06, taan bifnh, hoof chis minh"
  ],
  "Phường 07, Tân Bình, Hồ Chí Minh": [
    "phường 07, tân bình, hồ chí minh",
    "phuwowfng 07, taan bifnh, hoof chis minh"
  ],
  "Phường 08, Tân Bình, Hồ Chí Minh": [
    "phường 08, tân bình, hồ chí minh",
    "phuwowfng 08, taan bifnh, hoof chis minh"
  ],
  "Phường 09, Tân Bình, Hồ Chí Minh": [
    "phường 09, tân bình, hồ chí minh",
    "phuwowfng 09, taan bifnh, hoof chis minh"
  ],
  "Phường 10, Tân Bình, Hồ Chí Minh": [
    "phường 10, tân bình, hồ chí minh",
    "phuwowfng 10, taan bifnh, hoof chis minh"
  ],
  "Phường 11, Tân Bình, Hồ Chí Minh": [
    "phường 11, tân bình, hồ chí minh",
    "phuwowfng 11, taan bifnh, hoof chis minh"
  ],
  "Phường 12, Tân Bình, Hồ Chí Minh": [
    "phường 12, tân bình, hồ chí minh",
    "phuwowfng 12, taan bifnh, hoof chis minh"
  ],
  "Phường 13, Tân Bình, Hồ Chí Minh": [
    "phường 13, tân bình, hồ chí minh",
    "phuwowfng 13, taan bifnh, hoof chis minh"
  ],
  "Phường 14, Tân Bình, Hồ Chí Minh": [
    "phường 14, tân bình, hồ chí minh",
    "phuwowfng 14, taan bifnh, hoof chis minh"
  ],
  "Phường 15, Tân Bình, Hồ Chí Minh": [
    "phường 15, tân bình, hồ chí minh",
    "phuwowfng 15, taan bifnh, hoof chis minh"
  ],
  "Phượng Kỳ, Tứ Kỳ, Hải Dương": [
    "phượng kỳ, tứ kỳ, hải dương",
    "phuwowjng kyf, tuws kyf, hari duwowng"
  ],
  "Phả Lễ, Thuỷ Nguyên, Hải Phòng": [
    "phả lễ, thuỷ nguyên, hải phòng",
    "phar leex, thuyr nguyeen, hari phofng"
  ],
  "Phấn Mễ, Phú Lương, Thái Nguyên": [
    "phấn mễ, phú lương, thái nguyên",
    "phaasn meex, phus luwowng, thasi nguyeen"
  ],
  "Phổ Châu, Đức Phổ, Quảng Ngãi": [
    "phổ châu, đức phổ, quảng ngãi",
    "phoor chaau, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Nhơn, Đức Phổ, Quảng Ngãi": [
    "phổ nhơn, đức phổ, quảng ngãi",
    "phoor nhown, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Phong, Đức Phổ, Quảng Ngãi": [
    "phổ phong, đức phổ, quảng ngãi",
    "phoor phong, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Quang, Đức Phổ, Quảng Ngãi": [
    "phổ quang, đức phổ, quảng ngãi",
    "phoor quang, dduwsc phoor, quarng ngaxi"
  ],
  "Phủ Thông, Bạch Thông, Bắc Kạn": [
    "phủ thông, bạch thông, bắc kạn",
    "phur thoong, bajch thoong, bawsc kajn"
  ],
  "Pờ Ly Ngài, Hoàng Su Phì, Hà Giang": [
    "pờ ly ngài, hoàng su phì, hà giang",
    "powf ly ngafi, hoafng su phif, haf giang"
  ],
  "Quang Bình, Kiến Xương, Thái Bình": [
    "quang bình, kiến xương, thái bình",
    "quang bifnh, kieesn xuwowng, thasi bifnh"
  ],
  "Quang Chiểu, Mường Lát, Thanh Hóa": [
    "quang chiểu, mường lát, thanh hóa",
    "quang chieeru, muwowfng last, thanh hosa"
  ],
  "Quang Minh, Chơn Thành, Bình Phước": [
    "quang minh, chơn thành, bình phước",
    "quang minh, chown thafnh, bifnh phuwowsc"
  ],
  "Quang Phú, Đồng Hới, Quảng Bình": [
    "quang phú, đồng hới, quảng bình",
    "quang phus, ddoofng howsi, quarng bifnh"
  ],
  "Quang Thịnh, Lạng Giang, Bắc Giang": [
    "quang thịnh, lạng giang, bắc giang",
    "quang thijnh, lajng giang, bawsc giang"
  ],
  "Quang Trung, Kiến Xương, Thái Bình": [
    "quang trung, kiến xương, thái bình",
    "quang trung, kieesn xuwowng, thasi bifnh"
  ],
  "Quang Trung, Thống Nhất, Đồng Nai": [
    "quang trung, thống nhất, đồng nai",
    "quang trung, thoosng nhaast, ddoofng nai"
  ],
  "Quang Vinh, Thái Nguyên, Thái Nguyên": [
    "quang vinh, thái nguyên, thái nguyên",
    "quang vinh, thasi nguyeen, thasi nguyeen"
  ],
  "Quy Đức, Bình Chánh, Hồ Chí Minh": [
    "quy đức, bình chánh, hồ chí minh",
    "quy dduwsc, bifnh chasnh, hoof chis minh"
  ],
  "Quyết Thắng, Biên Hòa, Đồng Nai": [
    "quyết thắng, biên hòa, đồng nai",
    "quyeest thawsng, bieen hofa, ddoofng nai"
  ],
  "Quảng Nghĩa, Móng Cái, Quảng Ninh": [
    "quảng nghĩa, móng cái, quảng ninh",
    "quarng nghixa, mosng casi, quarng ninh"
  ],
  "Quảng Thành, Gia Nghĩa, Đắk Nông": [
    "quảng thành, gia nghĩa, đắk nông",
    "quarng thafnh, gia nghixa, ddawsk noong"
  ],
  "Quảng Thịnh, Hải Hà, Quảng Ninh": [
    "quảng thịnh, hải hà, quảng ninh",
    "quarng thijnh, hari haf, quarng ninh"
  ],
  "Quảng Thủy, Ba Đồn, Quảng Bình": [
    "quảng thủy, ba đồn, quảng bình",
    "quarng thury, ba ddoofn, quarng bifnh"
  ],
  "Quảng Tiến, Trảng Bom, Đồng Nai": [
    "quảng tiến, trảng bom, đồng nai",
    "quarng tieesn, trarng bom, ddoofng nai"
  ],
  "Quảng Trị, Đạ Tẻh, Lâm Đồng": [
    "quảng trị, đạ tẻh, lâm đồng",
    "quarng trij, ddaj terh, laam ddoofng"
  ],
  "Quảng Trực, Tuy Đức, Đắk Nông": [
    "quảng trực, tuy đức, đắk nông",
    "quarng truwjc, tuy dduwsc, ddawsk noong"
  ],
  "Quảng Yên, Quảng Yên, Quảng Ninh": [
    "quảng yên, quảng yên, quảng ninh",
    "quarng yeen, quarng yeen, quarng ninh"
  ],
  "Quới Thiện,  Vũng Liêm, Vĩnh Long": [
    "quới thiện,  vũng liêm, vĩnh long",
    "quowsi thieejn,  vuxng lieem, vixnh long"
  ],
  "Quỳnh Côi, Quỳnh Phụ, Thái Bình": [
    "quỳnh côi, quỳnh phụ, thái bình",
    "quyfnh cooi, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Giao, Quỳnh Phụ, Thái Bình": [
    "quỳnh giao, quỳnh phụ, thái bình",
    "quyfnh giao, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Khê, Quỳnh Phụ, Thái Bình": [
    "quỳnh khê, quỳnh phụ, thái bình",
    "quyfnh khee, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Lâm, Quỳnh Phụ, Thái Bình": [
    "quỳnh lâm, quỳnh phụ, thái bình",
    "quyfnh laam, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Lương, Quỳnh Lưu, Nghệ An": [
    "quỳnh lương, quỳnh lưu, nghệ an",
    "quyfnh luwowng, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Minh, Quỳnh Phụ, Thái Bình": [
    "quỳnh minh, quỳnh phụ, thái bình",
    "quyfnh minh, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Mỹ, Quỳnh Phụ, Thái Bình": [
    "quỳnh mỹ, quỳnh phụ, thái bình",
    "quyfnh myx, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Thuận, Quỳnh Lưu, Nghệ An": [
    "quỳnh thuận, quỳnh lưu, nghệ an",
    "quyfnh thuaajn, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Thạch, Quỳnh Lưu, Nghệ An": [
    "quỳnh thạch, quỳnh lưu, nghệ an",
    "quyfnh thajch, quyfnh luwu, ngheej an"
  ],
  "Quỳnh Thắng, Quỳnh Lưu, Nghệ An": [
    "quỳnh thắng, quỳnh lưu, nghệ an",
    "quyfnh thawsng, quyfnh luwu, ngheej an"
  ],
  "Rạch Gòi, Châu Thành A, Hậu Giang": [
    "rạch gòi, châu thành a, hậu giang",
    "rajch gofi, chaau thafnh a, haaju giang"
  ],
  "Rạng Đông, Nghĩa Hưng, Nam Định": [
    "rạng đông, nghĩa hưng, nam định",
    "rajng ddoong, nghixa huwng, nam ddijnh"
  ],
  "Song Thuận, Châu Thành, Tiền Giang": [
    "song thuận, châu thành, tiền giang",
    "song thuaajn, chaau thafnh, tieefn giang"
  ],
  "Suối Hiệp, Diên Khánh, Khánh Hòa": [
    "suối hiệp, diên khánh, khánh hòa",
    "suoosi hieejp, dieen khasnh, khasnh hofa"
  ],
  "Suối Kiết, Tánh Linh, Bình Thuận": [
    "suối kiết, tánh linh, bình thuận",
    "suoosi kieest, tasnh linh, bifnh thuaajn"
  ],
  "Sính Phình, Tủa Chùa, Điện Biên": [
    "sính phình, tủa chùa, điện biên",
    "sisnh phifnh, tura chufa, ddieejn bieen"
  ],
  "Sông Cầu, Đồng Hỷ, Thái Nguyên": [
    "sông cầu, đồng hỷ, thái nguyên",
    "soong caafu, ddoofng hyr, thasi nguyeen"
  ],
  "Sơn Cẩm, Thái Nguyên, Thái Nguyên": [
    "sơn cẩm, thái nguyên, thái nguyên",
    "sown caarm, thasi nguyeen, thasi nguyeen"
  ],
  "Sơn Dương, Sơn Dương, Tuyên Quang": [
    "sơn dương, sơn dương, tuyên quang",
    "sown duwowng, sown duwowng, tuyeen quang"
  ],
  "Sơn Thành Đông, Tây Hoà, Phú Yên": [
    "sơn thành đông, tây hoà, phú yên",
    "sown thafnh ddoong, taay hoaf, phus yeen"
  ],
  "Tam Quan Nam, Hoài Nhơn, Bình Định": [
    "tam quan nam, hoài nhơn, bình định",
    "tam quan nam, hoafi nhown, bifnh ddijnh"
  ],
  "Thanh Bình, Mường Khương, Lào Cai": [
    "thanh bình, mường khương, lào cai",
    "thanh bifnh, muwowfng khuwowng, lafo cai"
  ],
  "Thanh Cường, Thanh Hà, Hải Dương": [
    "thanh cường, thanh hà, hải dương",
    "thanh cuwowfng, thanh haf, hari duwowng"
  ],
  "Thanh Dương, Thanh Chương, Nghệ An": [
    "thanh dương, thanh chương, nghệ an",
    "thanh duwowng, thanh chuwowng, ngheej an"
  ],
  "Thanh Giang, Thanh Miện, Hải Dương": [
    "thanh giang, thanh miện, hải dương",
    "thanh giang, thanh mieejn, hari duwowng"
  ],
  "Thanh Hương, Thanh Chương, Nghệ An": [
    "thanh hương, thanh chương, nghệ an",
    "thanh huwowng, thanh chuwowng, ngheej an"
  ],
  "Thanh Hải, Phan Thiết, Bình Thuận": [
    "thanh hải, phan thiết, bình thuận",
    "thanh hari, phan thieest, bifnh thuaajn"
  ],
  "Thanh Khê Tây, Thanh Khê, Đà Nẵng": [
    "thanh khê tây, thanh khê, đà nẵng",
    "thanh khee taay, thanh khee, ddaf nawxng"
  ],
  "Thanh Lương, Hai Bà Trưng, Hà Nội": [
    "thanh lương, hai bà trưng, hà nội",
    "thanh luwowng, hai baf truwng, haf nooji"
  ],
  "Thanh Lương, Thanh Chương, Nghệ An": [
    "thanh lương, thanh chương, nghệ an",
    "thanh luwowng, thanh chuwowng, ngheej an"
  ],
  "Thanh Lương, Vĩnh Bảo, Hải Phòng": [
    "thanh lương, vĩnh bảo, hải phòng",
    "thanh luwowng, vixnh baro, hari phofng"
  ],
  "Thanh Mỹ, Tháp Mười, Đồng Tháp": [
    "thanh mỹ, tháp mười, đồng tháp",
    "thanh myx, thasp muwowfi, ddoofng thasp"
  ],
  "Thanh Nưa, Điện Biên, Điện Biên": [
    "thanh nưa, điện biên, điện biên",
    "thanh nuwa, ddieejn bieen, ddieejn bieen"
  ],
  "Thanh Thịnh, Thanh Chương, Nghệ An": [
    "thanh thịnh, thanh chương, nghệ an",
    "thanh thijnh, thanh chuwowng, ngheej an"
  ],
  "Thanh Thủy, Lệ Thủy, Quảng Bình": [
    "thanh thủy, lệ thủy, quảng bình",
    "thanh thury, leej thury, quarng bifnh"
  ],
  "Thanh Tùng, Thanh Miện, Hải Dương": [
    "thanh tùng, thanh miện, hải dương",
    "thanh tufng, thanh mieejn, hari duwowng"
  ],
  "Thanh Yên, Điện Biên, Điện Biên": [
    "thanh yên, điện biên, điện biên",
    "thanh yeen, ddieejn bieen, ddieejn bieen"
  ],
  "Thanh Đồng, Thanh Chương, Nghệ An": [
    "thanh đồng, thanh chương, nghệ an",
    "thanh ddoofng, thanh chuwowng, ngheej an"
  ],
  "Thiện Kế, Sơn Dương, Tuyên Quang": [
    "thiện kế, sơn dương, tuyên quang",
    "thieejn kees, sown duwowng, tuyeen quang"
  ],
  "Thiệu Chính, Thiệu Hóa, Thanh Hóa": [
    "thiệu chính, thiệu hóa, thanh hóa",
    "thieeju chisnh, thieeju hosa, thanh hosa"
  ],
  "Thiệu Ngọc, Thiệu Hóa, Thanh Hóa": [
    "thiệu ngọc, thiệu hóa, thanh hóa",
    "thieeju ngojc, thieeju hosa, thanh hosa"
  ],
  "Thiệu Thành, Thiệu Hóa, Thanh Hóa": [
    "thiệu thành, thiệu hóa, thanh hóa",
    "thieeju thafnh, thieeju hosa, thanh hosa"
  ],
  "Thiệu Tiến, Thiệu Hóa, Thanh Hóa": [
    "thiệu tiến, thiệu hóa, thanh hóa",
    "thieeju tieesn, thieeju hosa, thanh hosa"
  ],
  "Thuận Hòa, Huế, Thừa Thiên Huế": [
    "thuận hòa, huế, thừa thiên huế",
    "thuaajn hofa, huees, thuwfa thieen huees"
  ],
  "Thuận Hóa, Tuyên Hóa, Quảng Bình": [
    "thuận hóa, tuyên hóa, quảng bình",
    "thuaajn hosa, tuyeen hosa, quarng bifnh"
  ],
  "Thuỷ Xuân, Huế, Thừa Thiên Huế": [
    "thuỷ xuân, huế, thừa thiên huế",
    "thuyr xuaan, huees, thuwfa thieen huees"
  ],
  "Thành Công, Thạch Thành, Thanh Hóa": [
    "thành công, thạch thành, thanh hóa",
    "thafnh coong, thajch thafnh, thanh hosa"
  ],
  "Thành Hưng, Thạch Thành, Thanh Hóa": [
    "thành hưng, thạch thành, thanh hóa",
    "thafnh huwng, thajch thafnh, thanh hosa"
  ],
  "Thành Thọ, Thạch Thành, Thanh Hóa": [
    "thành thọ, thạch thành, thanh hóa",
    "thafnh thoj, thajch thafnh, thanh hosa"
  ],
  "Thác Mơ, Phước Long, Bình Phước": [
    "thác mơ, phước long, bình phước",
    "thasc mow, phuwowsc long, bifnh phuwowsc"
  ],
  "Thái Nguyên, Thái Thụy, Thái Bình": [
    "thái nguyên, thái thụy, thái bình",
    "thasi nguyeen, thasi thujy, thasi bifnh"
  ],
  "Thái Thịnh, Thái Thụy, Thái Bình": [
    "thái thịnh, thái thụy, thái bình",
    "thasi thijnh, thasi thujy, thasi bifnh"
  ],
  "Thái Thủy, Lệ Thủy, Quảng Bình": [
    "thái thủy, lệ thủy, quảng bình",
    "thasi thury, leej thury, quarng bifnh"
  ],
  "Thông Bình, Tân Hồng, Đồng Tháp": [
    "thông bình, tân hồng, đồng tháp",
    "thoong bifnh, taan hoofng, ddoofng thasp"
  ],
  "Thúc Kháng, Bình Giang, Hải Dương": [
    "thúc kháng, bình giang, hải dương",
    "thusc khasng, bifnh giang, hari duwowng"
  ],
  "Thượng Hóa, Minh Hóa, Quảng Bình": [
    "thượng hóa, minh hóa, quảng bình",
    "thuwowjng hosa, minh hosa, quarng bifnh"
  ],
  "Thượng Lâm, Lâm Bình, Tuyên Quang": [
    "thượng lâm, lâm bình, tuyên quang",
    "thuwowjng laam, laam bifnh, tuyeen quang"
  ],
  "Thượng Thôn, Hà Quảng, Cao Bằng": [
    "thượng thôn, hà quảng, cao bằng",
    "thuwowjng thoon, haf quarng, cao bawfng"
  ],
  "Thượng Vũ, Kim Thành, Hải Dương": [
    "thượng vũ, kim thành, hải dương",
    "thuwowjng vux, kim thafnh, hari duwowng"
  ],
  "Thượng Đình, Thanh Xuân, Hà Nội": [
    "thượng đình, thanh xuân, hà nội",
    "thuwowjng ddifnh, thanh xuaan, haf nooji"
  ],
  "Thạch Hóa, Tuyên Hóa, Quảng Bình": [
    "thạch hóa, tuyên hóa, quảng bình",
    "thajch hosa, tuyeen hosa, quarng bifnh"
  ],
  "Thạch Long, Thạch Thành, Thanh Hóa": [
    "thạch long, thạch thành, thanh hóa",
    "thajch long, thajch thafnh, thanh hosa"
  ],
  "Thạch Lâm, Thạch Thành, Thanh Hóa": [
    "thạch lâm, thạch thành, thanh hóa",
    "thajch laam, thajch thafnh, thanh hosa"
  ],
  "Thạch Sơn, Thạch Thành, Thanh Hóa": [
    "thạch sơn, thạch thành, thanh hóa",
    "thajch sown, thajch thafnh, thanh hosa"
  ],
  "Thạnh Hội, Tân Uyên, Bình Dương": [
    "thạnh hội, tân uyên, bình dương",
    "thajnh hooji, taan uyeen, bifnh duwowng"
  ],
  "Thạnh Lộc, Châu Thành, Kiên Giang": [
    "thạnh lộc, châu thành, kiên giang",
    "thajnh loojc, chaau thafnh, kieen giang"
  ],
  "Thạnh Lộc, Quận 12, Hồ Chí Minh": [
    "thạnh lộc, quận 12, hồ chí minh",
    "thajnh loojc, quaajn 12, hoof chis minh"
  ],
  "Thạnh Lộc, Vĩnh Thạnh, Cần Thơ": [
    "thạnh lộc, vĩnh thạnh, cần thơ",
    "thajnh loojc, vixnh thajnh, caafn thow"
  ],
  "Thạnh Lợi, Vĩnh Thạnh, Cần Thơ": [
    "thạnh lợi, vĩnh thạnh, cần thơ",
    "thajnh lowji, vixnh thajnh, caafn thow"
  ],
  "Thạnh Phú, Châu Thành, Tiền Giang": [
    "thạnh phú, châu thành, tiền giang",
    "thajnh phus, chaau thafnh, tieefn giang"
  ],
  "Thạnh Quới, Mỹ Xuyên, Sóc Trăng": [
    "thạnh quới, mỹ xuyên, sóc trăng",
    "thajnh quowsi, myx xuyeen, sosc trawng"
  ],
  "Thạnh Tân, Thạnh Trị, Sóc Trăng": [
    "thạnh tân, thạnh trị, sóc trăng",
    "thajnh taan, thajnh trij, sosc trawng"
  ],
  "Thạnh Xuân, Quận 12, Hồ Chí Minh": [
    "thạnh xuân, quận 12, hồ chí minh",
    "thajnh xuaan, quaajn 12, hoof chis minh"
  ],
  "Thạnh Đông, Tân Hiệp, Kiên Giang": [
    "thạnh đông, tân hiệp, kiên giang",
    "thajnh ddoong, taan hieejp, kieen giang"
  ],
  "Thải Giàng Phố, Bắc Hà, Lào Cai": [
    "thải giàng phố, bắc hà, lào cai",
    "thari giafng phoos, bawsc haf, lafo cai"
  ],
  "Thảo Điền, Quận 2, Hồ Chí Minh": [
    "thảo điền, quận 2, hồ chí minh",
    "tharo ddieefn, quaajn 2, hoof chis minh"
  ],
  "Thất Khê, Tràng Định, Lạng Sơn": [
    "thất khê, tràng định, lạng sơn",
    "thaast khee, trafng ddijnh, lajng sown"
  ],
  "Thắng Lợi, Thường Tín, Hà Nội": [
    "thắng lợi, thường tín, hà nội",
    "thawsng lowji, thuwowfng tisn, haf nooji"
  ],
  "Thắng Lợi, Vân Đồn, Quảng Ninh": [
    "thắng lợi, vân đồn, quảng ninh",
    "thawsng lowji, vaan ddoofn, quarng ninh"
  ],
  "Thọ Cường, Triệu Sơn, Thanh Hóa": [
    "thọ cường, triệu sơn, thanh hóa",
    "thoj cuwowfng, trieeju sown, thanh hosa"
  ],
  "Thọ Thanh, Thường Xuân, Thanh Hóa": [
    "thọ thanh, thường xuân, thanh hóa",
    "thoj thanh, thuwowfng xuaan, thanh hosa"
  ],
  "Thống Nhất, Buôn Hồ, Đắk Lắk": [
    "thống nhất, buôn hồ, đắk lắk",
    "thoosng nhaast, buoon hoof, ddawsk lawsk"
  ],
  "Thống Nhất, Gia Lộc, Hải Dương": [
    "thống nhất, gia lộc, hải dương",
    "thoosng nhaast, gia loojc, hari duwowng"
  ],
  "Thống Nhất, Lạc Thủy, Hoà Bình": [
    "thống nhất, lạc thủy, hoà bình",
    "thoosng nhaast, lajc thury, hoaf bifnh"
  ],
  "Thống Nhất, Lộc Bình, Lạng Sơn": [
    "thống nhất, lộc bình, lạng sơn",
    "thoosng nhaast, loojc bifnh, lajng sown"
  ],
  "Thống Nhất, Nam Định, Nam Định": [
    "thống nhất, nam định, nam định",
    "thoosng nhaast, nam ddijnh, nam ddijnh"
  ],
  "Thống Nhất, Yên Định, Thanh Hóa": [
    "thống nhất, yên định, thanh hóa",
    "thoosng nhaast, yeen ddijnh, thanh hosa"
  ],
  "Thới An Hội, Kế Sách, Sóc Trăng": [
    "thới an hội, kế sách, sóc trăng",
    "thowsi an hooji, kees sasch, sosc trawng"
  ],
  "Thới Thuận, Thốt Nốt, Cần Thơ": [
    "thới thuận, thốt nốt, cần thơ",
    "thowsi thuaajn, thoost noost, caafn thow"
  ],
  "Thụy Chính, Thái Thụy, Thái Bình": [
    "thụy chính, thái thụy, thái bình",
    "thujy chisnh, thasi thujy, thasi bifnh"
  ],
  "Thụy Duyên, Thái Thụy, Thái Bình": [
    "thụy duyên, thái thụy, thái bình",
    "thujy duyeen, thasi thujy, thasi bifnh"
  ],
  "Thụy Hương, Chương Mỹ, Hà Nội": [
    "thụy hương, chương mỹ, hà nội",
    "thujy huwowng, chuwowng myx, haf nooji"
  ],
  "Thụy Trình, Thái Thụy, Thái Bình": [
    "thụy trình, thái thụy, thái bình",
    "thujy trifnh, thasi thujy, thasi bifnh"
  ],
  "Thụy Việt, Thái Thụy, Thái Bình": [
    "thụy việt, thái thụy, thái bình",
    "thujy vieejt, thasi thujy, thasi bifnh"
  ],
  "Tiên Châu, Tiên Phước, Quảng Nam": [
    "tiên châu, tiên phước, quảng nam",
    "tieen chaau, tieen phuwowsc, quarng nam"
  ],
  "Tiên Cẩm, Tiên Phước, Quảng Nam": [
    "tiên cẩm, tiên phước, quảng nam",
    "tieen caarm, tieen phuwowsc, quarng nam"
  ],
  "Tiên Lãnh, Tiên Phước, Quảng Nam": [
    "tiên lãnh, tiên phước, quảng nam",
    "tieen laxnh, tieen phuwowsc, quarng nam"
  ],
  "Tiên Lập, Tiên Phước, Quảng Nam": [
    "tiên lập, tiên phước, quảng nam",
    "tieen laajp, tieen phuwowsc, quarng nam"
  ],
  "Tiên Lộc, Tiên Phước, Quảng Nam": [
    "tiên lộc, tiên phước, quảng nam",
    "tieen loojc, tieen phuwowsc, quarng nam"
  ],
  "Tiên Phong, Tiên Phước, Quảng Nam": [
    "tiên phong, tiên phước, quảng nam",
    "tieen phong, tieen phuwowsc, quarng nam"
  ],
  "Tiên Phương, Chương Mỹ, Hà Nội": [
    "tiên phương, chương mỹ, hà nội",
    "tieen phuwowng, chuwowng myx, haf nooji"
  ],
  "Tiên Thắng, Tiên Lãng, Hải Phòng": [
    "tiên thắng, tiên lãng, hải phòng",
    "tieen thawsng, tieen laxng, hari phofng"
  ],
  "Tiên Thọ, Tiên Phước, Quảng Nam": [
    "tiên thọ, tiên phước, quảng nam",
    "tieen thoj, tieen phuwowsc, quarng nam"
  ],
  "Tiên Trang, Quảng Xương, Thanh Hóa": [
    "tiên trang, quảng xương, thanh hóa",
    "tieen trang, quarng xuwowng, thanh hosa"
  ],
  "Tiền Phong, Quảng Yên, Quảng Ninh": [
    "tiền phong, quảng yên, quảng ninh",
    "tieefn phong, quarng yeen, quarng ninh"
  ],
  "Toàn Thắng, Tiên Lãng, Hải Phòng": [
    "toàn thắng, tiên lãng, hải phòng",
    "toafn thawsng, tieen laxng, hari phofng"
  ],
  "Triệu An, Triệu Phong, Quảng Trị": [
    "triệu an, triệu phong, quảng trị",
    "trieeju an, trieeju phong, quarng trij"
  ],
  "Triệu Hải, Đạ Tẻh, Lâm Đồng": [
    "triệu hải, đạ tẻh, lâm đồng",
    "trieeju hari, ddaj terh, laam ddoofng"
  ],
  "Triệu Thành, Triệu Sơn, Thanh Hóa": [
    "triệu thành, triệu sơn, thanh hóa",
    "trieeju thafnh, trieeju sown, thanh hosa"
  ],
  "Trung Hội, Định Hóa, Thái Nguyên": [
    "trung hội, định hóa, thái nguyên",
    "trung hooji, ddijnh hosa, thasi nguyeen"
  ],
  "Trà Dương, Bắc Trà My, Quảng Nam": [
    "trà dương, bắc trà my, quảng nam",
    "traf duwowng, bawsc traf my, quarng nam"
  ],
  "Trùng Khánh, Trùng Khánh, Cao Bằng": [
    "trùng khánh, trùng khánh, cao bằng",
    "trufng khasnh, trufng khasnh, cao bawfng"
  ],
  "Trường An, Huế, Thừa Thiên Huế": [
    "trường an, huế, thừa thiên huế",
    "truwowfng an, huees, thuwfa thieen huees"
  ],
  "Trường Khánh, Long Phú, Sóc Trăng": [
    "trường khánh, long phú, sóc trăng",
    "truwowfng khasnh, long phus, sosc trawng"
  ],
  "Trường Minh, Nông Cống, Thanh Hóa": [
    "trường minh, nông cống, thanh hóa",
    "truwowfng minh, noong coosng, thanh hosa"
  ],
  "Trường Sơn, Nông Cống, Thanh Hóa": [
    "trường sơn, nông cống, thanh hóa",
    "truwowfng sown, noong coosng, thanh hosa"
  ],
  "Trường Thành, Thới Lai, Cần Thơ": [
    "trường thành, thới lai, cần thơ",
    "truwowfng thafnh, thowsi lai, caafn thow"
  ],
  "Trường Thịnh, Ứng Hòa, Hà Nội": [
    "trường thịnh, ứng hòa, hà nội",
    "truwowfng thijnh, uwsng hofa, haf nooji"
  ],
  "Trường Xuân, Thọ Xuân, Thanh Hóa": [
    "trường xuân, thọ xuân, thanh hóa",
    "truwowfng xuaan, thoj xuaan, thanh hosa"
  ],
  "Trường Yên, Chương Mỹ, Hà Nội": [
    "trường yên, chương mỹ, hà nội",
    "truwowfng yeen, chuwowng myx, haf nooji"
  ],
  "Trường Đông, Hòa Thành, Tây Ninh": [
    "trường đông, hòa thành, tây ninh",
    "truwowfng ddoong, hofa thafnh, taay ninh"
  ],
  "Trực Thuận, Trực Ninh, Nam Định": [
    "trực thuận, trực ninh, nam định",
    "truwjc thuaajn, truwjc ninh, nam ddijnh"
  ],
  "Trực Thắng, Trực Ninh, Nam Định": [
    "trực thắng, trực ninh, nam định",
    "truwjc thawsng, truwjc ninh, nam ddijnh"
  ],
  "Tuyên Thạnh, Kiến Tường, Long An": [
    "tuyên thạnh, kiến tường, long an",
    "tuyeen thajnh, kieesn tuwowfng, long an"
  ],
  "Tuấn Việt, Kim Thành, Hải Dương": [
    "tuấn việt, kim thành, hải dương",
    "tuaasn vieejt, kim thafnh, hari duwowng"
  ],
  "Tuấn Đạo, Sơn Động, Bắc Giang": [
    "tuấn đạo, sơn động, bắc giang",
    "tuaasn ddajo, sown ddoojng, bawsc giang"
  ],
  "Tân An Luông,  Vũng Liêm, Vĩnh Long": [
    "tân an luông,  vũng liêm, vĩnh long",
    "taan an luoong,  vuxng lieem, vixnh long"
  ],
  "Tân Bình, Hải Dương, Hải Dương": [
    "tân bình, hải dương, hải dương",
    "taan bifnh, hari duwowng, hari duwowng"
  ],
  "Tân Hưng Đông, Cái Nước, Cà Mau": [
    "tân hưng đông, cái nước, cà mau",
    "taan huwng ddoong, casi nuwowsc, caf mau"
  ],
  "Tân Hưng, Hải Dương, Hải Dương": [
    "tân hưng, hải dương, hải dương",
    "taan huwng, hari duwowng, hari duwowng"
  ],
  "Tân Hưng, Hớn Quản, Bình Phước": [
    "tân hưng, hớn quản, bình phước",
    "taan huwng, howsn quarn, bifnh phuwowsc"
  ],
  "Tân Hưng, Đồng Phú, Bình Phước": [
    "tân hưng, đồng phú, bình phước",
    "taan huwng, ddoofng phus, bifnh phuwowsc"
  ],
  "Tân Hương, Châu Thành, Tiền Giang": [
    "tân hương, châu thành, tiền giang",
    "taan huwowng, chaau thafnh, tieefn giang"
  ],
  "Tân Hội, Đức Trọng, Lâm Đồng": [
    "tân hội, đức trọng, lâm đồng",
    "taan hooji, dduwsc trojng, laam ddoofng"
  ],
  "Tân Hợp, Hướng Hóa, Quảng Trị": [
    "tân hợp, hướng hóa, quảng trị",
    "taan howjp, huwowsng hosa, quarng trij"
  ],
  "Tân Kiên, Bình Chánh, Hồ Chí Minh": [
    "tân kiên, bình chánh, hồ chí minh",
    "taan kieen, bifnh chasnh, hoof chis minh"
  ],
  "Tân Liên, Hướng Hóa, Quảng Trị": [
    "tân liên, hướng hóa, quảng trị",
    "taan lieen, huwowsng hosa, quarng trij"
  ],
  "Tân Lập, Hướng Hóa, Quảng Trị": [
    "tân lập, hướng hóa, quảng trị",
    "taan laajp, huwowsng hosa, quarng trij"
  ],
  "Tân Lập, Thái Nguyên, Thái Nguyên": [
    "tân lập, thái nguyên, thái nguyên",
    "taan laajp, thasi nguyeen, thasi nguyeen"
  ],
  "Tân Lập, Đồng Phú, Bình Phước": [
    "tân lập, đồng phú, bình phước",
    "taan laajp, ddoofng phus, bifnh phuwowsc"
  ],
  "Tân Lộc Đông, Thới Bình, Cà Mau": [
    "tân lộc đông, thới bình, cà mau",
    "taan loojc ddoong, thowsi bifnh, caf mau"
  ],
  "Tân Lợi, Hớn Quản, Bình Phước": [
    "tân lợi, hớn quản, bình phước",
    "taan lowji, howsn quarn, bifnh phuwowsc"
  ],
  "Tân Lợi, Đồng Phú, Bình Phước": [
    "tân lợi, đồng phú, bình phước",
    "taan lowji, ddoofng phus, bifnh phuwowsc"
  ],
  "Tân Mỹ Chánh, Mỹ Tho, Tiền Giang": [
    "tân mỹ chánh, mỹ tho, tiền giang",
    "taan myx chasnh, myx tho, tieefn giang"
  ],
  "Tân Phú, Đồng Xoài, Bình Phước": [
    "tân phú, đồng xoài, bình phước",
    "taan phus, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Tân Quy Đông, Sa Đéc, Đồng Tháp": [
    "tân quy đông, sa đéc, đồng tháp",
    "taan quy ddoong, sa ddesc, ddoofng thasp"
  ],
  "Tân Thuận, Vĩnh Thuận, Kiên Giang": [
    "tân thuận, vĩnh thuận, kiên giang",
    "taan thuaajn, vixnh thuaajn, kieen giang"
  ],
  "Tân Thành, Thường Xuân, Thanh Hóa": [
    "tân thành, thường xuân, thanh hóa",
    "taan thafnh, thuwowfng xuaan, thanh hosa"
  ],
  "Tân Thạnh, Thanh Bình, Đồng Tháp": [
    "tân thạnh, thanh bình, đồng tháp",
    "taan thajnh, thanh bifnh, ddoofng thasp"
  ],
  "Tân Tiến, Tràng Định, Lạng Sơn": [
    "tân tiến, tràng định, lạng sơn",
    "taan tieesn, trafng ddijnh, lajng sown"
  ],
  "Tân Tiến, Vĩnh Tường, Vĩnh Phúc": [
    "tân tiến, vĩnh tường, vĩnh phúc",
    "taan tieesn, vixnh tuwowfng, vixnh phusc"
  ],
  "Tân Tạo A, Bình Tân, Hồ Chí Minh": [
    "tân tạo a, bình tân, hồ chí minh",
    "taan tajo a, bifnh taan, hoof chis minh"
  ],
  "Tượng Lĩnh, Nông Cống, Thanh Hóa": [
    "tượng lĩnh, nông cống, thanh hóa",
    "tuwowjng lixnh, noong coosng, thanh hosa"
  ],
  "Tả Thàng, Mường Khương, Lào Cai": [
    "tả thàng, mường khương, lào cai",
    "tar thafng, muwowfng khuwowng, lafo cai"
  ],
  "Tịnh Bình, Sơn Tịnh, Quảng Ngãi": [
    "tịnh bình, sơn tịnh, quảng ngãi",
    "tijnh bifnh, sown tijnh, quarng ngaxi"
  ],
  "Tịnh Bắc, Sơn Tịnh, Quảng Ngãi": [
    "tịnh bắc, sơn tịnh, quảng ngãi",
    "tijnh bawsc, sown tijnh, quarng ngaxi"
  ],
  "Tịnh Giang, Sơn Tịnh, Quảng Ngãi": [
    "tịnh giang, sơn tịnh, quảng ngãi",
    "tijnh giang, sown tijnh, quarng ngaxi"
  ],
  "Tịnh Phong, Sơn Tịnh, Quảng Ngãi": [
    "tịnh phong, sơn tịnh, quảng ngãi",
    "tijnh phong, sown tijnh, quarng ngaxi"
  ],
  "Tịnh Thọ, Sơn Tịnh, Quảng Ngãi": [
    "tịnh thọ, sơn tịnh, quảng ngãi",
    "tijnh thoj, sown tijnh, quarng ngaxi"
  ],
  "Tỏa Tình, Tuần Giáo, Điện Biên": [
    "tỏa tình, tuần giáo, điện biên",
    "tora tifnh, tuaafn giaso, ddieejn bieen"
  ],
  "Tủa Thàng, Tủa Chùa, Điện Biên": [
    "tủa thàng, tủa chùa, điện biên",
    "tura thafng, tura chufa, ddieejn bieen"
  ],
  "Tứ Trưng, Vĩnh Tường, Vĩnh Phúc": [
    "tứ trưng, vĩnh tường, vĩnh phúc",
    "tuws truwng, vixnh tuwowfng, vixnh phusc"
  ],
  "Tức Tranh, Phú Lương, Thái Nguyên": [
    "tức tranh, phú lương, thái nguyên",
    "tuwsc tranh, phus luwowng, thasi nguyeen"
  ],
  "Tự Cường, Tiên Lãng, Hải Phòng": [
    "tự cường, tiên lãng, hải phòng",
    "tuwj cuwowfng, tieen laxng, hari phofng"
  ],
  "Vinh Hà, Phú Vang, Thừa Thiên Huế": [
    "vinh hà, phú vang, thừa thiên huế",
    "vinh haf, phus vang, thuwfa thieen huees"
  ],
  "Việt Tiến, Vĩnh Bảo, Hải Phòng": [
    "việt tiến, vĩnh bảo, hải phòng",
    "vieejt tieesn, vixnh baro, hari phofng"
  ],
  "Vân Khánh Đông, An Minh, Kiên Giang": [
    "vân khánh đông, an minh, kiên giang",
    "vaan khasnh ddoong, an minh, kieen giang"
  ],
  "Vĩnh Hòa, Vĩnh Thạnh, Bình Định": [
    "vĩnh hòa, vĩnh thạnh, bình định",
    "vixnh hofa, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Hồng, Bình Giang, Hải Dương": [
    "vĩnh hồng, bình giang, hải dương",
    "vixnh hoofng, bifnh giang, hari duwowng"
  ],
  "Vĩnh Phú, Giồng Riềng, Kiên Giang": [
    "vĩnh phú, giồng riềng, kiên giang",
    "vixnh phus, gioofng rieefng, kieen giang"
  ],
  "Vĩnh Phước, Vĩnh Châu, Sóc Trăng": [
    "vĩnh phước, vĩnh châu, sóc trăng",
    "vixnh phuwowsc, vixnh chaau, sosc trawng"
  ],
  "Vĩnh Sơn, Vĩnh Thạnh, Bình Định": [
    "vĩnh sơn, vĩnh thạnh, bình định",
    "vixnh sown, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Thành, Thạnh Trị, Sóc Trăng": [
    "vĩnh thành, thạnh trị, sóc trăng",
    "vixnh thafnh, thajnh trij, sosc trawng"
  ],
  "Vĩnh Thạnh, Vĩnh Thạnh, Cần Thơ": [
    "vĩnh thạnh, vĩnh thạnh, cần thơ",
    "vixnh thajnh, vixnh thajnh, caafn thow"
  ],
  "Vĩnh Tường, Vị Thuỷ, Hậu Giang": [
    "vĩnh tường, vị thuỷ, hậu giang",
    "vixnh tuwowfng, vij thuyr, haaju giang"
  ],
  "Vĩnh Điều, Giang Thành, Kiên Giang": [
    "vĩnh điều, giang thành, kiên giang",
    "vixnh ddieefu, giang thafnh, kieen giang"
  ],
  "Vĩnh Điện, Điện Bàn, Quảng Nam": [
    "vĩnh điện, điện bàn, quảng nam",
    "vixnh ddieejn, ddieejn bafn, quarng nam"
  ],
  "Vũ Thắng, Kiến Xương, Thái Bình": [
    "vũ thắng, kiến xương, thái bình",
    "vux thawsng, kieesn xuwowng, thasi bifnh"
  ],
  "Vạn Xuân, Thường Xuân, Thanh Hóa": [
    "vạn xuân, thường xuân, thanh hóa",
    "vajn xuaan, thuwowfng xuaan, thanh hosa"
  ],
  "Vạn Điểm, Thường Tín, Hà Nội": [
    "vạn điểm, thường tín, hà nội",
    "vajn ddieerm, thuwowfng tisn, haf nooji"
  ],
  "Xuân Chinh, Thường Xuân, Thanh Hóa": [
    "xuân chinh, thường xuân, thanh hóa",
    "xuaan chinh, thuwowfng xuaan, thanh hosa"
  ],
  "Xuân Hòa, Xuân Trường, Nam Định": [
    "xuân hòa, xuân trường, nam định",
    "xuaan hofa, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Hương, Lạng Giang, Bắc Giang": [
    "xuân hương, lạng giang, bắc giang",
    "xuaan huwowng, lajng giang, bawsc giang"
  ],
  "Xuân Lao, Mường Ảng, Điện Biên": [
    "xuân lao, mường ảng, điện biên",
    "xuaan lao, muwowfng arng, ddieejn bieen"
  ],
  "Xuân Lộc, Thường Xuân, Thanh Hóa": [
    "xuân lộc, thường xuân, thanh hóa",
    "xuaan loojc, thuwowfng xuaan, thanh hosa"
  ],
  "Xuân Ninh, Xuân Trường, Nam Định": [
    "xuân ninh, xuân trường, nam định",
    "xuaan ninh, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Phú, Xuân Trường, Nam Định": [
    "xuân phú, xuân trường, nam định",
    "xuaan phus, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Phước, Đồng Xuân, Phú Yên": [
    "xuân phước, đồng xuân, phú yên",
    "xuaan phuwowsc, ddoofng xuaan, phus yeen"
  ],
  "Xuân Sơn Nam, Đồng Xuân, Phú Yên": [
    "xuân sơn nam, đồng xuân, phú yên",
    "xuaan sown nam, ddoofng xuaan, phus yeen"
  ],
  "Xuân Sơn, Đông Triều, Quảng Ninh": [
    "xuân sơn, đông triều, quảng ninh",
    "xuaan sown, ddoong trieefu, quarng ninh"
  ],
  "Xuân Thủy, Lệ Thủy, Quảng Bình": [
    "xuân thủy, lệ thủy, quảng bình",
    "xuaan thury, leej thury, quarng bifnh"
  ],
  "Xuân Trường, Bảo Lạc, Cao Bằng": [
    "xuân trường, bảo lạc, cao bằng",
    "xuaan truwowfng, baro lajc, cao bawfng"
  ],
  "Xuân Trường, Thọ Xuân, Thanh Hóa": [
    "xuân trường, thọ xuân, thanh hóa",
    "xuaan truwowfng, thoj xuaan, thanh hosa"
  ],
  "Xuân Tân, Xuân Trường, Nam Định": [
    "xuân tân, xuân trường, nam định",
    "xuaan taan, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Tảo, Bắc Từ Liêm, Hà Nội": [
    "xuân tảo, bắc từ liêm, hà nội",
    "xuaan taro, bawsc tuwf lieem, haf nooji"
  ],
  "Xuân Vinh, Xuân Trường, Nam Định": [
    "xuân vinh, xuân trường, nam định",
    "xuaan vinh, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Đường, Cẩm Mỹ, Đồng Nai": [
    "xuân đường, cẩm mỹ, đồng nai",
    "xuaan dduwowfng, caarm myx, ddoofng nai"
  ],
  "Xá Lượng, Tương Dương, Nghệ An": [
    "xá lượng, tương dương, nghệ an",
    "xas luwowjng, tuwowng duwowng, ngheej an"
  ],
  "Xá Tổng, Mường Chà, Điện Biên": [
    "xá tổng, mường chà, điện biên",
    "xas toorng, muwowfng chaf, ddieejn bieen"
  ],
  "Yên Thắng, Tương Dương, Nghệ An": [
    "yên thắng, tương dương, nghệ an",
    "yeen thawsng, tuwowng duwowng, ngheej an"
  ],
  "Yên Thọ, Đông Triều, Quảng Ninh": [
    "yên thọ, đông triều, quảng ninh",
    "yeen thoj, ddoong trieefu, quarng ninh"
  ],
  "Yên Trường, Yên Định, Thanh Hóa": [
    "yên trường, yên định, thanh hóa",
    "yeen truwowfng, yeen ddijnh, thanh hosa"
  ],
  "Ái Quốc, Hải Dương, Hải Dương": [
    "ái quốc, hải dương, hải dương",
    "asi quoosc, hari duwowng, hari duwowng"
  ],
  "Ân Hảo Tây, Hoài Ân, Bình Định": [
    "ân hảo tây, hoài ân, bình định",
    "aan haro taay, hoafi aan, bifnh ddijnh"
  ],
  "Ôn Lương, Phú Lương, Thái Nguyên": [
    "ôn lương, phú lương, thái nguyên",
    "oon luwowng, phus luwowng, thasi nguyeen"
  ],
  "Điền Hải, Đông Hải, Bạc Liêu": [
    "điền hải, đông hải, bạc liêu",
    "ddieefn hari, ddoong hari, bajc lieeu"
  ],
  "Điện Phong, Điện Bàn, Quảng Nam": [
    "điện phong, điện bàn, quảng nam",
    "ddieejn phong, ddieejn bafn, quarng nam"
  ],
  "Điện Quang, Điện Bàn, Quảng Nam": [
    "điện quang, điện bàn, quảng nam",
    "ddieejn quang, ddieejn bafn, quarng nam"
  ],
  "Điện Thọ, Điện Bàn, Quảng Nam": [
    "điện thọ, điện bàn, quảng nam",
    "ddieejn thoj, ddieejn bafn, quarng nam"
  ],
  "Điện Trung, Điện Bàn, Quảng Nam": [
    "điện trung, điện bàn, quảng nam",
    "ddieejn trung, ddieejn bafn, quarng nam"
  ],
  "Đoàn Kết, Bù Đăng, Bình Phước": [
    "đoàn kết, bù đăng, bình phước",
    "ddoafn keest, buf ddawng, bifnh phuwowsc"
  ],
  "Đào Hữu Cảnh, Châu Phú, An Giang": [
    "đào hữu cảnh, châu phú, an giang",
    "ddafo huwxu carnh, chaau phus, an giang"
  ],
  "Đào Viên, Tràng Định, Lạng Sơn": [
    "đào viên, tràng định, lạng sơn",
    "ddafo vieen, trafng ddijnh, lajng sown"
  ],
  "Đông Hoàng, Tiền Hải, Thái Bình": [
    "đông hoàng, tiền hải, thái bình",
    "ddoong hoafng, tieefn hari, thasi bifnh"
  ],
  "Đông Hoàng, Đông Hưng, Thái Bình": [
    "đông hoàng, đông hưng, thái bình",
    "ddoong hoafng, ddoong huwng, thasi bifnh"
  ],
  "Đông Hải, Quỳnh Phụ, Thái Bình": [
    "đông hải, quỳnh phụ, thái bình",
    "ddoong hari, quyfnh phuj, thasi bifnh"
  ],
  "Đông Lợi, Sơn Dương, Tuyên Quang": [
    "đông lợi, sơn dương, tuyên quang",
    "ddoong lowji, sown duwowng, tuyeen quang"
  ],
  "Đông Thọ, Sơn Dương, Tuyên Quang": [
    "đông thọ, sơn dương, tuyên quang",
    "ddoong thoj, sown duwowng, tuyeen quang"
  ],
  "Đông Xuyên, Ninh Giang, Hải Dương": [
    "đông xuyên, ninh giang, hải dương",
    "ddoong xuyeen, ninh giang, hari duwowng"
  ],
  "Đông Xuyên, Tiền Hải, Thái Bình": [
    "đông xuyên, tiền hải, thái bình",
    "ddoong xuyeen, tieefn hari, thasi bifnh"
  ],
  "Đường 10, Bù Đăng, Bình Phước": [
    "đường 10, bù đăng, bình phước",
    "dduwowfng 10, buf ddawng, bifnh phuwowsc"
  ],
  "Đạ Chais, Lạc Dương, Lâm Đồng": [
    "đạ chais, lạc dương, lâm đồng",
    "ddaj chais, lajc duwowng, laam ddoofng"
  ],
  "Đạ K' Nàng, Đam Rông, Lâm Đồng": [
    "đạ k' nàng, đam rông, lâm đồng",
    "ddaj k' nafng, ddam roong, laam ddoofng"
  ],
  "Đại Chánh, Đại Lộc, Quảng Nam": [
    "đại chánh, đại lộc, quảng nam",
    "ddaji chasnh, ddaji loojc, quarng nam"
  ],
  "Đại Hiệp, Đại Lộc, Quảng Nam": [
    "đại hiệp, đại lộc, quảng nam",
    "ddaji hieejp, ddaji loojc, quarng nam"
  ],
  "Đại Hồng, Đại Lộc, Quảng Nam": [
    "đại hồng, đại lộc, quảng nam",
    "ddaji hoofng, ddaji loojc, quarng nam"
  ],
  "Đại Nghĩa, Đại Lộc, Quảng Nam": [
    "đại nghĩa, đại lộc, quảng nam",
    "ddaji nghixa, ddaji loojc, quarng nam"
  ],
  "Đại Ân  2, Trần Đề, Sóc Trăng": [
    "đại ân  2, trần đề, sóc trăng",
    "ddaji aan  2, traafn ddeef, sosc trawng"
  ],
  "Đại Đức, Kim Thành, Hải Dương": [
    "đại đức, kim thành, hải dương",
    "ddaji dduwsc, kim thafnh, hari duwowng"
  ],
  "Đạo Đức, Bình Xuyên, Vĩnh Phúc": [
    "đạo đức, bình xuyên, vĩnh phúc",
    "ddajo dduwsc, bifnh xuyeen, vixnh phusc"
  ],
  "Đắk Búk So, Tuy Đức, Đắk Nông": [
    "đắk búk so, tuy đức, đắk nông",
    "ddawsk busk so, tuy dduwsc, ddawsk noong"
  ],
  "Đắk N'Drót, Đắk Mil, Đắk Nông": [
    "đắk n'drót, đắk mil, đắk nông",
    "ddawsk n'drost, ddawsk mil, ddawsk noong"
  ],
  "Đắk N'Dung, Đắk Song, Đắk Nông": [
    "đắk n'dung, đắk song, đắk nông",
    "ddawsk n'dung, ddawsk song, ddawsk noong"
  ],
  "Đắk Sin, Đắk R'Lấp, Đắk Nông": [
    "đắk sin, đắk r'lấp, đắk nông",
    "ddawsk sin, ddawsk r'laasp, ddawsk noong"
  ],
  "Đắk Wer, Đắk R'Lấp, Đắk Nông": [
    "đắk wer, đắk r'lấp, đắk nông",
    "ddawsk wer, ddawsk r'laasp, ddawsk noong"
  ],
  "Đề Thám, Tràng Định, Lạng Sơn": [
    "đề thám, tràng định, lạng sơn",
    "ddeef thasm, trafng ddijnh, lajng sown"
  ],
  "Định An, Dầu Tiếng, Bình Dương": [
    "định an, dầu tiếng, bình dương",
    "ddijnh an, daafu tieesng, bifnh duwowng"
  ],
  "Định Thành, Yên Định, Thanh Hóa": [
    "định thành, yên định, thanh hóa",
    "ddijnh thafnh, yeen ddijnh, thanh hosa"
  ],
  "Định Thủy, Mỏ Cày Nam, Bến Tre": [
    "định thủy, mỏ cày nam, bến tre",
    "ddijnh thury, mor cafy nam, beesn tre"
  ],
  "Định Tiến, Yên Định, Thanh Hóa": [
    "định tiến, yên định, thanh hóa",
    "ddijnh tieesn, yeen ddijnh, thanh hosa"
  ],
  "Đồng Cương, Yên Lạc, Vĩnh Phúc": [
    "đồng cương, yên lạc, vĩnh phúc",
    "ddoofng cuwowng, yeen lajc, vixnh phusc"
  ],
  "Đồng Cẩm, Kim Thành, Hải Dương": [
    "đồng cẩm, kim thành, hải dương",
    "ddoofng caarm, kim thafnh, hari duwowng"
  ],
  "Đồng Cốc, Lục Ngạn, Bắc Giang": [
    "đồng cốc, lục ngạn, bắc giang",
    "ddoofng coosc, lujc ngajn, bawsc giang"
  ],
  "Đồng Hóa, Tuyên Hóa, Quảng Bình": [
    "đồng hóa, tuyên hóa, quảng bình",
    "ddoofng hosa, tuyeen hosa, quarng bifnh"
  ],
  "Đồng Lương, Lang Chánh, Thanh Hóa": [
    "đồng lương, lang chánh, thanh hóa",
    "ddoofng luwowng, lang chasnh, thanh hosa"
  ],
  "Đồng Lạc, Chợ Đồn, Bắc Kạn": [
    "đồng lạc, chợ đồn, bắc kạn",
    "ddoofng lajc, chowj ddoofn, bawsc kajn"
  ],
  "Đồng Nhân, Hai Bà Trưng, Hà Nội": [
    "đồng nhân, hai bà trưng, hà nội",
    "ddoofng nhaan, hai baf truwng, haf nooji"
  ],
  "Đồng Quý, Sơn Dương, Tuyên Quang": [
    "đồng quý, sơn dương, tuyên quang",
    "ddoofng quys, sown duwowng, tuyeen quang"
  ],
  "Đồng Tháp, Đan Phượng, Hà Nội": [
    "đồng tháp, đan phượng, hà nội",
    "ddoofng thasp, ddan phuwowjng, haf nooji"
  ],
  "Đồng Tiến, Hữu Lũng, Lạng Sơn": [
    "đồng tiến, hữu lũng, lạng sơn",
    "ddoofng tieesn, huwxu luxng, lajng sown"
  ],
  "Đồng Tiến, Khoái Châu, Hưng Yên": [
    "đồng tiến, khoái châu, hưng yên",
    "ddoofng tieesn, khoasi chaau, huwng yeen"
  ],
  "Đồng Tiến, Triệu Sơn, Thanh Hóa": [
    "đồng tiến, triệu sơn, thanh hóa",
    "ddoofng tieesn, trieeju sown, thanh hosa"
  ],
  "Đồng Trúc, Thạch Thất, Hà Nội": [
    "đồng trúc, thạch thất, hà nội",
    "ddoofng trusc, thajch thaast, haf nooji"
  ],
  "Đồng Vương, Yên Thế, Bắc Giang": [
    "đồng vương, yên thế, bắc giang",
    "ddoofng vuwowng, yeen thees, bawsc giang"
  ],
  "Đồng Ích, Lập Thạch, Vĩnh Phúc": [
    "đồng ích, lập thạch, vĩnh phúc",
    "ddoofng isch, laajp thajch, vixnh phusc"
  ],
  "Đội Cấn, Tuyên Quang, Tuyên Quang": [
    "đội cấn, tuyên quang, tuyên quang",
    "ddooji caasn, tuyeen quang, tuyeen quang"
  ],
  "Đức Bình Tây, Sông Hinh, Phú Yên": [
    "đức bình tây, sông hinh, phú yên",
    "dduwsc bifnh taay, soong hinh, phus yeen"
  ],
  "Đức Hòa Đông, Đức Hòa, Long An": [
    "đức hòa đông, đức hòa, long an",
    "dduwsc hofa ddoong, dduwsc hofa, long an"
  ],
  "Đức Hồng, Trùng Khánh, Cao Bằng": [
    "đức hồng, trùng khánh, cao bằng",
    "dduwsc hoofng, trufng khasnh, cao bawfng"
  ],
  "Đức Long, Phan Thiết, Bình Thuận": [
    "đức long, phan thiết, bình thuận",
    "dduwsc long, phan thieest, bifnh thuaajn"
  ],
  "Đức Lợi, Mộ Đức, Quảng Ngãi": [
    "đức lợi, mộ đức, quảng ngãi",
    "dduwsc lowji, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Phong, Bù Đăng, Bình Phước": [
    "đức phong, bù đăng, bình phước",
    "dduwsc phong, buf ddawng, bifnh phuwowsc"
  ],
  "Đức Phong, Mộ Đức, Quảng Ngãi": [
    "đức phong, mộ đức, quảng ngãi",
    "dduwsc phong, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Xương, Gia Lộc, Hải Dương": [
    "đức xương, gia lộc, hải dương",
    "dduwsc xuwowng, gia loojc, hari duwowng"
  ],
  "A Lưới, A Lưới, Thừa Thiên Huế": [
    "a lưới, a lưới, thừa thiên huế",
    "a luwowsi, a luwowsi, thuwfa thieen huees"
  ],
  "A Roằng, A Lưới, Thừa Thiên Huế": [
    "a roằng, a lưới, thừa thiên huế",
    "a roawfng, a luwowsi, thuwfa thieen huees"
  ],
  "An Khương, Hớn Quản, Bình Phước": [
    "an khương, hớn quản, bình phước",
    "an khuwowng, howsn quarn, bifnh phuwowsc"
  ],
  "An Lợi Đông, Quận 2, Hồ Chí Minh": [
    "an lợi đông, quận 2, hồ chí minh",
    "an lowji ddoong, quaajn 2, hoof chis minh"
  ],
  "An Phú Đông, Quận 12, Hồ Chí Minh": [
    "an phú đông, quận 12, hồ chí minh",
    "an phus ddoong, quaajn 12, hoof chis minh"
  ],
  "An Thạnh Nam, Cù Lao Dung, Sóc Trăng": [
    "an thạnh nam, cù lao dung, sóc trăng",
    "an thajnh nam, cuf lao dung, sosc trawng"
  ],
  "Ba Hàng Đồi, Lạc Thủy, Hoà Bình": [
    "ba hàng đồi, lạc thủy, hoà bình",
    "ba hafng ddoofi, lajc thury, hoaf bifnh"
  ],
  "Biển Động, Lục Ngạn, Bắc Giang": [
    "biển động, lục ngạn, bắc giang",
    "bieern ddoojng, lujc ngajn, bawsc giang"
  ],
  "Bàu Năng, Dương Minh Châu, Tây Ninh": [
    "bàu năng, dương minh châu, tây ninh",
    "bafu nawng, duwowng minh chaau, taay ninh"
  ],
  "Bình Chương, Bình Sơn, Quảng Ngãi": [
    "bình chương, bình sơn, quảng ngãi",
    "bifnh chuwowng, bifnh sown, quarng ngaxi"
  ],
  "Bình Hưng, Bình Chánh, Hồ Chí Minh": [
    "bình hưng, bình chánh, hồ chí minh",
    "bifnh huwng, bifnh chasnh, hoof chis minh"
  ],
  "Bình Khánh, Cần Giờ, Hồ Chí Minh": [
    "bình khánh, cần giờ, hồ chí minh",
    "bifnh khasnh, caafn giowf, hoof chis minh"
  ],
  "Bình Khương, Bình Sơn, Quảng Ngãi": [
    "bình khương, bình sơn, quảng ngãi",
    "bifnh khuwowng, bifnh sown, quarng ngaxi"
  ],
  "Bình Lợi, Bình Chánh, Hồ Chí Minh": [
    "bình lợi, bình chánh, hồ chí minh",
    "bifnh lowji, bifnh chasnh, hoof chis minh"
  ],
  "Bình Phước, Bình Sơn, Quảng Ngãi": [
    "bình phước, bình sơn, quảng ngãi",
    "bifnh phuwowsc, bifnh sown, quarng ngaxi"
  ],
  "Bình Thuận, Đại Từ, Thái Nguyên": [
    "bình thuận, đại từ, thái nguyên",
    "bifnh thuaajn, ddaji tuwf, thasi nguyeen"
  ],
  "Bình Thành, Phụng Hiệp, Hậu Giang": [
    "bình thành, phụng hiệp, hậu giang",
    "bifnh thafnh, phujng hieejp, haaju giang"
  ],
  "Bình Thành, Định Hóa, Thái Nguyên": [
    "bình thành, định hóa, thái nguyên",
    "bifnh thafnh, ddijnh hosa, thasi nguyeen"
  ],
  "Bình Thạnh Đông, Phú Tân, An Giang": [
    "bình thạnh đông, phú tân, an giang",
    "bifnh thajnh ddoong, phus taan, an giang"
  ],
  "Bình Thọ, Thủ Đức, Hồ Chí Minh": [
    "bình thọ, thủ đức, hồ chí minh",
    "bifnh thoj, thur dduwsc, hoof chis minh"
  ],
  "Bình Ân, Gò Công Đông, Tiền Giang": [
    "bình ân, gò công đông, tiền giang",
    "bifnh aan, gof coong ddoong, tieefn giang"
  ],
  "Băng A Drênh, Krông A Na, Đắk Lắk": [
    "băng a drênh, krông a na, đắk lắk",
    "bawng a dreenh, kroong a na, ddawsk lawsk"
  ],
  "Bạch Đằng, Hai Bà Trưng, Hà Nội": [
    "bạch đằng, hai bà trưng, hà nội",
    "bajch ddawfng, hai baf truwng, haf nooji"
  ],
  "Bạch Đằng, Tiên Lãng, Hải Phòng": [
    "bạch đằng, tiên lãng, hải phòng",
    "bajch ddawfng, tieen laxng, hari phofng"
  ],
  "Bạch Đằng, Tân Uyên, Bình Dương": [
    "bạch đằng, tân uyên, bình dương",
    "bajch ddawfng, taan uyeen, bifnh duwowng"
  ],
  "Bản Ngoại, Đại Từ, Thái Nguyên": [
    "bản ngoại, đại từ, thái nguyên",
    "barn ngoaji, ddaji tuwf, thasi nguyeen"
  ],
  "Bế Văn Đàn, Quảng Hòa, Cao Bằng": [
    "bế văn đàn, quảng hòa, cao bằng",
    "bees vawn ddafn, quarng hofa, cao bawfng"
  ],
  "Bộc Nhiêu, Định Hóa, Thái Nguyên": [
    "bộc nhiêu, định hóa, thái nguyên",
    "boojc nhieeu, ddijnh hosa, thasi nguyeen"
  ],
  "Cam Thịnh Đông, Cam Ranh, Khánh Hòa": [
    "cam thịnh đông, cam ranh, khánh hòa",
    "cam thijnh ddoong, cam ranh, khasnh hofa"
  ],
  "Chánh Lộ, Quảng Ngãi, Quảng Ngãi": [
    "chánh lộ, quảng ngãi, quảng ngãi",
    "chasnh looj, quarng ngaxi, quarng ngaxi"
  ],
  "Chính Mỹ, Thuỷ Nguyên, Hải Phòng": [
    "chính mỹ, thuỷ nguyên, hải phòng",
    "chisnh myx, thuyr nguyeen, hari phofng"
  ],
  "Chương Dương, Hoàn Kiếm, Hà Nội": [
    "chương dương, hoàn kiếm, hà nội",
    "chuwowng duwowng, hoafn kieesm, haf nooji"
  ],
  "Chấn Hưng, Vĩnh Tường, Vĩnh Phúc": [
    "chấn hưng, vĩnh tường, vĩnh phúc",
    "chaasn huwng, vixnh tuwowfng, vixnh phusc"
  ],
  "Chế Cu Nha, Mù Căng Chải, Yên Bái": [
    "chế cu nha, mù căng chải, yên bái",
    "chees cu nha, muf cawng chari, yeen basi"
  ],
  "Cây Dương, Phụng Hiệp, Hậu Giang": [
    "cây dương, phụng hiệp, hậu giang",
    "caay duwowng, phujng hieejp, haaju giang"
  ],
  "Cư ÊBur, Buôn Ma Thuột, Đắk Lắk": [
    "cư êbur, buôn ma thuột, đắk lắk",
    "cuw eebur, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Cường Lợi, Đình Lập, Lạng Sơn": [
    "cường lợi, đình lập, lạng sơn",
    "cuwowfng lowji, ddifnh laajp, lajng sown"
  ],
  "Cẩm Hoàng, Cẩm Giàng, Hải Dương": [
    "cẩm hoàng, cẩm giàng, hải dương",
    "caarm hoafng, caarm giafng, hari duwowng"
  ],
  "Cẩm Đoài, Cẩm Giàng, Hải Dương": [
    "cẩm đoài, cẩm giàng, hải dương",
    "caarm ddoafi, caarm giafng, hari duwowng"
  ],
  "Cẩm Đông, Cẩm Giàng, Hải Dương": [
    "cẩm đông, cẩm giàng, hải dương",
    "caarm ddoong, caarm giafng, hari duwowng"
  ],
  "Cẩm Đường, Long Thành, Đồng Nai": [
    "cẩm đường, long thành, đồng nai",
    "caarm dduwowfng, long thafnh, ddoofng nai"
  ],
  "Diên Phước, Diên Khánh, Khánh Hòa": [
    "diên phước, diên khánh, khánh hòa",
    "dieen phuwowsc, dieen khasnh, khasnh hofa"
  ],
  "Diễn Trường, Diễn Châu, Nghệ An": [
    "diễn trường, diễn châu, nghệ an",
    "dieexn truwowfng, dieexn chaau, ngheej an"
  ],
  "Dương Phong, Bạch Thông, Bắc Kạn": [
    "dương phong, bạch thông, bắc kạn",
    "duwowng phong, bajch thoong, bawsc kajn"
  ],
  "Dương Thành, Phú Bình, Thái Nguyên": [
    "dương thành, phú bình, thái nguyên",
    "duwowng thafnh, phus bifnh, thasi nguyeen"
  ],
  "Dương Đức, Lạng Giang, Bắc Giang": [
    "dương đức, lạng giang, bắc giang",
    "duwowng dduwsc, lajng giang, bawsc giang"
  ],
  "Hiệp Hưng, Phụng Hiệp, Hậu Giang": [
    "hiệp hưng, phụng hiệp, hậu giang",
    "hieejp huwng, phujng hieejp, haaju giang"
  ],
  "Hiệp Phước, Nhà Bè, Hồ Chí Minh": [
    "hiệp phước, nhà bè, hồ chí minh",
    "hieejp phuwowsc, nhaf bef, hoof chis minh"
  ],
  "Hoa Động, Thuỷ Nguyên, Hải Phòng": [
    "hoa động, thuỷ nguyên, hải phòng",
    "hoa ddoojng, thuyr nguyeen, hari phofng"
  ],
  "Hoà Hiệp Trung, Đông Hòa, Phú Yên": [
    "hoà hiệp trung, đông hòa, phú yên",
    "hoaf hieejp trung, ddoong hofa, phus yeen"
  ],
  "Hoài Hương, Hoài Nhơn, Bình Định": [
    "hoài hương, hoài nhơn, bình định",
    "hoafi huwowng, hoafi nhown, bifnh ddijnh"
  ],
  "Hoàng Văn Thụ, Bình Gia, Lạng Sơn": [
    "hoàng văn thụ, bình gia, lạng sơn",
    "hoafng vawn thuj, bifnh gia, lajng sown"
  ],
  "Hoằng Thắng, Hoằng Hóa, Thanh Hóa": [
    "hoằng thắng, hoằng hóa, thanh hóa",
    "hoawfng thawsng, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Thịnh, Hoằng Hóa, Thanh Hóa": [
    "hoằng thịnh, hoằng hóa, thanh hóa",
    "hoawfng thijnh, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Trạch, Hoằng Hóa, Thanh Hóa": [
    "hoằng trạch, hoằng hóa, thanh hóa",
    "hoawfng trajch, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Đồng, Hoằng Hóa, Thanh Hóa": [
    "hoằng đồng, hoằng hóa, thanh hóa",
    "hoawfng ddoofng, hoawfng hosa, thanh hosa"
  ],
  "Hà Thượng, Đại Từ, Thái Nguyên": [
    "hà thượng, đại từ, thái nguyên",
    "haf thuwowjng, ddaji tuwf, thasi nguyeen"
  ],
  "Hành Đức, Nghĩa Hành, Quảng Ngãi": [
    "hành đức, nghĩa hành, quảng ngãi",
    "hafnh dduwsc, nghixa hafnh, quarng ngaxi"
  ],
  "Hòa Hiệp Bắc, Đông Hòa, Phú Yên": [
    "hòa hiệp bắc, đông hòa, phú yên",
    "hofa hieejp bawsc, ddoong hofa, phus yeen"
  ],
  "Hòa Phú, Buôn Ma Thuột, Đắk Lắk": [
    "hòa phú, buôn ma thuột, đắk lắk",
    "hofa phus, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Hòa Trạch, Bố Trạch, Quảng Bình": [
    "hòa trạch, bố trạch, quảng bình",
    "hofa trajch, boos trajch, quarng bifnh"
  ],
  "Hòa Xuân Đông, Đông Hòa, Phú Yên": [
    "hòa xuân đông, đông hòa, phú yên",
    "hofa xuaan ddoong, ddoong hofa, phus yeen"
  ],
  "Hòa Định Đông, Phú Hoà, Phú Yên": [
    "hòa định đông, phú hoà, phú yên",
    "hofa ddijnh ddoong, phus hoaf, phus yeen"
  ],
  "Hùng Thắng, Bình Giang, Hải Dương": [
    "hùng thắng, bình giang, hải dương",
    "hufng thawsng, bifnh giang, hari duwowng"
  ],
  "Hùng Việt, Tràng Định, Lạng Sơn": [
    "hùng việt, tràng định, lạng sơn",
    "hufng vieejt, trafng ddijnh, lajng sown"
  ],
  "Hùng Vương, Hồng Bàng, Hải Phòng": [
    "hùng vương, hồng bàng, hải phòng",
    "hufng vuwowng, hoofng bafng, hari phofng"
  ],
  "Hưng Bình, Đắk R'Lấp, Đắk Nông": [
    "hưng bình, đắk r'lấp, đắk nông",
    "huwng bifnh, ddawsk r'laasp, ddawsk noong"
  ],
  "Hưng Chiến, Bình Long, Bình Phước": [
    "hưng chiến, bình long, bình phước",
    "huwng chieesn, bifnh long, bifnh phuwowsc"
  ],
  "Hưng Nhượng, Giồng Trôm, Bến Tre": [
    "hưng nhượng, giồng trôm, bến tre",
    "huwng nhuwowjng, gioofng troom, beesn tre"
  ],
  "Hương Ngải, Thạch Thất, Hà Nội": [
    "hương ngải, thạch thất, hà nội",
    "huwowng ngari, thajch thaast, haf nooji"
  ],
  "Hương Nhượng, Lạc Sơn, Hoà Bình": [
    "hương nhượng, lạc sơn, hoà bình",
    "huwowng nhuwowjng, lajc sown, hoaf bifnh"
  ],
  "Hướng Đạo, Tam Dương, Vĩnh Phúc": [
    "hướng đạo, tam dương, vĩnh phúc",
    "huwowsng ddajo, tam duwowng, vixnh phusc"
  ],
  "Hạ Trạch, Bố Trạch, Quảng Bình": [
    "hạ trạch, bố trạch, quảng bình",
    "haj trajch, boos trajch, quarng bifnh"
  ],
  "Hải Dương, Hải Lăng, Quảng Trị": [
    "hải dương, hải lăng, quảng trị",
    "hari duwowng, hari lawng, quarng trij"
  ],
  "Hải Đường, Hải Hậu, Nam Định": [
    "hải đường, hải hậu, nam định",
    "hari dduwowfng, hari haaju, nam ddijnh"
  ],
  "Hải Định, Hải Lăng, Quảng Trị": [
    "hải định, hải lăng, quảng trị",
    "hari ddijnh, hari lawng, quarng trij"
  ],
  "Hậu Thạnh Tây, Tân Thạnh, Long An": [
    "hậu thạnh tây, tân thạnh, long an",
    "haaju thajnh taay, taan thajnh, long an"
  ],
  "Hẹ Muông, Điện Biên, Điện Biên": [
    "hẹ muông, điện biên, điện biên",
    "hej muoong, ddieejn bieen, ddieejn bieen"
  ],
  "Hồng Phong, Thanh Miện, Hải Dương": [
    "hồng phong, thanh miện, hải dương",
    "hoofng phong, thanh mieejn, hari duwowng"
  ],
  "Hồng Quang, Thanh Miện, Hải Dương": [
    "hồng quang, thanh miện, hải dương",
    "hoofng quang, thanh mieejn, hari duwowng"
  ],
  "Hồng Thái, Kiến Xương, Thái Bình": [
    "hồng thái, kiến xương, thái bình",
    "hoofng thasi, kieesn xuwowng, thasi bifnh"
  ],
  "Hồng Thủy, Lệ Thủy, Quảng Bình": [
    "hồng thủy, lệ thủy, quảng bình",
    "hoofng thury, leej thury, quarng bifnh"
  ],
  "Hội An Đông, Lấp Vò, Đồng Tháp": [
    "hội an đông, lấp vò, đồng tháp",
    "hooji an ddoong, laasp vof, ddoofng thasp"
  ],
  "Hợp Thành, Phú Lương, Thái Nguyên": [
    "hợp thành, phú lương, thái nguyên",
    "howjp thafnh, phus luwowng, thasi nguyeen"
  ],
  "Hợp Tiến, Đồng Hỷ, Thái Nguyên": [
    "hợp tiến, đồng hỷ, thái nguyên",
    "howjp tieesn, ddoofng hyr, thasi nguyeen"
  ],
  "Hừa Ngài, Mường Chà, Điện Biên": [
    "hừa ngài, mường chà, điện biên",
    "huwfa ngafi, muwowfng chaf, ddieejn bieen"
  ],
  "Hữu Bằng, Kiến Thuỵ, Hải Phòng": [
    "hữu bằng, kiến thuỵ, hải phòng",
    "huwxu bawfng, kieesn thuyj, hari phofng"
  ],
  "Hữu Khuông, Tương Dương, Nghệ An": [
    "hữu khuông, tương dương, nghệ an",
    "huwxu khuoong, tuwowng duwowng, ngheej an"
  ],
  "Kháng Nhật, Sơn Dương, Tuyên Quang": [
    "kháng nhật, sơn dương, tuyên quang",
    "khasng nhaajt, sown duwowng, tuyeen quang"
  ],
  "Khánh Bình, Trần Văn Thời, Cà Mau": [
    "khánh bình, trần văn thời, cà mau",
    "khasnh bifnh, traafn vawn thowfi, caf mau"
  ],
  "Khánh Hưng, Trần Văn Thời, Cà Mau": [
    "khánh hưng, trần văn thời, cà mau",
    "khasnh huwng, traafn vawn thowfi, caf mau"
  ],
  "Khánh Hải, Trần Văn Thời, Cà Mau": [
    "khánh hải, trần văn thời, cà mau",
    "khasnh hari, traafn vawn thowfi, caf mau"
  ],
  "Khánh Lộc, Trần Văn Thời, Cà Mau": [
    "khánh lộc, trần văn thời, cà mau",
    "khasnh loojc, traafn vawn thowfi, caf mau"
  ],
  "Kiên Lương, Kiên Lương, Kiên Giang": [
    "kiên lương, kiên lương, kiên giang",
    "kieen luwowng, kieen luwowng, kieen giang"
  ],
  "Kiến Thiết, Tiên Lãng, Hải Phòng": [
    "kiến thiết, tiên lãng, hải phòng",
    "kieesn thieest, tieen laxng, hari phofng"
  ],
  "Kiền Bái, Thuỷ Nguyên, Hải Phòng": [
    "kiền bái, thuỷ nguyên, hải phòng",
    "kieefn basi, thuyr nguyeen, hari phofng"
  ],
  "Kênh Giang, Thuỷ Nguyên, Hải Phòng": [
    "kênh giang, thuỷ nguyên, hải phòng",
    "keenh giang, thuyr nguyeen, hari phofng"
  ],
  "La Pan Tẩn, Mường Khương, Lào Cai": [
    "la pan tẩn, mường khương, lào cai",
    "la pan taarn, muwowfng khuwowng, lafo cai"
  ],
  "Linh Đông, Thủ Đức, Hồ Chí Minh": [
    "linh đông, thủ đức, hồ chí minh",
    "linh ddoong, thur dduwsc, hoof chis minh"
  ],
  "Liên Phương, Thường Tín, Hà Nội": [
    "liên phương, thường tín, hà nội",
    "lieen phuwowng, thuwowfng tisn, haf nooji"
  ],
  "Long Giang, Phước Long, Bình Phước": [
    "long giang, phước long, bình phước",
    "long giang, phuwowsc long, bifnh phuwowsc"
  ],
  "Long Thuận, Hồng Ngự, Đồng Tháp": [
    "long thuận, hồng ngự, đồng tháp",
    "long thuaajn, hoofng nguwj, ddoofng thasp"
  ],
  "Long Thành Bắc, Hòa Thành, Tây Ninh": [
    "long thành bắc, hòa thành, tây ninh",
    "long thafnh bawsc, hofa thafnh, taay ninh"
  ],
  "Long Thành Trung, Hòa Thành, Tây Ninh": [
    "long thành trung, hòa thành, tây ninh",
    "long thafnh trung, hofa thafnh, taay ninh"
  ],
  "Long Thạnh, Phụng Hiệp, Hậu Giang": [
    "long thạnh, phụng hiệp, hậu giang",
    "long thajnh, phujng hieejp, haaju giang"
  ],
  "Lâm Trạch, Bố Trạch, Quảng Bình": [
    "lâm trạch, bố trạch, quảng bình",
    "laam trajch, boos trajch, quarng bifnh"
  ],
  "Lưu Kiếm, Thuỷ Nguyên, Hải Phòng": [
    "lưu kiếm, thuỷ nguyên, hải phòng",
    "luwu kieesm, thuyr nguyeen, hari phofng"
  ],
  "Lương Bằng, Chợ Đồn, Bắc Kạn": [
    "lương bằng, chợ đồn, bắc kạn",
    "luwowng bawfng, chowj ddoofn, bawsc kajn"
  ],
  "Lương Ngoại, Bá Thước, Thanh Hóa": [
    "lương ngoại, bá thước, thanh hóa",
    "luwowng ngoaji, bas thuwowsc, thanh hosa"
  ],
  "Lương Ninh, Quảng Ninh, Quảng Bình": [
    "lương ninh, quảng ninh, quảng bình",
    "luwowng ninh, quarng ninh, quarng bifnh"
  ],
  "Lương Sơn, Thường Xuân, Thanh Hóa": [
    "lương sơn, thường xuân, thanh hóa",
    "luwowng sown, thuwowfng xuaan, thanh hosa"
  ],
  "Lưỡng Minh, Tương Dương, Nghệ An": [
    "lưỡng minh, tương dương, nghệ an",
    "luwowxng minh, tuwowng duwowng, ngheej an"
  ],
  "Lạc An, Bắc Tân Uyên, Bình Dương": [
    "lạc an, bắc tân uyên, bình dương",
    "lajc an, bawsc taan uyeen, bifnh duwowng"
  ],
  "Lạc Đạo, Phan Thiết, Bình Thuận": [
    "lạc đạo, phan thiết, bình thuận",
    "lajc ddajo, phan thieest, bifnh thuaajn"
  ],
  "Lại Xuân, Thuỷ Nguyên, Hải Phòng": [
    "lại xuân, thuỷ nguyên, hải phòng",
    "laji xuaan, thuyr nguyeen, hari phofng"
  ],
  "Lập Thạch, Lập Thạch, Vĩnh Phúc": [
    "lập thạch, lập thạch, vĩnh phúc",
    "laajp thajch, laajp thajch, vixnh phusc"
  ],
  "Lộc An, Phú Lộc, Thừa Thiên Huế": [
    "lộc an, phú lộc, thừa thiên huế",
    "loojc an, phus loojc, thuwfa thieen huees"
  ],
  "Lộc Ninh, Dương Minh Châu, Tây Ninh": [
    "lộc ninh, dương minh châu, tây ninh",
    "loojc ninh, duwowng minh chaau, taay ninh"
  ],
  "Lộc Thiện, Lộc Ninh, Bình Phước": [
    "lộc thiện, lộc ninh, bình phước",
    "loojc thieejn, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Thuận, Lộc Ninh, Bình Phước": [
    "lộc thuận, lộc ninh, bình phước",
    "loojc thuaajn, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Thạnh, Lộc Ninh, Bình Phước": [
    "lộc thạnh, lộc ninh, bình phước",
    "loojc thajnh, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Thịnh, Lộc Ninh, Bình Phước": [
    "lộc thịnh, lộc ninh, bình phước",
    "loojc thijnh, loojc ninh, bifnh phuwowsc"
  ],
  "Lộc Điền, Lộc Ninh, Bình Phước": [
    "lộc điền, lộc ninh, bình phước",
    "loojc ddieefn, loojc ninh, bifnh phuwowsc"
  ],
  "Minh Thành, Chơn Thành, Bình Phước": [
    "minh thành, chơn thành, bình phước",
    "minh thafnh, chown thafnh, bifnh phuwowsc"
  ],
  "Minh Đức, Hớn Quản, Bình Phước": [
    "minh đức, hớn quản, bình phước",
    "minh dduwsc, howsn quarn, bifnh phuwowsc"
  ],
  "Minh Đức, Thuỷ Nguyên, Hải Phòng": [
    "minh đức, thuỷ nguyên, hải phòng",
    "minh dduwsc, thuyr nguyeen, hari phofng"
  ],
  "Mường Chanh, Mường Lát, Thanh Hóa": [
    "mường chanh, mường lát, thanh hóa",
    "muwowfng chanh, muwowfng last, thanh hosa"
  ],
  "Mường Chiềng, Đà Bắc, Hoà Bình": [
    "mường chiềng, đà bắc, hoà bình",
    "muwowfng chieefng, ddaf bawsc, hoaf bifnh"
  ],
  "Mường Đun, Tủa Chùa, Điện Biên": [
    "mường đun, tủa chùa, điện biên",
    "muwowfng ddun, tura chufa, ddieejn bieen"
  ],
  "Mỹ An Hưng A, Lấp Vò, Đồng Tháp": [
    "mỹ an hưng a, lấp vò, đồng tháp",
    "myx an huwng a, laasp vof, ddoofng thasp"
  ],
  "Mỹ An Hưng B, Lấp Vò, Đồng Tháp": [
    "mỹ an hưng b, lấp vò, đồng tháp",
    "myx an huwng b, laasp vof, ddoofng thasp"
  ],
  "Mỹ Thạnh Bắc, Đức Huệ, Long An": [
    "mỹ thạnh bắc, đức huệ, long an",
    "myx thajnh bawsc, dduwsc hueej, long an"
  ],
  "Mỹ Thạnh Trung, Tam Bình, Vĩnh Long": [
    "mỹ thạnh trung, tam bình, vĩnh long",
    "myx thajnh trung, tam bifnh, vixnh long"
  ],
  "Mỹ Trạch, Bố Trạch, Quảng Bình": [
    "mỹ trạch, bố trạch, quảng bình",
    "myx trajch, boos trajch, quarng bifnh"
  ],
  "Mỹ Tịnh An, Chợ Gạo, Tiền Giang": [
    "mỹ tịnh an, chợ gạo, tiền giang",
    "myx tijnh an, chowj gajo, tieefn giang"
  ],
  "Mỹ Đông, Tháp Mười, Đồng Tháp": [
    "mỹ đông, tháp mười, đồng tháp",
    "myx ddoong, thasp muwowfi, ddoofng thasp"
  ],
  "N'Thol Hạ, Đức Trọng, Lâm Đồng": [
    "n'thol hạ, đức trọng, lâm đồng",
    "n'thol haj, dduwsc trojng, laam ddoofng"
  ],
  "NT Thái Bình, Đình Lập, Lạng Sơn": [
    "nt thái bình, đình lập, lạng sơn",
    "nt thasi bifnh, ddifnh laajp, lajng sown"
  ],
  "Nam Phúc Thăng, Cẩm Xuyên, Hà Tĩnh": [
    "nam phúc thăng, cẩm xuyên, hà tĩnh",
    "nam phusc thawng, caarm xuyeen, haf tixnh"
  ],
  "Nam Đồng, Hải Dương, Hải Dương": [
    "nam đồng, hải dương, hải dương",
    "nam ddoofng, hari duwowng, hari duwowng"
  ],
  "Nghiêm Xuyên, Thường Tín, Hà Nội": [
    "nghiêm xuyên, thường tín, hà nội",
    "nghieem xuyeen, thuwowfng tisn, haf nooji"
  ],
  "Nghĩa Hưng, Vĩnh Tường, Vĩnh Phúc": [
    "nghĩa hưng, vĩnh tường, vĩnh phúc",
    "nghixa huwng, vixnh tuwowfng, vixnh phusc"
  ],
  "Nghĩa Lộ, Quảng Ngãi, Quảng Ngãi": [
    "nghĩa lộ, quảng ngãi, quảng ngãi",
    "nghixa looj, quarng ngaxi, quarng ngaxi"
  ],
  "Nghĩa Ninh, Đồng Hới, Quảng Bình": [
    "nghĩa ninh, đồng hới, quảng bình",
    "nghixa ninh, ddoofng howsi, quarng bifnh"
  ],
  "Nghĩa Phú, Quảng Ngãi, Quảng Ngãi": [
    "nghĩa phú, quảng ngãi, quảng ngãi",
    "nghixa phus, quarng ngaxi, quarng ngaxi"
  ],
  "Nghĩa Thuận, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa thuận, tư nghĩa, quảng ngãi",
    "nghixa thuaajn, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Thắng, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa thắng, tư nghĩa, quảng ngãi",
    "nghixa thawsng, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Thịnh, Nghĩa Hưng, Nam Định": [
    "nghĩa thịnh, nghĩa hưng, nam định",
    "nghixa thijnh, nghixa huwng, nam ddijnh"
  ],
  "Nghĩa Điền, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa điền, tư nghĩa, quảng ngãi",
    "nghixa ddieefn, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Đạo, Thuận Thành, Bắc Ninh": [
    "nghĩa đạo, thuận thành, bắc ninh",
    "nghixa ddajo, thuaajn thafnh, bawsc ninh"
  ],
  "Nghĩa Đồng, Nghĩa Hưng, Nam Định": [
    "nghĩa đồng, nghĩa hưng, nam định",
    "nghixa ddoofng, nghixa huwng, nam ddijnh"
  ],
  "Nguyên Phúc, Bạch Thông, Bắc Kạn": [
    "nguyên phúc, bạch thông, bắc kạn",
    "nguyeen phusc, bajch thoong, bawsc kajn"
  ],
  "Nguyễn Trãi, Thường Tín, Hà Nội": [
    "nguyễn trãi, thường tín, hà nội",
    "nguyeexn traxi, thuwowfng tisn, haf nooji"
  ],
  "Nguyễn Việt Khái, Phú Tân, Cà Mau": [
    "nguyễn việt khái, phú tân, cà mau",
    "nguyeexn vieejt khasi, phus taan, caf mau"
  ],
  "Ngô Quyền, Thanh Miện, Hải Dương": [
    "ngô quyền, thanh miện, hải dương",
    "ngoo quyeefn, thanh mieejn, hari duwowng"
  ],
  "Ngọc Hoà, Giồng Riềng, Kiên Giang": [
    "ngọc hoà, giồng riềng, kiên giang",
    "ngojc hoaf, gioofng rieefng, kieen giang"
  ],
  "Ngọc Liên, Cẩm Giàng, Hải Dương": [
    "ngọc liên, cẩm giàng, hải dương",
    "ngojc lieen, caarm giafng, hari duwowng"
  ],
  "Ngọc Sơn, Hải Dương, Hải Dương": [
    "ngọc sơn, hải dương, hải dương",
    "ngojc sown, hari duwowng, hari duwowng"
  ],
  "Ngọc Trạo, Thạch Thành, Thanh Hóa": [
    "ngọc trạo, thạch thành, thanh hóa",
    "ngojc trajo, thajch thafnh, thanh hosa"
  ],
  "Nhuận Trạch, Lương Sơn, Hoà Bình": [
    "nhuận trạch, lương sơn, hoà bình",
    "nhuaajn trajch, luwowng sown, hoaf bifnh"
  ],
  "Nhân Quyền, Bình Giang, Hải Dương": [
    "nhân quyền, bình giang, hải dương",
    "nhaan quyeefn, bifnh giang, hari duwowng"
  ],
  "Nhị Châu, Hải Dương, Hải Dương": [
    "nhị châu, hải dương, hải dương",
    "nhij chaau, hari duwowng, hari duwowng"
  ],
  "Nông Thượng, Bắc Kạn, Bắc Kạn": [
    "nông thượng, bắc kạn, bắc kạn",
    "noong thuwowjng, bawsc kajn, bawsc kajn"
  ],
  "Nông Trường, Triệu Sơn, Thanh Hóa": [
    "nông trường, triệu sơn, thanh hóa",
    "noong truwowfng, trieeju sown, thanh hosa"
  ],
  "Nậm Chảy, Mường Khương, Lào Cai": [
    "nậm chảy, mường khương, lào cai",
    "naajm chary, muwowfng khuwowng, lafo cai"
  ],
  "Nậm Khắt, Mù Căng Chải, Yên Bái": [
    "nậm khắt, mù căng chải, yên bái",
    "naajm khawst, muf cawng chari, yeen basi"
  ],
  "Phan Đình Phùng, Mỹ Hào, Hưng Yên": [
    "phan đình phùng, mỹ hào, hưng yên",
    "phan ddifnh phufng, myx hafo, huwng yeen"
  ],
  "Phong Thạnh Tây, Giá Rai, Bạc Liêu": [
    "phong thạnh tây, giá rai, bạc liêu",
    "phong thajnh taay, gias rai, bajc lieeu"
  ],
  "Phình Sáng, Tuần Giáo, Điện Biên": [
    "phình sáng, tuần giáo, điện biên",
    "phifnh sasng, tuaafn giaso, ddieejn bieen"
  ],
  "Phù Hóa, Quảng Trạch, Quảng Bình": [
    "phù hóa, quảng trạch, quảng bình",
    "phuf hosa, quarng trajch, quarng bifnh"
  ],
  "Phú Cường, Đại Từ, Thái Nguyên": [
    "phú cường, đại từ, thái nguyên",
    "phus cuwowfng, ddaji tuwf, thasi nguyeen"
  ],
  "Phú Cường, Định Quán, Đồng Nai": [
    "phú cường, định quán, đồng nai",
    "phus cuwowfng, ddijnh quasn, ddoofng nai"
  ],
  "Phú Hồ, Phú Vang, Thừa Thiên Huế": [
    "phú hồ, phú vang, thừa thiên huế",
    "phus hoof, phus vang, thuwfa thieen huees"
  ],
  "Phú Mỹ Hưng, Củ Chi, Hồ Chí Minh": [
    "phú mỹ hưng, củ chi, hồ chí minh",
    "phus myx huwng, cur chi, hoof chis minh"
  ],
  "Phú Mỹ, Phú Vang, Thừa Thiên Huế": [
    "phú mỹ, phú vang, thừa thiên huế",
    "phus myx, phus vang, thuwfa thieen huees"
  ],
  "Phú Tân, Tân Phú Đông, Tiền Giang": [
    "phú tân, tân phú đông, tiền giang",
    "phus taan, taan phus ddoong, tieefn giang"
  ],
  "Phú Vinh, A Lưới, Thừa Thiên Huế": [
    "phú vinh, a lưới, thừa thiên huế",
    "phus vinh, a luwowsi, thuwfa thieen huees"
  ],
  "Phú Định, Bố Trạch, Quảng Bình": [
    "phú định, bố trạch, quảng bình",
    "phus ddijnh, boos trajch, quarng bifnh"
  ],
  "Phúc Diễn, Bắc Từ Liêm, Hà Nội": [
    "phúc diễn, bắc từ liêm, hà nội",
    "phusc dieexn, bawsc tuwf lieem, haf nooji"
  ],
  "Phúc Lương, Đại Từ, Thái Nguyên": [
    "phúc lương, đại từ, thái nguyên",
    "phusc luwowng, ddaji tuwf, thasi nguyeen"
  ],
  "Phúc Thành A, Kim Thành, Hải Dương": [
    "phúc thành a, kim thành, hải dương",
    "phusc thafnh a, kim thafnh, hari duwowng"
  ],
  "Phúc Trìu, Thái Nguyên, Thái Nguyên": [
    "phúc trìu, thái nguyên, thái nguyên",
    "phusc trifu, thasi nguyeen, thasi nguyeen"
  ],
  "Phúc Xuân, Thái Nguyên, Thái Nguyên": [
    "phúc xuân, thái nguyên, thái nguyên",
    "phusc xuaan, thasi nguyeen, thasi nguyeen"
  ],
  "Phương Công, Tiền Hải, Thái Bình": [
    "phương công, tiền hải, thái bình",
    "phuwowng coong, tieefn hari, thasi bifnh"
  ],
  "Phương Viên, Chợ Đồn, Bắc Kạn": [
    "phương viên, chợ đồn, bắc kạn",
    "phuwowng vieen, chowj ddoofn, bawsc kajn"
  ],
  "Phước An, Hớn Quản, Bình Phước": [
    "phước an, hớn quản, bình phước",
    "phuwowsc an, howsn quarn, bifnh phuwowsc"
  ],
  "Phước Cát 2, Cát Tiên, Lâm Đồng": [
    "phước cát 2, cát tiên, lâm đồng",
    "phuwowsc cast 2, cast tieen, laam ddoofng"
  ],
  "Phước Diêm, Thuận Nam, Ninh Thuận": [
    "phước diêm, thuận nam, ninh thuận",
    "phuwowsc dieem, thuaajn nam, ninh thuaajn"
  ],
  "Phước Hiệp, Củ Chi, Hồ Chí Minh": [
    "phước hiệp, củ chi, hồ chí minh",
    "phuwowsc hieejp, cur chi, hoof chis minh"
  ],
  "Phước Hiệp, Mỏ Cày Nam, Bến Tre": [
    "phước hiệp, mỏ cày nam, bến tre",
    "phuwowsc hieejp, mor cafy nam, beesn tre"
  ],
  "Phước Hoà, Phước Sơn, Quảng Nam": [
    "phước hoà, phước sơn, quảng nam",
    "phuwowsc hoaf, phuwowsc sown, quarng nam"
  ],
  "Phước Kiển, Nhà Bè, Hồ Chí Minh": [
    "phước kiển, nhà bè, hồ chí minh",
    "phuwowsc kieern, nhaf bef, hoof chis minh"
  ],
  "Phước Long A, Quận 9, Hồ Chí Minh": [
    "phước long a, quận 9, hồ chí minh",
    "phuwowsc long a, quaajn 9, hoof chis minh"
  ],
  "Phước Long B, Quận 9, Hồ Chí Minh": [
    "phước long b, quận 9, hồ chí minh",
    "phuwowsc long b, quaajn 9, hoof chis minh"
  ],
  "Phước Long, Phước Long, Bạc Liêu": [
    "phước long, phước long, bạc liêu",
    "phuwowsc long, phuwowsc long, bajc lieeu"
  ],
  "Phước Lộc, Đạ Huoai, Lâm Đồng": [
    "phước lộc, đạ huoai, lâm đồng",
    "phuwowsc loojc, ddaj huoai, laam ddoofng"
  ],
  "Phước Mỹ, Phước Sơn, Quảng Nam": [
    "phước mỹ, phước sơn, quảng nam",
    "phuwowsc myx, phuwowsc sown, quarng nam"
  ],
  "Phước Sơn, Bù Đăng, Bình Phước": [
    "phước sơn, bù đăng, bình phước",
    "phuwowsc sown, buf ddawng, bifnh phuwowsc"
  ],
  "Phước Thạnh, Châu Thành, Bến Tre": [
    "phước thạnh, châu thành, bến tre",
    "phuwowsc thajnh, chaau thafnh, beesn tre"
  ],
  "Phước Trà, Hiệp Đức, Quảng Nam": [
    "phước trà, hiệp đức, quảng nam",
    "phuwowsc traf, hieejp dduwsc, quarng nam"
  ],
  "Phước Vĩnh, Phú Giáo, Bình Dương": [
    "phước vĩnh, phú giáo, bình dương",
    "phuwowsc vixnh, phus giaso, bifnh duwowng"
  ],
  "Phường 1, Quảng Trị, Quảng Trị": [
    "phường 1, quảng trị, quảng trị",
    "phuwowfng 1, quarng trij, quarng trij"
  ],
  "Phường 2, Quảng Trị, Quảng Trị": [
    "phường 2, quảng trị, quảng trị",
    "phuwowfng 2, quarng trij, quarng trij"
  ],
  "Phường 3, Quảng Trị, Quảng Trị": [
    "phường 3, quảng trị, quảng trị",
    "phuwowfng 3, quarng trij, quarng trij"
  ],
  "Phượng Sơn, Lục Ngạn, Bắc Giang": [
    "phượng sơn, lục ngạn, bắc giang",
    "phuwowjng sown, lujc ngajn, bawsc giang"
  ],
  "Phạm Ngũ Lão, Kim Động, Hưng Yên": [
    "phạm ngũ lão, kim động, hưng yên",
    "phajm ngux laxo, kim ddoojng, huwng yeen"
  ],
  "Phổ Khánh, Đức Phổ, Quảng Ngãi": [
    "phổ khánh, đức phổ, quảng ngãi",
    "phoor khasnh, dduwsc phoor, quarng ngaxi"
  ],
  "Phục Lễ, Thuỷ Nguyên, Hải Phòng": [
    "phục lễ, thuỷ nguyên, hải phòng",
    "phujc leex, thuyr nguyeen, hari phofng"
  ],
  "Phụng Thượng, Phúc Thọ, Hà Nội": [
    "phụng thượng, phúc thọ, hà nội",
    "phujng thuwowjng, phusc thoj, haf nooji"
  ],
  "Púng Luông, Mù Căng Chải, Yên Bái": [
    "púng luông, mù căng chải, yên bái",
    "pusng luoong, muf cawng chari, yeen basi"
  ],
  "Quang Lịch, Kiến Xương, Thái Bình": [
    "quang lịch, kiến xương, thái bình",
    "quang lijch, kieesn xuwowng, thasi bifnh"
  ],
  "Quang Thuận, Bạch Thông, Bắc Kạn": [
    "quang thuận, bạch thông, bắc kạn",
    "quang thuaajn, bajch thoong, bawsc kajn"
  ],
  "Quang Trung, Hải Dương, Hải Dương": [
    "quang trung, hải dương, hải dương",
    "quang trung, hari duwowng, hari duwowng"
  ],
  "Quang Trung, Thái Nguyên, Thái Nguyên": [
    "quang trung, thái nguyên, thái nguyên",
    "quang trung, thasi nguyeen, thasi nguyeen"
  ],
  "Quyết Thắng, Hữu Lũng, Lạng Sơn": [
    "quyết thắng, hữu lũng, lạng sơn",
    "quyeest thawsng, huwxu luxng, lajng sown"
  ],
  "Quyết Tiến, Tiên Lãng, Hải Phòng": [
    "quyết tiến, tiên lãng, hải phòng",
    "quyeest tieesn, tieen laxng, hari phofng"
  ],
  "Quách Phẩm Bắc, Đầm Dơi, Cà Mau": [
    "quách phẩm bắc, đầm dơi, cà mau",
    "quasch phaarm bawsc, ddaafm dowi, caf mau"
  ],
  "Quảng Bạch, Chợ Đồn, Bắc Kạn": [
    "quảng bạch, chợ đồn, bắc kạn",
    "quarng bajch, chowj ddoofn, bawsc kajn"
  ],
  "Quảng Giao, Quảng Xương, Thanh Hóa": [
    "quảng giao, quảng xương, thanh hóa",
    "quarng giao, quarng xuwowng, thanh hosa"
  ],
  "Quảng Hòa, Quảng Xương, Thanh Hóa": [
    "quảng hòa, quảng xương, thanh hóa",
    "quarng hofa, quarng xuwowng, thanh hosa"
  ],
  "Quảng Khê, Quảng Xương, Thanh Hóa": [
    "quảng khê, quảng xương, thanh hóa",
    "quarng khee, quarng xuwowng, thanh hosa"
  ],
  "Quảng Long, Quảng Xương, Thanh Hóa": [
    "quảng long, quảng xương, thanh hóa",
    "quarng long, quarng xuwowng, thanh hosa"
  ],
  "Quảng Lưu, Quảng Xương, Thanh Hóa": [
    "quảng lưu, quảng xương, thanh hóa",
    "quarng luwu, quarng xuwowng, thanh hosa"
  ],
  "Quảng Nham, Quảng Xương, Thanh Hóa": [
    "quảng nham, quảng xương, thanh hóa",
    "quarng nham, quarng xuwowng, thanh hosa"
  ],
  "Quảng Ninh, Quảng Xương, Thanh Hóa": [
    "quảng ninh, quảng xương, thanh hóa",
    "quarng ninh, quarng xuwowng, thanh hosa"
  ],
  "Quảng Phú Cầu, Ứng Hòa, Hà Nội": [
    "quảng phú cầu, ứng hòa, hà nội",
    "quarng phus caafu, uwsng hofa, haf nooji"
  ],
  "Quảng Thuận, Ba Đồn, Quảng Bình": [
    "quảng thuận, ba đồn, quảng bình",
    "quarng thuaajn, ba ddoofn, quarng bifnh"
  ],
  "Quảng Văn, Quảng Xương, Thanh Hóa": [
    "quảng văn, quảng xương, thanh hóa",
    "quarng vawn, quarng xuwowng, thanh hosa"
  ],
  "Quảng Yên, Quảng Xương, Thanh Hóa": [
    "quảng yên, quảng xương, thanh hóa",
    "quarng yeen, quarng xuwowng, thanh hosa"
  ],
  "Quất Động, Thường Tín, Hà Nội": [
    "quất động, thường tín, hà nội",
    "quaast ddoojng, thuwowfng tisn, haf nooji"
  ],
  "Quốc Tử Giám, Đống Đa, Hà Nội": [
    "quốc tử giám, đống đa, hà nội",
    "quoosc tuwr giasm, ddoosng dda, haf nooji"
  ],
  "Quỳnh Bảo, Quỳnh Phụ, Thái Bình": [
    "quỳnh bảo, quỳnh phụ, thái bình",
    "quyfnh baro, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Hưng, Quỳnh Phụ, Thái Bình": [
    "quỳnh hưng, quỳnh phụ, thái bình",
    "quyfnh huwng, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Hải, Quỳnh Phụ, Thái Bình": [
    "quỳnh hải, quỳnh phụ, thái bình",
    "quyfnh hari, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Hội, Quỳnh Phụ, Thái Bình": [
    "quỳnh hội, quỳnh phụ, thái bình",
    "quyfnh hooji, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Thọ, Quỳnh Phụ, Thái Bình": [
    "quỳnh thọ, quỳnh phụ, thái bình",
    "quyfnh thoj, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Trang, Quỳnh Phụ, Thái Bình": [
    "quỳnh trang, quỳnh phụ, thái bình",
    "quyfnh trang, quyfnh phuj, thasi bifnh"
  ],
  "Song Phượng, Đan Phượng, Hà Nội": [
    "song phượng, đan phượng, hà nội",
    "song phuwowjng, ddan phuwowjng, haf nooji"
  ],
  "Song Tử Tây, Trường Sa, Khánh Hòa": [
    "song tử tây, trường sa, khánh hòa",
    "song tuwr taay, truwowfng sa, khasnh hofa"
  ],
  "Sán Xả Hồ, Hoàng Su Phì, Hà Giang": [
    "sán xả hồ, hoàng su phì, hà giang",
    "sasn xar hoof, hoafng su phif, haf giang"
  ],
  "Sín Thầu, Mường Nhé, Điện Biên": [
    "sín thầu, mường nhé, điện biên",
    "sisn thaafu, muwowfng nhes, ddieejn bieen"
  ],
  "Sông Đốc, Trần Văn Thời, Cà Mau": [
    "sông đốc, trần văn thời, cà mau",
    "soong ddoosc, traafn vawn thowfi, caf mau"
  ],
  "Sơn Giang, Phước Long, Bình Phước": [
    "sơn giang, phước long, bình phước",
    "sown giang, phuwowsc long, bifnh phuwowsc"
  ],
  "Tam Mỹ Đông, Núi Thành, Quảng Nam": [
    "tam mỹ đông, núi thành, quảng nam",
    "tam myx ddoong, nusi thafnh, quarng nam"
  ],
  "Thanh Bình, Hải Dương, Hải Dương": [
    "thanh bình, hải dương, hải dương",
    "thanh bifnh, hari duwowng, hari duwowng"
  ],
  "Thanh Bình, Hớn Quản, Bình Phước": [
    "thanh bình, hớn quản, bình phước",
    "thanh bifnh, howsn quarn, bifnh phuwowsc"
  ],
  "Thanh Chăn, Điện Biên, Điện Biên": [
    "thanh chăn, điện biên, điện biên",
    "thanh chawn, ddieejn bieen, ddieejn bieen"
  ],
  "Thanh Chương, Thanh Chương, Nghệ An": [
    "thanh chương, thanh chương, nghệ an",
    "thanh chuwowng, thanh chuwowng, ngheej an"
  ],
  "Thanh Hưng, Điện Biên, Điện Biên": [
    "thanh hưng, điện biên, điện biên",
    "thanh huwng, ddieejn bieen, ddieejn bieen"
  ],
  "Thanh Lương, Bình Long, Bình Phước": [
    "thanh lương, bình long, bình phước",
    "thanh luwowng, bifnh long, bifnh phuwowsc"
  ],
  "Thanh Miện, Thanh Miện, Hải Dương": [
    "thanh miện, thanh miện, hải dương",
    "thanh mieejn, thanh mieejn, hari duwowng"
  ],
  "Thanh Thạch, Tuyên Hóa, Quảng Bình": [
    "thanh thạch, tuyên hóa, quảng bình",
    "thanh thajch, tuyeen hosa, quarng bifnh"
  ],
  "Thanh Vĩnh Đông, Châu Thành, Long An": [
    "thanh vĩnh đông, châu thành, long an",
    "thanh vixnh ddoong, chaau thafnh, long an"
  ],
  "Thanh Xuân Bắc, Thanh Xuân, Hà Nội": [
    "thanh xuân bắc, thanh xuân, hà nội",
    "thanh xuaan bawsc, thanh xuaan, haf nooji"
  ],
  "Thanh Xuân Trung, Thanh Xuân, Hà Nội": [
    "thanh xuân trung, thanh xuân, hà nội",
    "thanh xuaan trung, thanh xuaan, haf nooji"
  ],
  "Thiện Hưng, Bù Đốp, Bình Phước": [
    "thiện hưng, bù đốp, bình phước",
    "thieejn huwng, buf ddoosp, bifnh phuwowsc"
  ],
  "Thiệu Nguyên, Thiệu Hóa, Thanh Hóa": [
    "thiệu nguyên, thiệu hóa, thanh hóa",
    "thieeju nguyeen, thieeju hosa, thanh hosa"
  ],
  "Thiệu Thịnh, Thiệu Hóa, Thanh Hóa": [
    "thiệu thịnh, thiệu hóa, thanh hóa",
    "thieeju thijnh, thieeju hosa, thanh hosa"
  ],
  "Thuần Thành, Thái Thụy, Thái Bình": [
    "thuần thành, thái thụy, thái bình",
    "thuaafn thafnh, thasi thujy, thasi bifnh"
  ],
  "Thuận Hạnh, Đắk Song, Đắk Nông": [
    "thuận hạnh, đắk song, đắk nông",
    "thuaajn hajnh, ddawsk song, ddawsk noong"
  ],
  "Thuận Lộc, Huế, Thừa Thiên Huế": [
    "thuận lộc, huế, thừa thiên huế",
    "thuaajn loojc, huees, thuwfa thieen huees"
  ],
  "Thuận Thành, Phổ Yên, Thái Nguyên": [
    "thuận thành, phổ yên, thái nguyên",
    "thuaajn thafnh, phoor yeen, thasi nguyeen"
  ],
  "Thuận Điền, Giồng Trôm, Bến Tre": [
    "thuận điền, giồng trôm, bến tre",
    "thuaajn ddieefn, gioofng troom, beesn tre"
  ],
  "Thuỷ Biều, Huế, Thừa Thiên Huế": [
    "thuỷ biều, huế, thừa thiên huế",
    "thuyr bieefu, huees, thuwfa thieen huees"
  ],
  "Thuỷ Sơn, Thuỷ Nguyên, Hải Phòng": [
    "thuỷ sơn, thuỷ nguyên, hải phòng",
    "thuyr sown, thuyr nguyeen, hari phofng"
  ],
  "Thành Thới A, Mỏ Cày Nam, Bến Tre": [
    "thành thới a, mỏ cày nam, bến tre",
    "thafnh thowsi a, mor cafy nam, beesn tre"
  ],
  "Thành Thới B, Mỏ Cày Nam, Bến Tre": [
    "thành thới b, mỏ cày nam, bến tre",
    "thafnh thowsi b, mor cafy nam, beesn tre"
  ],
  "Thành Tiến, Thạch Thành, Thanh Hóa": [
    "thành tiến, thạch thành, thanh hóa",
    "thafnh tieesn, thajch thafnh, thanh hosa"
  ],
  "Thành Trực, Thạch Thành, Thanh Hóa": [
    "thành trực, thạch thành, thanh hóa",
    "thafnh truwjc, thajch thafnh, thanh hosa"
  ],
  "Thành Tâm, Chơn Thành, Bình Phước": [
    "thành tâm, chơn thành, bình phước",
    "thafnh taam, chown thafnh, bifnh phuwowsc"
  ],
  "Thái Dương, Bình Giang, Hải Dương": [
    "thái dương, bình giang, hải dương",
    "thasi duwowng, bifnh giang, hari duwowng"
  ],
  "Thông Nguyên, Hoàng Su Phì, Hà Giang": [
    "thông nguyên, hoàng su phì, hà giang",
    "thoong nguyeen, hoafng su phif, haf giang"
  ],
  "Thường Thạnh, Cái Răng, Cần Thơ": [
    "thường thạnh, cái răng, cần thơ",
    "thuwowfng thajnh, casi rawng, caafn thow"
  ],
  "Thường Tín, Thường Tín, Hà Nội": [
    "thường tín, thường tín, hà nội",
    "thuwowfng tisn, thuwowfng tisn, haf nooji"
  ],
  "Thượng Lý, Hồng Bàng, Hải Phòng": [
    "thượng lý, hồng bàng, hải phòng",
    "thuwowjng lys, hoofng bafng, hari phofng"
  ],
  "Thượng Mỗ, Đan Phượng, Hà Nội": [
    "thượng mỗ, đan phượng, hà nội",
    "thuwowjng moox, ddan phuwowjng, haf nooji"
  ],
  "Thượng Vực, Chương Mỹ, Hà Nội": [
    "thượng vực, chương mỹ, hà nội",
    "thuwowjng vuwjc, chuwowng myx, haf nooji"
  ],
  "Thạch Bình, Thạch Thành, Thanh Hóa": [
    "thạch bình, thạch thành, thanh hóa",
    "thajch bifnh, thajch thafnh, thanh hosa"
  ],
  "Thạch Cẩm, Thạch Thành, Thanh Hóa": [
    "thạch cẩm, thạch thành, thanh hóa",
    "thajch caarm, thajch thafnh, thanh hosa"
  ],
  "Thạch Giám, Tương Dương, Nghệ An": [
    "thạch giám, tương dương, nghệ an",
    "thajch giasm, tuwowng duwowng, ngheej an"
  ],
  "Thạch Đồng, Thanh Thuỷ, Phú Thọ": [
    "thạch đồng, thanh thuỷ, phú thọ",
    "thajch ddoofng, thanh thuyr, phus thoj"
  ],
  "Thạnh Hoà, Tân Phước, Tiền Giang": [
    "thạnh hoà, tân phước, tiền giang",
    "thajnh hoaf, taan phuwowsc, tieefn giang"
  ],
  "Thạnh Hòa Sơn, Cầu Ngang, Trà Vinh": [
    "thạnh hòa sơn, cầu ngang, trà vinh",
    "thajnh hofa sown, caafu ngang, traf vinh"
  ],
  "Thạnh Hòa, Phụng Hiệp, Hậu Giang": [
    "thạnh hòa, phụng hiệp, hậu giang",
    "thajnh hofa, phujng hieejp, haaju giang"
  ],
  "Thạnh Mỹ, Tân Phước, Tiền Giang": [
    "thạnh mỹ, tân phước, tiền giang",
    "thajnh myx, taan phuwowsc, tieefn giang"
  ],
  "Thạnh Mỹ, Đơn Dương, Lâm Đồng": [
    "thạnh mỹ, đơn dương, lâm đồng",
    "thajnh myx, ddown duwowng, laam ddoofng"
  ],
  "Thạnh Ngãi, Mỏ Cày Bắc, Bến Tre": [
    "thạnh ngãi, mỏ cày bắc, bến tre",
    "thajnh ngaxi, mor cafy bawsc, beesn tre"
  ],
  "Thạnh Phước, Bình Đại, Bến Tre": [
    "thạnh phước, bình đại, bến tre",
    "thajnh phuwowsc, bifnh ddaji, beesn tre"
  ],
  "Thạnh Tiến, Vĩnh Thạnh, Cần Thơ": [
    "thạnh tiến, vĩnh thạnh, cần thơ",
    "thajnh tieesn, vixnh thajnh, caafn thow"
  ],
  "Thạnh Trị, Thạnh Trị, Sóc Trăng": [
    "thạnh trị, thạnh trị, sóc trăng",
    "thajnh trij, thajnh trij, sosc trawng"
  ],
  "Thạnh Tân, Tân Phước, Tiền Giang": [
    "thạnh tân, tân phước, tiền giang",
    "thajnh taan, taan phuwowsc, tieefn giang"
  ],
  "Thắng Lợi, Sông Công, Thái Nguyên": [
    "thắng lợi, sông công, thái nguyên",
    "thawsng lowji, soong coong, thasi nguyeen"
  ],
  "Thắng Thuỷ, Vĩnh Bảo, Hải Phòng": [
    "thắng thuỷ, vĩnh bảo, hải phòng",
    "thawsng thuyr, vixnh baro, hari phofng"
  ],
  "Thống Nhất, Thường Tín, Hà Nội": [
    "thống nhất, thường tín, hà nội",
    "thoosng nhaast, thuwowfng tisn, haf nooji"
  ],
  "Thụy Quỳnh, Thái Thụy, Thái Bình": [
    "thụy quỳnh, thái thụy, thái bình",
    "thujy quyfnh, thasi thujy, thasi bifnh"
  ],
  "Thứ Mười Một, An Minh, Kiên Giang": [
    "thứ mười một, an minh, kiên giang",
    "thuws muwowfi moojt, an minh, kieen giang"
  ],
  "Tiên Cường, Tiên Lãng, Hải Phòng": [
    "tiên cường, tiên lãng, hải phòng",
    "tieen cuwowfng, tieen laxng, hari phofng"
  ],
  "Tiên Cảnh, Tiên Phước, Quảng Nam": [
    "tiên cảnh, tiên phước, quảng nam",
    "tieen carnh, tieen phuwowsc, quarng nam"
  ],
  "Tiên Hiệp, Tiên Phước, Quảng Nam": [
    "tiên hiệp, tiên phước, quảng nam",
    "tieen hieejp, tieen phuwowsc, quarng nam"
  ],
  "Tiên Ngọc, Tiên Phước, Quảng Nam": [
    "tiên ngọc, tiên phước, quảng nam",
    "tieen ngojc, tieen phuwowsc, quarng nam"
  ],
  "Tiến Lợi, Phan Thiết, Bình Thuận": [
    "tiến lợi, phan thiết, bình thuận",
    "tieesn lowji, phan thieest, bifnh thuaajn"
  ],
  "Tri Phương, Tràng Định, Lạng Sơn": [
    "tri phương, tràng định, lạng sơn",
    "tri phuwowng, trafng ddijnh, lajng sown"
  ],
  "Triệu Ái, Triệu Phong, Quảng Trị": [
    "triệu ái, triệu phong, quảng trị",
    "trieeju asi, trieeju phong, quarng trij"
  ],
  "Triệu Đề, Lập Thạch, Vĩnh Phúc": [
    "triệu đề, lập thạch, vĩnh phúc",
    "trieeju ddeef, laajp thajch, vixnh phusc"
  ],
  "Trung Thành, Tràng Định, Lạng Sơn": [
    "trung thành, tràng định, lạng sơn",
    "trung thafnh, trafng ddijnh, lajng sown"
  ],
  "Trường Giang, Nông Cống, Thanh Hóa": [
    "trường giang, nông cống, thanh hóa",
    "truwowfng giang, noong coosng, thanh hosa"
  ],
  "Trường Long, Phong Điền, Cần Thơ": [
    "trường long, phong điền, cần thơ",
    "truwowfng long, phong ddieefn, caafn thow"
  ],
  "Trường Thắng, Thới Lai, Cần Thơ": [
    "trường thắng, thới lai, cần thơ",
    "truwowfng thawsng, thowsi lai, caafn thow"
  ],
  "Trường Trung, Nông Cống, Thanh Hóa": [
    "trường trung, nông cống, thanh hóa",
    "truwowfng trung, noong coosng, thanh hosa"
  ],
  "Trường Xuân A, Thới Lai, Cần Thơ": [
    "trường xuân a, thới lai, cần thơ",
    "truwowfng xuaan a, thowsi lai, caafn thow"
  ],
  "Trường Xuân B, Thới Lai, Cần Thơ": [
    "trường xuân b, thới lai, cần thơ",
    "truwowfng xuaan b, thowsi lai, caafn thow"
  ],
  "Trấn Dương, Vĩnh Bảo, Hải Phòng": [
    "trấn dương, vĩnh bảo, hải phòng",
    "traasn duwowng, vixnh baro, hari phofng"
  ],
  "Trần Hợi, Trần Văn Thời, Cà Mau": [
    "trần hợi, trần văn thời, cà mau",
    "traafn howji, traafn vawn thowfi, caf mau"
  ],
  "Trần Phú, Hải Dương, Hải Dương": [
    "trần phú, hải dương, hải dương",
    "traafn phus, hari duwowng, hari duwowng"
  ],
  "Trần Phú, Quảng Ngãi, Quảng Ngãi": [
    "trần phú, quảng ngãi, quảng ngãi",
    "traafn phus, quarng ngaxi, quarng ngaxi"
  ],
  "Trực Cường, Trực Ninh, Nam Định": [
    "trực cường, trực ninh, nam định",
    "truwjc cuwowfng, truwjc ninh, nam ddijnh"
  ],
  "Tuy Phước, Tuy Phước, Bình Định": [
    "tuy phước, tuy phước, bình định",
    "tuy phuwowsc, tuy phuwowsc, bifnh ddijnh"
  ],
  "Tuân Chính, Vĩnh Tường, Vĩnh Phúc": [
    "tuân chính, vĩnh tường, vĩnh phúc",
    "tuaan chisnh, vixnh tuwowfng, vixnh phusc"
  ],
  "Tuần Giáo, Tuần Giáo, Điện Biên": [
    "tuần giáo, tuần giáo, điện biên",
    "tuaafn giaso, tuaafn giaso, ddieejn bieen"
  ],
  "Tân An, Thủ Dầu Một, Bình Dương": [
    "tân an, thủ dầu một, bình dương",
    "taan an, thur daafu moojt, bifnh duwowng"
  ],
  "Tân Bình, Đồng Xoài, Bình Phước": [
    "tân bình, đồng xoài, bình phước",
    "taan bifnh, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Tân Dương, Định Hóa, Thái Nguyên": [
    "tân dương, định hóa, thái nguyên",
    "taan duwowng, ddijnh hosa, thasi nguyeen"
  ],
  "Tân Hiệp, Hớn Quản, Bình Phước": [
    "tân hiệp, hớn quản, bình phước",
    "taan hieejp, howsn quarn, bifnh phuwowsc"
  ],
  "Tân Hòa, Buôn Ma Thuột, Đắk Lắk": [
    "tân hòa, buôn ma thuột, đắk lắk",
    "taan hofa, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Tân Hòa, Gò Công Đông, Tiền Giang": [
    "tân hòa, gò công đông, tiền giang",
    "taan hofa, gof coong ddoong, tieefn giang"
  ],
  "Tân Hộ Cơ, Tân Hồng, Đồng Tháp": [
    "tân hộ cơ, tân hồng, đồng tháp",
    "taan hooj cow, taan hoofng, ddoofng thasp"
  ],
  "Tân Kiều, Tháp Mười, Đồng Tháp": [
    "tân kiều, tháp mười, đồng tháp",
    "taan kieefu, thasp muwowfi, ddoofng thasp"
  ],
  "Tân Lâm Hương, Thạch Hà, Hà Tĩnh": [
    "tân lâm hương, thạch hà, hà tĩnh",
    "taan laam huwowng, thajch haf, haf tixnh"
  ],
  "Tân Lý Tây, Châu Thành, Tiền Giang": [
    "tân lý tây, châu thành, tiền giang",
    "taan lys taay, chaau thafnh, tieefn giang"
  ],
  "Tân Lập 1, Tân Phước, Tiền Giang": [
    "tân lập 1, tân phước, tiền giang",
    "taan laajp 1, taan phuwowsc, tieefn giang"
  ],
  "Tân Lập 2, Tân Phước, Tiền Giang": [
    "tân lập 2, tân phước, tiền giang",
    "taan laajp 2, taan phuwowsc, tieefn giang"
  ],
  "Tân Nhựt, Bình Chánh, Hồ Chí Minh": [
    "tân nhựt, bình chánh, hồ chí minh",
    "taan nhuwjt, bifnh chasnh, hoof chis minh"
  ],
  "Tân Phú Trung, Củ Chi, Hồ Chí Minh": [
    "tân phú trung, củ chi, hồ chí minh",
    "taan phus trung, cur chi, hoof chis minh"
  ],
  "Tân Phú Đông, Sa Đéc, Đồng Tháp": [
    "tân phú đông, sa đéc, đồng tháp",
    "taan phus ddoong, sa ddesc, ddoofng thasp"
  ],
  "Tân Phú, Tân Phú Đông, Tiền Giang": [
    "tân phú, tân phú đông, tiền giang",
    "taan phus, taan phus ddoong, tieefn giang"
  ],
  "Tân Phước, Tân Hồng, Đồng Tháp": [
    "tân phước, tân hồng, đồng tháp",
    "taan phuwowsc, taan hoofng, ddoofng thasp"
  ],
  "Tân Sơn Nhì, Tân Phú, Hồ Chí Minh": [
    "tân sơn nhì, tân phú, hồ chí minh",
    "taan sown nhif, taan phus, hoof chis minh"
  ],
  "Tân Thành A, Tân Hồng, Đồng Tháp": [
    "tân thành a, tân hồng, đồng tháp",
    "taan thafnh a, taan hoofng, ddoofng thasp"
  ],
  "Tân Thành B, Tân Hồng, Đồng Tháp": [
    "tân thành b, tân hồng, đồng tháp",
    "taan thafnh b, taan hoofng, ddoofng thasp"
  ],
  "Tân Thành, Hướng Hóa, Quảng Trị": [
    "tân thành, hướng hóa, quảng trị",
    "taan thafnh, huwowsng hosa, quarng trij"
  ],
  "Tân Thành, Thái Nguyên, Thái Nguyên": [
    "tân thành, thái nguyên, thái nguyên",
    "taan thafnh, thasi nguyeen, thasi nguyeen"
  ],
  "Tân Thành, Đức Trọng, Lâm Đồng": [
    "tân thành, đức trọng, lâm đồng",
    "taan thafnh, dduwsc trojng, laam ddoofng"
  ],
  "Tân Thịnh, Định Hóa, Thái Nguyên": [
    "tân thịnh, định hóa, thái nguyên",
    "taan thijnh, ddijnh hosa, thasi nguyeen"
  ],
  "Tân Tiến, Đồng Phú, Bình Phước": [
    "tân tiến, đồng phú, bình phước",
    "taan tieesn, ddoofng phus, bifnh phuwowsc"
  ],
  "Tân Trạch, Bố Trạch, Quảng Bình": [
    "tân trạch, bố trạch, quảng bình",
    "taan trajch, boos trajch, quarng bifnh"
  ],
  "Tân Tây, Gò Công Đông, Tiền Giang": [
    "tân tây, gò công đông, tiền giang",
    "taan taay, gof coong ddoong, tieefn giang"
  ],
  "Tân Việt, Đông Triều, Quảng Ninh": [
    "tân việt, đông triều, quảng ninh",
    "taan vieejt, ddoong trieefu, quarng ninh"
  ],
  "Tân Xuân, Đồng Xoài, Bình Phước": [
    "tân xuân, đồng xoài, bình phước",
    "taan xuaan, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Tân Đông Hiệp, Dĩ An, Bình Dương": [
    "tân đông hiệp, dĩ an, bình dương",
    "taan ddoong hieejp, dix an, bifnh duwowng"
  ],
  "Tây Trạch, Bố Trạch, Quảng Bình": [
    "tây trạch, bố trạch, quảng bình",
    "taay trajch, boos trajch, quarng bifnh"
  ],
  "Tây Yên Tử, Sơn Động, Bắc Giang": [
    "tây yên tử, sơn động, bắc giang",
    "taay yeen tuwr, sown ddoojng, bawsc giang"
  ],
  "Tênh Phông, Tuần Giáo, Điện Biên": [
    "tênh phông, tuần giáo, điện biên",
    "teenh phoong, tuaafn giaso, ddieejn bieen"
  ],
  "Túc Duyên, Thái Nguyên, Thái Nguyên": [
    "túc duyên, thái nguyên, thái nguyên",
    "tusc duyeen, thasi nguyeen, thasi nguyeen"
  ],
  "Tảo Dương Văn, Ứng Hòa, Hà Nội": [
    "tảo dương văn, ứng hòa, hà nội",
    "taro duwowng vawn, uwsng hofa, haf nooji"
  ],
  "Tịnh Hiệp, Sơn Tịnh, Quảng Ngãi": [
    "tịnh hiệp, sơn tịnh, quảng ngãi",
    "tijnh hieejp, sown tijnh, quarng ngaxi"
  ],
  "Tịnh Hòa, Quảng Ngãi, Quảng Ngãi": [
    "tịnh hòa, quảng ngãi, quảng ngãi",
    "tijnh hofa, quarng ngaxi, quarng ngaxi"
  ],
  "Tịnh Khê, Quảng Ngãi, Quảng Ngãi": [
    "tịnh khê, quảng ngãi, quảng ngãi",
    "tijnh khee, quarng ngaxi, quarng ngaxi"
  ],
  "Tịnh Kỳ, Quảng Ngãi, Quảng Ngãi": [
    "tịnh kỳ, quảng ngãi, quảng ngãi",
    "tijnh kyf, quarng ngaxi, quarng ngaxi"
  ],
  "Tịnh Long, Quảng Ngãi, Quảng Ngãi": [
    "tịnh long, quảng ngãi, quảng ngãi",
    "tijnh long, quarng ngaxi, quarng ngaxi"
  ],
  "Tịnh Đông, Sơn Tịnh, Quảng Ngãi": [
    "tịnh đông, sơn tịnh, quảng ngãi",
    "tijnh ddoong, sown tijnh, quarng ngaxi"
  ],
  "Vang Quới Tây, Bình Đại, Bến Tre": [
    "vang quới tây, bình đại, bến tre",
    "vang quowsi taay, bifnh ddaji, beesn tre"
  ],
  "Việt Dân, Đông Triều, Quảng Ninh": [
    "việt dân, đông triều, quảng ninh",
    "vieejt daan, ddoong trieefu, quarng ninh"
  ],
  "Việt Hoà, Hải Dương, Hải Dương": [
    "việt hoà, hải dương, hải dương",
    "vieejt hoaf, hari duwowng, hari duwowng"
  ],
  "Việt Xuân, Vĩnh Tường, Vĩnh Phúc": [
    "việt xuân, vĩnh tường, vĩnh phúc",
    "vieejt xuaan, vixnh tuwowfng, vixnh phusc"
  ],
  "Vân Trường, Tiền Hải, Thái Bình": [
    "vân trường, tiền hải, thái bình",
    "vaan truwowfng, tieefn hari, thasi bifnh"
  ],
  "Vĩnh Bình, Gò Công Tây, Tiền Giang": [
    "vĩnh bình, gò công tây, tiền giang",
    "vixnh bifnh, gof coong taay, tieefn giang"
  ],
  "Vĩnh Hòa, U Minh Thượng, Kiên Giang": [
    "vĩnh hòa, u minh thượng, kiên giang",
    "vixnh hofa, u minh thuwowjng, kieen giang"
  ],
  "Vĩnh Hảo, Vĩnh Thạnh, Bình Định": [
    "vĩnh hảo, vĩnh thạnh, bình định",
    "vixnh haro, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Hựu, Gò Công Tây, Tiền Giang": [
    "vĩnh hựu, gò công tây, tiền giang",
    "vixnh huwju, gof coong taay, tieefn giang"
  ],
  "Vĩnh Quang, Vĩnh Thạnh, Bình Định": [
    "vĩnh quang, vĩnh thạnh, bình định",
    "vixnh quang, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Thuận, Vĩnh Thuận, Kiên Giang": [
    "vĩnh thuận, vĩnh thuận, kiên giang",
    "vixnh thuaajn, vixnh thuaajn, kieen giang"
  ],
  "Vĩnh Thạnh Trung, Châu Phú, An Giang": [
    "vĩnh thạnh trung, châu phú, an giang",
    "vixnh thajnh trung, chaau phus, an giang"
  ],
  "Vĩnh Tiến, Tràng Định, Lạng Sơn": [
    "vĩnh tiến, tràng định, lạng sơn",
    "vixnh tieesn, trafng ddijnh, lajng sown"
  ],
  "Xuân Bắc, Xuân Trường, Nam Định": [
    "xuân bắc, xuân trường, nam định",
    "xuaan bawsc, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Châu, Xuân Trường, Nam Định": [
    "xuân châu, xuân trường, nam định",
    "xuaan chaau, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Kiên, Xuân Trường, Nam Định": [
    "xuân kiên, xuân trường, nam định",
    "xuaan kieen, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Phong, Xuân Trường, Nam Định": [
    "xuân phong, xuân trường, nam định",
    "xuaan phong, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Phương, Nam Từ Liêm, Hà Nội": [
    "xuân phương, nam từ liêm, hà nội",
    "xuaan phuwowng, nam tuwf lieem, haf nooji"
  ],
  "Xuân Phương, Phú Bình, Thái Nguyên": [
    "xuân phương, phú bình, thái nguyên",
    "xuaan phuwowng, phus bifnh, thasi nguyeen"
  ],
  "Xuân Trung, Xuân Trường, Nam Định": [
    "xuân trung, xuân trường, nam định",
    "xuaan trung, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Trường, Xuân Lộc, Đồng Nai": [
    "xuân trường, xuân lộc, đồng nai",
    "xuaan truwowfng, xuaan loojc, ddoofng nai"
  ],
  "Xuân Trường, Đà Lạt, Lâm Đồng": [
    "xuân trường, đà lạt, lâm đồng",
    "xuaan truwowfng, ddaf lajt, laam ddoofng"
  ],
  "Xuân Tường, Thanh Chương, Nghệ An": [
    "xuân tường, thanh chương, nghệ an",
    "xuaan tuwowfng, thanh chuwowng, ngheej an"
  ],
  "Xuân Đài, Xuân Trường, Nam Định": [
    "xuân đài, xuân trường, nam định",
    "xuaan ddafi, xuaan truwowfng, nam ddijnh"
  ],
  "Yên Luông, Gò Công Tây, Tiền Giang": [
    "yên luông, gò công tây, tiền giang",
    "yeen luoong, gof coong taay, tieefn giang"
  ],
  "Yên Thượng, Chợ Đồn, Bắc Kạn": [
    "yên thượng, chợ đồn, bắc kạn",
    "yeen thuwowjng, chowj ddoofn, bawsc kajn"
  ],
  "Yên Trạch, Phú Lương, Thái Nguyên": [
    "yên trạch, phú lương, thái nguyên",
    "yeen trajch, phus luwowng, thasi nguyeen"
  ],
  "Yên Đức, Đông Triều, Quảng Ninh": [
    "yên đức, đông triều, quảng ninh",
    "yeen dduwsc, ddoong trieefu, quarng ninh"
  ],
  "Đa Mi, Hàm Thuận Bắc, Bình Thuận": [
    "đa mi, hàm thuận bắc, bình thuận",
    "dda mi, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Đan Phượng, Đan Phượng, Hà Nội": [
    "đan phượng, đan phượng, hà nội",
    "ddan phuwowjng, ddan phuwowjng, haf nooji"
  ],
  "Điềm Thụy, Phú Bình, Thái Nguyên": [
    "điềm thụy, phú bình, thái nguyên",
    "ddieefm thujy, phus bifnh, thasi nguyeen"
  ],
  "Điện Hồng, Điện Bàn, Quảng Nam": [
    "điện hồng, điện bàn, quảng nam",
    "ddieejn hoofng, ddieejn bafn, quarng nam"
  ],
  "Điện Ngọc, Điện Bàn, Quảng Nam": [
    "điện ngọc, điện bàn, quảng nam",
    "ddieejn ngojc, ddieejn bafn, quarng nam"
  ],
  "Điện Tiến, Điện Bàn, Quảng Nam": [
    "điện tiến, điện bàn, quảng nam",
    "ddieejn tieesn, ddieejn bafn, quarng nam"
  ],
  "Đoài Dương, Trùng Khánh, Cao Bằng": [
    "đoài dương, trùng khánh, cao bằng",
    "ddoafi duwowng, trufng khasnh, cao bawfng"
  ],
  "Đoàn Kết, Thanh Miện, Hải Dương": [
    "đoàn kết, thanh miện, hải dương",
    "ddoafn keest, thanh mieejn, hari duwowng"
  ],
  "Đoàn Kết, Tràng Định, Lạng Sơn": [
    "đoàn kết, tràng định, lạng sơn",
    "ddoafn keest, trafng ddijnh, lajng sown"
  ],
  "Đoàn Tùng, Thanh Miện, Hải Dương": [
    "đoàn tùng, thanh miện, hải dương",
    "ddoafn tufng, thanh mieejn, hari duwowng"
  ],
  "Đông Dương, Đông Hưng, Thái Bình": [
    "đông dương, đông hưng, thái bình",
    "ddoong duwowng, ddoong huwng, thasi bifnh"
  ],
  "Đông Lương, Đông Hà, Quảng Trị": [
    "đông lương, đông hà, quảng trị",
    "ddoong luwowng, ddoong haf, quarng trij"
  ],
  "Đông Sơn, Thuỷ Nguyên, Hải Phòng": [
    "đông sơn, thuỷ nguyên, hải phòng",
    "ddoong sown, thuyr nguyeen, hari phofng"
  ],
  "Đông Thạnh, Châu Thành, Hậu Giang": [
    "đông thạnh, châu thành, hậu giang",
    "ddoong thajnh, chaau thafnh, haaju giang"
  ],
  "Đông Thạnh, Hóc Môn, Hồ Chí Minh": [
    "đông thạnh, hóc môn, hồ chí minh",
    "ddoong thajnh, hosc moon, hoof chis minh"
  ],
  "Đông Động, Đông Hưng, Thái Bình": [
    "đông động, đông hưng, thái bình",
    "ddoong ddoojng, ddoong huwng, thasi bifnh"
  ],
  "Đưng KNớ, Lạc Dương, Lâm Đồng": [
    "đưng knớ, lạc dương, lâm đồng",
    "dduwng knows, lajc duwowng, laam ddoofng"
  ],
  "Đường Thượng, Yên Minh, Hà Giang": [
    "đường thượng, yên minh, hà giang",
    "dduwowfng thuwowjng, yeen minh, haf giang"
  ],
  "Đại Hợp, Kiến Thuỵ, Hải Phòng": [
    "đại hợp, kiến thuỵ, hải phòng",
    "ddaji howjp, kieesn thuyj, hari phofng"
  ],
  "Đại Thạnh, Đại Lộc, Quảng Nam": [
    "đại thạnh, đại lộc, quảng nam",
    "ddaji thajnh, ddaji loojc, quarng nam"
  ],
  "Đại Thắng, Tiên Lãng, Hải Phòng": [
    "đại thắng, tiên lãng, hải phòng",
    "ddaji thawsng, tieen laxng, hari phofng"
  ],
  "Đại Thắng, Đại Lộc, Quảng Nam": [
    "đại thắng, đại lộc, quảng nam",
    "ddaji thawsng, ddaji loojc, quarng nam"
  ],
  "Đại Đồng, Thanh Chương, Nghệ An": [
    "đại đồng, thanh chương, nghệ an",
    "ddaji ddoofng, thanh chuwowng, ngheej an"
  ],
  "Đại Đồng, Thạch Thất, Hà Nội": [
    "đại đồng, thạch thất, hà nội",
    "ddaji ddoofng, thajch thaast, haf nooji"
  ],
  "Đại Đồng, Đại Lộc, Quảng Nam": [
    "đại đồng, đại lộc, quảng nam",
    "ddaji ddoofng, ddaji loojc, quarng nam"
  ],
  "Đắk R'Măng, Đăk Glong, Đắk Nông": [
    "đắk r'măng, đăk glong, đắk nông",
    "ddawsk r'mawng, ddawk glong, ddawsk noong"
  ],
  "Đằng Giang, Ngô Quyền, Hải Phòng": [
    "đằng giang, ngô quyền, hải phòng",
    "ddawfng giang, ngoo quyeefn, hari phofng"
  ],
  "Đặng Cương, An Dương, Hải Phòng": [
    "đặng cương, an dương, hải phòng",
    "ddawjng cuwowng, an duwowng, hari phofng"
  ],
  "Định Quán, Định Quán, Đồng Nai": [
    "định quán, định quán, đồng nai",
    "ddijnh quasn, ddijnh quasn, ddoofng nai"
  ],
  "Định Sơn, Cẩm Giàng, Hải Dương": [
    "định sơn, cẩm giàng, hải dương",
    "ddijnh sown, caarm giafng, hari duwowng"
  ],
  "Định Thành, Đông Hải, Bạc Liêu": [
    "định thành, đông hải, bạc liêu",
    "ddijnh thafnh, ddoong hari, bajc lieeu"
  ],
  "Đồng Nơ, Hớn Quản, Bình Phước": [
    "đồng nơ, hớn quản, bình phước",
    "ddoofng now, howsn quarn, bifnh phuwowsc"
  ],
  "Đồng Thắng, Triệu Sơn, Thanh Hóa": [
    "đồng thắng, triệu sơn, thanh hóa",
    "ddoofng thawsng, trieeju sown, thanh hosa"
  ],
  "Đồng Thịnh, Ngọc Lặc, Thanh Hóa": [
    "đồng thịnh, ngọc lặc, thanh hóa",
    "ddoofng thijnh, ngojc lawjc, thanh hosa"
  ],
  "Đồng Tiến, Phổ Yên, Thái Nguyên": [
    "đồng tiến, phổ yên, thái nguyên",
    "ddoofng tieesn, phoor yeen, thasi nguyeen"
  ],
  "Đội Cấn, Tràng Định, Lạng Sơn": [
    "đội cấn, tràng định, lạng sơn",
    "ddooji caasn, trafng ddijnh, lajng sown"
  ],
  "Đức Chánh, Mộ Đức, Quảng Ngãi": [
    "đức chánh, mộ đức, quảng ngãi",
    "dduwsc chasnh, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Hiệp, Mộ Đức, Quảng Ngãi": [
    "đức hiệp, mộ đức, quảng ngãi",
    "dduwsc hieejp, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Hạnh, Đức Linh, Bình Thuận": [
    "đức hạnh, đức linh, bình thuận",
    "dduwsc hajnh, dduwsc linh, bifnh thuaajn"
  ],
  "Đức Liễu, Bù Đăng, Bình Phước": [
    "đức liễu, bù đăng, bình phước",
    "dduwsc lieexu, buf ddawng, bifnh phuwowsc"
  ],
  "Đức Ninh, Đồng Hới, Quảng Bình": [
    "đức ninh, đồng hới, quảng bình",
    "dduwsc ninh, ddoofng howsi, quarng bifnh"
  ],
  "Đức Thuận, Tánh Linh, Bình Thuận": [
    "đức thuận, tánh linh, bình thuận",
    "dduwsc thuaajn, tasnh linh, bifnh thuaajn"
  ],
  "Đức Thượng, Hoài Đức, Hà Nội": [
    "đức thượng, hoài đức, hà nội",
    "dduwsc thuwowjng, hoafi dduwsc, haf nooji"
  ],
  "Ẳng Cang, Mường Ảng, Điện Biên": [
    "ẳng cang, mường ảng, điện biên",
    "awrng cang, muwowfng arng, ddieejn bieen"
  ],
  "Ẳng Nưa, Mường Ảng, Điện Biên": [
    "ẳng nưa, mường ảng, điện biên",
    "awrng nuwa, muwowfng arng, ddieejn bieen"
  ],
  "Ẳng Tở, Mường Ảng, Điện Biên": [
    "ẳng tở, mường ảng, điện biên",
    "awrng towr, muwowfng arng, ddieejn bieen"
  ],
  "An Phú Tây, Bình Chánh, Hồ Chí Minh": [
    "an phú tây, bình chánh, hồ chí minh",
    "an phus taay, bifnh chasnh, hoof chis minh"
  ],
  "An Thượng, Hải Dương, Hải Dương": [
    "an thượng, hải dương, hải dương",
    "an thuwowjng, hari duwowng, hari duwowng"
  ],
  "An Thạnh Tây, Cù Lao Dung, Sóc Trăng": [
    "an thạnh tây, cù lao dung, sóc trăng",
    "an thajnh taay, cuf lao dung, sosc trawng"
  ],
  "Bàn Thạch, Giồng Riềng, Kiên Giang": [
    "bàn thạch, giồng riềng, kiên giang",
    "bafn thajch, gioofng rieefng, kieen giang"
  ],
  "Bình Chánh, Bình Chánh, Hồ Chí Minh": [
    "bình chánh, bình chánh, hồ chí minh",
    "bifnh chasnh, bifnh chasnh, hoof chis minh"
  ],
  "Bình Dương, Vĩnh Tường, Vĩnh Phúc": [
    "bình dương, vĩnh tường, vĩnh phúc",
    "bifnh duwowng, vixnh tuwowfng, vixnh phusc"
  ],
  "Bình Hàng Tây, Cao Lãnh, Đồng Tháp": [
    "bình hàng tây, cao lãnh, đồng tháp",
    "bifnh hafng taay, cao laxnh, ddoofng thasp"
  ],
  "Bình Hòa Phước, Long Hồ, Vĩnh Long": [
    "bình hòa phước, long hồ, vĩnh long",
    "bifnh hofa phuwowsc, long hoof, vixnh long"
  ],
  "Bình Nguyên, Kiến Xương, Thái Bình": [
    "bình nguyên, kiến xương, thái bình",
    "bifnh nguyeen, kieesn xuwowng, thasi bifnh"
  ],
  "Bình Thạnh, Hồng Ngự, Đồng Tháp": [
    "bình thạnh, hồng ngự, đồng tháp",
    "bifnh thajnh, hoofng nguwj, ddoofng thasp"
  ],
  "Bình Tân Phú, Bình Sơn, Quảng Ngãi": [
    "bình tân phú, bình sơn, quảng ngãi",
    "bifnh taan phus, bifnh sown, quarng ngaxi"
  ],
  "Bình Định, Kiến Xương, Thái Bình": [
    "bình định, kiến xương, thái bình",
    "bifnh ddijnh, kieesn xuwowng, thasi bifnh"
  ],
  "Bùi Thị Xuân, Qui Nhơn, Bình Định": [
    "bùi thị xuân, qui nhơn, bình định",
    "bufi thij xuaan, qui nhown, bifnh ddijnh"
  ],
  "Bắc Nghĩa, Đồng Hới, Quảng Bình": [
    "bắc nghĩa, đồng hới, quảng bình",
    "bawsc nghixa, ddoofng howsi, quarng bifnh"
  ],
  "Bắc Trạch, Bố Trạch, Quảng Bình": [
    "bắc trạch, bố trạch, quảng bình",
    "bawsc trajch, boos trajch, quarng bifnh"
  ],
  "Bến Củi, Dương Minh Châu, Tây Ninh": [
    "bến củi, dương minh châu, tây ninh",
    "beesn curi, duwowng minh chaau, taay ninh"
  ],
  "Cam Phước Đông, Cam Ranh, Khánh Hòa": [
    "cam phước đông, cam ranh, khánh hòa",
    "cam phuwowsc ddoong, cam ranh, khasnh hofa"
  ],
  "Chi Lăng Nam, Thanh Miện, Hải Dương": [
    "chi lăng nam, thanh miện, hải dương",
    "chi lawng nam, thanh mieejn, hari duwowng"
  ],
  "Chiềng Sinh, Tuần Giáo, Điện Biên": [
    "chiềng sinh, tuần giáo, điện biên",
    "chieefng sinh, tuaafn giaso, ddieejn bieen"
  ],
  "Chung Chải, Mường Nhé, Điện Biên": [
    "chung chải, mường nhé, điện biên",
    "chung chari, muwowfng nhes, ddieejn bieen"
  ],
  "Chơn Thành, Chơn Thành, Bình Phước": [
    "chơn thành, chơn thành, bình phước",
    "chown thafnh, chown thafnh, bifnh phuwowsc"
  ],
  "Cư Dliê M'nông, Cư M'gar, Đắk Lắk": [
    "cư dliê m'nông, cư m'gar, đắk lắk",
    "cuw dliee m'noong, cuw m'gar, ddawsk lawsk"
  ],
  "Cần Thạnh, Cần Giờ, Hồ Chí Minh": [
    "cần thạnh, cần giờ, hồ chí minh",
    "caafn thajnh, caafn giowf, hoof chis minh"
  ],
  "Cầu Ông Lãnh, Quận 1, Hồ Chí Minh": [
    "cầu ông lãnh, quận 1, hồ chí minh",
    "caafu oong laxnh, quaajn 1, hoof chis minh"
  ],
  "Cẩm Điền, Cẩm Giàng, Hải Dương": [
    "cẩm điền, cẩm giàng, hải dương",
    "caarm ddieefn, caarm giafng, hari duwowng"
  ],
  "Cổ Nhuế 1, Bắc Từ Liêm, Hà Nội": [
    "cổ nhuế 1, bắc từ liêm, hà nội",
    "coor nhuees 1, bawsc tuwf lieem, haf nooji"
  ],
  "Cổ Nhuế 2, Bắc Từ Liêm, Hà Nội": [
    "cổ nhuế 2, bắc từ liêm, hà nội",
    "coor nhuees 2, bawsc tuwf lieem, haf nooji"
  ],
  "Dương Quan, Thuỷ Nguyên, Hải Phòng": [
    "dương quan, thuỷ nguyên, hải phòng",
    "duwowng quan, thuyr nguyeen, hari phofng"
  ],
  "Dương Thủy, Lệ Thủy, Quảng Bình": [
    "dương thủy, lệ thủy, quảng bình",
    "duwowng thury, leej thury, quarng bifnh"
  ],
  "Dương Xuân Hội, Châu Thành, Long An": [
    "dương xuân hội, châu thành, long an",
    "duwowng xuaan hooji, chaau thafnh, long an"
  ],
  "Giang Sơn Đông, Đô Lương, Nghệ An": [
    "giang sơn đông, đô lương, nghệ an",
    "giang sown ddoong, ddoo luwowng, ngheej an"
  ],
  "Giục Tượng, Châu Thành, Kiên Giang": [
    "giục tượng, châu thành, kiên giang",
    "giujc tuwowjng, chaau thafnh, kieen giang"
  ],
  "Hiệp Mỹ Đông, Cầu Ngang, Trà Vinh": [
    "hiệp mỹ đông, cầu ngang, trà vinh",
    "hieejp myx ddoong, caafu ngang, traf vinh"
  ],
  "Hiệp Thuận, Hiệp Đức, Quảng Nam": [
    "hiệp thuận, hiệp đức, quảng nam",
    "hieejp thuaajn, hieejp dduwsc, quarng nam"
  ],
  "Hoà Chánh, U Minh Thượng, Kiên Giang": [
    "hoà chánh, u minh thượng, kiên giang",
    "hoaf chasnh, u minh thuwowjng, kieen giang"
  ],
  "Hoàng Hoa Thám, Chí Linh, Hải Dương": [
    "hoàng hoa thám, chí linh, hải dương",
    "hoafng hoa thasm, chis linh, hari duwowng"
  ],
  "Hoàng Quế, Đông Triều, Quảng Ninh": [
    "hoàng quế, đông triều, quảng ninh",
    "hoafng quees, ddoong trieefu, quarng ninh"
  ],
  "Huổi Lèng, Mường Chà, Điện Biên": [
    "huổi lèng, mường chà, điện biên",
    "huoori lefng, muwowfng chaf, ddieejn bieen"
  ],
  "Hàm Minh, Hàm Thuận Nam, Bình Thuận": [
    "hàm minh, hàm thuận nam, bình thuận",
    "hafm minh, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Hàm Mỹ, Hàm Thuận Nam, Bình Thuận": [
    "hàm mỹ, hàm thuận nam, bình thuận",
    "hafm myx, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Hành Thiện, Nghĩa Hành, Quảng Ngãi": [
    "hành thiện, nghĩa hành, quảng ngãi",
    "hafnh thieejn, nghixa hafnh, quarng ngaxi"
  ],
  "Hành Thuận, Nghĩa Hành, Quảng Ngãi": [
    "hành thuận, nghĩa hành, quảng ngãi",
    "hafnh thuaajn, nghixa hafnh, quarng ngaxi"
  ],
  "Hành Thịnh, Nghĩa Hành, Quảng Ngãi": [
    "hành thịnh, nghĩa hành, quảng ngãi",
    "hafnh thijnh, nghixa hafnh, quarng ngaxi"
  ],
  "Hòa Bình Thạnh, Châu Thành, An Giang": [
    "hòa bình thạnh, châu thành, an giang",
    "hofa bifnh thajnh, chaau thafnh, an giang"
  ],
  "Hòa Thọ Đông, Cẩm Lệ, Đà Nẵng": [
    "hòa thọ đông, cẩm lệ, đà nẵng",
    "hofa thoj ddoong, caarm leej, ddaf nawxng"
  ],
  "Hòa Xuân, Buôn Ma Thuột, Đắk Lắk": [
    "hòa xuân, buôn ma thuột, đắk lắk",
    "hofa xuaan, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Hưng Phước, Bù Đốp, Bình Phước": [
    "hưng phước, bù đốp, bình phước",
    "huwng phuwowsc, buf ddoosp, bifnh phuwowsc"
  ],
  "Hưng Thạnh, Tân Phước, Tiền Giang": [
    "hưng thạnh, tân phước, tiền giang",
    "huwng thajnh, taan phuwowsc, tieefn giang"
  ],
  "Hưng Trạch, Bố Trạch, Quảng Bình": [
    "hưng trạch, bố trạch, quảng bình",
    "huwng trajch, boos trajch, quarng bifnh"
  ],
  "Hưng Yên Bắc, Hưng Nguyên, Nghệ An": [
    "hưng yên bắc, hưng nguyên, nghệ an",
    "huwng yeen bawsc, huwng nguyeen, ngheej an"
  ],
  "Hưng Đạo, Đông Triều, Quảng Ninh": [
    "hưng đạo, đông triều, quảng ninh",
    "huwng ddajo, ddoong trieefu, quarng ninh"
  ],
  "Hương Sơn, Thái Nguyên, Thái Nguyên": [
    "hương sơn, thái nguyên, thái nguyên",
    "huwowng sown, thasi nguyeen, thasi nguyeen"
  ],
  "Hướng Hiệp, Đa Krông, Quảng Trị": [
    "hướng hiệp, đa krông, quảng trị",
    "huwowsng hieejp, dda kroong, quarng trij"
  ],
  "Hải Thành, Đồng Hới, Quảng Bình": [
    "hải thành, đồng hới, quảng bình",
    "hari thafnh, ddoofng howsi, quarng bifnh"
  ],
  "Hậu Mỹ Bắc A, Cái Bè, Tiền Giang": [
    "hậu mỹ bắc a, cái bè, tiền giang",
    "haaju myx bawsc a, casi bef, tieefn giang"
  ],
  "Hậu Mỹ Bắc B, Cái Bè, Tiền Giang": [
    "hậu mỹ bắc b, cái bè, tiền giang",
    "haaju myx bawsc b, casi bef, tieefn giang"
  ],
  "Hố Quáng Phìn, Đồng Văn, Hà Giang": [
    "hố quáng phìn, đồng văn, hà giang",
    "hoos quasng phifn, ddoofng vawn, haf giang"
  ],
  "Hồng Kim, A Lưới, Thừa Thiên Huế": [
    "hồng kim, a lưới, thừa thiên huế",
    "hoofng kim, a luwowsi, thuwfa thieen huees"
  ],
  "Hồng Phong, Đông Triều, Quảng Ninh": [
    "hồng phong, đông triều, quảng ninh",
    "hoofng phong, ddoong trieefu, quarng ninh"
  ],
  "Hồng Tiến, Kiến Xương, Thái Bình": [
    "hồng tiến, kiến xương, thái bình",
    "hoofng tieesn, kieesn xuwowng, thasi bifnh"
  ],
  "Hợp Thành, Thuỷ Nguyên, Hải Phòng": [
    "hợp thành, thuỷ nguyên, hải phòng",
    "howjp thafnh, thuyr nguyeen, hari phofng"
  ],
  "Khánh Yên Thượng, Văn Bàn, Lào Cai": [
    "khánh yên thượng, văn bàn, lào cai",
    "khasnh yeen thuwowjng, vawn bafn, lafo cai"
  ],
  "Khương Thượng, Đống Đa, Hà Nội": [
    "khương thượng, đống đa, hà nội",
    "khuwowng thuwowjng, ddoosng dda, haf nooji"
  ],
  "Kim Phượng, Định Hóa, Thái Nguyên": [
    "kim phượng, định hóa, thái nguyên",
    "kim phuwowjng, ddijnh hosa, thasi nguyeen"
  ],
  "Kiến Quốc, Kiến Thuỵ, Hải Phòng": [
    "kiến quốc, kiến thuỵ, hải phòng",
    "kieesn quoosc, kieesn thuyj, hari phofng"
  ],
  "La Dạ, Hàm Thuận Bắc, Bình Thuận": [
    "la dạ, hàm thuận bắc, bình thuận",
    "la daj, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "La Pán Tẩn, Mù Căng Chải, Yên Bái": [
    "la pán tẩn, mù căng chải, yên bái",
    "la pasn taarn, muf cawng chari, yeen basi"
  ],
  "Leng Su Sìn, Mường Nhé, Điện Biên": [
    "leng su sìn, mường nhé, điện biên",
    "leng su sifn, muwowfng nhes, ddieejn bieen"
  ],
  "Linh Chiểu, Thủ Đức, Hồ Chí Minh": [
    "linh chiểu, thủ đức, hồ chí minh",
    "linh chieeru, thur dduwsc, hoof chis minh"
  ],
  "Liên Hiệp, Đức Trọng, Lâm Đồng": [
    "liên hiệp, đức trọng, lâm đồng",
    "lieen hieejp, dduwsc trojng, laam ddoofng"
  ],
  "Liên Hồng, Hải Dương, Hải Dương": [
    "liên hồng, hải dương, hải dương",
    "lieen hoofng, hari duwowng, hari duwowng"
  ],
  "Liên Nghĩa, Đức Trọng, Lâm Đồng": [
    "liên nghĩa, đức trọng, lâm đồng",
    "lieen nghixa, dduwsc trojng, laam ddoofng"
  ],
  "Liên Trạch, Bố Trạch, Quảng Bình": [
    "liên trạch, bố trạch, quảng bình",
    "lieen trajch, boos trajch, quarng bifnh"
  ],
  "Long Hựu Đông, Cần Đước, Long An": [
    "long hựu đông, cần đước, long an",
    "long huwju ddoong, caafn dduwowsc, long an"
  ],
  "Long Khánh A, Hồng Ngự, Đồng Tháp": [
    "long khánh a, hồng ngự, đồng tháp",
    "long khasnh a, hoofng nguwj, ddoofng thasp"
  ],
  "Long Khánh B, Hồng Ngự, Đồng Tháp": [
    "long khánh b, hồng ngự, đồng tháp",
    "long khasnh b, hoofng nguwj, ddoofng thasp"
  ],
  "Long Thạnh, Giồng Riềng, Kiên Giang": [
    "long thạnh, giồng riềng, kiên giang",
    "long thajnh, gioofng rieefng, kieen giang"
  ],
  "Long Thủy, Phước Long, Bình Phước": [
    "long thủy, phước long, bình phước",
    "long thury, phuwowsc long, bifnh phuwowsc"
  ],
  "Luận Thành, Thường Xuân, Thanh Hóa": [
    "luận thành, thường xuân, thanh hóa",
    "luaajn thafnh, thuwowfng xuaan, thanh hosa"
  ],
  "Láng Biển, Tháp Mười, Đồng Tháp": [
    "láng biển, tháp mười, đồng tháp",
    "lasng bieern, thasp muwowfi, ddoofng thasp"
  ],
  "Lâm Trung Thủy, Đức Thọ, Hà Tĩnh": [
    "lâm trung thủy, đức thọ, hà tĩnh",
    "laam trung thury, dduwsc thoj, haf tixnh"
  ],
  "Lâm Động, Thuỷ Nguyên, Hải Phòng": [
    "lâm động, thuỷ nguyên, hải phòng",
    "laam ddoojng, thuyr nguyeen, hari phofng"
  ],
  "Lê Hồng Phong, Qui Nhơn, Bình Định": [
    "lê hồng phong, qui nhơn, bình định",
    "lee hoofng phong, qui nhown, bifnh ddijnh"
  ],
  "Lê Hồng Phong, Thái Bình, Thái Bình": [
    "lê hồng phong, thái bình, thái bình",
    "lee hoofng phong, thasi bifnh, thasi bifnh"
  ],
  "Lăng Cô, Phú Lộc, Thừa Thiên Huế": [
    "lăng cô, phú lộc, thừa thiên huế",
    "lawng coo, phus loojc, thuwfa thieen huees"
  ],
  "Lương Khánh Thiện, Phủ Lý, Hà Nam": [
    "lương khánh thiện, phủ lý, hà nam",
    "luwowng khasnh thieejn, phur lys, haf nam"
  ],
  "Lương Thế Trân, Cái Nước, Cà Mau": [
    "lương thế trân, cái nước, cà mau",
    "luwowng thees traan, casi nuwowsc, caf mau"
  ],
  "Lạc Dương, Lạc Dương, Lâm Đồng": [
    "lạc dương, lạc dương, lâm đồng",
    "lajc duwowng, lajc duwowng, laam ddoofng"
  ],
  "Lại Thượng, Thạch Thất, Hà Nội": [
    "lại thượng, thạch thất, hà nội",
    "laji thuwowjng, thajch thaast, haf nooji"
  ],
  "Ma Lâm, Hàm Thuận Bắc, Bình Thuận": [
    "ma lâm, hàm thuận bắc, bình thuận",
    "ma laam, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Ma Thì Hồ, Mường Chà, Điện Biên": [
    "ma thì hồ, mường chà, điện biên",
    "ma thif hoof, muwowfng chaf, ddieejn bieen"
  ],
  "Minh Thạnh, Dầu Tiếng, Bình Dương": [
    "minh thạnh, dầu tiếng, bình dương",
    "minh thajnh, daafu tieesng, bifnh duwowng"
  ],
  "Minh Thắng, Chơn Thành, Bình Phước": [
    "minh thắng, chơn thành, bình phước",
    "minh thawsng, chown thafnh, bifnh phuwowsc"
  ],
  "Mường Báng, Tủa Chùa, Điện Biên": [
    "mường báng, tủa chùa, điện biên",
    "muwowfng basng, tura chufa, ddieejn bieen"
  ],
  "Mường Mùn, Tuần Giáo, Điện Biên": [
    "mường mùn, tuần giáo, điện biên",
    "muwowfng mufn, tuaafn giaso, ddieejn bieen"
  ],
  "Mỹ Chánh Tây, Phù Mỹ, Bình Định": [
    "mỹ chánh tây, phù mỹ, bình định",
    "myx chasnh taay, phuf myx, bifnh ddijnh"
  ],
  "Mỹ Hiệp Sơn, Hòn Đất, Kiên Giang": [
    "mỹ hiệp sơn, hòn đất, kiên giang",
    "myx hieejp sown, hofn ddaast, kieen giang"
  ],
  "Mỹ Hạnh Trung, Cai Lậy, Tiền Giang": [
    "mỹ hạnh trung, cai lậy, tiền giang",
    "myx hajnh trung, cai laajy, tieefn giang"
  ],
  "Mỹ Phước, Tân Phước, Tiền Giang": [
    "mỹ phước, tân phước, tiền giang",
    "myx phuwowsc, taan phuwowsc, tieefn giang"
  ],
  "Mỹ Thành Bắc, Cai Lậy, Tiền Giang": [
    "mỹ thành bắc, cai lậy, tiền giang",
    "myx thafnh bawsc, cai laajy, tieefn giang"
  ],
  "Mỹ Thạnh Đông, Đức Huệ, Long An": [
    "mỹ thạnh đông, đức huệ, long an",
    "myx thajnh ddoong, dduwsc hueej, long an"
  ],
  "Mỹ Đồng, Thuỷ Nguyên, Hải Phòng": [
    "mỹ đồng, thuỷ nguyên, hải phòng",
    "myx ddoofng, thuyr nguyeen, hari phofng"
  ],
  "Mỹ Đức Đông, Cái Bè, Tiền Giang": [
    "mỹ đức đông, cái bè, tiền giang",
    "myx dduwsc ddoong, casi bef, tieefn giang"
  ],
  "Nghĩa Dõng, Quảng Ngãi, Quảng Ngãi": [
    "nghĩa dõng, quảng ngãi, quảng ngãi",
    "nghixa doxng, quarng ngaxi, quarng ngaxi"
  ],
  "Nghĩa Dũng, Quảng Ngãi, Quảng Ngãi": [
    "nghĩa dũng, quảng ngãi, quảng ngãi",
    "nghixa duxng, quarng ngaxi, quarng ngaxi"
  ],
  "Nghĩa Phương, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa phương, tư nghĩa, quảng ngãi",
    "nghixa phuwowng, tuw nghixa, quarng ngaxi"
  ],
  "Nghĩa Thương, Tư Nghĩa, Quảng Ngãi": [
    "nghĩa thương, tư nghĩa, quảng ngãi",
    "nghixa thuwowng, tuw nghixa, quarng ngaxi"
  ],
  "Nguyễn Thái Học, Yên Bái, Yên Bái": [
    "nguyễn thái học, yên bái, yên bái",
    "nguyeexn thasi hojc, yeen basi, yeen basi"
  ],
  "Ngọc Châu, Hải Dương, Hải Dương": [
    "ngọc châu, hải dương, hải dương",
    "ngojc chaau, hari duwowng, hari duwowng"
  ],
  "Ngọc Chúc, Giồng Riềng, Kiên Giang": [
    "ngọc chúc, giồng riềng, kiên giang",
    "ngojc chusc, gioofng rieefng, kieen giang"
  ],
  "Ngọc Định, Định Quán, Đồng Nai": [
    "ngọc định, định quán, đồng nai",
    "ngojc ddijnh, ddijnh quasn, ddoofng nai"
  ],
  "Ngối Cáy, Mường Ảng, Điện Biên": [
    "ngối cáy, mường ảng, điện biên",
    "ngoosi casy, muwowfng arng, ddieejn bieen"
  ],
  "Nhân Trạch, Bố Trạch, Quảng Bình": [
    "nhân trạch, bố trạch, quảng bình",
    "nhaan trajch, boos trajch, quarng bifnh"
  ],
  "Nhân Đạo, Đắk R'Lấp, Đắk Nông": [
    "nhân đạo, đắk r'lấp, đắk nông",
    "nhaan ddajo, ddawsk r'laasp, ddawsk noong"
  ],
  "Nại Hiên Đông, Sơn Trà, Đà Nẵng": [
    "nại hiên đông, sơn trà, đà nẵng",
    "naji hieen ddoong, sown traf, ddaf nawxng"
  ],
  "Phong Dụ Thượng, Văn Yên, Yên Bái": [
    "phong dụ thượng, văn yên, yên bái",
    "phong duj thuwowjng, vawn yeen, yeen basi"
  ],
  "Phong Điền, Trần Văn Thời, Cà Mau": [
    "phong điền, trần văn thời, cà mau",
    "phong ddieefn, traafn vawn thowfi, caf mau"
  ],
  "Phú Diên, Phú Vang, Thừa Thiên Huế": [
    "phú diên, phú vang, thừa thiên huế",
    "phus dieen, phus vang, thuwfa thieen huees"
  ],
  "Phú Hòa Đông, Củ Chi, Hồ Chí Minh": [
    "phú hòa đông, củ chi, hồ chí minh",
    "phus hofa ddoong, cur chi, hoof chis minh"
  ],
  "Phú Hải, Phú Vang, Thừa Thiên Huế": [
    "phú hải, phú vang, thừa thiên huế",
    "phus hari, phus vang, thuwfa thieen huees"
  ],
  "Phú Mậu, Phú Vang, Thừa Thiên Huế": [
    "phú mậu, phú vang, thừa thiên huế",
    "phus maaju, phus vang, thuwfa thieen huees"
  ],
  "Phú Nghĩa, Bù Gia Mập, Bình Phước": [
    "phú nghĩa, bù gia mập, bình phước",
    "phus nghixa, buf gia maajp, bifnh phuwowsc"
  ],
  "Phú Riềng, Phú Riềng, Bình Phước": [
    "phú riềng, phú riềng, bình phước",
    "phus rieefng, phus rieefng, bifnh phuwowsc"
  ],
  "Phú Thanh, Phú Vang, Thừa Thiên Huế": [
    "phú thanh, phú vang, thừa thiên huế",
    "phus thanh, phus vang, thuwfa thieen huees"
  ],
  "Phú Thọ Hòa, Tân Phú, Hồ Chí Minh": [
    "phú thọ hòa, tân phú, hồ chí minh",
    "phus thoj hofa, taan phus, hoof chis minh"
  ],
  "Phú Xuân, Phú Vang, Thừa Thiên Huế": [
    "phú xuân, phú vang, thừa thiên huế",
    "phus xuaan, phus vang, thuwfa thieen huees"
  ],
  "Phú Điền, Tháp Mười, Đồng Tháp": [
    "phú điền, tháp mười, đồng tháp",
    "phus ddieefn, thasp muwowfi, ddoofng thasp"
  ],
  "Phúc Trạch, Bố Trạch, Quảng Bình": [
    "phúc trạch, bố trạch, quảng bình",
    "phusc trajch, boos trajch, quarng bifnh"
  ],
  "Phương Phú, Phụng Hiệp, Hậu Giang": [
    "phương phú, phụng hiệp, hậu giang",
    "phuwowng phus, phujng hieejp, haaju giang"
  ],
  "Phương Thịnh, Cao Lãnh, Đồng Tháp": [
    "phương thịnh, cao lãnh, đồng tháp",
    "phuwowng thijnh, cao laxnh, ddoofng thasp"
  ],
  "Phương Đình, Đan Phượng, Hà Nội": [
    "phương đình, đan phượng, hà nội",
    "phuwowng ddifnh, ddan phuwowjng, haf nooji"
  ],
  "Phương Định, Trực Ninh, Nam Định": [
    "phương định, trực ninh, nam định",
    "phuwowng ddijnh, truwjc ninh, nam ddijnh"
  ],
  "Phước Công, Phước Sơn, Quảng Nam": [
    "phước công, phước sơn, quảng nam",
    "phuwowsc coong, phuwowsc sown, quarng nam"
  ],
  "Phước Dân, Ninh Phước, Ninh Thuận": [
    "phước dân, ninh phước, ninh thuận",
    "phuwowsc daan, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Hòa, Tuy Phước, Bình Định": [
    "phước hòa, tuy phước, bình định",
    "phuwowsc hofa, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Lộc, Phước Sơn, Quảng Nam": [
    "phước lộc, phước sơn, quảng nam",
    "phuwowsc loojc, phuwowsc sown, quarng nam"
  ],
  "Phước Năng, Phước Sơn, Quảng Nam": [
    "phước năng, phước sơn, quảng nam",
    "phuwowsc nawng, phuwowsc sown, quarng nam"
  ],
  "Phước Sơn, Ninh Phước, Ninh Thuận": [
    "phước sơn, ninh phước, ninh thuận",
    "phuwowsc sown, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Sơn, Tuy Phước, Bình Định": [
    "phước sơn, tuy phước, bình định",
    "phuwowsc sown, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Thạnh, Củ Chi, Hồ Chí Minh": [
    "phước thạnh, củ chi, hồ chí minh",
    "phuwowsc thajnh, cur chi, hoof chis minh"
  ],
  "Phước Tân Hưng, Châu Thành, Long An": [
    "phước tân hưng, châu thành, long an",
    "phuwowsc taan huwng, chaau thafnh, long an"
  ],
  "Phước Vinh, Ninh Phước, Ninh Thuận": [
    "phước vinh, ninh phước, ninh thuận",
    "phuwowsc vinh, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Vĩnh, Huế, Thừa Thiên Huế": [
    "phước vĩnh, huế, thừa thiên huế",
    "phuwowsc vixnh, huees, thuwfa thieen huees"
  ],
  "Phước Xuân, Phước Sơn, Quảng Nam": [
    "phước xuân, phước sơn, quảng nam",
    "phuwowsc xuaan, phuwowsc sown, quarng nam"
  ],
  "Phường 01, Phú Nhuận, Hồ Chí Minh": [
    "phường 01, phú nhuận, hồ chí minh",
    "phuwowfng 01, phus nhuaajn, hoof chis minh"
  ],
  "Phường 02, Phú Nhuận, Hồ Chí Minh": [
    "phường 02, phú nhuận, hồ chí minh",
    "phuwowfng 02, phus nhuaajn, hoof chis minh"
  ],
  "Phường 03, Phú Nhuận, Hồ Chí Minh": [
    "phường 03, phú nhuận, hồ chí minh",
    "phuwowfng 03, phus nhuaajn, hoof chis minh"
  ],
  "Phường 04, Phú Nhuận, Hồ Chí Minh": [
    "phường 04, phú nhuận, hồ chí minh",
    "phuwowfng 04, phus nhuaajn, hoof chis minh"
  ],
  "Phường 05, Phú Nhuận, Hồ Chí Minh": [
    "phường 05, phú nhuận, hồ chí minh",
    "phuwowfng 05, phus nhuaajn, hoof chis minh"
  ],
  "Phường 07, Phú Nhuận, Hồ Chí Minh": [
    "phường 07, phú nhuận, hồ chí minh",
    "phuwowfng 07, phus nhuaajn, hoof chis minh"
  ],
  "Phường 08, Phú Nhuận, Hồ Chí Minh": [
    "phường 08, phú nhuận, hồ chí minh",
    "phuwowfng 08, phus nhuaajn, hoof chis minh"
  ],
  "Phường 09, Phú Nhuận, Hồ Chí Minh": [
    "phường 09, phú nhuận, hồ chí minh",
    "phuwowfng 09, phus nhuaajn, hoof chis minh"
  ],
  "Phường 10, Phú Nhuận, Hồ Chí Minh": [
    "phường 10, phú nhuận, hồ chí minh",
    "phuwowfng 10, phus nhuaajn, hoof chis minh"
  ],
  "Phường 11, Phú Nhuận, Hồ Chí Minh": [
    "phường 11, phú nhuận, hồ chí minh",
    "phuwowfng 11, phus nhuaajn, hoof chis minh"
  ],
  "Phường 12, Phú Nhuận, Hồ Chí Minh": [
    "phường 12, phú nhuận, hồ chí minh",
    "phuwowfng 12, phus nhuaajn, hoof chis minh"
  ],
  "Phường 13, Phú Nhuận, Hồ Chí Minh": [
    "phường 13, phú nhuận, hồ chí minh",
    "phuwowfng 13, phus nhuaajn, hoof chis minh"
  ],
  "Phường 14, Phú Nhuận, Hồ Chí Minh": [
    "phường 14, phú nhuận, hồ chí minh",
    "phuwowfng 14, phus nhuaajn, hoof chis minh"
  ],
  "Phường 15, Phú Nhuận, Hồ Chí Minh": [
    "phường 15, phú nhuận, hồ chí minh",
    "phuwowfng 15, phus nhuaajn, hoof chis minh"
  ],
  "Phường 17, Phú Nhuận, Hồ Chí Minh": [
    "phường 17, phú nhuận, hồ chí minh",
    "phuwowfng 17, phus nhuaajn, hoof chis minh"
  ],
  "Phạm Ngũ Lão, Quận 1, Hồ Chí Minh": [
    "phạm ngũ lão, quận 1, hồ chí minh",
    "phajm ngux laxo, quaajn 1, hoof chis minh"
  ],
  "Phổ Thuận, Đức Phổ, Quảng Ngãi": [
    "phổ thuận, đức phổ, quảng ngãi",
    "phoor thuaajn, dduwsc phoor, quarng ngaxi"
  ],
  "Phổ Thạnh, Đức Phổ, Quảng Ngãi": [
    "phổ thạnh, đức phổ, quảng ngãi",
    "phoor thajnh, dduwsc phoor, quarng ngaxi"
  ],
  "Quảng Bình, Quảng Xương, Thanh Hóa": [
    "quảng bình, quảng xương, thanh hóa",
    "quarng bifnh, quarng xuwowng, thanh hosa"
  ],
  "Quảng Hải, Quảng Xương, Thanh Hóa": [
    "quảng hải, quảng xương, thanh hóa",
    "quarng hari, quarng xuwowng, thanh hosa"
  ],
  "Quảng Hợp, Quảng Xương, Thanh Hóa": [
    "quảng hợp, quảng xương, thanh hóa",
    "quarng howjp, quarng xuwowng, thanh hosa"
  ],
  "Quảng Lâm, Mường Nhé, Điện Biên": [
    "quảng lâm, mường nhé, điện biên",
    "quarng laam, muwowfng nhes, ddieejn bieen"
  ],
  "Quảng Lập, Đơn Dương, Lâm Đồng": [
    "quảng lập, đơn dương, lâm đồng",
    "quarng laajp, ddown duwowng, laam ddoofng"
  ],
  "Quảng Lộc, Quảng Xương, Thanh Hóa": [
    "quảng lộc, quảng xương, thanh hóa",
    "quarng loojc, quarng xuwowng, thanh hosa"
  ],
  "Quảng Nghiệp, Tứ Kỳ, Hải Dương": [
    "quảng nghiệp, tứ kỳ, hải dương",
    "quarng nghieejp, tuws kyf, hari duwowng"
  ],
  "Quảng Nhân, Quảng Xương, Thanh Hóa": [
    "quảng nhân, quảng xương, thanh hóa",
    "quarng nhaan, quarng xuwowng, thanh hosa"
  ],
  "Quảng Phú, Quảng Ngãi, Quảng Ngãi": [
    "quảng phú, quảng ngãi, quảng ngãi",
    "quarng phus, quarng ngaxi, quarng ngaxi"
  ],
  "Quảng Phúc, Quảng Xương, Thanh Hóa": [
    "quảng phúc, quảng xương, thanh hóa",
    "quarng phusc, quarng xuwowng, thanh hosa"
  ],
  "Quảng Thái, Quảng Xương, Thanh Hóa": [
    "quảng thái, quảng xương, thanh hóa",
    "quarng thasi, quarng xuwowng, thanh hosa"
  ],
  "Quảng Trung, Quảng Xương, Thanh Hóa": [
    "quảng trung, quảng xương, thanh hóa",
    "quarng trung, quarng xuwowng, thanh hosa"
  ],
  "Quảng Tín, Đắk R'Lấp, Đắk Nông": [
    "quảng tín, đắk r'lấp, đắk nông",
    "quarng tisn, ddawsk r'laasp, ddawsk noong"
  ],
  "Quảng Điền, Krông A Na, Đắk Lắk": [
    "quảng điền, krông a na, đắk lắk",
    "quarng ddieefn, kroong a na, ddawsk lawsk"
  ],
  "Quốc Khánh, Tràng Định, Lạng Sơn": [
    "quốc khánh, tràng định, lạng sơn",
    "quoosc khasnh, trafng ddijnh, lajng sown"
  ],
  "Quốc Tuấn, Kiến Xương, Thái Bình": [
    "quốc tuấn, kiến xương, thái bình",
    "quoosc tuaasn, kieesn xuwowng, thasi bifnh"
  ],
  "Quốc Việt, Tràng Định, Lạng Sơn": [
    "quốc việt, tràng định, lạng sơn",
    "quoosc vieejt, trafng ddijnh, lajng sown"
  ],
  "Quỳnh Hoàng, Quỳnh Phụ, Thái Bình": [
    "quỳnh hoàng, quỳnh phụ, thái bình",
    "quyfnh hoafng, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Hồng, Quỳnh Phụ, Thái Bình": [
    "quỳnh hồng, quỳnh phụ, thái bình",
    "quyfnh hoofng, quyfnh phuj, thasi bifnh"
  ],
  "Quỳnh Ngọc, Quỳnh Phụ, Thái Bình": [
    "quỳnh ngọc, quỳnh phụ, thái bình",
    "quyfnh ngojc, quyfnh phuj, thasi bifnh"
  ],
  "Rạng Đông, Tuần Giáo, Điện Biên": [
    "rạng đông, tuần giáo, điện biên",
    "rajng ddoong, tuaafn giaso, ddieejn bieen"
  ],
  "Suối Đá, Dương Minh Châu, Tây Ninh": [
    "suối đá, dương minh châu, tây ninh",
    "suoosi ddas, duwowng minh chaau, taay ninh"
  ],
  "Tam Quan Bắc, Hoài Nhơn, Bình Định": [
    "tam quan bắc, hoài nhơn, bình định",
    "tam quan bawsc, hoafi nhown, bifnh ddijnh"
  ],
  "Thanh Khê Đông, Thanh Khê, Đà Nẵng": [
    "thanh khê đông, thanh khê, đà nẵng",
    "thanh khee ddoong, thanh khee, ddaf nawxng"
  ],
  "Thanh Khương, Thuận Thành, Bắc Ninh": [
    "thanh khương, thuận thành, bắc ninh",
    "thanh khuwowng, thuaajn thafnh, bawsc ninh"
  ],
  "Thanh Luông, Điện Biên, Điện Biên": [
    "thanh luông, điện biên, điện biên",
    "thanh luoong, ddieejn bieen, ddieejn bieen"
  ],
  "Thanh Trạch, Bố Trạch, Quảng Bình": [
    "thanh trạch, bố trạch, quảng bình",
    "thanh trajch, boos trajch, quarng bifnh"
  ],
  "Thanh Định, Định Hóa, Thái Nguyên": [
    "thanh định, định hóa, thái nguyên",
    "thanh ddijnh, ddijnh hosa, thasi nguyeen"
  ],
  "Thuận An, Phú Vang, Thừa Thiên Huế": [
    "thuận an, phú vang, thừa thiên huế",
    "thuaajn an, phus vang, thuwfa thieen huees"
  ],
  "Thuận Nghĩa Hòa, Thạnh Hóa, Long An": [
    "thuận nghĩa hòa, thạnh hóa, long an",
    "thuaajn nghixa hofa, thajnh hosa, long an"
  ],
  "Thuận Phú, Đồng Phú, Bình Phước": [
    "thuận phú, đồng phú, bình phước",
    "thuaajn phus, ddoofng phus, bifnh phuwowsc"
  ],
  "Thuận Phước, Hải Châu, Đà Nẵng": [
    "thuận phước, hải châu, đà nẵng",
    "thuaajn phuwowsc, hari chaau, ddaf nawxng"
  ],
  "Thuận Thành, Huế, Thừa Thiên Huế": [
    "thuận thành, huế, thừa thiên huế",
    "thuaajn thafnh, huees, thuwfa thieen huees"
  ],
  "Thành Công, Gò Công Tây, Tiền Giang": [
    "thành công, gò công tây, tiền giang",
    "thafnh coong, gof coong taay, tieefn giang"
  ],
  "Thái Thượng, Thái Thụy, Thái Bình": [
    "thái thượng, thái thụy, thái bình",
    "thasi thuwowjng, thasi thujy, thasi bifnh"
  ],
  "Thèn Chu Phìn, Hoàng Su Phì, Hà Giang": [
    "thèn chu phìn, hoàng su phì, hà giang",
    "thefn chu phifn, hoafng su phif, haf giang"
  ],
  "Thượng Cường, Chi Lăng, Lạng Sơn": [
    "thượng cường, chi lăng, lạng sơn",
    "thuwowjng cuwowfng, chi lawng, lajng sown"
  ],
  "Thượng Quận, Kinh Môn, Hải Dương": [
    "thượng quận, kinh môn, hải dương",
    "thuwowjng quaajn, kinh moon, hari duwowng"
  ],
  "Thượng Tân Lộc, Nam Đàn, Nghệ An": [
    "thượng tân lộc, nam đàn, nghệ an",
    "thuwowjng taan loojc, nam ddafn, ngheej an"
  ],
  "Thượng Ấm, Sơn Dương, Tuyên Quang": [
    "thượng ấm, sơn dương, tuyên quang",
    "thuwowjng aasm, sown duwowng, tuyeen quang"
  ],
  "Thạch Lỗi, Cẩm Giàng, Hải Dương": [
    "thạch lỗi, cẩm giàng, hải dương",
    "thajch looxi, caarm giafng, hari duwowng"
  ],
  "Thạnh Hòa, Giồng Riềng, Kiên Giang": [
    "thạnh hòa, giồng riềng, kiên giang",
    "thajnh hofa, gioofng rieefng, kieen giang"
  ],
  "Thạnh Qưới, Vĩnh Thạnh, Cần Thơ": [
    "thạnh qưới, vĩnh thạnh, cần thơ",
    "thajnh quwowsi, vixnh thajnh, caafn thow"
  ],
  "Thạnh Thắng, Vĩnh Thạnh, Cần Thơ": [
    "thạnh thắng, vĩnh thạnh, cần thơ",
    "thajnh thawsng, vixnh thajnh, caafn thow"
  ],
  "Thạnh Xuân, Châu Thành A, Hậu Giang": [
    "thạnh xuân, châu thành a, hậu giang",
    "thajnh xuaan, chaau thafnh a, haaju giang"
  ],
  "Thạnh Đông A, Tân Hiệp, Kiên Giang": [
    "thạnh đông a, tân hiệp, kiên giang",
    "thajnh ddoong a, taan hieejp, kieen giang"
  ],
  "Thạnh Đông B, Tân Hiệp, Kiên Giang": [
    "thạnh đông b, tân hiệp, kiên giang",
    "thajnh ddoong b, taan hieejp, kieen giang"
  ],
  "Thống Nhất, Bù Đăng, Bình Phước": [
    "thống nhất, bù đăng, bình phước",
    "thoosng nhaast, buf ddawng, bifnh phuwowsc"
  ],
  "Thới An Đông, Bình Thuỷ, Cần Thơ": [
    "thới an đông, bình thuỷ, cần thơ",
    "thowsi an ddoong, bifnh thuyr, caafn thow"
  ],
  "Tiến Thành, Phan Thiết, Bình Thuận": [
    "tiến thành, phan thiết, bình thuận",
    "tieesn thafnh, phan thieest, bifnh thuaajn"
  ],
  "Triệu Hòa, Triệu Phong, Quảng Trị": [
    "triệu hòa, triệu phong, quảng trị",
    "trieeju hofa, trieeju phong, quarng trij"
  ],
  "Triệu Long, Triệu Phong, Quảng Trị": [
    "triệu long, triệu phong, quảng trị",
    "trieeju long, trieeju phong, quarng trij"
  ],
  "Triệu Nguyên, Nguyên Bình, Cao Bằng": [
    "triệu nguyên, nguyên bình, cao bằng",
    "trieeju nguyeen, nguyeen bifnh, cao bawfng"
  ],
  "Triệu Nguyên, Đa Krông, Quảng Trị": [
    "triệu nguyên, đa krông, quảng trị",
    "trieeju nguyeen, dda kroong, quarng trij"
  ],
  "Triệu Sơn, Triệu Phong, Quảng Trị": [
    "triệu sơn, triệu phong, quảng trị",
    "trieeju sown, trieeju phong, quarng trij"
  ],
  "Triệu Tài, Triệu Phong, Quảng Trị": [
    "triệu tài, triệu phong, quảng trị",
    "trieeju tafi, trieeju phong, quarng trij"
  ],
  "Triệu Vân, Triệu Phong, Quảng Trị": [
    "triệu vân, triệu phong, quảng trị",
    "trieeju vaan, trieeju phong, quarng trij"
  ],
  "Trung Lương, Định Hóa, Thái Nguyên": [
    "trung lương, định hóa, thái nguyên",
    "trung luwowng, ddijnh hosa, thasi nguyeen"
  ],
  "Trung Lập Hạ, Củ Chi, Hồ Chí Minh": [
    "trung lập hạ, củ chi, hồ chí minh",
    "trung laajp haj, cur chi, hoof chis minh"
  ],
  "Trung Mỹ Tây, Quận 12, Hồ Chí Minh": [
    "trung mỹ tây, quận 12, hồ chí minh",
    "trung myx taay, quaajn 12, hoof chis minh"
  ],
  "Trung Phúc Cường, Nam Đàn, Nghệ An": [
    "trung phúc cường, nam đàn, nghệ an",
    "trung phusc cuwowfng, nam ddafn, ngheej an"
  ],
  "Trung Sơn, A Lưới, Thừa Thiên Huế": [
    "trung sơn, a lưới, thừa thiên huế",
    "trung sown, a luwowsi, thuwfa thieen huees"
  ],
  "Trung Thành, Thái Nguyên, Thái Nguyên": [
    "trung thành, thái nguyên, thái nguyên",
    "trung thafnh, thasi nguyeen, thasi nguyeen"
  ],
  "Trung Trạch, Bố Trạch, Quảng Bình": [
    "trung trạch, bố trạch, quảng bình",
    "trung trajch, boos trajch, quarng bifnh"
  ],
  "Trường Sinh, Sơn Dương, Tuyên Quang": [
    "trường sinh, sơn dương, tuyên quang",
    "truwowfng sinh, sown duwowng, tuyeen quang"
  ],
  "Trường Xuân, Đắk Song, Đắk Nông": [
    "trường xuân, đắk song, đắk nông",
    "truwowfng xuaan, ddawsk song, ddawsk noong"
  ],
  "Trạch Mỹ Lộc, Phúc Thọ, Hà Nội": [
    "trạch mỹ lộc, phúc thọ, hà nội",
    "trajch myx loojc, phusc thoj, haf nooji"
  ],
  "Trại Chuối, Hồng Bàng, Hải Phòng": [
    "trại chuối, hồng bàng, hải phòng",
    "traji chuoosi, hoofng bafng, hari phofng"
  ],
  "Tân Công Sính, Tam Nông, Đồng Tháp": [
    "tân công sính, tam nông, đồng tháp",
    "taan coong sisnh, tam noong, ddoofng thasp"
  ],
  "Tân Cương, Thái Nguyên, Thái Nguyên": [
    "tân cương, thái nguyên, thái nguyên",
    "taan cuwowng, thasi nguyeen, thasi nguyeen"
  ],
  "Tân Dương, Thuỷ Nguyên, Hải Phòng": [
    "tân dương, thuỷ nguyên, hải phòng",
    "taan duwowng, thuyr nguyeen, hari phofng"
  ],
  "Tân Hội Trung, Cao Lãnh, Đồng Tháp": [
    "tân hội trung, cao lãnh, đồng tháp",
    "taan hooji trung, cao laxnh, ddoofng thasp"
  ],
  "Tân Lập, Buôn Ma Thuột, Đắk Lắk": [
    "tân lập, buôn ma thuột, đắk lắk",
    "taan laajp, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Tân Lợi, Buôn Ma Thuột, Đắk Lắk": [
    "tân lợi, buôn ma thuột, đắk lắk",
    "taan lowji, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Tân Mỹ, Bắc Tân Uyên, Bình Dương": [
    "tân mỹ, bắc tân uyên, bình dương",
    "taan myx, bawsc taan uyeen, bifnh duwowng"
  ],
  "Tân Phú Tây, Mỏ Cày Bắc, Bến Tre": [
    "tân phú tây, mỏ cày bắc, bến tre",
    "taan phus taay, mor cafy bawsc, beesn tre"
  ],
  "Tân Thành, Đồng Xoài, Bình Phước": [
    "tân thành, đồng xoài, bình phước",
    "taan thafnh, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Tân Thịnh, Thái Nguyên, Thái Nguyên": [
    "tân thịnh, thái nguyên, thái nguyên",
    "taan thijnh, thasi nguyeen, thasi nguyeen"
  ],
  "Tăng Bạt Hổ, Hoài Ân, Bình Định": [
    "tăng bạt hổ, hoài ân, bình định",
    "tawng bajt hoor, hoafi aan, bifnh ddijnh"
  ],
  "Tăng Hoà, Gò Công Đông, Tiền Giang": [
    "tăng hoà, gò công đông, tiền giang",
    "tawng hoaf, gof coong ddoong, tieefn giang"
  ],
  "Tịnh Châu, Quảng Ngãi, Quảng Ngãi": [
    "tịnh châu, quảng ngãi, quảng ngãi",
    "tijnh chaau, quarng ngaxi, quarng ngaxi"
  ],
  "Tứ Cường, Thanh Miện, Hải Dương": [
    "tứ cường, thanh miện, hải dương",
    "tuws cuwowfng, thanh mieejn, hari duwowng"
  ],
  "Vinh Mỹ, Phú Lộc, Thừa Thiên Huế": [
    "vinh mỹ, phú lộc, thừa thiên huế",
    "vinh myx, phus loojc, thuwfa thieen huees"
  ],
  "Vinh Thanh, Phú Vang, Thừa Thiên Huế": [
    "vinh thanh, phú vang, thừa thiên huế",
    "vinh thanh, phus vang, thuwfa thieen huees"
  ],
  "Vinh Xuân, Phú Vang, Thừa Thiên Huế": [
    "vinh xuân, phú vang, thừa thiên huế",
    "vinh xuaan, phus vang, thuwfa thieen huees"
  ],
  "Vàm Láng, Gò Công Đông, Tiền Giang": [
    "vàm láng, gò công đông, tiền giang",
    "vafm lasng, gof coong ddoong, tieefn giang"
  ],
  "Vĩnh Hiệp, Vĩnh Thạnh, Bình Định": [
    "vĩnh hiệp, vĩnh thạnh, bình định",
    "vixnh hieejp, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Hoà Phú, Châu Thành, Kiên Giang": [
    "vĩnh hoà phú, châu thành, kiên giang",
    "vixnh hoaf phus, chaau thafnh, kieen giang"
  ],
  "Vĩnh Thanh Vân, Rạch Giá, Kiên Giang": [
    "vĩnh thanh vân, rạch giá, kiên giang",
    "vixnh thanh vaan, rajch gias, kieen giang"
  ],
  "Vĩnh Thịnh, Vĩnh Tường, Vĩnh Phúc": [
    "vĩnh thịnh, vĩnh tường, vĩnh phúc",
    "vixnh thijnh, vixnh tuwowfng, vixnh phusc"
  ],
  "Vạn Trạch, Bố Trạch, Quảng Bình": [
    "vạn trạch, bố trạch, quảng bình",
    "vajn trajch, boos trajch, quarng bifnh"
  ],
  "Xuân Dương, Thường Xuân, Thanh Hóa": [
    "xuân dương, thường xuân, thanh hóa",
    "xuaan duwowng, thuwowfng xuaan, thanh hosa"
  ],
  "Xuân Hồng, Xuân Trường, Nam Định": [
    "xuân hồng, xuân trường, nam định",
    "xuaan hoofng, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Ngọc, Xuân Trường, Nam Định": [
    "xuân ngọc, xuân trường, nam định",
    "xuaan ngojc, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Sơn Bắc, Đồng Xuân, Phú Yên": [
    "xuân sơn bắc, đồng xuân, phú yên",
    "xuaan sown bawsc, ddoofng xuaan, phus yeen"
  ],
  "Xuân Thiện, Thống Nhất, Đồng Nai": [
    "xuân thiện, thống nhất, đồng nai",
    "xuaan thieejn, thoosng nhaast, ddoofng nai"
  ],
  "Xuân Thành, Xuân Trường, Nam Định": [
    "xuân thành, xuân trường, nam định",
    "xuaan thafnh, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Thắng, Thường Xuân, Thanh Hóa": [
    "xuân thắng, thường xuân, thanh hóa",
    "xuaan thawsng, thuwowfng xuaan, thanh hosa"
  ],
  "Xuân Thủy, Xuân Trường, Nam Định": [
    "xuân thủy, xuân trường, nam định",
    "xuaan thury, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Tiến, Xuân Trường, Nam Định": [
    "xuân tiến, xuân trường, nam định",
    "xuaan tieesn, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Trạch, Bố Trạch, Quảng Bình": [
    "xuân trạch, bố trạch, quảng bình",
    "xuaan trajch, boos trajch, quarng bifnh"
  ],
  "Xuân Đỉnh, Bắc Từ Liêm, Hà Nội": [
    "xuân đỉnh, bắc từ liêm, hà nội",
    "xuaan ddirnh, bawsc tuwf lieem, haf nooji"
  ],
  "Ân Hảo Đông, Hoài Ân, Bình Định": [
    "ân hảo đông, hoài ân, bình định",
    "aan haro ddoong, hoafi aan, bifnh ddijnh"
  ],
  "Đa Phước, Bình Chánh, Hồ Chí Minh": [
    "đa phước, bình chánh, hồ chí minh",
    "dda phuwowsc, bifnh chasnh, hoof chis minh"
  ],
  "Điềm Mặc, Định Hóa, Thái Nguyên": [
    "điềm mặc, định hóa, thái nguyên",
    "ddieefm mawjc, ddijnh hosa, thasi nguyeen"
  ],
  "Điện Dương, Điện Bàn, Quảng Nam": [
    "điện dương, điện bàn, quảng nam",
    "ddieejn duwowng, ddieejn bafn, quarng nam"
  ],
  "Đoàn Thượng, Gia Lộc, Hải Dương": [
    "đoàn thượng, gia lộc, hải dương",
    "ddoafn thuwowjng, gia loojc, hari duwowng"
  ],
  "Đình Phùng, Kiến Xương, Thái Bình": [
    "đình phùng, kiến xương, thái bình",
    "ddifnh phufng, kieesn xuwowng, thasi bifnh"
  ],
  "Đông Cường, Đông Hưng, Thái Bình": [
    "đông cường, đông hưng, thái bình",
    "ddoong cuwowfng, ddoong huwng, thasi bifnh"
  ],
  "Đông Hòa Hiệp, Cái Bè, Tiền Giang": [
    "đông hòa hiệp, cái bè, tiền giang",
    "ddoong hofa hieejp, casi bef, tieefn giang"
  ],
  "Đông Ngạc, Bắc Từ Liêm, Hà Nội": [
    "đông ngạc, bắc từ liêm, hà nội",
    "ddoong ngajc, bawsc tuwf lieem, haf nooji"
  ],
  "Đông Phương, Đông Hưng, Thái Bình": [
    "đông phương, đông hưng, thái bình",
    "ddoong phuwowng, ddoong huwng, thasi bifnh"
  ],
  "Đông Phước, Châu Thành, Hậu Giang": [
    "đông phước, châu thành, hậu giang",
    "ddoong phuwowsc, chaau thafnh, haaju giang"
  ],
  "Đại Cường, Đại Lộc, Quảng Nam": [
    "đại cường, đại lộc, quảng nam",
    "ddaji cuwowfng, ddaji loojc, quarng nam"
  ],
  "Đại Hòa Lộc, Bình Đại, Bến Tre": [
    "đại hòa lộc, bình đại, bến tre",
    "ddaji hofa loojc, bifnh ddaji, beesn tre"
  ],
  "Định Biên, Định Hóa, Thái Nguyên": [
    "định biên, định hóa, thái nguyên",
    "ddijnh bieen, ddijnh hosa, thasi nguyeen"
  ],
  "Đồng Phú, Đồng Hới, Quảng Bình": [
    "đồng phú, đồng hới, quảng bình",
    "ddoofng phus, ddoofng howsi, quarng bifnh"
  ],
  "Đồng Sơn, Gò Công Tây, Tiền Giang": [
    "đồng sơn, gò công tây, tiền giang",
    "ddoofng sown, gof coong taay, tieefn giang"
  ],
  "Đồng Sơn, Đồng Hới, Quảng Bình": [
    "đồng sơn, đồng hới, quảng bình",
    "ddoofng sown, ddoofng howsi, quarng bifnh"
  ],
  "Đồng Thắng, Chợ Đồn, Bắc Kạn": [
    "đồng thắng, chợ đồn, bắc kạn",
    "ddoofng thawsng, chowj ddoofn, bawsc kajn"
  ],
  "Đồng Thắng, Đình Lập, Lạng Sơn": [
    "đồng thắng, đình lập, lạng sơn",
    "ddoofng thawsng, ddifnh laajp, lajng sown"
  ],
  "Đồng Tiến, Quỳnh Phụ, Thái Bình": [
    "đồng tiến, quỳnh phụ, thái bình",
    "ddoofng tieesn, quyfnh phuj, thasi bifnh"
  ],
  "Đồng Tâm, Đồng Phú, Bình Phước": [
    "đồng tâm, đồng phú, bình phước",
    "ddoofng taam, ddoofng phus, bifnh phuwowsc"
  ],
  "Đức Bình Đông, Sông Hinh, Phú Yên": [
    "đức bình đông, sông hinh, phú yên",
    "dduwsc bifnh ddoong, soong hinh, phus yeen"
  ],
  "Đức Chính, Cẩm Giàng, Hải Dương": [
    "đức chính, cẩm giàng, hải dương",
    "dduwsc chisnh, caarm giafng, hari duwowng"
  ],
  "Đức Lương, Đại Từ, Thái Nguyên": [
    "đức lương, đại từ, thái nguyên",
    "dduwsc luwowng, ddaji tuwf, thasi nguyeen"
  ],
  "Đức Nghĩa, Phan Thiết, Bình Thuận": [
    "đức nghĩa, phan thiết, bình thuận",
    "dduwsc nghixa, phan thieest, bifnh thuaajn"
  ],
  "Đức Nhuận, Mộ Đức, Quảng Ngãi": [
    "đức nhuận, mộ đức, quảng ngãi",
    "dduwsc nhuaajn, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Thạnh, Mộ Đức, Quảng Ngãi": [
    "đức thạnh, mộ đức, quảng ngãi",
    "dduwsc thajnh, mooj dduwsc, quarng ngaxi"
  ],
  "Đức Thắng, Mộ Đức, Quảng Ngãi": [
    "đức thắng, mộ đức, quảng ngãi",
    "dduwsc thawsng, mooj dduwsc, quarng ngaxi"
  ],
  " Hoàng Văn Thụ, Văn Lãng, Lạng Sơn": [
    " hoàng văn thụ, văn lãng, lạng sơn",
    " hoafng vawn thuj, vawn laxng, lajng sown"
  ],
  " Hòa Thuận, Giồng Riềng, Kiên Giang": [
    " hòa thuận, giồng riềng, kiên giang",
    " hofa thuaajn, gioofng rieefng, kieen giang"
  ],
  "Biển Bạch Đông, Thới Bình, Cà Mau": [
    "biển bạch đông, thới bình, cà mau",
    "bieern bajch ddoong, thowsi bifnh, caf mau"
  ],
  "Bình Chiểu, Thủ Đức, Hồ Chí Minh": [
    "bình chiểu, thủ đức, hồ chí minh",
    "bifnh chieeru, thur dduwsc, hoof chis minh"
  ],
  "Bình Dương, Đông Triều, Quảng Ninh": [
    "bình dương, đông triều, quảng ninh",
    "bifnh duwowng, ddoong trieefu, quarng ninh"
  ],
  "Bình Hàng Trung, Cao Lãnh, Đồng Tháp": [
    "bình hàng trung, cao lãnh, đồng tháp",
    "bifnh hafng trung, cao laxnh, ddoofng thasp"
  ],
  "Bình Mỹ, Bắc Tân Uyên, Bình Dương": [
    "bình mỹ, bắc tân uyên, bình dương",
    "bifnh myx, bawsc taan uyeen, bifnh duwowng"
  ],
  "Bình Phước Xuân, Chợ Mới, An Giang": [
    "bình phước xuân, chợ mới, an giang",
    "bifnh phuwowsc xuaan, chowj mowsi, an giang"
  ],
  "Bình Thạnh, Đức Trọng, Lâm Đồng": [
    "bình thạnh, đức trọng, lâm đồng",
    "bifnh thajnh, dduwsc trojng, laam ddoofng"
  ],
  "Bình Trưng Tây, Quận 2, Hồ Chí Minh": [
    "bình trưng tây, quận 2, hồ chí minh",
    "bifnh truwng taay, quaajn 2, hoof chis minh"
  ],
  "Bùi Hữu Nghĩa, Bình Thuỷ, Cần Thơ": [
    "bùi hữu nghĩa, bình thuỷ, cần thơ",
    "bufi huwxu nghixa, bifnh thuyr, caafn thow"
  ],
  "Bảo Cường, Định Hóa, Thái Nguyên": [
    "bảo cường, định hóa, thái nguyên",
    "baro cuwowfng, ddijnh hosa, thasi nguyeen"
  ],
  "Chánh Phú Hòa, Bến Cát, Bình Dương": [
    "chánh phú hòa, bến cát, bình dương",
    "chasnh phus hofa, beesn cast, bifnh duwowng"
  ],
  "Châu Quế Thượng, Văn Yên, Yên Bái": [
    "châu quế thượng, văn yên, yên bái",
    "chaau quees thuwowjng, vawn yeen, yeen basi"
  ],
  "Chương Dương, Thường Tín, Hà Nội": [
    "chương dương, thường tín, hà nội",
    "chuwowng duwowng, thuwowfng tisn, haf nooji"
  ],
  "Chương Dương, Đông Hưng, Thái Bình": [
    "chương dương, đông hưng, thái bình",
    "chuwowng duwowng, ddoong huwng, thasi bifnh"
  ],
  "Cái Tàu Hạ, Châu Thành, Đồng Tháp": [
    "cái tàu hạ, châu thành, đồng tháp",
    "casi tafu haj, chaau thafnh, ddoofng thasp"
  ],
  "Cảnh Hóa, Quảng Trạch, Quảng Bình": [
    "cảnh hóa, quảng trạch, quảng bình",
    "carnh hosa, quarng trajch, quarng bifnh"
  ],
  "Cầu Khởi, Dương Minh Châu, Tây Ninh": [
    "cầu khởi, dương minh châu, tây ninh",
    "caafu khowri, duwowng minh chaau, taay ninh"
  ],
  "Dầu Tiếng, Dầu Tiếng, Bình Dương": [
    "dầu tiếng, dầu tiếng, bình dương",
    "daafu tieesng, daafu tieesng, bifnh duwowng"
  ],
  "Dế Su Phình, Mù Căng Chải, Yên Bái": [
    "dế su phình, mù căng chải, yên bái",
    "dees su phifnh, muf cawng chari, yeen basi"
  ],
  "Gia Thuận, Gò Công Đông, Tiền Giang": [
    "gia thuận, gò công đông, tiền giang",
    "gia thuaajn, gof coong ddoong, tieefn giang"
  ],
  "Him Lam, Điện Biên Phủ, Điện Biên": [
    "him lam, điện biên phủ, điện biên",
    "him lam, ddieejn bieen phur, ddieejn bieen"
  ],
  "Hiệp An, Thủ Dầu Một, Bình Dương": [
    "hiệp an, thủ dầu một, bình dương",
    "hieejp an, thur daafu moojt, bifnh duwowng"
  ],
  "Hiệp Phước, Nhơn Trạch, Đồng Nai": [
    "hiệp phước, nhơn trạch, đồng nai",
    "hieejp phuwowsc, nhown trajch, ddoofng nai"
  ],
  "Hoà Phú, Thủ Dầu Một, Bình Dương": [
    "hoà phú, thủ dầu một, bình dương",
    "hoaf phus, thur daafu moojt, bifnh duwowng"
  ],
  "Hoài Thượng, Thuận Thành, Bắc Ninh": [
    "hoài thượng, thuận thành, bắc ninh",
    "hoafi thuwowjng, thuaajn thafnh, bawsc ninh"
  ],
  "Hoàng Văn Thụ, Bắc Giang, Bắc Giang": [
    "hoàng văn thụ, bắc giang, bắc giang",
    "hoafng vawn thuj, bawsc giang, bawsc giang"
  ],
  "Hoàng Văn Thụ, Chương Mỹ, Hà Nội": [
    "hoàng văn thụ, chương mỹ, hà nội",
    "hoafng vawn thuj, chuwowng myx, haf nooji"
  ],
  "Hoàng Văn Thụ, Lạng Sơn, Lạng Sơn": [
    "hoàng văn thụ, lạng sơn, lạng sơn",
    "hoafng vawn thuj, lajng sown, lajng sown"
  ],
  "Hoằng Phượng, Hoằng Hóa, Thanh Hóa": [
    "hoằng phượng, hoằng hóa, thanh hóa",
    "hoawfng phuwowjng, hoawfng hosa, thanh hosa"
  ],
  "Hoằng Trường, Hoằng Hóa, Thanh Hóa": [
    "hoằng trường, hoằng hóa, thanh hóa",
    "hoawfng truwowfng, hoawfng hosa, thanh hosa"
  ],
  "Huổi Lếnh, Mường Nhé, Điện Biên": [
    "huổi lếnh, mường nhé, điện biên",
    "huoori leesnh, muwowfng nhes, ddieejn bieen"
  ],
  "Huỳnh Hữu Nghĩa, Mỹ Tú, Sóc Trăng": [
    "huỳnh hữu nghĩa, mỹ tú, sóc trăng",
    "huyfnh huwxu nghixa, myx tus, sosc trawng"
  ],
  "Hàm Cần, Hàm Thuận Nam, Bình Thuận": [
    "hàm cần, hàm thuận nam, bình thuận",
    "hafm caafn, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Hành Phước, Nghĩa Hành, Quảng Ngãi": [
    "hành phước, nghĩa hành, quảng ngãi",
    "hafnh phuwowsc, nghixa hafnh, quarng ngaxi"
  ],
  "Hòa Cường Nam, Hải Châu, Đà Nẵng": [
    "hòa cường nam, hải châu, đà nẵng",
    "hofa cuwowfng nam, hari chaau, ddaf nawxng"
  ],
  "Hòa Hiệp Nam, Liên Chiểu, Đà Nẵng": [
    "hòa hiệp nam, liên chiểu, đà nẵng",
    "hofa hieejp nam, lieen chieeru, ddaf nawxng"
  ],
  "Hòa Khánh Nam, Liên Chiểu, Đà Nẵng": [
    "hòa khánh nam, liên chiểu, đà nẵng",
    "hofa khasnh nam, lieen chieeru, ddaf nawxng"
  ],
  "Hòa Khánh, Buôn Ma Thuột, Đắk Lắk": [
    "hòa khánh, buôn ma thuột, đắk lắk",
    "hofa khasnh, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Hòa Thuận Tây, Hải Châu, Đà Nẵng": [
    "hòa thuận tây, hải châu, đà nẵng",
    "hofa thuaajn taay, hari chaau, ddaf nawxng"
  ],
  "Hóa Thượng, Đồng Hỷ, Thái Nguyên": [
    "hóa thượng, đồng hỷ, thái nguyên",
    "hosa thuwowjng, ddoofng hyr, thasi nguyeen"
  ],
  "Hưng Thạnh, Tháp Mười, Đồng Tháp": [
    "hưng thạnh, tháp mười, đồng tháp",
    "huwng thajnh, thasp muwowfi, ddoofng thasp"
  ],
  "Hướng Linh, Hướng Hóa, Quảng Trị": [
    "hướng linh, hướng hóa, quảng trị",
    "huwowsng linh, huwowsng hosa, quarng trij"
  ],
  "Hướng Sơn, Hướng Hóa, Quảng Trị": [
    "hướng sơn, hướng hóa, quảng trị",
    "huwowsng sown, huwowsng hosa, quarng trij"
  ],
  "Hướng Tân, Hướng Hóa, Quảng Trị": [
    "hướng tân, hướng hóa, quảng trị",
    "huwowsng taan, huwowsng hosa, quarng trij"
  ],
  "Hải Thượng, Hải Lăng, Quảng Trị": [
    "hải thượng, hải lăng, quảng trị",
    "hari thuwowjng, hari lawng, quarng trij"
  ],
  "Hải Trường, Hải Lăng, Quảng Trị": [
    "hải trường, hải lăng, quảng trị",
    "hari truwowfng, hari lawng, quarng trij"
  ],
  "Hậu Thạnh Đông, Tân Thạnh, Long An": [
    "hậu thạnh đông, tân thạnh, long an",
    "haaju thajnh ddoong, taan thajnh, long an"
  ],
  "Hồng Hạ, A Lưới, Thừa Thiên Huế": [
    "hồng hạ, a lưới, thừa thiên huế",
    "hoofng haj, a luwowsi, thuwfa thieen huees"
  ],
  "Hồng Vân, A Lưới, Thừa Thiên Huế": [
    "hồng vân, a lưới, thừa thiên huế",
    "hoofng vaan, a luwowsi, thuwfa thieen huees"
  ],
  "Kháng Chiến, Tràng Định, Lạng Sơn": [
    "kháng chiến, tràng định, lạng sơn",
    "khasng chieesn, trafng ddijnh, lajng sown"
  ],
  "Khánh Thượng, Khánh Vĩnh, Khánh Hòa": [
    "khánh thượng, khánh vĩnh, khánh hòa",
    "khasnh thuwowjng, khasnh vixnh, khasnh hofa"
  ],
  "Kim Dinh, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "kim dinh, bà rịa, bà rịa - vũng tàu",
    "kim dinh, baf rija, baf rija - vuxng tafu"
  ],
  "Kiến Thành, Đắk R'Lấp, Đắk Nông": [
    "kiến thành, đắk r'lấp, đắk nông",
    "kieesn thafnh, ddawsk r'laasp, ddawsk noong"
  ],
  "Kiến Xương, Kiến Xương, Thái Bình": [
    "kiến xương, kiến xương, thái bình",
    "kieesn xuwowng, kieesn xuwowng, thasi bifnh"
  ],
  "Kiến Đức, Đắk R'Lấp, Đắk Nông": [
    "kiến đức, đắk r'lấp, đắk nông",
    "kieesn dduwsc, ddawsk r'laasp, ddawsk noong"
  ],
  "Lao Xả Phình, Tủa Chùa, Điện Biên": [
    "lao xả phình, tủa chùa, điện biên",
    "lao xar phifnh, tura chufa, ddieejn bieen"
  ],
  "Long Thạnh Mỹ, Quận 9, Hồ Chí Minh": [
    "long thạnh mỹ, quận 9, hồ chí minh",
    "long thajnh myx, quaajn 9, hoof chis minh"
  ],
  "Lâm Đớt, A Lưới, Thừa Thiên Huế": [
    "lâm đớt, a lưới, thừa thiên huế",
    "laam ddowst, a luwowsi, thuwfa thieen huees"
  ],
  "Lê Đại Hành, Hai Bà Trưng, Hà Nội": [
    "lê đại hành, hai bà trưng, hà nội",
    "lee ddaji hafnh, hai baf truwng, haf nooji"
  ],
  "Lý Thường Kiệt, Yên Mỹ, Hưng Yên": [
    "lý thường kiệt, yên mỹ, hưng yên",
    "lys thuwowfng kieejt, yeen myx, huwng yeen"
  ],
  "Lương Thiện, Sơn Dương, Tuyên Quang": [
    "lương thiện, sơn dương, tuyên quang",
    "luwowng thieejn, sown duwowng, tuyeen quang"
  ],
  "Lộc Hòa, Phú Lộc, Thừa Thiên Huế": [
    "lộc hòa, phú lộc, thừa thiên huế",
    "loojc hofa, phus loojc, thuwfa thieen huees"
  ],
  "Lộc Sơn, Phú Lộc, Thừa Thiên Huế": [
    "lộc sơn, phú lộc, thừa thiên huế",
    "loojc sown, phus loojc, thuwfa thieen huees"
  ],
  "Lộc Trì, Phú Lộc, Thừa Thiên Huế": [
    "lộc trì, phú lộc, thừa thiên huế",
    "loojc trif, phus loojc, thuwfa thieen huees"
  ],
  "Minh Thuận, U Minh Thượng, Kiên Giang": [
    "minh thuận, u minh thượng, kiên giang",
    "minh thuaajn, u minh thuwowjng, kieen giang"
  ],
  "Mường Chà, Mường Chà, Điện Biên": [
    "mường chà, mường chà, điện biên",
    "muwowfng chaf, muwowfng chaf, ddieejn bieen"
  ],
  "Mường Khong, Tuần Giáo, Điện Biên": [
    "mường khong, tuần giáo, điện biên",
    "muwowfng khong, tuaafn giaso, ddieejn bieen"
  ],
  "Mường Lói, Điện Biên, Điện Biên": [
    "mường lói, điện biên, điện biên",
    "muwowfng losi, ddieejn bieen, ddieejn bieen"
  ],
  "Mường Nhà, Điện Biên, Điện Biên": [
    "mường nhà, điện biên, điện biên",
    "muwowfng nhaf, ddieejn bieen, ddieejn bieen"
  ],
  "Mường Nhé, Mường Nhé, Điện Biên": [
    "mường nhé, mường nhé, điện biên",
    "muwowfng nhes, muwowfng nhes, ddieejn bieen"
  ],
  "Mường Thín, Tuần Giáo, Điện Biên": [
    "mường thín, tuần giáo, điện biên",
    "muwowfng thisn, tuaafn giaso, ddieejn bieen"
  ],
  "Mỹ Hạnh Đông, Cai Lậy, Tiền Giang": [
    "mỹ hạnh đông, cai lậy, tiền giang",
    "myx hajnh ddoong, cai laajy, tieefn giang"
  ],
  "Mỹ Phước Tây, Cai Lậy, Tiền Giang": [
    "mỹ phước tây, cai lậy, tiền giang",
    "myx phuwowsc taay, cai laajy, tieefn giang"
  ],
  "Na Son, Điện Biên Đông, Điện Biên": [
    "na son, điện biên đông, điện biên",
    "na son, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Nghĩa Chánh, Quảng Ngãi, Quảng Ngãi": [
    "nghĩa chánh, quảng ngãi, quảng ngãi",
    "nghixa chasnh, quarng ngaxi, quarng ngaxi"
  ],
  "Nguyễn Trung Trực, Ba Đình, Hà Nội": [
    "nguyễn trung trực, ba đình, hà nội",
    "nguyeexn trung truwjc, ba ddifnh, haf nooji"
  ],
  "Nguyệt Đức, Thuận Thành, Bắc Ninh": [
    "nguyệt đức, thuận thành, bắc ninh",
    "nguyeejt dduwsc, thuaajn thafnh, bawsc ninh"
  ],
  "Ngọc Phụng, Thường Xuân, Thanh Hóa": [
    "ngọc phụng, thường xuân, thanh hóa",
    "ngojc phujng, thuwowfng xuaan, thanh hosa"
  ],
  "Ngọc Thành, Giồng Riềng, Kiên Giang": [
    "ngọc thành, giồng riềng, kiên giang",
    "ngojc thafnh, gioofng rieefng, kieen giang"
  ],
  "Nhơn Nghĩa A, Châu Thành A, Hậu Giang": [
    "nhơn nghĩa a, châu thành a, hậu giang",
    "nhown nghixa a, chaau thafnh a, haaju giang"
  ],
  "Nong U, Điện Biên Đông, Điện Biên": [
    "nong u, điện biên đông, điện biên",
    "nong u, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Noong Luống, Điện Biên, Điện Biên": [
    "noong luống, điện biên, điện biên",
    "noong luoosng, ddieejn bieen, ddieejn bieen"
  ],
  "Noọng Hẹt, Điện Biên, Điện Biên": [
    "noọng hẹt, điện biên, điện biên",
    "noojng hejt, ddieejn bieen, ddieejn bieen"
  ],
  "Nặm Lịch, Mường Ảng, Điện Biên": [
    "nặm lịch, mường ảng, điện biên",
    "nawjm lijch, muwowfng arng, ddieejn bieen"
  ],
  "Phan Rí Thành, Bắc Bình, Bình Thuận": [
    "phan rí thành, bắc bình, bình thuận",
    "phan ris thafnh, bawsc bifnh, bifnh thuaajn"
  ],
  "Phong Thạnh Đông, Giá Rai, Bạc Liêu": [
    "phong thạnh đông, giá rai, bạc liêu",
    "phong thajnh ddoong, gias rai, bajc lieeu"
  ],
  "Phùng Chí Kiên, Bắc Kạn, Bắc Kạn": [
    "phùng chí kiên, bắc kạn, bắc kạn",
    "phufng chis kieen, bawsc kajn, bawsc kajn"
  ],
  "Phú Hòa, Thủ Dầu Một, Bình Dương": [
    "phú hòa, thủ dầu một, bình dương",
    "phus hofa, thur daafu moojt, bifnh duwowng"
  ],
  "Phú Lộc, Phú Lộc, Thừa Thiên Huế": [
    "phú lộc, phú lộc, thừa thiên huế",
    "phus loojc, phus loojc, thuwfa thieen huees"
  ],
  "Phú Mỹ, Thủ Dầu Một, Bình Dương": [
    "phú mỹ, thủ dầu một, bình dương",
    "phus myx, thur daafu moojt, bifnh duwowng"
  ],
  "Phú Thuận A, Hồng Ngự, Đồng Tháp": [
    "phú thuận a, hồng ngự, đồng tháp",
    "phus thuaajn a, hoofng nguwj, ddoofng thasp"
  ],
  "Phú Thuận B, Hồng Ngự, Đồng Tháp": [
    "phú thuận b, hồng ngự, đồng tháp",
    "phus thuaajn b, hoofng nguwj, ddoofng thasp"
  ],
  "Phú Tân, Thủ Dầu Một, Bình Dương": [
    "phú tân, thủ dầu một, bình dương",
    "phus taan, thur daafu moojt, bifnh duwowng"
  ],
  "Phú Đông, Tân Phú Đông, Tiền Giang": [
    "phú đông, tân phú đông, tiền giang",
    "phus ddoong, taan phus ddoong, tieefn giang"
  ],
  "Phương Bình, Phụng Hiệp, Hậu Giang": [
    "phương bình, phụng hiệp, hậu giang",
    "phuwowng bifnh, phujng hieejp, haaju giang"
  ],
  "Phước Chánh, Phước Sơn, Quảng Nam": [
    "phước chánh, phước sơn, quảng nam",
    "phuwowsc chasnh, phuwowsc sown, quarng nam"
  ],
  "Phước Hiệp, Phước Sơn, Quảng Nam": [
    "phước hiệp, phước sơn, quảng nam",
    "phuwowsc hieejp, phuwowsc sown, quarng nam"
  ],
  "Phước Hưng, Tuy Phước, Bình Định": [
    "phước hưng, tuy phước, bình định",
    "phuwowsc huwng, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Hải, Ninh Phước, Ninh Thuận": [
    "phước hải, ninh phước, ninh thuận",
    "phuwowsc hari, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Hậu, Ninh Phước, Ninh Thuận": [
    "phước hậu, ninh phước, ninh thuận",
    "phuwowsc haaju, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Hữu, Ninh Phước, Ninh Thuận": [
    "phước hữu, ninh phước, ninh thuận",
    "phuwowsc huwxu, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Khánh, Nhơn Trạch, Đồng Nai": [
    "phước khánh, nhơn trạch, đồng nai",
    "phuwowsc khasnh, nhown trajch, ddoofng nai"
  ],
  "Phước Lập, Tân Phước, Tiền Giang": [
    "phước lập, tân phước, tiền giang",
    "phuwowsc laajp, taan phuwowsc, tieefn giang"
  ],
  "Phước Lộc, Tuy Phước, Bình Định": [
    "phước lộc, tuy phước, bình định",
    "phuwowsc loojc, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Quang, Tuy Phước, Bình Định": [
    "phước quang, tuy phước, bình định",
    "phuwowsc quang, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Thành, Phước Sơn, Quảng Nam": [
    "phước thành, phước sơn, quảng nam",
    "phuwowsc thafnh, phuwowsc sown, quarng nam"
  ],
  "Phước Thái, Ninh Phước, Ninh Thuận": [
    "phước thái, ninh phước, ninh thuận",
    "phuwowsc thasi, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Tân, Phú Riềng, Bình Phước": [
    "phước tân, phú riềng, bình phước",
    "phuwowsc taan, phus rieefng, bifnh phuwowsc"
  ],
  "Phước Vĩnh An, Củ Chi, Hồ Chí Minh": [
    "phước vĩnh an, củ chi, hồ chí minh",
    "phuwowsc vixnh an, cur chi, hoof chis minh"
  ],
  "Phước Vĩnh Tây, Cần Giuộc, Long An": [
    "phước vĩnh tây, cần giuộc, long an",
    "phuwowsc vixnh taay, caafn giuoojc, long an"
  ],
  "Phước Đức, Phước Sơn, Quảng Nam": [
    "phước đức, phước sơn, quảng nam",
    "phuwowsc dduwsc, phuwowsc sown, quarng nam"
  ],
  "Phường 01, Bình Thạnh, Hồ Chí Minh": [
    "phường 01, bình thạnh, hồ chí minh",
    "phuwowfng 01, bifnh thajnh, hoof chis minh"
  ],
  "Phường 02, Bình Thạnh, Hồ Chí Minh": [
    "phường 02, bình thạnh, hồ chí minh",
    "phuwowfng 02, bifnh thajnh, hoof chis minh"
  ],
  "Phường 03, Bình Thạnh, Hồ Chí Minh": [
    "phường 03, bình thạnh, hồ chí minh",
    "phuwowfng 03, bifnh thajnh, hoof chis minh"
  ],
  "Phường 05, Bình Thạnh, Hồ Chí Minh": [
    "phường 05, bình thạnh, hồ chí minh",
    "phuwowfng 05, bifnh thajnh, hoof chis minh"
  ],
  "Phường 06, Bình Thạnh, Hồ Chí Minh": [
    "phường 06, bình thạnh, hồ chí minh",
    "phuwowfng 06, bifnh thajnh, hoof chis minh"
  ],
  "Phường 07, Bình Thạnh, Hồ Chí Minh": [
    "phường 07, bình thạnh, hồ chí minh",
    "phuwowfng 07, bifnh thajnh, hoof chis minh"
  ],
  "Phường 11, Bình Thạnh, Hồ Chí Minh": [
    "phường 11, bình thạnh, hồ chí minh",
    "phuwowfng 11, bifnh thajnh, hoof chis minh"
  ],
  "Phường 12, Bình Thạnh, Hồ Chí Minh": [
    "phường 12, bình thạnh, hồ chí minh",
    "phuwowfng 12, bifnh thajnh, hoof chis minh"
  ],
  "Phường 13, Bình Thạnh, Hồ Chí Minh": [
    "phường 13, bình thạnh, hồ chí minh",
    "phuwowfng 13, bifnh thajnh, hoof chis minh"
  ],
  "Phường 14, Bình Thạnh, Hồ Chí Minh": [
    "phường 14, bình thạnh, hồ chí minh",
    "phuwowfng 14, bifnh thajnh, hoof chis minh"
  ],
  "Phường 15, Bình Thạnh, Hồ Chí Minh": [
    "phường 15, bình thạnh, hồ chí minh",
    "phuwowfng 15, bifnh thajnh, hoof chis minh"
  ],
  "Phường 17, Bình Thạnh, Hồ Chí Minh": [
    "phường 17, bình thạnh, hồ chí minh",
    "phuwowfng 17, bifnh thajnh, hoof chis minh"
  ],
  "Phường 19, Bình Thạnh, Hồ Chí Minh": [
    "phường 19, bình thạnh, hồ chí minh",
    "phuwowfng 19, bifnh thajnh, hoof chis minh"
  ],
  "Phường 21, Bình Thạnh, Hồ Chí Minh": [
    "phường 21, bình thạnh, hồ chí minh",
    "phuwowfng 21, bifnh thajnh, hoof chis minh"
  ],
  "Phường 22, Bình Thạnh, Hồ Chí Minh": [
    "phường 22, bình thạnh, hồ chí minh",
    "phuwowfng 22, bifnh thajnh, hoof chis minh"
  ],
  "Phường 24, Bình Thạnh, Hồ Chí Minh": [
    "phường 24, bình thạnh, hồ chí minh",
    "phuwowfng 24, bifnh thajnh, hoof chis minh"
  ],
  "Phường 25, Bình Thạnh, Hồ Chí Minh": [
    "phường 25, bình thạnh, hồ chí minh",
    "phuwowfng 25, bifnh thajnh, hoof chis minh"
  ],
  "Phường 26, Bình Thạnh, Hồ Chí Minh": [
    "phường 26, bình thạnh, hồ chí minh",
    "phuwowfng 26, bifnh thajnh, hoof chis minh"
  ],
  "Phường 27, Bình Thạnh, Hồ Chí Minh": [
    "phường 27, bình thạnh, hồ chí minh",
    "phuwowfng 27, bifnh thajnh, hoof chis minh"
  ],
  "Phường 28, Bình Thạnh, Hồ Chí Minh": [
    "phường 28, bình thạnh, hồ chí minh",
    "phuwowfng 28, bifnh thajnh, hoof chis minh"
  ],
  "Phường Đúc, Huế, Thừa Thiên Huế": [
    "phường đúc, huế, thừa thiên huế",
    "phuwowfng ddusc, huees, thuwfa thieen huees"
  ],
  "Phạm Văn Cội, Củ Chi, Hồ Chí Minh": [
    "phạm văn cội, củ chi, hồ chí minh",
    "phajm vawn cooji, cur chi, hoof chis minh"
  ],
  "Phổ Cường, Đức Phổ, Quảng Ngãi": [
    "phổ cường, đức phổ, quảng ngãi",
    "phoor cuwowfng, dduwsc phoor, quarng ngaxi"
  ],
  "Phụng Hiệp, Phụng Hiệp, Hậu Giang": [
    "phụng hiệp, phụng hiệp, hậu giang",
    "phujng hieejp, phujng hieejp, haaju giang"
  ],
  "Quyết Thắng, Sơn Dương, Tuyên Quang": [
    "quyết thắng, sơn dương, tuyên quang",
    "quyeest thawsng, sown duwowng, tuyeen quang"
  ],
  "Quán Triều, Thái Nguyên, Thái Nguyên": [
    "quán triều, thái nguyên, thái nguyên",
    "quasn trieefu, thasi nguyeen, thasi nguyeen"
  ],
  "Quảng Chính, Quảng Xương, Thanh Hóa": [
    "quảng chính, quảng xương, thanh hóa",
    "quarng chisnh, quarng xuwowng, thanh hosa"
  ],
  "Quảng Kim, Quảng Trạch, Quảng Bình": [
    "quảng kim, quảng trạch, quảng bình",
    "quarng kim, quarng trajch, quarng bifnh"
  ],
  "Quảng Ngọc, Quảng Xương, Thanh Hóa": [
    "quảng ngọc, quảng xương, thanh hóa",
    "quarng ngojc, quarng xuwowng, thanh hosa"
  ],
  "Quảng Thanh, Thuỷ Nguyên, Hải Phòng": [
    "quảng thanh, thuỷ nguyên, hải phòng",
    "quarng thanh, thuyr nguyeen, hari phofng"
  ],
  "Quảng Đức, Quảng Xương, Thanh Hóa": [
    "quảng đức, quảng xương, thanh hóa",
    "quarng dduwsc, quarng xuwowng, thanh hosa"
  ],
  "Quỳnh Nguyên, Quỳnh Phụ, Thái Bình": [
    "quỳnh nguyên, quỳnh phụ, thái bình",
    "quyfnh nguyeen, quyfnh phuj, thasi bifnh"
  ],
  "Sen Thượng, Mường Nhé, Điện Biên": [
    "sen thượng, mường nhé, điện biên",
    "sen thuwowjng, muwowfng nhes, ddieejn bieen"
  ],
  "Sơn Thủy, A Lưới, Thừa Thiên Huế": [
    "sơn thủy, a lưới, thừa thiên huế",
    "sown thury, a luwowsi, thuwfa thieen huees"
  ],
  "Sịa, Quảng Điền, Thừa Thiên Huế": [
    "sịa, quảng điền, thừa thiên huế",
    "sija, quarng ddieefn, thuwfa thieen huees"
  ],
  "Thanh Tuyền, Dầu Tiếng, Bình Dương": [
    "thanh tuyền, dầu tiếng, bình dương",
    "thanh tuyeefn, daafu tieesng, bifnh duwowng"
  ],
  "Thanh Xương, Điện Biên, Điện Biên": [
    "thanh xương, điện biên, điện biên",
    "thanh xuwowng, ddieejn bieen, ddieejn bieen"
  ],
  "Thuận Lợi, Đồng Phú, Bình Phước": [
    "thuận lợi, đồng phú, bình phước",
    "thuaajn lowji, ddoofng phus, bifnh phuwowsc"
  ],
  "Thuận Thiên, Kiến Thuỵ, Hải Phòng": [
    "thuận thiên, kiến thuỵ, hải phòng",
    "thuaajn thieen, kieesn thuyj, hari phofng"
  ],
  "Thuỵ Hương, Kiến Thuỵ, Hải Phòng": [
    "thuỵ hương, kiến thuỵ, hải phòng",
    "thuyj huwowng, kieesn thuyj, hari phofng"
  ],
  "Thài Phìn Tủng, Đồng Văn, Hà Giang": [
    "thài phìn tủng, đồng văn, hà giang",
    "thafi phifn turng, ddoofng vawn, haf giang"
  ],
  "Thăng Phước, Hiệp Đức, Quảng Nam": [
    "thăng phước, hiệp đức, quảng nam",
    "thawng phuwowsc, hieejp dduwsc, quarng nam"
  ],
  "Thường Thắng, Hiệp Hòa, Bắc Giang": [
    "thường thắng, hiệp hòa, bắc giang",
    "thuwowfng thawsng, hieejp hofa, bawsc giang"
  ],
  "Thượng Bằng La, Văn Chấn, Yên Bái": [
    "thượng bằng la, văn chấn, yên bái",
    "thuwowjng bawfng la, vawn chaasn, yeen basi"
  ],
  "Thượng Cát, Bắc Từ Liêm, Hà Nội": [
    "thượng cát, bắc từ liêm, hà nội",
    "thuwowjng cast, bawsc tuwf lieem, haf nooji"
  ],
  "Thượng Đình, Phú Bình, Thái Nguyên": [
    "thượng đình, phú bình, thái nguyên",
    "thuwowjng ddifnh, phus bifnh, thasi nguyeen"
  ],
  "Thạch Khôi, Hải Dương, Hải Dương": [
    "thạch khôi, hải dương, hải dương",
    "thajch khooi, hari duwowng, hari duwowng"
  ],
  "Thạch Quảng, Thạch Thành, Thanh Hóa": [
    "thạch quảng, thạch thành, thanh hóa",
    "thajch quarng, thajch thafnh, thanh hosa"
  ],
  "Thạch Định, Thạch Thành, Thanh Hóa": [
    "thạch định, thạch thành, thanh hóa",
    "thajch ddijnh, thajch thafnh, thanh hosa"
  ],
  "Thạch Đồng, Thạch Thành, Thanh Hóa": [
    "thạch đồng, thạch thành, thanh hóa",
    "thajch ddoofng, thajch thafnh, thanh hosa"
  ],
  "Thạnh Bình, Giồng Riềng, Kiên Giang": [
    "thạnh bình, giồng riềng, kiên giang",
    "thajnh bifnh, gioofng rieefng, kieen giang"
  ],
  "Thạnh Hưng, Giồng Riềng, Kiên Giang": [
    "thạnh hưng, giồng riềng, kiên giang",
    "thajnh huwng, gioofng rieefng, kieen giang"
  ],
  "Thạnh Lộc, Giồng Riềng, Kiên Giang": [
    "thạnh lộc, giồng riềng, kiên giang",
    "thajnh loojc, gioofng rieefng, kieen giang"
  ],
  "Thạnh Lợi, Tháp Mười, Đồng Tháp": [
    "thạnh lợi, tháp mười, đồng tháp",
    "thajnh lowji, thasp muwowfi, ddoofng thasp"
  ],
  "Thạnh Phước, Tân Uyên, Bình Dương": [
    "thạnh phước, tân uyên, bình dương",
    "thajnh phuwowsc, taan uyeen, bifnh duwowng"
  ],
  "Thạnh Trị, Gò Công Tây, Tiền Giang": [
    "thạnh trị, gò công tây, tiền giang",
    "thajnh trij, gof coong taay, tieefn giang"
  ],
  "Thạnh Yên, U Minh Thượng, Kiên Giang": [
    "thạnh yên, u minh thượng, kiên giang",
    "thajnh yeen, u minh thuwowjng, kieen giang"
  ],
  "Thịnh Vượng, Nguyên Bình, Cao Bằng": [
    "thịnh vượng, nguyên bình, cao bằng",
    "thijnh vuwowjng, nguyeen bifnh, cao bawfng"
  ],
  "Thịnh Đán, Thái Nguyên, Thái Nguyên": [
    "thịnh đán, thái nguyên, thái nguyên",
    "thijnh ddasn, thasi nguyeen, thasi nguyeen"
  ],
  "Thới Tam Thôn, Hóc Môn, Hồ Chí Minh": [
    "thới tam thôn, hóc môn, hồ chí minh",
    "thowsi tam thoon, hosc moon, hoof chis minh"
  ],
  "Thụy Trường, Thái Thụy, Thái Bình": [
    "thụy trường, thái thụy, thái bình",
    "thujy truwowfng, thasi thujy, thasi bifnh"
  ],
  "Tiến Hưng, Đồng Xoài, Bình Phước": [
    "tiến hưng, đồng xoài, bình phước",
    "tieesn huwng, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Tiền Tiến, Hải Dương, Hải Dương": [
    "tiền tiến, hải dương, hải dương",
    "tieefn tieesn, hari duwowng, hari duwowng"
  ],
  "Triệu Giang, Triệu Phong, Quảng Trị": [
    "triệu giang, triệu phong, quảng trị",
    "trieeju giang, trieeju phong, quarng trij"
  ],
  "Triệu Lăng, Triệu Phong, Quảng Trị": [
    "triệu lăng, triệu phong, quảng trị",
    "trieeju lawng, trieeju phong, quarng trij"
  ],
  "Triệu Trung, Triệu Phong, Quảng Trị": [
    "triệu trung, triệu phong, quảng trị",
    "trieeju trung, trieeju phong, quarng trij"
  ],
  "Triệu Độ, Triệu Phong, Quảng Trị": [
    "triệu độ, triệu phong, quảng trị",
    "trieeju ddooj, trieeju phong, quarng trij"
  ],
  "Trung Thành Tây,  Vũng Liêm, Vĩnh Long": [
    "trung thành tây,  vũng liêm, vĩnh long",
    "trung thafnh taay,  vuxng lieem, vixnh long"
  ],
  "Truông Mít, Dương Minh Châu, Tây Ninh": [
    "truông mít, dương minh châu, tây ninh",
    "truoong mist, duwowng minh chaau, taay ninh"
  ],
  "Trương Định, Hai Bà Trưng, Hà Nội": [
    "trương định, hai bà trưng, hà nội",
    "truwowng ddijnh, hai baf truwng, haf nooji"
  ],
  "Trường Sơn, Quảng Ninh, Quảng Bình": [
    "trường sơn, quảng ninh, quảng bình",
    "truwowfng sown, quarng ninh, quarng bifnh"
  ],
  "Trường Thạnh, Quận 9, Hồ Chí Minh": [
    "trường thạnh, quận 9, hồ chí minh",
    "truwowfng thajnh, quaajn 9, hoof chis minh"
  ],
  "Trừ Văn Thố, Bàu Bàng, Bình Dương": [
    "trừ văn thố, bàu bàng, bình dương",
    "truwf vawn thoos, bafu bafng, bifnh duwowng"
  ],
  "Tân Bình, Bắc Tân Uyên, Bình Dương": [
    "tân bình, bắc tân uyên, bình dương",
    "taan bifnh, bawsc taan uyeen, bifnh duwowng"
  ],
  "Tân Công Chí, Tân Hồng, Đồng Tháp": [
    "tân công chí, tân hồng, đồng tháp",
    "taan coong chis, taan hoofng, ddoofng thasp"
  ],
  "Tân Hòa Tây, Tân Phước, Tiền Giang": [
    "tân hòa tây, tân phước, tiền giang",
    "taan hofa taay, taan phuwowsc, tieefn giang"
  ],
  "Tân Khánh Hòa, Giang Thành, Kiên Giang": [
    "tân khánh hòa, giang thành, kiên giang",
    "taan khasnh hofa, giang thafnh, kieen giang"
  ],
  "Tân Khánh Đông, Sa Đéc, Đồng Tháp": [
    "tân khánh đông, sa đéc, đồng tháp",
    "taan khasnh ddoong, sa ddesc, ddoofng thasp"
  ],
  "Tân Lý Đông, Châu Thành, Tiền Giang": [
    "tân lý đông, châu thành, tiền giang",
    "taan lys ddoong, chaau thafnh, tieefn giang"
  ],
  "Tân Lập, Bắc Tân Uyên, Bình Dương": [
    "tân lập, bắc tân uyên, bình dương",
    "taan laajp, bawsc taan uyeen, bifnh duwowng"
  ],
  "Tân Lập, Hàm Thuận Nam, Bình Thuận": [
    "tân lập, hàm thuận nam, bình thuận",
    "taan laajp, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Tân Phước, Đồng Phú, Bình Phước": [
    "tân phước, đồng phú, bình phước",
    "taan phuwowsc, ddoofng phus, bifnh phuwowsc"
  ],
  "Tân Quới Trung,  Vũng Liêm, Vĩnh Long": [
    "tân quới trung,  vũng liêm, vĩnh long",
    "taan quowsi trung,  vuxng lieem, vixnh long"
  ],
  "Tân Thanh Tây, Mỏ Cày Bắc, Bến Tre": [
    "tân thanh tây, mỏ cày bắc, bến tre",
    "taan thanh taay, mor cafy bawsc, beesn tre"
  ],
  "Tân Thiện, Đồng Xoài, Bình Phước": [
    "tân thiện, đồng xoài, bình phước",
    "taan thieejn, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Tân Thuận Tây, Cao Lãnh, Đồng Tháp": [
    "tân thuận tây, cao lãnh, đồng tháp",
    "taan thuaajn taay, cao laxnh, ddoofng thasp"
  ],
  "Tân Thuận Tây, Quận 7, Hồ Chí Minh": [
    "tân thuận tây, quận 7, hồ chí minh",
    "taan thuaajn taay, quaajn 7, hoof chis minh"
  ],
  "Tân Thành, Buôn Ma Thuột, Đắk Lắk": [
    "tân thành, buôn ma thuột, đắk lắk",
    "taan thafnh, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Tân Thành, Gò Công Đông, Tiền Giang": [
    "tân thành, gò công đông, tiền giang",
    "taan thafnh, gof coong ddoong, tieefn giang"
  ],
  "Tân Thông Hội, Củ Chi, Hồ Chí Minh": [
    "tân thông hội, củ chi, hồ chí minh",
    "taan thoong hooji, cur chi, hoof chis minh"
  ],
  "Tân Thạnh Tây, Củ Chi, Hồ Chí Minh": [
    "tân thạnh tây, củ chi, hồ chí minh",
    "taan thajnh taay, cur chi, hoof chis minh"
  ],
  "Tân Thới Hòa, Tân Phú, Hồ Chí Minh": [
    "tân thới hòa, tân phú, hồ chí minh",
    "taan thowsi hofa, taan phus, hoof chis minh"
  ],
  "Tân Thới Nhì, Hóc Môn, Hồ Chí Minh": [
    "tân thới nhì, hóc môn, hồ chí minh",
    "taan thowsi nhif, hosc moon, hoof chis minh"
  ],
  "Tân Thới, Tân Phú Đông, Tiền Giang": [
    "tân thới, tân phú đông, tiền giang",
    "taan thowsi, taan phus ddoong, tieefn giang"
  ],
  "Tân Tiến, Buôn Ma Thuột, Đắk Lắk": [
    "tân tiến, buôn ma thuột, đắk lắk",
    "taan tieesn, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Tân Trường, Cẩm Giàng, Hải Dương": [
    "tân trường, cẩm giàng, hải dương",
    "taan truwowfng, caarm giafng, hari duwowng"
  ],
  "Tân Đông, Gò Công Đông, Tiền Giang": [
    "tân đông, gò công đông, tiền giang",
    "taan ddoong, gof coong ddoong, tieefn giang"
  ],
  "Tân Đồng, Đồng Xoài, Bình Phước": [
    "tân đồng, đồng xoài, bình phước",
    "taan ddoofng, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Tích Lương, Thái Nguyên, Thái Nguyên": [
    "tích lương, thái nguyên, thái nguyên",
    "tisch luwowng, thasi nguyeen, thasi nguyeen"
  ],
  "Tạ An Khương  Nam, Đầm Dơi, Cà Mau": [
    "tạ an khương  nam, đầm dơi, cà mau",
    "taj an khuwowng  nam, ddaafm dowi, caf mau"
  ],
  "Tả Gia Khâu, Mường Khương, Lào Cai": [
    "tả gia khâu, mường khương, lào cai",
    "tar gia khaau, muwowfng khuwowng, lafo cai"
  ],
  "Vang Quới Đông, Bình Đại, Bến Tre": [
    "vang quới đông, bình đại, bến tre",
    "vang quowsi ddoong, bifnh ddaji, beesn tre"
  ],
  "Vinh Hưng, Phú Lộc, Thừa Thiên Huế": [
    "vinh hưng, phú lộc, thừa thiên huế",
    "vinh huwng, phus loojc, thuwfa thieen huees"
  ],
  "Vĩnh Bình Nam, Vĩnh Thuận, Kiên Giang": [
    "vĩnh bình nam, vĩnh thuận, kiên giang",
    "vixnh bifnh nam, vixnh thuaajn, kieen giang"
  ],
  "Vĩnh Hòa Hưng Nam, Gò Quao, Kiên Giang": [
    "vĩnh hòa hưng nam, gò quao, kiên giang",
    "vixnh hofa huwng nam, gof quao, kieen giang"
  ],
  "Vĩnh Lộc A, Bình Chánh, Hồ Chí Minh": [
    "vĩnh lộc a, bình chánh, hồ chí minh",
    "vixnh loojc a, bifnh chasnh, hoof chis minh"
  ],
  "Vĩnh Lộc B, Bình Chánh, Hồ Chí Minh": [
    "vĩnh lộc b, bình chánh, hồ chí minh",
    "vixnh loojc b, bifnh chasnh, hoof chis minh"
  ],
  "Vĩnh Phú Tây, Phước Long, Bạc Liêu": [
    "vĩnh phú tây, phước long, bạc liêu",
    "vixnh phus taay, phuwowsc long, bajc lieeu"
  ],
  "Vĩnh Thuận, Vĩnh Thạnh, Bình Định": [
    "vĩnh thuận, vĩnh thạnh, bình định",
    "vixnh thuaajn, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Thạnh, Giồng Riềng, Kiên Giang": [
    "vĩnh thạnh, giồng riềng, kiên giang",
    "vixnh thajnh, gioofng rieefng, kieen giang"
  ],
  "Vĩnh Thạnh, Vĩnh Thạnh, Bình Định": [
    "vĩnh thạnh, vĩnh thạnh, bình định",
    "vixnh thajnh, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Thịnh, Vĩnh Thạnh, Bình Định": [
    "vĩnh thịnh, vĩnh thạnh, bình định",
    "vixnh thijnh, vixnh thajnh, bifnh ddijnh"
  ],
  "Vĩnh Tường, Vĩnh Tường, Vĩnh Phúc": [
    "vĩnh tường, vĩnh tường, vĩnh phúc",
    "vixnh tuwowfng, vixnh tuwowfng, vixnh phusc"
  ],
  "Ân Tường Tây, Hoài Ân, Bình Định": [
    "ân tường tây, hoài ân, bình định",
    "aan tuwowfng taay, hoafi aan, bifnh ddijnh"
  ],
  "Điền Thượng, Bá Thước, Thanh Hóa": [
    "điền thượng, bá thước, thanh hóa",
    "ddieefn thuwowjng, bas thuwowsc, thanh hosa"
  ],
  "Điện Phương, Điện Bàn, Quảng Nam": [
    "điện phương, điện bàn, quảng nam",
    "ddieejn phuwowng, ddieejn bafn, quarng nam"
  ],
  "Điện Phước, Điện Bàn, Quảng Nam": [
    "điện phước, điện bàn, quảng nam",
    "ddieejn phuwowsc, ddieejn bafn, quarng nam"
  ],
  "Đông Sơn, A Lưới, Thừa Thiên Huế": [
    "đông sơn, a lưới, thừa thiên huế",
    "ddoong sown, a luwowsi, thuwfa thieen huees"
  ],
  "Đại Phước, Nhơn Trạch, Đồng Nai": [
    "đại phước, nhơn trạch, đồng nai",
    "ddaji phuwowsc, nhown trajch, ddoofng nai"
  ],
  "Đại Trạch, Bố Trạch, Quảng Bình": [
    "đại trạch, bố trạch, quảng bình",
    "ddaji trajch, boos trajch, quarng bifnh"
  ],
  "Đại Đồng, Kiến Thuỵ, Hải Phòng": [
    "đại đồng, kiến thuỵ, hải phòng",
    "ddaji ddoofng, kieesn thuyj, hari phofng"
  ],
  "Đại Đồng, Tràng Định, Lạng Sơn": [
    "đại đồng, tràng định, lạng sơn",
    "ddaji ddoofng, trafng ddijnh, lajng sown"
  ],
  "Đại Đồng, Vĩnh Tường, Vĩnh Phúc": [
    "đại đồng, vĩnh tường, vĩnh phúc",
    "ddaji ddoofng, vixnh tuwowfng, vixnh phusc"
  ],
  "Đạo Nghĩa, Đắk R'Lấp, Đắk Nông": [
    "đạo nghĩa, đắk r'lấp, đắk nông",
    "ddajo nghixa, ddawsk r'laasp, ddawsk noong"
  ],
  "Định Thành A, Đông Hải, Bạc Liêu": [
    "định thành a, đông hải, bạc liêu",
    "ddijnh thafnh a, ddoong hari, bajc lieeu"
  ],
  "Đồng Bẩm, Thái Nguyên, Thái Nguyên": [
    "đồng bẩm, thái nguyên, thái nguyên",
    "ddoofng baarm, thasi nguyeen, thasi nguyeen"
  ],
  "Đồng Hải, Đồng Hới, Quảng Bình": [
    "đồng hải, đồng hới, quảng bình",
    "ddoofng hari, ddoofng howsi, quarng bifnh"
  ],
  "Đồng Liên, Thái Nguyên, Thái Nguyên": [
    "đồng liên, thái nguyên, thái nguyên",
    "ddoofng lieen, thasi nguyeen, thasi nguyeen"
  ],
  "Đồng Quang, Thái Nguyên, Thái Nguyên": [
    "đồng quang, thái nguyên, thái nguyên",
    "ddoofng quang, thasi nguyeen, thasi nguyeen"
  ],
  "Động Đạt, Phú Lương, Thái Nguyên": [
    "động đạt, phú lương, thái nguyên",
    "ddoojng ddajt, phus luwowng, thasi nguyeen"
  ],
  "Đức Chính, Đông Triều, Quảng Ninh": [
    "đức chính, đông triều, quảng ninh",
    "dduwsc chisnh, ddoong trieefu, quarng ninh"
  ],
  "Đức Hòa Thượng, Đức Hòa, Long An": [
    "đức hòa thượng, đức hòa, long an",
    "dduwsc hofa thuwowjng, dduwsc hofa, long an"
  ],
  "Đức Thắng, Bắc Từ Liêm, Hà Nội": [
    "đức thắng, bắc từ liêm, hà nội",
    "dduwsc thawsng, bawsc tuwf lieem, haf nooji"
  ],
  "Đức Thắng, Phan Thiết, Bình Thuận": [
    "đức thắng, phan thiết, bình thuận",
    "dduwsc thawsng, phan thieest, bifnh thuaajn"
  ],
  "Đức Trạch, Bố Trạch, Quảng Bình": [
    "đức trạch, bố trạch, quảng bình",
    "dduwsc trajch, boos trajch, quarng bifnh"
  ],
  "An Minh Bắc, U Minh Thượng, Kiên Giang": [
    "an minh bắc, u minh thượng, kiên giang",
    "an minh bawsc, u minh thuwowjng, kieen giang"
  ],
  "An Phú Thuận, Châu Thành, Đồng Tháp": [
    "an phú thuận, châu thành, đồng tháp",
    "an phus thuaajn, chaau thafnh, ddoofng thasp"
  ],
  "An Thạnh Thủy, Chợ Gạo, Tiền Giang": [
    "an thạnh thủy, chợ gạo, tiền giang",
    "an thajnh thury, chowj gajo, tieefn giang"
  ],
  "An Thạnh Đông, Cù Lao Dung, Sóc Trăng": [
    "an thạnh đông, cù lao dung, sóc trăng",
    "an thajnh ddoong, cuf lao dung, sosc trawng"
  ],
  "Bình Hưng Hòa, Bình Tân, Hồ Chí Minh": [
    "bình hưng hòa, bình tân, hồ chí minh",
    "bifnh huwng hofa, bifnh taan, hoof chis minh"
  ],
  "Bình Nghị, Gò Công Đông, Tiền Giang": [
    "bình nghị, gò công đông, tiền giang",
    "bifnh nghij, gof coong ddoong, tieefn giang"
  ],
  "Bình Thắng, Bù Gia Mập, Bình Phước": [
    "bình thắng, bù gia mập, bình phước",
    "bifnh thawsng, buf gia maajp, bifnh phuwowsc"
  ],
  "Bình Định Nam, Thăng Bình, Quảng Nam": [
    "bình định nam, thăng bình, quảng nam",
    "bifnh ddijnh nam, thawng bifnh, quarng nam"
  ],
  "Bù Gia Mập, Bù Gia Mập, Bình Phước": [
    "bù gia mập, bù gia mập, bình phước",
    "buf gia maajp, buf gia maajp, bifnh phuwowsc"
  ],
  "Chi Lăng Bắc, Thanh Miện, Hải Dương": [
    "chi lăng bắc, thanh miện, hải dương",
    "chi lawng bawsc, thanh mieejn, hari duwowng"
  ],
  "Chiềng Đông, Tuần Giáo, Điện Biên": [
    "chiềng đông, tuần giáo, điện biên",
    "chieefng ddoong, tuaafn giaso, ddieejn bieen"
  ],
  "Châu Pha, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "châu pha, phú mỹ, bà rịa - vũng tàu",
    "chaau pha, phus myx, baf rija - vuxng tafu"
  ],
  "Cây Trường II, Bàu Bàng, Bình Dương": [
    "cây trường ii, bàu bàng, bình dương",
    "caay truwowfng ii, bafu bafng, bifnh duwowng"
  ],
  "Dưỡng Điềm, Châu Thành, Tiền Giang": [
    "dưỡng điềm, châu thành, tiền giang",
    "duwowxng ddieefm, chaau thafnh, tieefn giang"
  ],
  "Dịch Vọng Hậu, Cầu Giấy, Hà Nội": [
    "dịch vọng hậu, cầu giấy, hà nội",
    "dijch vojng haaju, caafu giaasy, haf nooji"
  ],
  "Giang Hải, Phú Lộc, Thừa Thiên Huế": [
    "giang hải, phú lộc, thừa thiên huế",
    "giang hari, phus loojc, thuwfa thieen huees"
  ],
  "Hiệp Thạnh, Đức Trọng, Lâm Đồng": [
    "hiệp thạnh, đức trọng, lâm đồng",
    "hieejp thajnh, dduwsc trojng, laam ddoofng"
  ],
  "Hoà Long, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "hoà long, bà rịa, bà rịa - vũng tàu",
    "hoaf long, baf rija, baf rija - vuxng tafu"
  ],
  "Hoài Thanh Tây, Hoài Nhơn, Bình Định": [
    "hoài thanh tây, hoài nhơn, bình định",
    "hoafi thanh taay, hoafi nhown, bifnh ddijnh"
  ],
  "Hoàng Động, Thuỷ Nguyên, Hải Phòng": [
    "hoàng động, thuỷ nguyên, hải phòng",
    "hoafng ddoojng, thuyr nguyeen, hari phofng"
  ],
  "Hàm Kiệm, Hàm Thuận Nam, Bình Thuận": [
    "hàm kiệm, hàm thuận nam, bình thuận",
    "hafm kieejm, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Hàm Phú, Hàm Thuận Bắc, Bình Thuận": [
    "hàm phú, hàm thuận bắc, bình thuận",
    "hafm phus, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hàm Trí, Hàm Thuận Bắc, Bình Thuận": [
    "hàm trí, hàm thuận bắc, bình thuận",
    "hafm tris, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hành Tín Tây, Nghĩa Hành, Quảng Ngãi": [
    "hành tín tây, nghĩa hành, quảng ngãi",
    "hafnh tisn taay, nghixa hafnh, quarng ngaxi"
  ],
  "Hòa Thuận, Buôn Ma Thuột, Đắk Lắk": [
    "hòa thuận, buôn ma thuột, đắk lắk",
    "hofa thuaajn, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Hòa Thắng, Buôn Ma Thuột, Đắk Lắk": [
    "hòa thắng, buôn ma thuột, đắk lắk",
    "hofa thawsng, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Hưng Khánh Trung B, Chợ Lách, Bến Tre": [
    "hưng khánh trung b, chợ lách, bến tre",
    "huwng khasnh trung b, chowj lasch, beesn tre"
  ],
  "Hướng Lập, Hướng Hóa, Quảng Trị": [
    "hướng lập, hướng hóa, quảng trị",
    "huwowsng laajp, huwowsng hosa, quarng trij"
  ],
  "Hướng Lộc, Hướng Hóa, Quảng Trị": [
    "hướng lộc, hướng hóa, quảng trị",
    "huwowsng loojc, huwowsng hosa, quarng trij"
  ],
  "Hồng Bắc, A Lưới, Thừa Thiên Huế": [
    "hồng bắc, a lưới, thừa thiên huế",
    "hoofng bawsc, a luwowsi, thuwfa thieen huees"
  ],
  "Hồng Thái, A Lưới, Thừa Thiên Huế": [
    "hồng thái, a lưới, thừa thiên huế",
    "hoofng thasi, a luwowsi, thuwfa thieen huees"
  ],
  "Khánh Xuân, Buôn Ma Thuột, Đắk Lắk": [
    "khánh xuân, buôn ma thuột, đắk lắk",
    "khasnh xuaan, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Long Phước, Phước Long, Bình Phước": [
    "long phước, phước long, bình phước",
    "long phuwowsc, phuwowsc long, bifnh phuwowsc"
  ],
  "Long Tâm, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "long tâm, bà rịa, bà rịa - vũng tàu",
    "long taam, baf rija, baf rija - vuxng tafu"
  ],
  "Long Điền Tây, Đông Hải, Bạc Liêu": [
    "long điền tây, đông hải, bạc liêu",
    "long ddieefn taay, ddoong hari, bajc lieeu"
  ],
  "Lê Minh Xuân, Bình Chánh, Hồ Chí Minh": [
    "lê minh xuân, bình chánh, hồ chí minh",
    "lee minh xuaan, bifnh chasnh, hoof chis minh"
  ],
  "Lương Điền, Cẩm Giàng, Hải Dương": [
    "lương điền, cẩm giàng, hải dương",
    "luwowng ddieefn, caarm giafng, hari duwowng"
  ],
  "Lộc Bình, Phú Lộc, Thừa Thiên Huế": [
    "lộc bình, phú lộc, thừa thiên huế",
    "loojc bifnh, phus loojc, thuwfa thieen huees"
  ],
  "Lộc Bổn, Phú Lộc, Thừa Thiên Huế": [
    "lộc bổn, phú lộc, thừa thiên huế",
    "loojc boorn, phus loojc, thuwfa thieen huees"
  ],
  "Lộc Vĩnh, Phú Lộc, Thừa Thiên Huế": [
    "lộc vĩnh, phú lộc, thừa thiên huế",
    "loojc vixnh, phus loojc, thuwfa thieen huees"
  ],
  "Mường Pồn, Điện Biên, Điện Biên": [
    "mường pồn, điện biên, điện biên",
    "muwowfng poofn, ddieejn bieen, ddieejn bieen"
  ],
  "Mường Toong, Mường Nhé, Điện Biên": [
    "mường toong, mường nhé, điện biên",
    "muwowfng toong, muwowfng nhes, ddieejn bieen"
  ],
  "Mường Tùng, Mường Chà, Điện Biên": [
    "mường tùng, mường chà, điện biên",
    "muwowfng tufng, muwowfng chaf, ddieejn bieen"
  ],
  "NT Việt Trung, Bố Trạch, Quảng Bình": [
    "nt việt trung, bố trạch, quảng bình",
    "nt vieejt trung, boos trajch, quarng bifnh"
  ],
  "Nghĩa Thắng, Đắk R'Lấp, Đắk Nông": [
    "nghĩa thắng, đắk r'lấp, đắk nông",
    "nghixa thawsng, ddawsk r'laasp, ddawsk noong"
  ],
  "Nguyễn Cư Trinh, Quận 1, Hồ Chí Minh": [
    "nguyễn cư trinh, quận 1, hồ chí minh",
    "nguyeexn cuw trinh, quaajn 1, hoof chis minh"
  ],
  "Nguyễn Huệ, Đông Triều, Quảng Ninh": [
    "nguyễn huệ, đông triều, quảng ninh",
    "nguyeexn hueej, ddoong trieefu, quarng ninh"
  ],
  "Nguyễn Trãi, Hải Dương, Hải Dương": [
    "nguyễn trãi, hải dương, hải dương",
    "nguyeexn traxi, hari duwowng, hari duwowng"
  ],
  "Nguyễn Văn Cừ, Qui Nhơn, Bình Định": [
    "nguyễn văn cừ, qui nhơn, bình định",
    "nguyeexn vawn cuwf, qui nhown, bifnh ddijnh"
  ],
  "Ngàm Đăng Vài, Hoàng Su Phì, Hà Giang": [
    "ngàm đăng vài, hoàng su phì, hà giang",
    "ngafm ddawng vafi, hoafng su phif, haf giang"
  ],
  "Ngọc Thuận, Giồng Riềng, Kiên Giang": [
    "ngọc thuận, giồng riềng, kiên giang",
    "ngojc thuaajn, gioofng rieefng, kieen giang"
  ],
  "Ninh Thạnh Lợi, Hồng Dân, Bạc Liêu": [
    "ninh thạnh lợi, hồng dân, bạc liêu",
    "ninh thajnh lowji, hoofng daan, bajc lieeu"
  ],
  "Phan Bội Châu, Hồng Bàng, Hải Phòng": [
    "phan bội châu, hồng bàng, hải phòng",
    "phan booji chaau, hoofng bafng, hari phofng"
  ],
  "Phan Đình Phùng, Nam Định, Nam Định": [
    "phan đình phùng, nam định, nam định",
    "phan ddifnh phufng, nam ddijnh, nam ddijnh"
  ],
  "Phong An, Phong Điền, Thừa Thiên Huế": [
    "phong an, phong điền, thừa thiên huế",
    "phong an, phong ddieefn, thuwfa thieen huees"
  ],
  "Phú Dương, Phú Vang, Thừa Thiên Huế": [
    "phú dương, phú vang, thừa thiên huế",
    "phus duwowng, phus vang, thuwfa thieen huees"
  ],
  "Phú Long, Hàm Thuận Bắc, Bình Thuận": [
    "phú long, hàm thuận bắc, bình thuận",
    "phus long, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Phú Lương, Phú Vang, Thừa Thiên Huế": [
    "phú lương, phú vang, thừa thiên huế",
    "phus luwowng, phus vang, thuwfa thieen huees"
  ],
  "Phú Lợi, Thủ Dầu Một, Bình Dương": [
    "phú lợi, thủ dầu một, bình dương",
    "phus lowji, thur daafu moojt, bifnh duwowng"
  ],
  "Phú Mỹ, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "phú mỹ, phú mỹ, bà rịa - vũng tàu",
    "phus myx, phus myx, baf rija - vuxng tafu"
  ],
  "Phú Thuận, Phú Vang, Thừa Thiên Huế": [
    "phú thuận, phú vang, thừa thiên huế",
    "phus thuaajn, phus vang, thuwfa thieen huees"
  ],
  "Phú Thạnh, Tân Phú Đông, Tiền Giang": [
    "phú thạnh, tân phú đông, tiền giang",
    "phus thajnh, taan phus ddoong, tieefn giang"
  ],
  "Phú Thọ, Thủ Dầu Một, Bình Dương": [
    "phú thọ, thủ dầu một, bình dương",
    "phus thoj, thur daafu moojt, bifnh duwowng"
  ],
  "Phước Hiệp, Tuy Phước, Bình Định": [
    "phước hiệp, tuy phước, bình định",
    "phuwowsc hieejp, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Kháng, Thuận Bắc, Ninh Thuận": [
    "phước kháng, thuận bắc, ninh thuận",
    "phuwowsc khasng, thuaajn bawsc, ninh thuaajn"
  ],
  "Phước Minh, Bù Gia Mập, Bình Phước": [
    "phước minh, bù gia mập, bình phước",
    "phuwowsc minh, buf gia maajp, bifnh phuwowsc"
  ],
  "Phước Minh, Dương Minh Châu, Tây Ninh": [
    "phước minh, dương minh châu, tây ninh",
    "phuwowsc minh, duwowng minh chaau, taay ninh"
  ],
  "Phước Nghĩa, Tuy Phước, Bình Định": [
    "phước nghĩa, tuy phước, bình định",
    "phuwowsc nghixa, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Ninh, Dương Minh Châu, Tây Ninh": [
    "phước ninh, dương minh châu, tây ninh",
    "phuwowsc ninh, duwowng minh chaau, taay ninh"
  ],
  "Phước Thiền, Nhơn Trạch, Đồng Nai": [
    "phước thiền, nhơn trạch, đồng nai",
    "phuwowsc thieefn, nhown trajch, ddoofng nai"
  ],
  "Phước Thiện, Bù Đốp, Bình Phước": [
    "phước thiện, bù đốp, bình phước",
    "phuwowsc thieejn, buf ddoosp, bifnh phuwowsc"
  ],
  "Phước Thành, Tuy Phước, Bình Định": [
    "phước thành, tuy phước, bình định",
    "phuwowsc thafnh, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Tín, Phước Long, Bình Phước": [
    "phước tín, phước long, bình phước",
    "phuwowsc tisn, phuwowsc long, bifnh phuwowsc"
  ],
  "Pú Nhi, Điện Biên Đông, Điện Biên": [
    "pú nhi, điện biên đông, điện biên",
    "pus nhi, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Quảng Lưu, Quảng Trạch, Quảng Bình": [
    "quảng lưu, quảng trạch, quảng bình",
    "quarng luwu, quarng trajch, quarng bifnh"
  ],
  "Quảng Phú, Quảng Trạch, Quảng Bình": [
    "quảng phú, quảng trạch, quảng bình",
    "quarng phus, quarng trajch, quarng bifnh"
  ],
  "Quảng Thạch, Quảng Xương, Thanh Hóa": [
    "quảng thạch, quảng xương, thanh hóa",
    "quarng thajch, quarng xuwowng, thanh hosa"
  ],
  "Quảng Trạch, Quảng Xương, Thanh Hóa": [
    "quảng trạch, quảng xương, thanh hóa",
    "quarng trajch, quarng xuwowng, thanh hosa"
  ],
  "Quảng Định, Quảng Xương, Thanh Hóa": [
    "quảng định, quảng xương, thanh hóa",
    "quarng ddijnh, quarng xuwowng, thanh hosa"
  ],
  "Thanh Bình Thịnh, Đức Thọ, Hà Tĩnh": [
    "thanh bình thịnh, đức thọ, hà tĩnh",
    "thanh bifnh thijnh, dduwsc thoj, haf tixnh"
  ],
  "Thiên Hương, Thuỷ Nguyên, Hải Phòng": [
    "thiên hương, thuỷ nguyên, hải phòng",
    "thieen huwowng, thuyr nguyeen, hari phofng"
  ],
  "Thuận Nam, Hàm Thuận Nam, Bình Thuận": [
    "thuận nam, hàm thuận nam, bình thuận",
    "thuaajn nam, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Thuận Đức, Đồng Hới, Quảng Bình": [
    "thuận đức, đồng hới, quảng bình",
    "thuaajn dduwsc, ddoofng howsi, quarng bifnh"
  ],
  "Thuỷ Triều, Thuỷ Nguyên, Hải Phòng": [
    "thuỷ triều, thuỷ nguyên, hải phòng",
    "thuyr trieefu, thuyr nguyeen, hari phofng"
  ],
  "Thành Công, Buôn Ma Thuột, Đắk Lắk": [
    "thành công, buôn ma thuột, đắk lắk",
    "thafnh coong, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Thường Lạc, Hồng Ngự, Đồng Tháp": [
    "thường lạc, hồng ngự, đồng tháp",
    "thuwowfng lajc, hoofng nguwj, ddoofng thasp"
  ],
  "Thường Xuân, Thường Xuân, Thanh Hóa": [
    "thường xuân, thường xuân, thanh hóa",
    "thuwowfng xuaan, thuwowfng xuaan, thanh hosa"
  ],
  "Thạch Tượng, Thạch Thành, Thanh Hóa": [
    "thạch tượng, thạch thành, thanh hóa",
    "thajch tuwowjng, thajch thafnh, thanh hosa"
  ],
  "Thạnh Mỹ Lợi, Quận 2, Hồ Chí Minh": [
    "thạnh mỹ lợi, quận 2, hồ chí minh",
    "thajnh myx lowji, quaajn 2, hoof chis minh"
  ],
  "Thạnh Nhựt, Gò Công Tây, Tiền Giang": [
    "thạnh nhựt, gò công tây, tiền giang",
    "thajnh nhuwjt, gof coong taay, tieefn giang"
  ],
  "Thạnh Thới An, Trần Đề, Sóc Trăng": [
    "thạnh thới an, trần đề, sóc trăng",
    "thajnh thowsi an, traafn ddeef, sosc trawng"
  ],
  "Thịnh Đức, Thái Nguyên, Thái Nguyên": [
    "thịnh đức, thái nguyên, thái nguyên",
    "thijnh dduwsc, thasi nguyeen, thasi nguyeen"
  ],
  "Thọ Nghiệp, Xuân Trường, Nam Định": [
    "thọ nghiệp, xuân trường, nam định",
    "thoj nghieejp, xuaan truwowfng, nam ddijnh"
  ],
  "Thụy Phương, Bắc Từ Liêm, Hà Nội": [
    "thụy phương, bắc từ liêm, hà nội",
    "thujy phuwowng, bawsc tuwf lieem, haf nooji"
  ],
  "Thủy Xuân Tiên, Chương Mỹ, Hà Nội": [
    "thủy xuân tiên, chương mỹ, hà nội",
    "thury xuaan tieen, chuwowng myx, haf nooji"
  ],
  "Tiến Thành, Đồng Xoài, Bình Phước": [
    "tiến thành, đồng xoài, bình phước",
    "tieesn thafnh, ddoofng xoafi, bifnh phuwowsc"
  ],
  "Triệu Thành, Triệu Phong, Quảng Trị": [
    "triệu thành, triệu phong, quảng trị",
    "trieeju thafnh, trieeju phong, quarng trij"
  ],
  "Triệu Đại, Triệu Phong, Quảng Trị": [
    "triệu đại, triệu phong, quảng trị",
    "trieeju ddaji, trieeju phong, quarng trij"
  ],
  "Tràng Lương, Đông Triều, Quảng Ninh": [
    "tràng lương, đông triều, quảng ninh",
    "trafng luwowng, ddoong trieefu, quarng ninh"
  ],
  "Trưng Vương, Thái Nguyên, Thái Nguyên": [
    "trưng vương, thái nguyên, thái nguyên",
    "truwng vuwowng, thasi nguyeen, thasi nguyeen"
  ],
  "Trường Long Hòa, Duyên Hải, Trà Vinh": [
    "trường long hòa, duyên hải, trà vinh",
    "truwowfng long hofa, duyeen hari, traf vinh"
  ],
  "Trường Thủy, Lệ Thủy, Quảng Bình": [
    "trường thủy, lệ thủy, quảng bình",
    "truwowfng thury, leej thury, quarng bifnh"
  ],
  "Trường Xuân, Quảng Ninh, Quảng Bình": [
    "trường xuân, quảng ninh, quảng bình",
    "truwowfng xuaan, quarng ninh, quarng bifnh"
  ],
  "Trần Hưng Đạo, Hoàn Kiếm, Hà Nội": [
    "trần hưng đạo, hoàn kiếm, hà nội",
    "traafn huwng ddajo, hoafn kieesm, haf nooji"
  ],
  "Trần Hưng Đạo, Hạ Long, Quảng Ninh": [
    "trần hưng đạo, hạ long, quảng ninh",
    "traafn huwng ddajo, haj long, quarng ninh"
  ],
  "Trần Nguyên Hãn, Lê Chân, Hải Phòng": [
    "trần nguyên hãn, lê chân, hải phòng",
    "traafn nguyeen haxn, lee chaan, hari phofng"
  ],
  "Trần Thành Ngọ, Kiến An, Hải Phòng": [
    "trần thành ngọ, kiến an, hải phòng",
    "traafn thafnh ngoj, kieesn an, hari phofng"
  ],
  "Trần Đăng Ninh, Nam Định, Nam Định": [
    "trần đăng ninh, nam định, nam định",
    "traafn ddawng ninh, nam ddijnh, nam ddijnh"
  ],
  "Tân  Khánh Trung, Lấp Vò, Đồng Tháp": [
    "tân  khánh trung, lấp vò, đồng tháp",
    "taan  khasnh trung, laasp vof, ddoofng thasp"
  ],
  "Tân Hoà, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "tân hoà, phú mỹ, bà rịa - vũng tàu",
    "taan hoaf, phus myx, baf rija - vuxng tafu"
  ],
  "Tân Lợi Thạnh, Giồng Trôm, Bến Tre": [
    "tân lợi thạnh, giồng trôm, bến tre",
    "taan lowji thajnh, gioofng troom, beesn tre"
  ],
  "Tân Phú Trung, Châu Thành, Đồng Tháp": [
    "tân phú trung, châu thành, đồng tháp",
    "taan phus trung, chaau thafnh, ddoofng thasp"
  ],
  "Tân Quý Tây, Bình Chánh, Hồ Chí Minh": [
    "tân quý tây, bình chánh, hồ chí minh",
    "taan quys taay, bifnh chasnh, hoof chis minh"
  ],
  "Tân Thành, Bắc Tân Uyên, Bình Dương": [
    "tân thành, bắc tân uyên, bình dương",
    "taan thafnh, bawsc taan uyeen, bifnh duwowng"
  ],
  "Tân Thành, Hàm Thuận Nam, Bình Thuận": [
    "tân thành, hàm thuận nam, bình thuận",
    "taan thafnh, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Tân Thạnh, Tân Phú Đông, Tiền Giang": [
    "tân thạnh, tân phú đông, tiền giang",
    "taan thajnh, taan phus ddoong, tieefn giang"
  ],
  "Tân Vĩnh Hiệp, Tân Uyên, Bình Dương": [
    "tân vĩnh hiệp, tân uyên, bình dương",
    "taan vixnh hieejp, taan uyeen, bifnh duwowng"
  ],
  "Tân Điền, Gò Công Đông, Tiền Giang": [
    "tân điền, gò công đông, tiền giang",
    "taan ddieefn, gof coong ddoong, tieefn giang"
  ],
  "Tăng Nhơn Phú A, Quận 9, Hồ Chí Minh": [
    "tăng nhơn phú a, quận 9, hồ chí minh",
    "tawng nhown phus a, quaajn 9, hoof chis minh"
  ],
  "Tăng Nhơn Phú B, Quận 9, Hồ Chí Minh": [
    "tăng nhơn phú b, quận 9, hồ chí minh",
    "tawng nhown phus b, quaajn 9, hoof chis minh"
  ],
  "Tả Sìn Thàng, Tủa Chùa, Điện Biên": [
    "tả sìn thàng, tủa chùa, điện biên",
    "tar sifn thafng, tura chufa, ddieejn bieen"
  ],
  "Tả Sử Choóng, Hoàng Su Phì, Hà Giang": [
    "tả sử choóng, hoàng su phì, hà giang",
    "tar suwr choosng, hoafng su phif, haf giang"
  ],
  "Tịnh Thiện, Quảng Ngãi, Quảng Ngãi": [
    "tịnh thiện, quảng ngãi, quảng ngãi",
    "tijnh thieejn, quarng ngaxi, quarng ngaxi"
  ],
  "Tứ Hạ, Hương Trà, Thừa Thiên Huế": [
    "tứ hạ, hương trà, thừa thiên huế",
    "tuws haj, huwowng traf, thuwfa thieen huees"
  ],
  "Vinh Hiền, Phú Lộc, Thừa Thiên Huế": [
    "vinh hiền, phú lộc, thừa thiên huế",
    "vinh hieefn, phus loojc, thuwfa thieen huees"
  ],
  "Vĩnh Hòa Hiệp, Châu Thành, Kiên Giang": [
    "vĩnh hòa hiệp, châu thành, kiên giang",
    "vixnh hofa hieejp, chaau thafnh, kieen giang"
  ],
  "Vĩnh Thuận Tây, Vị Thuỷ, Hậu Giang": [
    "vĩnh thuận tây, vị thuỷ, hậu giang",
    "vixnh thuaajn taay, vij thuyr, haaju giang"
  ],
  "Vĩnh Thuận Đông, Long Mỹ, Hậu Giang": [
    "vĩnh thuận đông, long mỹ, hậu giang",
    "vixnh thuaajn ddoong, long myx, haaju giang"
  ],
  "Xa Dung, Điện Biên Đông, Điện Biên": [
    "xa dung, điện biên đông, điện biên",
    "xa dung, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Xuân Lộc, Phú Lộc, Thừa Thiên Huế": [
    "xuân lộc, phú lộc, thừa thiên huế",
    "xuaan loojc, phus loojc, thuwfa thieen huees"
  ],
  "Xuân Phương, Xuân Trường, Nam Định": [
    "xuân phương, xuân trường, nam định",
    "xuaan phuwowng, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Thới Sơn, Hóc Môn, Hồ Chí Minh": [
    "xuân thới sơn, hóc môn, hồ chí minh",
    "xuaan thowsi sown, hosc moon, hoof chis minh"
  ],
  "Đa Phước Hội, Mỏ Cày Nam, Bến Tre": [
    "đa phước hội, mỏ cày nam, bến tre",
    "dda phuwowsc hooji, mor cafy nam, beesn tre"
  ],
  "Đinh Trang Thượng, Di Linh, Lâm Đồng": [
    "đinh trang thượng, di linh, lâm đồng",
    "ddinh trang thuwowjng, di linh, laam ddoofng"
  ],
  "Điện Nam Bắc, Điện Bàn, Quảng Nam": [
    "điện nam bắc, điện bàn, quảng nam",
    "ddieejn nam bawsc, ddieejn bafn, quarng nam"
  ],
  "Điện Nam Trung, Điện Bàn, Quảng Nam": [
    "điện nam trung, điện bàn, quảng nam",
    "ddieejn nam trung, ddieejn bafn, quarng nam"
  ],
  "Đông Phương, Kiến Thuỵ, Hải Phòng": [
    "đông phương, kiến thuỵ, hải phòng",
    "ddoong phuwowng, kieesn thuyj, hari phofng"
  ],
  "Đông Phước A, Châu Thành, Hậu Giang": [
    "đông phước a, châu thành, hậu giang",
    "ddoong phuwowsc a, chaau thafnh, haaju giang"
  ],
  "Đông Triều, Đông Triều, Quảng Ninh": [
    "đông triều, đông triều, quảng ninh",
    "ddoong trieefu, ddoong trieefu, quarng ninh"
  ],
  "Định Hiệp, Dầu Tiếng, Bình Dương": [
    "định hiệp, dầu tiếng, bình dương",
    "ddijnh hieejp, daafu tieesng, bifnh duwowng"
  ],
  "Định Thành, Dầu Tiếng, Bình Dương": [
    "định thành, dầu tiếng, bình dương",
    "ddijnh thafnh, daafu tieesng, bifnh duwowng"
  ],
  "Đồng Thịnh, Định Hóa, Thái Nguyên": [
    "đồng thịnh, định hóa, thái nguyên",
    "ddoofng thijnh, ddijnh hosa, thasi nguyeen"
  ],
  "Đồng Tiến, Đồng Phú, Bình Phước": [
    "đồng tiến, đồng phú, bình phước",
    "ddoofng tieesn, ddoofng phus, bifnh phuwowsc"
  ],
  "Đồng Trạch, Bố Trạch, Quảng Bình": [
    "đồng trạch, bố trạch, quảng bình",
    "ddoofng trajch, boos trajch, quarng bifnh"
  ],
  "Đức Hạnh, Bù Gia Mập, Bình Phước": [
    "đức hạnh, bù gia mập, bình phước",
    "dduwsc hajnh, buf gia maajp, bifnh phuwowsc"
  ],
  "Đức Lập Thượng, Đức Hòa, Long An": [
    "đức lập thượng, đức hòa, long an",
    "dduwsc laajp thuwowjng, dduwsc hofa, long an"
  ],
  "An Thới Đông, Cần Giờ, Hồ Chí Minh": [
    "an thới đông, cần giờ, hồ chí minh",
    "an thowsi ddoong, caafn giowf, hoof chis minh"
  ],
  "Bình Thạnh Trung, Lấp Vò, Đồng Tháp": [
    "bình thạnh trung, lấp vò, đồng tháp",
    "bifnh thajnh trung, laasp vof, ddoofng thasp"
  ],
  "Bình Trưng Đông, Quận 2, Hồ Chí Minh": [
    "bình trưng đông, quận 2, hồ chí minh",
    "bifnh truwng ddoong, quaajn 2, hoof chis minh"
  ],
  "Bảo An, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "bảo an, phan rang-tháp chàm, ninh thuận",
    "baro an, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Chánh Mỹ, Thủ Dầu Một, Bình Dương": [
    "chánh mỹ, thủ dầu một, bình dương",
    "chasnh myx, thur daafu moojt, bifnh duwowng"
  ],
  "Cẩm Thượng, Hải Dương, Hải Dương": [
    "cẩm thượng, hải dương, hải dương",
    "caarm thuwowjng, hari duwowng, hari duwowng"
  ],
  "Giồng Riềng, Giồng Riềng, Kiên Giang": [
    "giồng riềng, giồng riềng, kiên giang",
    "gioofng rieefng, gioofng rieefng, kieen giang"
  ],
  "Hiếu Liêm, Bắc Tân Uyên, Bình Dương": [
    "hiếu liêm, bắc tân uyên, bình dương",
    "hieesu lieem, bawsc taan uyeen, bifnh duwowng"
  ],
  "Hoài Châu Bắc, Hoài Nhơn, Bình Định": [
    "hoài châu bắc, hoài nhơn, bình định",
    "hoafi chaau bawsc, hoafi nhown, bifnh ddijnh"
  ],
  "Hoàng Văn Thụ, Hồng Bàng, Hải Phòng": [
    "hoàng văn thụ, hồng bàng, hải phòng",
    "hoafng vawn thuj, hoofng bafng, hari phofng"
  ],
  "Hàm Liêm, Hàm Thuận Bắc, Bình Thuận": [
    "hàm liêm, hàm thuận bắc, bình thuận",
    "hafm lieem, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hàm Thạnh, Hàm Thuận Nam, Bình Thuận": [
    "hàm thạnh, hàm thuận nam, bình thuận",
    "hafm thajnh, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Hòa Cường Bắc, Hải Châu, Đà Nẵng": [
    "hòa cường bắc, hải châu, đà nẵng",
    "hofa cuwowfng bawsc, hari chaau, ddaf nawxng"
  ],
  "Hòa Hiệp Bắc, Liên Chiểu, Đà Nẵng": [
    "hòa hiệp bắc, liên chiểu, đà nẵng",
    "hofa hieejp bawsc, lieen chieeru, ddaf nawxng"
  ],
  "Hòa Khánh Bắc, Liên Chiểu, Đà Nẵng": [
    "hòa khánh bắc, liên chiểu, đà nẵng",
    "hofa khasnh bawsc, lieen chieeru, ddaf nawxng"
  ],
  "Hòa Thuận Đông, Hải Châu, Đà Nẵng": [
    "hòa thuận đông, hải châu, đà nẵng",
    "hofa thuaajn ddoong, hari chaau, ddaf nawxng"
  ],
  "Hương An, Hương Trà, Thừa Thiên Huế": [
    "hương an, hương trà, thừa thiên huế",
    "huwowng an, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Phong, A Lưới, Thừa Thiên Huế": [
    "hương phong, a lưới, thừa thiên huế",
    "huwowng phong, a luwowsi, thuwfa thieen huees"
  ],
  "Hương Phú, Nam Đông, Thừa Thiên Huế": [
    "hương phú, nam đông, thừa thiên huế",
    "huwowng phus, nam ddoong, thuwfa thieen huees"
  ],
  "Hương Sơn, Nam Đông, Thừa Thiên Huế": [
    "hương sơn, nam đông, thừa thiên huế",
    "huwowng sown, nam ddoong, thuwfa thieen huees"
  ],
  "Hướng Phùng, Hướng Hóa, Quảng Trị": [
    "hướng phùng, hướng hóa, quảng trị",
    "huwowsng phufng, huwowsng hosa, quarng trij"
  ],
  "Hướng Việt, Hướng Hóa, Quảng Trị": [
    "hướng việt, hướng hóa, quảng trị",
    "huwowsng vieejt, huwowsng hosa, quarng trij"
  ],
  "Hồ Đắc Kiện, Châu Thành, Sóc Trăng": [
    "hồ đắc kiện, châu thành, sóc trăng",
    "hoof ddawsc kieejn, chaau thafnh, sosc trawng"
  ],
  "Hồng Thủy, A Lưới, Thừa Thiên Huế": [
    "hồng thủy, a lưới, thừa thiên huế",
    "hoofng thury, a luwowsi, thuwfa thieen huees"
  ],
  "Keo Lôm, Điện Biên Đông, Điện Biên": [
    "keo lôm, điện biên đông, điện biên",
    "keo loom, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Long Bình Điền, Chợ Gạo, Tiền Giang": [
    "long bình điền, chợ gạo, tiền giang",
    "long bifnh ddieefn, chowj gajo, tieefn giang"
  ],
  "Long Sơn, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "long sơn, vũng tàu, bà rịa - vũng tàu",
    "long sown, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Long Toàn, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "long toàn, bà rịa, bà rịa - vũng tàu",
    "long toafn, baf rija, baf rija - vuxng tafu"
  ],
  "Lương Hòa Lạc, Chợ Gạo, Tiền Giang": [
    "lương hòa lạc, chợ gạo, tiền giang",
    "luwowng hofa lajc, chowj gajo, tieefn giang"
  ],
  "Lưỡng Vượng, Tuyên Quang, Tuyên Quang": [
    "lưỡng vượng, tuyên quang, tuyên quang",
    "luwowxng vuwowjng, tuyeen quang, tuyeen quang"
  ],
  "Lộc Thủy, Phú Lộc, Thừa Thiên Huế": [
    "lộc thủy, phú lộc, thừa thiên huế",
    "loojc thury, phus loojc, thuwfa thieen huees"
  ],
  "Lộc Tiến, Phú Lộc, Thừa Thiên Huế": [
    "lộc tiến, phú lộc, thừa thiên huế",
    "loojc tieesn, phus loojc, thuwfa thieen huees"
  ],
  "Mù Căng Chải, Mù Căng Chải, Yên Bái": [
    "mù căng chải, mù căng chải, yên bái",
    "muf cawng chari, muf cawng chari, yeen basi"
  ],
  "Mương Mán, Hàm Thuận Nam, Bình Thuận": [
    "mương mán, hàm thuận nam, bình thuận",
    "muwowng masn, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Mường Lạn, Mường Ảng, Điện Biên": [
    "mường lạn, mường ảng, điện biên",
    "muwowfng lajn, muwowfng arng, ddieejn bieen"
  ],
  "Mường Mươn, Mường Chà, Điện Biên": [
    "mường mươn, mường chà, điện biên",
    "muwowfng muwown, muwowfng chaf, ddieejn bieen"
  ],
  "Mường Ảng, Mường Ảng, Điện Biên": [
    "mường ảng, mường ảng, điện biên",
    "muwowfng arng, muwowfng arng, ddieejn bieen"
  ],
  "Mỹ Thạnh, Hàm Thuận Nam, Bình Thuận": [
    "mỹ thạnh, hàm thuận nam, bình thuận",
    "myx thajnh, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Mỹ Xuân, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "mỹ xuân, phú mỹ, bà rịa - vũng tàu",
    "myx xuaan, phus myx, baf rija - vuxng tafu"
  ],
  "Nam Phương Tiến, Chương Mỹ, Hà Nội": [
    "nam phương tiến, chương mỹ, hà nội",
    "nam phuwowng tieesn, chuwowng myx, haf nooji"
  ],
  "Nam Thanh, Điện Biên Phủ, Điện Biên": [
    "nam thanh, điện biên phủ, điện biên",
    "nam thanh, ddieejn bieen phur, ddieejn bieen"
  ],
  "Nguyễn Nghiêm, Đức Phổ, Quảng Ngãi": [
    "nguyễn nghiêm, đức phổ, quảng ngãi",
    "nguyeexn nghieem, dduwsc phoor, quarng ngaxi"
  ],
  "Nguyễn Văn Thảnh, Bình Tân, Vĩnh Long": [
    "nguyễn văn thảnh, bình tân, vĩnh long",
    "nguyeexn vawn tharnh, bifnh taan, vixnh long"
  ],
  "Ngư Thủy Bắc, Lệ Thủy, Quảng Bình": [
    "ngư thủy bắc, lệ thủy, quảng bình",
    "nguw thury bawsc, leej thury, quarng bifnh"
  ],
  "Nhuận Phú Tân, Mỏ Cày Bắc, Bến Tre": [
    "nhuận phú tân, mỏ cày bắc, bến tre",
    "nhuaajn phus taan, mor cafy bawsc, beesn tre"
  ],
  "Noong Bua, Điện Biên Phủ, Điện Biên": [
    "noong bua, điện biên phủ, điện biên",
    "noong bua, ddieejn bieen phur, ddieejn bieen"
  ],
  "Nà Tấu, Điện Biên Phủ, Điện Biên": [
    "nà tấu, điện biên phủ, điện biên",
    "naf taasu, ddieejn bieen phur, ddieejn bieen"
  ],
  "Phong Thu, Phong Điền, Thừa Thiên Huế": [
    "phong thu, phong điền, thừa thiên huế",
    "phong thu, phong ddieefn, thuwfa thieen huees"
  ],
  "Phước Bình, Phước Long, Bình Phước": [
    "phước bình, phước long, bình phước",
    "phuwowsc bifnh, phuwowsc long, bifnh phuwowsc"
  ],
  "Phước Chiến, Thuận Bắc, Ninh Thuận": [
    "phước chiến, thuận bắc, ninh thuận",
    "phuwowsc chieesn, thuaajn bawsc, ninh thuaajn"
  ],
  "Phước Thuận, Ninh Phước, Ninh Thuận": [
    "phước thuận, ninh phước, ninh thuận",
    "phuwowsc thuaajn, ninh phuwowsc, ninh thuaajn"
  ],
  "Phước Thuận, Tuy Phước, Bình Định": [
    "phước thuận, tuy phước, bình định",
    "phuwowsc thuaajn, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Thắng, Tuy Phước, Bình Định": [
    "phước thắng, tuy phước, bình định",
    "phuwowsc thawsng, tuy phuwowsc, bifnh ddijnh"
  ],
  "Phước Vĩnh Đông, Cần Giuộc, Long An": [
    "phước vĩnh đông, cần giuộc, long an",
    "phuwowsc vixnh ddoong, caafn giuoojc, long an"
  ],
  "Phượng Tiến, Định Hóa, Thái Nguyên": [
    "phượng tiến, định hóa, thái nguyên",
    "phuwowjng tieesn, ddijnh hosa, thasi nguyeen"
  ],
  "Phạm Văn Hai, Bình Chánh, Hồ Chí Minh": [
    "phạm văn hai, bình chánh, hồ chí minh",
    "phajm vawn hai, bifnh chasnh, hoof chis minh"
  ],
  "Phạm Đình Hổ, Hai Bà Trưng, Hà Nội": [
    "phạm đình hổ, hai bà trưng, hà nội",
    "phajm ddifnh hoor, hai baf truwng, haf nooji"
  ],
  "Quyết Thắng, Hải Dương, Hải Dương": [
    "quyết thắng, hải dương, hải dương",
    "quyeest thawsng, hari duwowng, hari duwowng"
  ],
  "Quyết Thắng, Thái Nguyên, Thái Nguyên": [
    "quyết thắng, thái nguyên, thái nguyên",
    "quyeest thawsng, thasi nguyeen, thasi nguyeen"
  ],
  "Quảng Châu, Quảng Trạch, Quảng Bình": [
    "quảng châu, quảng trạch, quảng bình",
    "quarng chaau, quarng trajch, quarng bifnh"
  ],
  "Quảng Hưng, Quảng Trạch, Quảng Bình": [
    "quảng hưng, quảng trạch, quảng bình",
    "quarng huwng, quarng trajch, quarng bifnh"
  ],
  "Quảng Hợp, Quảng Trạch, Quảng Bình": [
    "quảng hợp, quảng trạch, quảng bình",
    "quarng howjp, quarng trajch, quarng bifnh"
  ],
  "Quảng Nhâm, A Lưới, Thừa Thiên Huế": [
    "quảng nhâm, a lưới, thừa thiên huế",
    "quarng nhaam, a luwowsi, thuwfa thieen huees"
  ],
  "Quảng Thanh, Quảng Trạch, Quảng Bình": [
    "quảng thanh, quảng trạch, quảng bình",
    "quarng thanh, quarng trajch, quarng bifnh"
  ],
  "Quảng Tùng, Quảng Trạch, Quảng Bình": [
    "quảng tùng, quảng trạch, quảng bình",
    "quarng tufng, quarng trajch, quarng bifnh"
  ],
  "Quảng Xuân, Quảng Trạch, Quảng Bình": [
    "quảng xuân, quảng trạch, quảng bình",
    "quarng xuaan, quarng trajch, quarng bifnh"
  ],
  "Tam Thôn Hiệp, Cần Giờ, Hồ Chí Minh": [
    "tam thôn hiệp, cần giờ, hồ chí minh",
    "tam thoon hieejp, caafn giowf, hoof chis minh"
  ],
  "Thiện Nghiệp, Phan Thiết, Bình Thuận": [
    "thiện nghiệp, phan thiết, bình thuận",
    "thieejn nghieejp, phan thieest, bifnh thuaajn"
  ],
  "Thuận Quí, Hàm Thuận Nam, Bình Thuận": [
    "thuận quí, hàm thuận nam, bình thuận",
    "thuaajn quis, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Thành Nhất, Buôn Ma Thuột, Đắk Lắk": [
    "thành nhất, buôn ma thuột, đắk lắk",
    "thafnh nhaast, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Thượng Hiền, Kiến Xương, Thái Bình": [
    "thượng hiền, kiến xương, thái bình",
    "thuwowjng hieefn, kieesn xuwowng, thasi bifnh"
  ],
  "Thượng Trưng, Vĩnh Tường, Vĩnh Phúc": [
    "thượng trưng, vĩnh tường, vĩnh phúc",
    "thuwowjng truwng, vixnh tuwowfng, vixnh phusc"
  ],
  "Thượng Yên Công, Uông Bí, Quảng Ninh": [
    "thượng yên công, uông bí, quảng ninh",
    "thuwowjng yeen coong, uoong bis, quarng ninh"
  ],
  "Thạnh Phú Đông, Giồng Trôm, Bến Tre": [
    "thạnh phú đông, giồng trôm, bến tre",
    "thajnh phus ddoong, gioofng troom, beesn tre"
  ],
  "Thạnh Yên A, U Minh Thượng, Kiên Giang": [
    "thạnh yên a, u minh thượng, kiên giang",
    "thajnh yeen a, u minh thuwowjng, kieen giang"
  ],
  "Thắng Lợi, Buôn Ma Thuột, Đắk Lắk": [
    "thắng lợi, buôn ma thuột, đắk lắk",
    "thawsng lowji, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Triệu Thuận, Triệu Phong, Quảng Trị": [
    "triệu thuận, triệu phong, quảng trị",
    "trieeju thuaajn, trieeju phong, quarng trij"
  ],
  "Triệu Trạch, Triệu Phong, Quảng Trị": [
    "triệu trạch, triệu phong, quảng trị",
    "trieeju trajch, trieeju phong, quarng trij"
  ],
  "Trung Thành Đông,  Vũng Liêm, Vĩnh Long": [
    "trung thành đông,  vũng liêm, vĩnh long",
    "trung thafnh ddoong,  vuxng lieem, vixnh long"
  ],
  "Trường Long A, Châu Thành A, Hậu Giang": [
    "trường long a, châu thành a, hậu giang",
    "truwowfng long a, chaau thafnh a, haaju giang"
  ],
  "Trường Thọ, Thủ Đức, Hồ Chí Minh": [
    "trường thọ, thủ đức, hồ chí minh",
    "truwowfng thoj, thur dduwsc, hoof chis minh"
  ],
  "Trường Xuân, Tháp Mười, Đồng Tháp": [
    "trường xuân, tháp mười, đồng tháp",
    "truwowfng xuaan, thasp muwowfi, ddoofng thasp"
  ],
  "Trần Hưng Đạo, Nam Định, Nam Định": [
    "trần hưng đạo, nam định, nam định",
    "traafn huwng ddajo, nam ddijnh, nam ddijnh"
  ],
  "Trần Hưng Đạo, Qui Nhơn, Bình Định": [
    "trần hưng đạo, qui nhơn, bình định",
    "traafn huwng ddajo, qui nhown, bifnh ddijnh"
  ],
  "Trần Hưng Đạo, Thái Bình, Thái Bình": [
    "trần hưng đạo, thái bình, thái bình",
    "traafn huwng ddajo, thasi bifnh, thasi bifnh"
  ],
  "Trần Nguyên Hãn, Bắc Giang, Bắc Giang": [
    "trần nguyên hãn, bắc giang, bắc giang",
    "traafn nguyeen haxn, bawsc giang, bawsc giang"
  ],
  "Trần Quang Diệu, Qui Nhơn, Bình Định": [
    "trần quang diệu, qui nhơn, bình định",
    "traafn quang dieeju, qui nhown, bifnh ddijnh"
  ],
  "Trần Quang Khải, Nam Định, Nam Định": [
    "trần quang khải, nam định, nam định",
    "traafn quang khari, nam ddijnh, nam ddijnh"
  ],
  "Trần Tế Xương, Nam Định, Nam Định": [
    "trần tế xương, nam định, nam định",
    "traafn tees xuwowng, nam ddijnh, nam ddijnh"
  ],
  "Tung Chung Phố, Mường Khương, Lào Cai": [
    "tung chung phố, mường khương, lào cai",
    "tung chung phoos, muwowfng khuwowng, lafo cai"
  ],
  "Tân Bình Thạnh, Chợ Gạo, Tiền Giang": [
    "tân bình thạnh, chợ gạo, tiền giang",
    "taan bifnh thajnh, chowj gajo, tieefn giang"
  ],
  "Tân Chánh Hiệp, Quận 12, Hồ Chí Minh": [
    "tân chánh hiệp, quận 12, hồ chí minh",
    "taan chasnh hieejp, quaajn 12, hoof chis minh"
  ],
  "Tân Hòa Thành, Tân Phước, Tiền Giang": [
    "tân hòa thành, tân phước, tiền giang",
    "taan hofa thafnh, taan phuwowsc, tieefn giang"
  ],
  "Tân Hòa Đông, Tân Phước, Tiền Giang": [
    "tân hòa đông, tân phước, tiền giang",
    "taan hofa ddoong, taan phuwowsc, tieefn giang"
  ],
  "Tân Hưng Thuận, Quận 12, Hồ Chí Minh": [
    "tân hưng thuận, quận 12, hồ chí minh",
    "taan huwng thuaajn, quaajn 12, hoof chis minh"
  ],
  "Tân Hưng, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "tân hưng, bà rịa, bà rịa - vũng tàu",
    "taan huwng, baf rija, baf rija - vuxng tafu"
  ],
  "Tân Hải, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "tân hải, phú mỹ, bà rịa - vũng tàu",
    "taan hari, phus myx, baf rija - vuxng tafu"
  ],
  "Tân Hội Đông, Châu Thành, Tiền Giang": [
    "tân hội đông, châu thành, tiền giang",
    "taan hooji ddoong, chaau thafnh, tieefn giang"
  ],
  "Tân Phước, Gò Công Đông, Tiền Giang": [
    "tân phước, gò công đông, tiền giang",
    "taan phuwowsc, gof coong ddoong, tieefn giang"
  ],
  "Tân Thuận Bình, Chợ Gạo, Tiền Giang": [
    "tân thuận bình, chợ gạo, tiền giang",
    "taan thuaajn bifnh, chowj gajo, tieefn giang"
  ],
  "Tân Thuận Đông, Cao Lãnh, Đồng Tháp": [
    "tân thuận đông, cao lãnh, đồng tháp",
    "taan thuaajn ddoong, cao laxnh, ddoofng thasp"
  ],
  "Tân Thuận Đông, Quận 7, Hồ Chí Minh": [
    "tân thuận đông, quận 7, hồ chí minh",
    "taan thuaajn ddoong, quaajn 7, hoof chis minh"
  ],
  "Tân Thuận, Hàm Thuận Nam, Bình Thuận": [
    "tân thuận, hàm thuận nam, bình thuận",
    "taan thuaajn, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Tân Thành Bình, Mỏ Cày Bắc, Bến Tre": [
    "tân thành bình, mỏ cày bắc, bến tre",
    "taan thafnh bifnh, mor cafy bawsc, beesn tre"
  ],
  "Tân Thạnh Đông, Củ Chi, Hồ Chí Minh": [
    "tân thạnh đông, củ chi, hồ chí minh",
    "taan thajnh ddoong, cur chi, hoof chis minh"
  ],
  "Tân Thới Hiệp, Quận 12, Hồ Chí Minh": [
    "tân thới hiệp, quận 12, hồ chí minh",
    "taan thowsi hieejp, quaajn 12, hoof chis minh"
  ],
  "Tân Thới Nhất, Quận 12, Hồ Chí Minh": [
    "tân thới nhất, quận 12, hồ chí minh",
    "taan thowsi nhaast, quaajn 12, hoof chis minh"
  ],
  "Tân Định, Bắc Tân Uyên, Bình Dương": [
    "tân định, bắc tân uyên, bình dương",
    "taan ddijnh, bawsc taan uyeen, bifnh duwowng"
  ],
  "Tóc Tiên, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "tóc tiên, phú mỹ, bà rịa - vũng tàu",
    "tosc tieen, phus myx, baf rija - vuxng tafu"
  ],
  "Vĩnh Bình Bắc, Vĩnh Thuận, Kiên Giang": [
    "vĩnh bình bắc, vĩnh thuận, kiên giang",
    "vixnh bifnh bawsc, vixnh thuaajn, kieen giang"
  ],
  "Vĩnh Hòa Hưng Bắc, Gò Quao, Kiên Giang": [
    "vĩnh hòa hưng bắc, gò quao, kiên giang",
    "vixnh hofa huwng bawsc, gof quao, kieen giang"
  ],
  "Vĩnh Phú Đông, Phước Long, Bạc Liêu": [
    "vĩnh phú đông, phước long, bạc liêu",
    "vixnh phus ddoong, phuwowsc long, bajc lieeu"
  ],
  "Xuân Thượng, Xuân Trường, Nam Định": [
    "xuân thượng, xuân trường, nam định",
    "xuaan thuwowjng, xuaan truwowfng, nam ddijnh"
  ],
  "Xuân Trường, Xuân Trường, Nam Định": [
    "xuân trường, xuân trường, nam định",
    "xuaan truwowfng, xuaan truwowfng, nam ddijnh"
  ],
  "Ân Tường Đông, Hoài Ân, Bình Định": [
    "ân tường đông, hoài ân, bình định",
    "aan tuwowfng ddoong, hoafi aan, bifnh ddijnh"
  ],
  "Điện Nam Đông, Điện Bàn, Quảng Nam": [
    "điện nam đông, điện bàn, quảng nam",
    "ddieejn nam ddoong, ddieejn bafn, quarng nam"
  ],
  "Đồng Thạnh, Gò Công Tây, Tiền Giang": [
    "đồng thạnh, gò công tây, tiền giang",
    "ddoofng thajnh, gof coong taay, tieefn giang"
  ],
  "An Ngãi, Long Điền, Bà Rịa - Vũng Tàu": [
    "an ngãi, long điền, bà rịa - vũng tàu",
    "an ngaxi, long ddieefn, baf rija - vuxng tafu"
  ],
  "Bình Ba, Châu Đức, Bà Rịa - Vũng Tàu": [
    "bình ba, châu đức, bà rịa - vũng tàu",
    "bifnh ba, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Bình Hưng Hoà A, Bình Tân, Hồ Chí Minh": [
    "bình hưng hoà a, bình tân, hồ chí minh",
    "bifnh huwng hoaf a, bifnh taan, hoof chis minh"
  ],
  "Bình Hưng Hoà B, Bình Tân, Hồ Chí Minh": [
    "bình hưng hoà b, bình tân, hồ chí minh",
    "bifnh huwng hoaf b, bifnh taan, hoof chis minh"
  ],
  "Bình Phục Nhứt, Chợ Gạo, Tiền Giang": [
    "bình phục nhứt, chợ gạo, tiền giang",
    "bifnh phujc nhuwst, chowj gajo, tieefn giang"
  ],
  "Bình Trị Đông, Bình Tân, Hồ Chí Minh": [
    "bình trị đông, bình tân, hồ chí minh",
    "bifnh trij ddoong, bifnh taan, hoof chis minh"
  ],
  "Bình Định Bắc, Thăng Bình, Quảng Nam": [
    "bình định bắc, thăng bình, quảng nam",
    "bifnh ddijnh bawsc, thawng bifnh, quarng nam"
  ],
  "Cù Bị, Châu Đức, Bà Rịa - Vũng Tàu": [
    "cù bị, châu đức, bà rịa - vũng tàu",
    "cuf bij, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Cảnh Dương, Quảng Trạch, Quảng Bình": [
    "cảnh dương, quảng trạch, quảng bình",
    "carnh duwowng, quarng trajch, quarng bifnh"
  ],
  "Hàm Chính, Hàm Thuận Bắc, Bình Thuận": [
    "hàm chính, hàm thuận bắc, bình thuận",
    "hafm chisnh, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hàm Cường, Hàm Thuận Nam, Bình Thuận": [
    "hàm cường, hàm thuận nam, bình thuận",
    "hafm cuwowfng, hafm thuaajn nam, bifnh thuaajn"
  ],
  "Hàm Hiệp, Hàm Thuận Bắc, Bình Thuận": [
    "hàm hiệp, hàm thuận bắc, bình thuận",
    "hafm hieejp, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hàm Đức, Hàm Thuận Bắc, Bình Thuận": [
    "hàm đức, hàm thuận bắc, bình thuận",
    "hafm dduwsc, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hương Hữu, Nam Đông, Thừa Thiên Huế": [
    "hương hữu, nam đông, thừa thiên huế",
    "huwowng huwxu, nam ddoong, thuwfa thieen huees"
  ],
  "Hương Lộc, Nam Đông, Thừa Thiên Huế": [
    "hương lộc, nam đông, thừa thiên huế",
    "huwowng loojc, nam ddoong, thuwfa thieen huees"
  ],
  "Hương Xuân, Nam Đông, Thừa Thiên Huế": [
    "hương xuân, nam đông, thừa thiên huế",
    "huwowng xuaan, nam ddoong, thuwfa thieen huees"
  ],
  "Hồng Sơn, Hàm Thuận Bắc, Bình Thuận": [
    "hồng sơn, hàm thuận bắc, bình thuận",
    "hoofng sown, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Khánh Bình Tây, Trần Văn Thời, Cà Mau": [
    "khánh bình tây, trần văn thời, cà mau",
    "khasnh bifnh taay, traafn vawn thowfi, caf mau"
  ],
  "Kim Long, Châu Đức, Bà Rịa - Vũng Tàu": [
    "kim long, châu đức, bà rịa - vũng tàu",
    "kim long, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Kinh Dinh, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "kinh dinh, phan rang-tháp chàm, ninh thuận",
    "kinh dinh, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Long Điền Đông, Đông Hải, Bạc Liêu": [
    "long điền đông, đông hải, bạc liêu",
    "long ddieefn ddoong, ddoong hari, bajc lieeu"
  ],
  "Lê Hồng Phong, Quảng Ngãi, Quảng Ngãi": [
    "lê hồng phong, quảng ngãi, quảng ngãi",
    "lee hoofng phong, quarng ngaxi, quarng ngaxi"
  ],
  "Lê Thanh Nghị, Hải Dương, Hải Dương": [
    "lê thanh nghị, hải dương, hải dương",
    "lee thanh nghij, hari duwowng, hari duwowng"
  ],
  "Lùng Khấu Nhin, Mường Khương, Lào Cai": [
    "lùng khấu nhin, mường khương, lào cai",
    "lufng khaasu nhin, muwowfng khuwowng, lafo cai"
  ],
  "Lý Thường Kiệt, Qui Nhơn, Bình Định": [
    "lý thường kiệt, qui nhơn, bình định",
    "lys thuwowfng kieejt, qui nhown, bifnh ddijnh"
  ],
  "Lộc An, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "lộc an, đất đỏ, bà rịa - vũng tàu",
    "loojc an, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Lộc Điền, Phú Lộc, Thừa Thiên Huế": [
    "lộc điền, phú lộc, thừa thiên huế",
    "loojc ddieefn, phus loojc, thuwfa thieen huees"
  ],
  "Mường Khương, Mường Khương, Lào Cai": [
    "mường khương, mường khương, lào cai",
    "muwowfng khuwowng, muwowfng khuwowng, lafo cai"
  ],
  "Mường Đăng, Mường Ảng, Điện Biên": [
    "mường đăng, mường ảng, điện biên",
    "muwowfng ddawng, muwowfng arng, ddieejn bieen"
  ],
  "Nguyễn Nghiêm, Quảng Ngãi, Quảng Ngãi": [
    "nguyễn nghiêm, quảng ngãi, quảng ngãi",
    "nguyeexn nghieem, quarng ngaxi, quarng ngaxi"
  ],
  "Nguyễn Thái Bình, Quận 1, Hồ Chí Minh": [
    "nguyễn thái bình, quận 1, hồ chí minh",
    "nguyeexn thasi bifnh, quaajn 1, hoof chis minh"
  ],
  "Ninh Thạnh Lợi A, Hồng Dân, Bạc Liêu": [
    "ninh thạnh lợi a, hồng dân, bạc liêu",
    "ninh thajnh lowji a, hoofng daan, bajc lieeu"
  ],
  "Nà Nhạn, Điện Biên Phủ, Điện Biên": [
    "nà nhạn, điện biên phủ, điện biên",
    "naf nhajn, ddieejn bieen phur, ddieejn bieen"
  ],
  "Phong Hòa, Phong Điền, Thừa Thiên Huế": [
    "phong hòa, phong điền, thừa thiên huế",
    "phong hofa, phong ddieefn, thuwfa thieen huees"
  ],
  "Phong Mỹ, Phong Điền, Thừa Thiên Huế": [
    "phong mỹ, phong điền, thừa thiên huế",
    "phong myx, phong ddieefn, thuwfa thieen huees"
  ],
  "Phong Sơn, Phong Điền, Thừa Thiên Huế": [
    "phong sơn, phong điền, thừa thiên huế",
    "phong sown, phong ddieefn, thuwfa thieen huees"
  ],
  "Phú Bài, Hương Thủy, Thừa Thiên Huế": [
    "phú bài, hương thủy, thừa thiên huế",
    "phus bafi, huwowng thury, thuwfa thieen huees"
  ],
  "Phú Sơn, Hương Thủy, Thừa Thiên Huế": [
    "phú sơn, hương thủy, thừa thiên huế",
    "phus sown, huwowng thury, thuwfa thieen huees"
  ],
  "Phú Thượng, Phú Vang, Thừa Thiên Huế": [
    "phú thượng, phú vang, thừa thiên huế",
    "phus thuwowjng, phus vang, thuwfa thieen huees"
  ],
  "Phước Trung, Gò Công Đông, Tiền Giang": [
    "phước trung, gò công đông, tiền giang",
    "phuwowsc trung, gof coong ddoong, tieefn giang"
  ],
  "Phạm Ngũ Lão, Hải Dương, Hải Dương": [
    "phạm ngũ lão, hải dương, hải dương",
    "phajm ngux laxo, hari duwowng, hari duwowng"
  ],
  "Phủ Hà, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "phủ hà, phan rang-tháp chàm, ninh thuận",
    "phur haf, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Pá Khoang, Điện Biên Phủ, Điện Biên": [
    "pá khoang, điện biên phủ, điện biên",
    "pas khoang, ddieejn bieen phur, ddieejn bieen"
  ],
  "Quảng Tiến, Quảng Trạch, Quảng Bình": [
    "quảng tiến, quảng trạch, quảng bình",
    "quarng tieesn, quarng trajch, quarng bifnh"
  ],
  "Quảng Trường, Quảng Xương, Thanh Hóa": [
    "quảng trường, quảng xương, thanh hóa",
    "quarng truwowfng, quarng xuwowng, thanh hosa"
  ],
  "Quảng Đông, Quảng Trạch, Quảng Bình": [
    "quảng đông, quảng trạch, quảng bình",
    "quarng ddoong, quarng trajch, quarng bifnh"
  ],
  "Sông Xoài, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "sông xoài, phú mỹ, bà rịa - vũng tàu",
    "soong xoafi, phus myx, baf rija - vuxng tafu"
  ],
  "Thanh Minh, Điện Biên Phủ, Điện Biên": [
    "thanh minh, điện biên phủ, điện biên",
    "thanh minh, ddieejn bieen phur, ddieejn bieen"
  ],
  "Thuỷ Đường, Thuỷ Nguyên, Hải Phòng": [
    "thuỷ đường, thuỷ nguyên, hải phòng",
    "thuyr dduwowfng, thuyr nguyeen, hari phofng"
  ],
  "Thân Cửu Nghĩa, Châu Thành, Tiền Giang": [
    "thân cửu nghĩa, châu thành, tiền giang",
    "thaan cuwru nghixa, chaau thafnh, tieefn giang"
  ],
  "Thượng Trạch, Bố Trạch, Quảng Bình": [
    "thượng trạch, bố trạch, quảng bình",
    "thuwowjng trajch, boos trajch, quarng bifnh"
  ],
  "Thạnh Phước, Giồng Riềng, Kiên Giang": [
    "thạnh phước, giồng riềng, kiên giang",
    "thajnh phuwowsc, gioofng rieefng, kieen giang"
  ],
  "Thống Nhất, Buôn Ma Thuột, Đắk Lắk": [
    "thống nhất, buôn ma thuột, đắk lắk",
    "thoosng nhaast, buoon ma thuoojt, ddawsk lawsk"
  ],
  "Triệu Phước, Triệu Phong, Quảng Trị": [
    "triệu phước, triệu phong, quảng trị",
    "trieeju phuwowsc, trieeju phong, quarng trij"
  ],
  "Tân Phú Thạnh, Châu Thành A, Hậu Giang": [
    "tân phú thạnh, châu thành a, hậu giang",
    "taan phus thajnh, chaau thafnh a, haaju giang"
  ],
  "Tân Thanh, Điện Biên Phủ, Điện Biên": [
    "tân thanh, điện biên phủ, điện biên",
    "taan thanh, ddieejn bieen phur, ddieejn bieen"
  ],
  "Tạ An Khương  Đông, Đầm Dơi, Cà Mau": [
    "tạ an khương  đông, đầm dơi, cà mau",
    "taj an khuwowng  ddoong, ddaafm dowi, caf mau"
  ],
  "Tả Ngải Chồ, Mường Khương, Lào Cai": [
    "tả ngải chồ, mường khương, lào cai",
    "tar ngari choof, muwowfng khuwowng, lafo cai"
  ],
  "Tịnh Ấn Tây, Quảng Ngãi, Quảng Ngãi": [
    "tịnh ấn tây, quảng ngãi, quảng ngãi",
    "tijnh aasn taay, quarng ngaxi, quarng ngaxi"
  ],
  "Vĩnh Trạch Đông, Bạc Liêu, Bạc Liêu": [
    "vĩnh trạch đông, bạc liêu, bạc liêu",
    "vixnh trajch ddoong, bajc lieeu, bajc lieeu"
  ],
  "Xuân Thới Đông, Hóc Môn, Hồ Chí Minh": [
    "xuân thới đông, hóc môn, hồ chí minh",
    "xuaan thowsi ddoong, hosc moon, hoof chis minh"
  ],
  "Xà Bang, Châu Đức, Bà Rịa - Vũng Tàu": [
    "xà bang, châu đức, bà rịa - vũng tàu",
    "xaf bang, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Điện Thắng Nam, Điện Bàn, Quảng Nam": [
    "điện thắng nam, điện bàn, quảng nam",
    "ddieejn thawsng nam, ddieejn bafn, quarng nam"
  ],
  "Đô Vinh, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "đô vinh, phan rang-tháp chàm, ninh thuận",
    "ddoo vinh, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Đông Phương Yên, Chương Mỹ, Hà Nội": [
    "đông phương yên, chương mỹ, hà nội",
    "ddoong phuwowng yeen, chuwowng myx, haf nooji"
  ],
  "Đất Cuốc, Bắc Tân Uyên, Bình Dương": [
    "đất cuốc, bắc tân uyên, bình dương",
    "ddaast cuoosc, bawsc taan uyeen, bifnh duwowng"
  ],
  "Định Hoà, Thủ Dầu Một, Bình Dương": [
    "định hoà, thủ dầu một, bình dương",
    "ddijnh hoaf, thur daafu moojt, bifnh duwowng"
  ],
  "An Nhứt, Long Điền, Bà Rịa - Vũng Tàu": [
    "an nhứt, long điền, bà rịa - vũng tàu",
    "an nhuwst, long ddieefn, baf rija - vuxng tafu"
  ],
  "Bàn Tân Định, Giồng Riềng, Kiên Giang": [
    "bàn tân định, giồng riềng, kiên giang",
    "bafn taan ddijnh, gioofng rieefng, kieen giang"
  ],
  "Bàu Lâm, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "bàu lâm, xuyên mộc, bà rịa - vũng tàu",
    "bafu laam, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Bình Thành, Hương Trà, Thừa Thiên Huế": [
    "bình thành, hương trà, thừa thiên huế",
    "bifnh thafnh, huwowng traf, thuwfa thieen huees"
  ],
  "Bình Tiến, Hương Trà, Thừa Thiên Huế": [
    "bình tiến, hương trà, thừa thiên huế",
    "bifnh tieesn, huwowng traf, thuwfa thieen huees"
  ],
  "Chánh Nghĩa, Thủ Dầu Một, Bình Dương": [
    "chánh nghĩa, thủ dầu một, bình dương",
    "chasnh nghixa, thur daafu moojt, bifnh duwowng"
  ],
  "Hiệp Thành, Thủ Dầu Một, Bình Dương": [
    "hiệp thành, thủ dầu một, bình dương",
    "hieejp thafnh, thur daafu moojt, bifnh duwowng"
  ],
  "Hoàng Văn Thụ, Thái Nguyên, Thái Nguyên": [
    "hoàng văn thụ, thái nguyên, thái nguyên",
    "hoafng vawn thuj, thasi nguyeen, thasi nguyeen"
  ],
  "Huống Thượng, Thái Nguyên, Thái Nguyên": [
    "huống thượng, thái nguyên, thái nguyên",
    "huoosng thuwowjng, thasi nguyeen, thasi nguyeen"
  ],
  "Hàm Thắng, Hàm Thuận Bắc, Bình Thuận": [
    "hàm thắng, hàm thuận bắc, bình thuận",
    "hafm thawsng, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hành Tín  Đông, Nghĩa Hành, Quảng Ngãi": [
    "hành tín  đông, nghĩa hành, quảng ngãi",
    "hafnh tisn  ddoong, nghixa hafnh, quarng ngaxi"
  ],
  "Háng Lìa, Điện Biên Đông, Điện Biên": [
    "háng lìa, điện biên đông, điện biên",
    "hasng lifa, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Hương Hồ, Hương Trà, Thừa Thiên Huế": [
    "hương hồ, hương trà, thừa thiên huế",
    "huwowng hoof, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Nguyên, A Lưới, Thừa Thiên Huế": [
    "hương nguyên, a lưới, thừa thiên huế",
    "huwowng nguyeen, a luwowsi, thuwfa thieen huees"
  ],
  "Hương Vinh, Hương Trà, Thừa Thiên Huế": [
    "hương vinh, hương trà, thừa thiên huế",
    "huwowng vinh, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Vân, Hương Trà, Thừa Thiên Huế": [
    "hương vân, hương trà, thừa thiên huế",
    "huwowng vaan, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Văn, Hương Trà, Thừa Thiên Huế": [
    "hương văn, hương trà, thừa thiên huế",
    "huwowng vawn, huwowng traf, thuwfa thieen huees"
  ],
  "Hắc Dịch, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "hắc dịch, phú mỹ, bà rịa - vũng tàu",
    "hawsc dijch, phus myx, baf rija - vuxng tafu"
  ],
  "Hồng Liêm, Hàm Thuận Bắc, Bình Thuận": [
    "hồng liêm, hàm thuận bắc, bình thuận",
    "hoofng lieem, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Hồng Thái Tây, Đông Triều, Quảng Ninh": [
    "hồng thái tây, đông triều, quảng ninh",
    "hoofng thasi taay, ddoong trieefu, quarng ninh"
  ],
  "Khánh Thạnh Tân, Mỏ Cày Bắc, Bến Tre": [
    "khánh thạnh tân, mỏ cày bắc, bến tre",
    "khasnh thajnh taan, mor cafy bawsc, beesn tre"
  ],
  "Liên Trường, Quảng Trạch, Quảng Bình": [
    "liên trường, quảng trạch, quảng bình",
    "lieen truwowfng, quarng trajch, quarng bifnh"
  ],
  "Long Hương, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "long hương, bà rịa, bà rịa - vũng tàu",
    "long huwowng, baf rija, baf rija - vuxng tafu"
  ],
  "Long Mỹ, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "long mỹ, đất đỏ, bà rịa - vũng tàu",
    "long myx, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Long Tân, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "long tân, đất đỏ, bà rịa - vũng tàu",
    "long taan, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Mỹ Bình, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "mỹ bình, phan rang-tháp chàm, ninh thuận",
    "myx bifnh, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Mỹ Hải, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "mỹ hải, phan rang-tháp chàm, ninh thuận",
    "myx hari, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Phong Bình, Phong Điền, Thừa Thiên Huế": [
    "phong bình, phong điền, thừa thiên huế",
    "phong bifnh, phong ddieefn, thuwfa thieen huees"
  ],
  "Phong Hải, Phong Điền, Thừa Thiên Huế": [
    "phong hải, phong điền, thừa thiên huế",
    "phong hari, phong ddieefn, thuwfa thieen huees"
  ],
  "Phong Xuân, Phong Điền, Thừa Thiên Huế": [
    "phong xuân, phong điền, thừa thiên huế",
    "phong xuaan, phong ddieefn, thuwfa thieen huees"
  ],
  "Phì Nhừ, Điện Biên Đông, Điện Biên": [
    "phì nhừ, điện biên đông, điện biên",
    "phif nhuwf, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Phú Cường, Thủ Dầu Một, Bình Dương": [
    "phú cường, thủ dầu một, bình dương",
    "phus cuwowfng, thur daafu moojt, bifnh duwowng"
  ],
  "Phước Mỹ Trung, Mỏ Cày Bắc, Bến Tre": [
    "phước mỹ trung, mỏ cày bắc, bến tre",
    "phuwowsc myx trung, mor cafy bawsc, beesn tre"
  ],
  "Phường 1, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 1, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 1, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 2, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 2, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 2, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 3, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 3, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 3, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 4, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 4, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 4, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 5, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 5, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 5, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 7, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 7, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 7, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 8, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 8, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 8, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 9, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 9, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 9, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Pú Hồng, Điện Biên Đông, Điện Biên": [
    "pú hồng, điện biên đông, điện biên",
    "pus hoofng, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Quảng Thạch, Quảng Trạch, Quảng Bình": [
    "quảng thạch, quảng trạch, quảng bình",
    "quarng thajch, quarng trajch, quarng bifnh"
  ],
  "Thanh Bình, Điện Biên Phủ, Điện Biên": [
    "thanh bình, điện biên phủ, điện biên",
    "thanh bifnh, ddieejn bieen phur, ddieejn bieen"
  ],
  "Thanh Sơn, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "thanh sơn, phan rang-tháp chàm, ninh thuận",
    "thanh sown, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Thuận Hòa, Hàm Thuận Bắc, Bình Thuận": [
    "thuận hòa, hàm thuận bắc, bình thuận",
    "thuaajn hofa, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Thuận Minh, Hàm Thuận Bắc, Bình Thuận": [
    "thuận minh, hàm thuận bắc, bình thuận",
    "thuaajn minh, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Thường Tân, Bắc Tân Uyên, Bình Dương": [
    "thường tân, bắc tân uyên, bình dương",
    "thuwowfng taan, bawsc taan uyeen, bifnh duwowng"
  ],
  "Thượng Long, Nam Đông, Thừa Thiên Huế": [
    "thượng long, nam đông, thừa thiên huế",
    "thuwowjng long, nam ddoong, thuwfa thieen huees"
  ],
  "Thượng Lộ, Nam Đông, Thừa Thiên Huế": [
    "thượng lộ, nam đông, thừa thiên huế",
    "thuwowjng looj, nam ddoong, thuwfa thieen huees"
  ],
  "Thắng Tam, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "thắng tam, vũng tàu, bà rịa - vũng tàu",
    "thawsng tam, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Triệu Thượng, Triệu Phong, Quảng Trị": [
    "triệu thượng, triệu phong, quảng trị",
    "trieeju thuwowjng, trieeju phong, quarng trij"
  ],
  "Trung Lập Thượng, Củ Chi, Hồ Chí Minh": [
    "trung lập thượng, củ chi, hồ chí minh",
    "trung laajp thuwowjng, cur chi, hoof chis minh"
  ],
  "Trần Văn Thời, Trần Văn Thời, Cà Mau": [
    "trần văn thời, trần văn thời, cà mau",
    "traafn vawn thowfi, traafn vawn thowfi, caf mau"
  ],
  "Tân Lâm, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "tân lâm, xuyên mộc, bà rịa - vũng tàu",
    "taan laam, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Tân Phước Khánh, Tân Uyên, Bình Dương": [
    "tân phước khánh, tân uyên, bình dương",
    "taan phuwowsc khasnh, taan uyeen, bifnh duwowng"
  ],
  "Tìa Dình, Điện Biên Đông, Điện Biên": [
    "tìa dình, điện biên đông, điện biên",
    "tifa difnh, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Tấn Tài, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "tấn tài, phan rang-tháp chàm, ninh thuận",
    "taasn tafi, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Văn Hải, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "văn hải, phan rang-tháp chàm, ninh thuận",
    "vawn hari, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Đài Sơn, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "đài sơn, phan rang-tháp chàm, ninh thuận",
    "ddafi sown, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Đông Giang, Hàm Thuận Bắc, Bình Thuận": [
    "đông giang, hàm thuận bắc, bình thuận",
    "ddoong giang, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Đông Hưng Thuận, Quận 12, Hồ Chí Minh": [
    "đông hưng thuận, quận 12, hồ chí minh",
    "ddoong huwng thuaajn, quaajn 12, hoof chis minh"
  ],
  "Đồng Nai Thượng, Cát Tiên, Lâm Đồng": [
    "đồng nai thượng, cát tiên, lâm đồng",
    "ddoofng nai thuwowjng, cast tieen, laam ddoofng"
  ],
  "Bàu Chinh, Châu Đức, Bà Rịa - Vũng Tàu": [
    "bàu chinh, châu đức, bà rịa - vũng tàu",
    "bafu chinh, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Bình Giã, Châu Đức, Bà Rịa - Vũng Tàu": [
    "bình giã, châu đức, bà rịa - vũng tàu",
    "bifnh giax, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Bình Trị Đông A, Bình Tân, Hồ Chí Minh": [
    "bình trị đông a, bình tân, hồ chí minh",
    "bifnh trij ddoong a, bifnh taan, hoof chis minh"
  ],
  "Bình Trị Đông B, Bình Tân, Hồ Chí Minh": [
    "bình trị đông b, bình tân, hồ chí minh",
    "bifnh trij ddoong b, bifnh taan, hoof chis minh"
  ],
  "Hòa Bình, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "hòa bình, xuyên mộc, bà rịa - vũng tàu",
    "hofa bifnh, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Hòa Hưng, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "hòa hưng, xuyên mộc, bà rịa - vũng tàu",
    "hofa huwng, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Hòa Hội, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "hòa hội, xuyên mộc, bà rịa - vũng tàu",
    "hofa hooji, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Hưng Khánh Trung A, Mỏ Cày Bắc, Bến Tre": [
    "hưng khánh trung a, mỏ cày bắc, bến tre",
    "huwng khasnh trung a, mor cafy bawsc, beesn tre"
  ],
  "Hương Bình, Hương Trà, Thừa Thiên Huế": [
    "hương bình, hương trà, thừa thiên huế",
    "huwowng bifnh, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Chữ, Hương Trà, Thừa Thiên Huế": [
    "hương chữ, hương trà, thừa thiên huế",
    "huwowng chuwx, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Phong, Hương Trà, Thừa Thiên Huế": [
    "hương phong, hương trà, thừa thiên huế",
    "huwowng phong, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Thọ, Hương Trà, Thừa Thiên Huế": [
    "hương thọ, hương trà, thừa thiên huế",
    "huwowng thoj, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Toàn, Hương Trà, Thừa Thiên Huế": [
    "hương toàn, hương trà, thừa thiên huế",
    "huwowng toafn, huwowng traf, thuwfa thieen huees"
  ],
  "Hương Xuân, Hương Trà, Thừa Thiên Huế": [
    "hương xuân, hương trà, thừa thiên huế",
    "huwowng xuaan, huwowng traf, thuwfa thieen huees"
  ],
  "Hải Dương, Hương Trà, Thừa Thiên Huế": [
    "hải dương, hương trà, thừa thiên huế",
    "hari duwowng, huwowng traf, thuwfa thieen huees"
  ],
  "Hồng Thượng, A Lưới, Thừa Thiên Huế": [
    "hồng thượng, a lưới, thừa thiên huế",
    "hoofng thuwowjng, a luwowsi, thuwfa thieen huees"
  ],
  "Khuê Ngọc Điền, Krông Bông, Đắk Lắk": [
    "khuê ngọc điền, krông bông, đắk lắk",
    "khuee ngojc ddieefn, kroong boong, ddawsk lawsk"
  ],
  "Khánh Bình Đông, Trần Văn Thời, Cà Mau": [
    "khánh bình đông, trần văn thời, cà mau",
    "khasnh bifnh ddoong, traafn vawn thowfi, caf mau"
  ],
  "Kiểng Phước, Gò Công Đông, Tiền Giang": [
    "kiểng phước, gò công đông, tiền giang",
    "kieerng phuwowsc, gof coong ddoong, tieefn giang"
  ],
  "Long Hải, Long Điền, Bà Rịa - Vũng Tàu": [
    "long hải, long điền, bà rịa - vũng tàu",
    "long hari, long ddieefn, baf rija - vuxng tafu"
  ],
  "Long Phước, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "long phước, bà rịa, bà rịa - vũng tàu",
    "long phuwowsc, baf rija, baf rija - vuxng tafu"
  ],
  "Long Điền Đông A, Đông Hải, Bạc Liêu": [
    "long điền đông a, đông hải, bạc liêu",
    "long ddieefn ddoong a, ddoong hari, bajc lieeu"
  ],
  "Láng Dài, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "láng dài, đất đỏ, bà rịa - vũng tàu",
    "lasng dafi, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Mỹ Đông, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "mỹ đông, phan rang-tháp chàm, ninh thuận",
    "myx ddoong, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Ngãi Giao, Châu Đức, Bà Rịa - Vũng Tàu": [
    "ngãi giao, châu đức, bà rịa - vũng tàu",
    "ngaxi giao, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Phan Đình Phùng, Thái Nguyên, Thái Nguyên": [
    "phan đình phùng, thái nguyên, thái nguyên",
    "phan ddifnh phufng, thasi nguyeen, thasi nguyeen"
  ],
  "Phong Hiền, Phong Điền, Thừa Thiên Huế": [
    "phong hiền, phong điền, thừa thiên huế",
    "phong hieefn, phong ddieefn, thuwfa thieen huees"
  ],
  "Phong Thạnh Tây A, Phước Long, Bạc Liêu": [
    "phong thạnh tây a, phước long, bạc liêu",
    "phong thajnh taay a, phuwowsc long, bajc lieeu"
  ],
  "Phong Thạnh Tây B, Phước Long, Bạc Liêu": [
    "phong thạnh tây b, phước long, bạc liêu",
    "phong thajnh taay b, phuwowsc long, bajc lieeu"
  ],
  "Phước Hoà, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "phước hoà, phú mỹ, bà rịa - vũng tàu",
    "phuwowsc hoaf, phus myx, baf rija - vuxng tafu"
  ],
  "Phường 10, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 10, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 10, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 11, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 11, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 11, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phường 12, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "phường 12, vũng tàu, bà rịa - vũng tàu",
    "phuwowfng 12, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Quảng An, Quảng Điền, Thừa Thiên Huế": [
    "quảng an, quảng điền, thừa thiên huế",
    "quarng an, quarng ddieefn, thuwfa thieen huees"
  ],
  "Quảng Phương, Quảng Trạch, Quảng Bình": [
    "quảng phương, quảng trạch, quảng bình",
    "quarng phuwowng, quarng trajch, quarng bifnh"
  ],
  "Rạch Dừa, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "rạch dừa, vũng tàu, bà rịa - vũng tàu",
    "rajch duwfa, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Suối Rao, Châu Đức, Bà Rịa - Vũng Tàu": [
    "suối rao, châu đức, bà rịa - vũng tàu",
    "suoosi rao, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Sơn Bình, Châu Đức, Bà Rịa - Vũng Tàu": [
    "sơn bình, châu đức, bà rịa - vũng tàu",
    "sown bifnh, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Thắng Nhì, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "thắng nhì, vũng tàu, bà rịa - vũng tàu",
    "thawsng nhif, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Thủy Phù, Hương Thủy, Thừa Thiên Huế": [
    "thủy phù, hương thủy, thừa thiên huế",
    "thury phuf, huwowng thury, thuwfa thieen huees"
  ],
  "Thủy Tân, Hương Thủy, Thừa Thiên Huế": [
    "thủy tân, hương thủy, thừa thiên huế",
    "thury taan, huwowng thury, thuwfa thieen huees"
  ],
  "Thủy Vân, Hương Thủy, Thừa Thiên Huế": [
    "thủy vân, hương thủy, thừa thiên huế",
    "thury vaan, huwowng thury, thuwfa thieen huees"
  ],
  "Trường Long Tây, Châu Thành A, Hậu Giang": [
    "trường long tây, châu thành a, hậu giang",
    "truwowfng long taay, chaau thafnh a, haaju giang"
  ],
  "Tân Nhuận Đông, Châu Thành, Đồng Tháp": [
    "tân nhuận đông, châu thành, đồng tháp",
    "taan nhuaajn ddoong, chaau thafnh, ddoofng thasp"
  ],
  "Tân Phước Hưng, Phụng Hiệp, Hậu Giang": [
    "tân phước hưng, phụng hiệp, hậu giang",
    "taan phuwowsc huwng, phujng hieejp, haaju giang"
  ],
  "Tân Phước, Phú Mỹ, Bà Rịa - Vũng Tàu": [
    "tân phước, phú mỹ, bà rịa - vũng tàu",
    "taan phuwowsc, phus myx, baf rija - vuxng tafu"
  ],
  "Tịnh Ấn Đông, Quảng Ngãi, Quảng Ngãi": [
    "tịnh ấn đông, quảng ngãi, quảng ngãi",
    "tijnh aasn ddoong, quarng ngaxi, quarng ngaxi"
  ],
  "Xuân Sơn, Châu Đức, Bà Rịa - Vũng Tàu": [
    "xuân sơn, châu đức, bà rịa - vũng tàu",
    "xuaan sown, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Điền Hòa, Phong Điền, Thừa Thiên Huế": [
    "điền hòa, phong điền, thừa thiên huế",
    "ddieefn hofa, phong ddieefn, thuwfa thieen huees"
  ],
  "Điền Môn, Phong Điền, Thừa Thiên Huế": [
    "điền môn, phong điền, thừa thiên huế",
    "ddieefn moon, phong ddieefn, thuwfa thieen huees"
  ],
  "Điện Thắng Bắc, Điện Bàn, Quảng Nam": [
    "điện thắng bắc, điện bàn, quảng nam",
    "ddieejn thawsng bawsc, ddieejn bafn, quarng nam"
  ],
  "Điện Thắng Trung, Điện Bàn, Quảng Nam": [
    "điện thắng trung, điện bàn, quảng nam",
    "ddieejn thawsng trung, ddieejn bafn, quarng nam"
  ],
  "Đá Bạc, Châu Đức, Bà Rịa - Vũng Tàu": [
    "đá bạc, châu đức, bà rịa - vũng tàu",
    "ddas bajc, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Đông Tiến, Hàm Thuận Bắc, Bình Thuận": [
    "đông tiến, hàm thuận bắc, bình thuận",
    "ddoong tieesn, hafm thuaajn bawsc, bifnh thuaajn"
  ],
  "Đăng Hưng Phước, Chợ Gạo, Tiền Giang": [
    "đăng hưng phước, chợ gạo, tiền giang",
    "ddawng huwng phuwowsc, chowj gajo, tieefn giang"
  ],
  "Đạo Long, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "đạo long, phan rang-tháp chàm, ninh thuận",
    "ddajo long, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Đốc Binh Kiều, Tháp Mười, Đồng Tháp": [
    "đốc binh kiều, tháp mười, đồng tháp",
    "ddoosc binh kieefu, thasp muwowfi, ddoofng thasp"
  ],
  "Đổng Quốc Bình, Ngô Quyền, Hải Phòng": [
    "đổng quốc bình, ngô quyền, hải phòng",
    "ddoorng quoosc bifnh, ngoo quyeefn, hari phofng"
  ],
  "Đức Ninh Đông, Đồng Hới, Quảng Bình": [
    "đức ninh đông, đồng hới, quảng bình",
    "dduwsc ninh ddoong, ddoofng howsi, quarng bifnh"
  ],
  "Bình Châu, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "bình châu, xuyên mộc, bà rịa - vũng tàu",
    "bifnh chaau, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Bình Trung, Châu Đức, Bà Rịa - Vũng Tàu": [
    "bình trung, châu đức, bà rịa - vũng tàu",
    "bifnh trung, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Bông Trang, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "bông trang, xuyên mộc, bà rịa - vũng tàu",
    "boong trang, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Chiềng Sơ, Điện Biên Đông, Điện Biên": [
    "chiềng sơ, điện biên đông, điện biên",
    "chieefng sow, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Dương Hòa, Hương Thủy, Thừa Thiên Huế": [
    "dương hòa, hương thủy, thừa thiên huế",
    "duwowng hofa, huwowng thury, thuwfa thieen huees"
  ],
  "Dương Hồng  Thủy, Thái Thụy, Thái Bình": [
    "dương hồng  thủy, thái thụy, thái bình",
    "duwowng hoofng  thury, thasi thujy, thasi bifnh"
  ],
  "Dương Minh Châu, Dương Minh Châu, Tây Ninh": [
    "dương minh châu, dương minh châu, tây ninh",
    "duwowng minh chaau, duwowng minh chaau, taay ninh"
  ],
  "Hiệp Bình Chánh, Thủ Đức, Hồ Chí Minh": [
    "hiệp bình chánh, thủ đức, hồ chí minh",
    "hieejp bifnh chasnh, thur dduwsc, hoof chis minh"
  ],
  "Hòa Hiệp, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "hòa hiệp, xuyên mộc, bà rịa - vũng tàu",
    "hofa hieejp, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Hồng Thái Đông, Đông Triều, Quảng Ninh": [
    "hồng thái đông, đông triều, quảng ninh",
    "hoofng thasi ddoong, ddoong trieefu, quarng ninh"
  ],
  "Luân Giới, Điện Biên Đông, Điện Biên": [
    "luân giới, điện biên đông, điện biên",
    "luaan giowsi, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Láng Lớn, Châu Đức, Bà Rịa - Vũng Tàu": [
    "láng lớn, châu đức, bà rịa - vũng tàu",
    "lasng lowsn, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Lịch Hội Thượng, Trần Đề, Sóc Trăng": [
    "lịch hội thượng, trần đề, sóc trăng",
    "lijch hooji thuwowjng, traafn ddeef, sosc trawng"
  ],
  "Mỹ Hương, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "mỹ hương, phan rang-tháp chàm, ninh thuận",
    "myx huwowng, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Phong Điền, Phong Điền, Thừa Thiên Huế": [
    "phong điền, phong điền, thừa thiên huế",
    "phong ddieefn, phong ddieefn, thuwfa thieen huees"
  ],
  "Phước Hưng, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "phước hưng, bà rịa, bà rịa - vũng tàu",
    "phuwowsc huwng, baf rija, baf rija - vuxng tafu"
  ],
  "Phước Trung, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "phước trung, bà rịa, bà rịa - vũng tàu",
    "phuwowsc trung, baf rija, baf rija - vuxng tafu"
  ],
  "Thành Hải, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "thành hải, phan rang-tháp chàm, ninh thuận",
    "thafnh hari, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Thường Phước 1, Hồng Ngự, Đồng Tháp": [
    "thường phước 1, hồng ngự, đồng tháp",
    "thuwowfng phuwowsc 1, hoofng nguwj, ddoofng thasp"
  ],
  "Thường Phước 2, Hồng Ngự, Đồng Tháp": [
    "thường phước 2, hồng ngự, đồng tháp",
    "thuwowfng phuwowsc 2, hoofng nguwj, ddoofng thasp"
  ],
  "Thượng Nhật, Nam Đông, Thừa Thiên Huế": [
    "thượng nhật, nam đông, thừa thiên huế",
    "thuwowjng nhaajt, nam ddoong, thuwfa thieen huees"
  ],
  "Thạnh Thới Thuận, Trần Đề, Sóc Trăng": [
    "thạnh thới thuận, trần đề, sóc trăng",
    "thajnh thowsi thuaajn, traafn ddeef, sosc trawng"
  ],
  "Thủy Châu, Hương Thủy, Thừa Thiên Huế": [
    "thủy châu, hương thủy, thừa thiên huế",
    "thury chaau, huwowng thury, thuwfa thieen huees"
  ],
  "Thủy Thanh, Hương Thủy, Thừa Thiên Huế": [
    "thủy thanh, hương thủy, thừa thiên huế",
    "thury thanh, huwowng thury, thuwfa thieen huees"
  ],
  "Trần Hưng Đạo, Hải Dương, Hải Dương": [
    "trần hưng đạo, hải dương, hải dương",
    "traafn huwng ddajo, hari duwowng, hari duwowng"
  ],
  "Trần Hưng Đạo, Quảng Ngãi, Quảng Ngãi": [
    "trần hưng đạo, quảng ngãi, quảng ngãi",
    "traafn huwng ddajo, quarng ngaxi, quarng ngaxi"
  ],
  "Xuân Thới Thượng, Hóc Môn, Hồ Chí Minh": [
    "xuân thới thượng, hóc môn, hồ chí minh",
    "xuaan thowsi thuwowjng, hosc moon, hoof chis minh"
  ],
  "Điền Hải, Phong Điền, Thừa Thiên Huế": [
    "điền hải, phong điền, thừa thiên huế",
    "ddieefn hari, phong ddieefn, thuwfa thieen huees"
  ],
  "Điền Lộc, Phong Điền, Thừa Thiên Huế": [
    "điền lộc, phong điền, thừa thiên huế",
    "ddieefn loojc, phong ddieefn, thuwfa thieen huees"
  ],
  "Đông Hải, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "đông hải, phan rang-tháp chàm, ninh thuận",
    "ddoong hari, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Đại Đồng Thành, Thuận Thành, Bắc Ninh": [
    "đại đồng thành, thuận thành, bắc ninh",
    "ddaji ddoofng thafnh, thuaajn thafnh, bawsc ninh"
  ],
  "Long Điền, Long Điền, Bà Rịa - Vũng Tàu": [
    "long điền, long điền, bà rịa - vũng tàu",
    "long ddieefn, long ddieefn, baf rija - vuxng tafu"
  ],
  "Mường Thanh, Điện Biên Phủ, Điện Biên": [
    "mường thanh, điện biên phủ, điện biên",
    "muwowfng thanh, ddieejn bieen phur, ddieejn bieen"
  ],
  "Nguyễn Thị Minh Khai, Bắc Kạn, Bắc Kạn": [
    "nguyễn thị minh khai, bắc kạn, bắc kạn",
    "nguyeexn thij minh khai, bawsc kajn, bawsc kajn"
  ],
  "Phong Chương, Phong Điền, Thừa Thiên Huế": [
    "phong chương, phong điền, thừa thiên huế",
    "phong chuwowng, phong ddieefn, thuwfa thieen huees"
  ],
  "Phình Giàng, Điện Biên Đông, Điện Biên": [
    "phình giàng, điện biên đông, điện biên",
    "phifnh giafng, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Phước Hiệp, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "phước hiệp, bà rịa, bà rịa - vũng tàu",
    "phuwowsc hieejp, baf rija, baf rija - vuxng tafu"
  ],
  "Phước Mỹ, Phan Rang-Tháp Chàm, Ninh Thuận": [
    "phước mỹ, phan rang-tháp chàm, ninh thuận",
    "phuwowsc myx, phan rang-thasp chafm, ninh thuaajn"
  ],
  "Quảng Phú, Quảng Điền, Thừa Thiên Huế": [
    "quảng phú, quảng điền, thừa thiên huế",
    "quarng phus, quarng ddieefn, thuwfa thieen huees"
  ],
  "Quảng Vinh, Quảng Điền, Thừa Thiên Huế": [
    "quảng vinh, quảng điền, thừa thiên huế",
    "quarng vinh, quarng ddieefn, thuwfa thieen huees"
  ],
  "Tam Phước, Long Điền, Bà Rịa - Vũng Tàu": [
    "tam phước, long điền, bà rịa - vũng tàu",
    "tam phuwowsc, long ddieefn, baf rija - vuxng tafu"
  ],
  "Thượng Quảng, Nam Đông, Thừa Thiên Huế": [
    "thượng quảng, nam đông, thừa thiên huế",
    "thuwowjng quarng, nam ddoong, thuwfa thieen huees"
  ],
  "Thắng Nhất, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "thắng nhất, vũng tàu, bà rịa - vũng tàu",
    "thawsng nhaast, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Thủy Bằng, Hương Thủy, Thừa Thiên Huế": [
    "thủy bằng, hương thủy, thừa thiên huế",
    "thury bawfng, huwowng thury, thuwfa thieen huees"
  ],
  "Xuyên Mộc, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "xuyên mộc, xuyên mộc, bà rịa - vũng tàu",
    "xuyeen moojc, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Đất Đỏ, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "đất đỏ, đất đỏ, bà rịa - vũng tàu",
    "ddaast ddor, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Bưng Riềng, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "bưng riềng, xuyên mộc, bà rịa - vũng tàu",
    "buwng rieefng, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Hiệp Bình Phước, Thủ Đức, Hồ Chí Minh": [
    "hiệp bình phước, thủ đức, hồ chí minh",
    "hieejp bifnh phuwowsc, thur dduwsc, hoof chis minh"
  ],
  "Mường Luân, Điện Biên Đông, Điện Biên": [
    "mường luân, điện biên đông, điện biên",
    "muwowfng luaan, ddieejn bieen ddoong, ddieejn bieen"
  ],
  "Mường Phăng, Điện Biên Phủ, Điện Biên": [
    "mường phăng, điện biên phủ, điện biên",
    "muwowfng phawng, ddieejn bieen phur, ddieejn bieen"
  ],
  "Nghĩa Thành, Châu Đức, Bà Rịa - Vũng Tàu": [
    "nghĩa thành, châu đức, bà rịa - vũng tàu",
    "nghixa thafnh, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Nông Trường Việt Lâm, Vị Xuyên, Hà Giang": [
    "nông trường việt lâm, vị xuyên, hà giang",
    "noong truwowfng vieejt laam, vij xuyeen, haf giang"
  ],
  "Phước Nguyên, Bà Rịa, Bà Rịa - Vũng Tàu": [
    "phước nguyên, bà rịa, bà rịa - vũng tàu",
    "phuwowsc nguyeen, baf rija, baf rija - vuxng tafu"
  ],
  "Phước Tân, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "phước tân, xuyên mộc, bà rịa - vũng tàu",
    "phuwowsc taan, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Quảng Công, Quảng Điền, Thừa Thiên Huế": [
    "quảng công, quảng điền, thừa thiên huế",
    "quarng coong, quarng ddieefn, thuwfa thieen huees"
  ],
  "Quảng Lợi, Quảng Điền, Thừa Thiên Huế": [
    "quảng lợi, quảng điền, thừa thiên huế",
    "quarng lowji, quarng ddieefn, thuwfa thieen huees"
  ],
  "Quảng Thái, Quảng Điền, Thừa Thiên Huế": [
    "quảng thái, quảng điền, thừa thiên huế",
    "quarng thasi, quarng ddieefn, thuwfa thieen huees"
  ],
  "Quảng Thọ, Quảng Điền, Thừa Thiên Huế": [
    "quảng thọ, quảng điền, thừa thiên huế",
    "quarng thoj, quarng ddieefn, thuwfa thieen huees"
  ],
  "Suối Nghệ, Châu Đức, Bà Rịa - Vũng Tàu": [
    "suối nghệ, châu đức, bà rịa - vũng tàu",
    "suoosi ngheej, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Thanh Trường, Điện Biên Phủ, Điện Biên": [
    "thanh trường, điện biên phủ, điện biên",
    "thanh truwowfng, ddieejn bieen phur, ddieejn bieen"
  ],
  "Thủy Dương, Hương Thủy, Thừa Thiên Huế": [
    "thủy dương, hương thủy, thừa thiên huế",
    "thury duwowng, huwowng thury, thuwfa thieen huees"
  ],
  "Thủy Lương, Hương Thủy, Thừa Thiên Huế": [
    "thủy lương, hương thủy, thừa thiên huế",
    "thury luwowng, huwowng thury, thuwfa thieen huees"
  ],
  "Điền Hương, Phong Điền, Thừa Thiên Huế": [
    "điền hương, phong điền, thừa thiên huế",
    "ddieefn huwowng, phong ddieefn, thuwfa thieen huees"
  ],
  "Khánh Bình Tây Bắc, Trần Văn Thời, Cà Mau": [
    "khánh bình tây bắc, trần văn thời, cà mau",
    "khasnh bifnh taay bawsc, traafn vawn thowfi, caf mau"
  ],
  "Nguyễn An Ninh, Vũng Tàu, Bà Rịa - Vũng Tàu": [
    "nguyễn an ninh, vũng tàu, bà rịa - vũng tàu",
    "nguyeexn an ninh, vuxng tafu, baf rija - vuxng tafu"
  ],
  "Phước Bửu, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "phước bửu, xuyên mộc, bà rịa - vũng tàu",
    "phuwowsc buwru, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Phước Hưng, Long Điền, Bà Rịa - Vũng Tàu": [
    "phước hưng, long điền, bà rịa - vũng tàu",
    "phuwowsc huwng, long ddieefn, baf rija - vuxng tafu"
  ],
  "Phước Hải, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "phước hải, đất đỏ, bà rịa - vũng tàu",
    "phuwowsc hari, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Phước Hội, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "phước hội, đất đỏ, bà rịa - vũng tàu",
    "phuwowsc hooji, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Quảng Ngạn, Quảng Điền, Thừa Thiên Huế": [
    "quảng ngạn, quảng điền, thừa thiên huế",
    "quarng ngajn, quarng ddieefn, thuwfa thieen huees"
  ],
  "Quảng Thành, Châu Đức, Bà Rịa - Vũng Tàu": [
    "quảng thành, châu đức, bà rịa - vũng tàu",
    "quarng thafnh, chaau dduwsc, baf rija - vuxng tafu"
  ],
  "Quảng Thành, Quảng Điền, Thừa Thiên Huế": [
    "quảng thành, quảng điền, thừa thiên huế",
    "quarng thafnh, quarng ddieefn, thuwfa thieen huees"
  ],
  "Thường Thới Tiền, Hồng Ngự, Đồng Tháp": [
    "thường thới tiền, hồng ngự, đồng tháp",
    "thuwowfng thowsi tieefn, hoofng nguwj, ddoofng thasp"
  ],
  "Thủy Phương, Hương Thủy, Thừa Thiên Huế": [
    "thủy phương, hương thủy, thừa thiên huế",
    "thury phuwowng, huwowng thury, thuwfa thieen huees"
  ],
  "Trương Quang Trọng, Quảng Ngãi, Quảng Ngãi": [
    "trương quang trọng, quảng ngãi, quảng ngãi",
    "truwowng quang trojng, quarng ngaxi, quarng ngaxi"
  ],
  "Phước Tỉnh, Long Điền, Bà Rịa - Vũng Tàu": [
    "phước tỉnh, long điền, bà rịa - vũng tàu",
    "phuwowsc tirnh, long ddieefn, baf rija - vuxng tafu"
  ],
  "Thường Thới Hậu A, Hồng Ngự, Đồng Tháp": [
    "thường thới hậu a, hồng ngự, đồng tháp",
    "thuwowfng thowsi haaju a, hoofng nguwj, ddoofng thasp"
  ],
  "Phước Thuận, Xuyên Mộc, Bà Rịa - Vũng Tàu": [
    "phước thuận, xuyên mộc, bà rịa - vũng tàu",
    "phuwowsc thuaajn, xuyeen moojc, baf rija - vuxng tafu"
  ],
  "Quảng Phước, Quảng Điền, Thừa Thiên Huế": [
    "quảng phước, quảng điền, thừa thiên huế",
    "quarng phuwowsc, quarng ddieefn, thuwfa thieen huees"
  ],
  "Tương Bình Hiệp, Thủ Dầu Một, Bình Dương": [
    "tương bình hiệp, thủ dầu một, bình dương",
    "tuwowng bifnh hieejp, thur daafu moojt, bifnh duwowng"
  ],
  "Phước Long Thọ, Đất Đỏ, Bà Rịa - Vũng Tàu": [
    "phước long thọ, đất đỏ, bà rịa - vũng tàu",
    "phuwowsc long thoj, ddaast ddor, baf rija - vuxng tafu"
  ],
  "Điện Biên Đông, Điện Biên Đông, Điện Biên": [
    "điện biên đông, điện biên đông, điện biên",
    "ddieejn bieen ddoong, ddieejn bieen ddoong, ddieejn bieen"
  ]
}